/* eslint-disable */
module.exports = {
name: "@yarnpkg/plugin-version",
factory: function (require) {
var plugin;plugin=(()=>{var __webpack_modules__={3354:(e,n,t)=>{"use strict";t.r(n),t.d(n,{default:()=>P});var r=t(966);
/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */function i(e,n,t,r){var i,u=arguments.length,o=u<3?n:null===r?r=Object.getOwnPropertyDescriptor(n,t):r;if("object"==typeof Reflect&&"function"==typeof Reflect.decorate)o=Reflect.decorate(e,n,t,r);else for(var a=e.length-1;a>=0;a--)(i=e[a])&&(o=(u<3?i(o):u>3?i(n,t,o):i(n,t))||o);return u>3&&o&&Object.defineProperty(n,t,o),o}var u=t(2594),o=t(8042),a=t(4688),l=t(9145),s=t(9513),f=t.n(s);const c=/^(>=|[~^]|)(0|[1-9]\d*)\.(0|[1-9]\d*)\.(0|[1-9]\d*)(-(0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*)(\.(0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*))*)?(\+[0-9a-zA-Z-]+(\.[0-9a-zA-Z-]+)*)?$/;var d;async function p(e){const n=new Map,t=e.configuration.get("deferredVersionFolder");if(!a.xfs.existsSync(t))return new Map;const i=await a.xfs.readdirPromise(t);for(const u of i){if(!u.endsWith(".yml"))continue;const i=a.ppath.join(t,u),o=await a.xfs.readFilePromise(i,"utf8"),s=(0,l.parseSyml)(o);for(const[t,u]of Object.entries(s.releases||{})){const o=r.structUtils.parseIdent(t),l=e.tryWorkspaceByIdent(o);if(null===l)throw new Error(`Assertion failed: Expected a release definition file to only reference existing workspaces (${a.ppath.basename(i)} references ${t})`);if(null===l.manifest.version)throw new Error(`Assertion failed: Expected the workspace to have a version (${r.structUtils.prettyLocator(e.configuration,l.anchoredLocator)})`);const s=n.get(l),c=_(l.manifest.version,u);if(null===c)throw new Error(`Assertion failed: Expected ${l.manifest.version} to support being bumped via strategy ${u}`);const d=void 0!==s?f().gt(c,s)?c:s:c;n.set(l,d)}}return n}async function h(e,{allowEmpty:n=!1}={}){const t=e.configuration;if(null===t.projectCwd)throw new o.UsageError("This command can only be run from within a Yarn project");const i=await async function(e){let n,t=null,r=e;do{n=r,await a.xfs.existsPromise(a.ppath.join(n,".git"))&&(t=n),r=a.ppath.dirname(n)}while(null===t&&r!==n);return t}(t.projectCwd),u=null!==i?await async function(e,{baseRefs:n}){if(0===n.length)throw new o.UsageError("Can't run this command with zero base refs specified.");const t=[];for(const i of n){const{code:n}=await r.execUtils.execvp("git",["merge-base",i,"HEAD"],{cwd:e});0===n&&t.push(i)}if(0===t.length)throw new o.UsageError("No ancestor could be found between any of HEAD and "+n.join(", "));const{stdout:i}=await r.execUtils.execvp("git",["merge-base","HEAD",...t],{cwd:e,strict:!0}),u=i.trim(),{stdout:a}=await r.execUtils.execvp("git",["show","--quiet","--pretty=format:%s",u],{cwd:e,strict:!0});return{hash:u,title:a.trim()}}(i,{baseRefs:t.get("changesetBaseRefs")}):null,s=null!==i?await async function(e,{base:n,project:t}){const i=r.miscUtils.buildIgnorePattern(t.configuration.get("changesetIgnorePatterns")),{stdout:u}=await r.execUtils.execvp("git",["diff","--name-only",""+n],{cwd:e,strict:!0}),o=u.split(/\r\n|\r|\n/).filter(e=>e.length>0).map(n=>a.ppath.resolve(e,a.npath.toPortablePath(n))),{stdout:l}=await r.execUtils.execvp("git",["ls-files","--others","--exclude-standard"],{cwd:e,strict:!0}),s=l.split(/\r\n|\r|\n/).filter(e=>e.length>0).map(n=>a.ppath.resolve(e,a.npath.toPortablePath(n))),f=[...new Set([...o,...s].sort())];return i?f.filter(e=>!a.ppath.relative(t.cwd,e).match(i)):f}(i,{base:u.hash,project:e}):[],f=t.get("deferredVersionFolder"),c=s.filter(e=>null!==a.ppath.contains(f,e));if(c.length>1)throw new o.UsageError("Your current branch contains multiple versioning files; this isn't supported:\n- "+c.join("\n- "));const p=new Set(r.miscUtils.mapAndFilter(s,n=>{const t=e.tryWorkspaceByFilePath(n);return null===t?r.miscUtils.mapAndFilter.skip:t}));if(0===c.length&&0===p.size&&!n)return null;const h=1===c.length?c[0]:a.ppath.join(f,r.hashUtils.makeHash(Math.random().toString()).slice(0,8)+".yml"),m=a.xfs.existsSync(h)?await a.xfs.readFilePromise(h,"utf8"):"{}",v=(0,l.parseSyml)(m),_=new Map;for(const n of v.declined||[]){const t=r.structUtils.parseIdent(n),i=e.getWorkspaceByIdent(t);_.set(i,d.DECLINE)}for(const[n,t]of Object.entries(v.releases||{})){const i=r.structUtils.parseIdent(n),u=e.getWorkspaceByIdent(i);_.set(u,t)}return{project:e,root:i,baseHash:null!==u?u.hash:null,baseTitle:null!==u?u.title:null,changedFiles:new Set(s),changedWorkspaces:p,releaseRoots:new Set([...p].filter(e=>null!==e.manifest.version)),releases:_,async saveAll(){const n={},t=[],i=[];for(const u of e.workspaces){if(null===u.manifest.version)continue;const e=r.structUtils.stringifyIdent(u.locator),o=_.get(u);o===d.DECLINE?t.push(e):void 0!==o?n[e]=o:p.has(u)&&i.push(e)}await a.xfs.mkdirPromise(a.ppath.dirname(h),{recursive:!0}),await a.xfs.changeFilePromise(h,(0,l.stringifySyml)(new l.stringifySyml.PreserveOrdering({releases:Object.keys(n).length>0?n:void 0,declined:t.length>0?t:void 0,undecided:i.length>0?i:void 0})))}}}function m(e){const n=new Set;for(const t of e.changedWorkspaces)null!==t.manifest.version&&(e.releases.has(t)||n.add(t));return n}function v(e,{include:n=new Set}={}){const t=[],i=new Map(r.miscUtils.mapAndFilter([...e.releases],([e,n])=>n===d.DECLINE?r.miscUtils.mapAndFilter.skip:[e.anchoredLocator.locatorHash,e])),u=new Map(r.miscUtils.mapAndFilter([...e.releases],([e,n])=>n!==d.DECLINE?r.miscUtils.mapAndFilter.skip:[e.anchoredLocator.locatorHash,e]));for(const o of e.project.workspaces){if(!n.has(o)){if(u.has(o.anchoredLocator.locatorHash))continue;if(i.has(o.anchoredLocator.locatorHash))continue}if(null!==o.manifest.version)for(const n of r.Manifest.hardDependencies)for(const r of o.manifest.getForScope(n).values()){const n=e.project.tryWorkspaceByDescriptor(r);null!==n&&(i.has(n.anchoredLocator.locatorHash)&&t.push([o,n]))}}return t}function _(e,n){if(f().valid(n))return n;if(null===e)throw new o.UsageError(`Cannot apply the release strategy "${n}" unless the workspace already has a valid version`);if(!f().valid(e))throw new o.UsageError(`Cannot apply the release strategy "${n}" on a non-semver version (${e})`);const t=f().inc(e,n);if(null===t)throw new o.UsageError(`Cannot apply the release strategy "${n}" on the specified version (${e})`);return t}!function(e){e.UNDECIDED="undecided",e.DECLINE="decline",e.MAJOR="major",e.MINOR="minor",e.PATCH="patch",e.PRERELEASE="prerelease"}(d||(d={}));class b extends u.BaseCommand{constructor(){super(...arguments),this.all=!1,this.json=!1}async execute(){const e=await r.Configuration.find(this.context.cwd,this.context.plugins),{project:n,workspace:t}=await r.Project.find(e,this.context.cwd),i=await r.Cache.find(e);if(!t)throw new u.WorkspaceRequiredError(n.cwd,this.context.cwd);return(await r.StreamReport.start({configuration:e,json:this.json,stdout:this.context.stdout},async e=>{let u=await p(n);if(!this.all){const e=u.get(t);if(void 0===e)return;u=new Map([[t,e]])}await function(e,n,{report:t}){const i=new Map;for(const t of e.workspaces)for(const u of r.Manifest.allDependencies)for(const o of t.manifest[u].values()){const a=e.tryWorkspaceByDescriptor(o);if(null===a)continue;if(!n.has(a))continue;r.miscUtils.getArrayWithDefault(i,a).push([t,u,o.identHash])}for(const[u,o]of n){const n=u.manifest.version;u.manifest.version=o;const a=null!==u.manifest.name?r.structUtils.stringifyIdent(u.manifest.name):null;t.reportInfo(r.MessageName.UNNAMED,`${r.structUtils.prettyLocator(e.configuration,u.anchoredLocator)}: Bumped to ${o}`),t.reportJson({cwd:u.cwd,ident:a,oldVersion:n,newVersion:o});const l=i.get(u);if(void 0!==l)for(const[n,i,a]of l){const l=n.manifest[i].get(a);if(void 0===l)throw new Error("Assertion failed: The dependency should have existed");let s=l.range,f=!1;if(s.startsWith(r.WorkspaceResolver.protocol)&&(s=s.slice(r.WorkspaceResolver.protocol.length),f=!0,s===u.relativeCwd))continue;const d=s.match(c);if(!d){t.reportWarning(r.MessageName.UNNAMED,`Couldn't auto-upgrade range ${s} (in ${r.structUtils.prettyLocator(e.configuration,u.anchoredLocator)})`);continue}let p=`${d[1]}${o}`;f&&(p=`${r.WorkspaceResolver.protocol}${p}`);const h=r.structUtils.makeDescriptor(l,p);n.manifest[i].set(a,h)}}}(n,u,{report:e}),this.all?await async function(e){const n=e.configuration.get("deferredVersionFolder");a.xfs.existsSync(n)&&await a.xfs.removePromise(n)}(n):await async function(e){const n=e.configuration.get("deferredVersionFolder");if(!a.xfs.existsSync(n))return;const t=await a.xfs.readdirPromise(n);for(const i of t){if(!i.endsWith(".yml"))continue;const t=a.ppath.join(n,i),u=await a.xfs.readFilePromise(t,"utf8"),o=(0,l.parseSyml)(u),s=null==o?void 0:o.releases;if(s){for(const n of Object.keys(s)){const t=r.structUtils.parseLocator(n);null===e.tryWorkspaceByLocator(t)&&delete o.releases[n]}await a.xfs.changeFilePromise(t,(0,l.stringifySyml)(new l.stringifySyml.PreserveOrdering(o)))}}}(n),await n.install({cache:i,report:e})})).exitCode()}}b.usage=o.Command.Usage({category:"Release-related commands",description:"apply all the deferred version bumps at once",details:"\n      This command will apply the deferred version changes (scheduled via `yarn version major|minor|patch`) on the current workspace (or all of them if `--all`) is specified.\n\n      It will also update the `workspace:` references across all your local workspaces so that they keep refering to the same workspace even after the version bump.\n\n      If the `--json` flag is set the output will follow a JSON-stream output also known as NDJSON (https://github.com/ndjson/ndjson-spec).\n    ",examples:[["Apply the version change to the local workspace","yarn version apply"],["Apply the version change to all the workspaces in the local workspace","yarn version apply --all"]]}),i([o.Command.Boolean("--all")],b.prototype,"all",void 0),i([o.Command.Boolean("--json")],b.prototype,"json",void 0),i([o.Command.Path("version","apply")],b.prototype,"execute",null);var g,y=t(4930),D=t(7382),w=t.n(D);!function(e){e.BEFORE="before",e.AFTER="after"}(g||(g={}));const E=function(e,n,{active:t,minus:r,plus:i,set:u,loop:o=!0}){const{stdin:a}=(0,D.useContext)(y.m6);(0,D.useEffect)(()=>{if(!t)return;const l=(t,a)=>{const l=n.indexOf(e);switch(a.name){case r:{const e=l-1;if(o)return void u(n[(n.length+e)%n.length]);if(e<0)return;u(n[e])}break;case i:{const e=l+1;if(o)return void u(n[e%n.length]);if(e>=n.length)return;u(n[e])}}};return a.on("keypress",l),()=>{a.off("keypress",l)}},[n,e,t])},T=({active:e=!0,children:n=[],radius:t=10,size:r=1,loop:i=!0,onFocusRequest:u,willReachEnd:o})=>{const a=w().Children.map(n,e=>(e=>{if(null===e.key)throw new Error("Expected all children to have a key");return e.key})(e)),l=a[0],[s,f]=(0,D.useState)(l),c=a.indexOf(s);(0,D.useEffect)(()=>{a.includes(s)||f(l)},[n]),(0,D.useEffect)(()=>{o&&c>=a.length-2&&o()},[c]),function({active:e,handler:n}){const{stdin:t}=(0,D.useContext)(y.m6);(0,D.useEffect)(()=>{if(!e||void 0===n)return;const r=(e,t)=>{"tab"===t.name&&(t.shift?n(g.BEFORE):n(g.AFTER))};return t.on("keypress",r),()=>{t.off("keypress",r)}},[e,n])}({active:e,handler:u}),E(s,a,{active:e,minus:"up",plus:"down",set:f,loop:i});let d=c-t,p=c+t;p>a.length&&(d-=p-a.length,p=a.length),d<0&&(p+=-d,d=0),p>=a.length&&(p=a.length-1);const h=[];for(let t=d;t<=p;++t){const i=a[t],u=e&&i===s;h.push(w().createElement(y.xu,{key:i,height:r},w().createElement(y.xu,{marginLeft:1,marginRight:1},u?w().createElement(y.mj,{cyan:!0,bold:!0},">"):" "),w().createElement(y.xu,null,w().cloneElement(n[t],{active:u}))))}return w().createElement(y.xu,{flexDirection:"column",width:"100%"},h)},C=w().createContext(null),k=function({children:e}){const{setRawMode:n}=(0,D.useContext)(y.m6);(0,D.useEffect)(()=>{n&&n(!0)},[]);const[t,r]=(0,D.useState)(new Map),i=(0,D.useMemo)(()=>({getAll:()=>t,get:e=>t.get(e),set:(e,n)=>r(new Map([...t,[e,n]]))}),[t,r]);return w().createElement(C.Provider,{value:i,children:e})};class M extends o.Command{async execute(){return this.interactive?await this.executeInteractive():await this.executeStandard()}async executeInteractive(){const e=await r.Configuration.find(this.context.cwd,this.context.plugins),{project:n,workspace:t}=await r.Project.find(e,this.context.cwd);if(!t)throw new u.WorkspaceRequiredError(n.cwd,this.context.cwd);await n.restoreInstallState();const i=await h(n);if(null===i||0===i.releaseRoots.size)return 0;if(null===i.root)throw new o.UsageError("This command can only be run on Git repositories");const l=()=>w().createElement(y.xu,{flexDirection:"row",paddingBottom:1},w().createElement(y.xu,{flexDirection:"column",width:60},w().createElement(y.xu,null,"Press ",w().createElement(y.mj,{bold:!0,cyanBright:!0},"<up>"),"/",w().createElement(y.mj,{bold:!0,cyanBright:!0},"<down>")," to select workspaces."),w().createElement(y.xu,null,"Press ",w().createElement(y.mj,{bold:!0,cyanBright:!0},"<left>"),"/",w().createElement(y.mj,{bold:!0,cyanBright:!0},"<right>")," to select release strategies.")),w().createElement(y.xu,{flexDirection:"column"},w().createElement(y.xu,{marginLeft:1},"Press ",w().createElement(y.mj,{bold:!0,cyanBright:!0},"<enter>")," to save."),w().createElement(y.xu,{marginLeft:1},"Press ",w().createElement(y.mj,{bold:!0,cyanBright:!0},"<ctrl+c>")," to abort."))),s=({workspace:n,active:t,decision:i,setDecision:u})=>{const o=n.manifest.version;if(null===o)throw new Error(`Assertion failed: The version should have been set (${r.structUtils.prettyLocator(e,n.anchoredLocator)})`);const a=null===f().prerelease(o)?[d.UNDECIDED,d.DECLINE,d.PATCH,d.MINOR,d.MAJOR,d.PRERELEASE]:[d.UNDECIDED,d.DECLINE,d.PRERELEASE,d.MAJOR];E(i,a,{active:t,minus:"left",plus:"right",set:u});const l=i===d.UNDECIDED?w().createElement(y.mj,{yellow:!0},o):i===d.DECLINE?w().createElement(y.mj,{green:!0},o):w().createElement(w().Fragment,null,w().createElement(y.mj,{magenta:!0},o)," → ",w().createElement(y.mj,{green:!0},f().inc(o,i)));return w().createElement(y.xu,{flexDirection:"column"},w().createElement(y.xu,null,r.structUtils.prettyLocator(e,n.anchoredLocator)," - ",l),w().createElement(y.xu,null,a.map(e=>e===i?w().createElement(y.xu,{key:e,paddingLeft:2},w().createElement(y.mj,{green:!0},"◉ ")," ",e," "):w().createElement(y.xu,{key:e,paddingLeft:2},w().createElement(y.mj,{yellow:!0},"◯ ")," ",e," "))))},c=e=>{const n=new Set(i.releaseRoots),t=new Map([...e].filter(([e])=>n.has(e)));for(;;){const r=v({project:i.project,releases:t});let u=!1;if(r.length>0)for(const[i]of r)if(!n.has(i)){n.add(i),u=!0;const r=e.get(i);void 0!==r&&t.set(i,r)}if(!u)break}return{relevantWorkspaces:n,relevantReleases:t}},p=({workspaces:e,releases:n})=>{const t=[];t.push(e.size+" total");let r=0,i=0;for(const t of e){const e=n.get(t);void 0===e?i+=1:e!==d.DECLINE&&(r+=1)}return t.push(`${r} release${1===r?"":"s"}`),t.push(i+" remaining"),w().createElement(y.mj,{yellow:!0},t.join(", "))},m=await async function(e,n){let t;const{waitUntilExit:r}=(0,y.sY)(w().createElement(k,null,w().createElement(e,Object.assign({},n,{useSubmit:e=>{const{exit:n}=(0,D.useContext)(y.Il),{stdin:r}=(0,D.useContext)(y.m6);(0,D.useEffect)(()=>{const i=(r,i)=>{"return"===i.name&&(t=e,n())};return r.on("keypress",i),()=>{r.off("keypress",i)}},[r,n,e])}}))));return await r(),t}(({useSubmit:e})=>{const[n,t]=(()=>{const[e,n]=(0,D.useState)(i.releases),t=(0,D.useCallback)((t,r)=>{const i=new Map(e);r!==d.UNDECIDED?i.set(t,r):i.delete(t);const{relevantReleases:u}=c(i);n(u)},[e,n]);return[e,t]})();e(n);const{relevantWorkspaces:r}=c(n),u=new Set([...r].filter(e=>!i.releaseRoots.has(e))),[o,f]=(0,D.useState)(0),h=(0,D.useCallback)(e=>{switch(e){case g.BEFORE:f(o-1);break;case g.AFTER:f(o+1)}},[o,f]);return w().createElement(y.xu,{width:80,flexDirection:"column"},w().createElement(l,null),w().createElement(y.xu,{textWrap:"wrap"},"The following files have been modified in your local checkout."),w().createElement(y.xu,{flexDirection:"column",marginTop:1,paddingLeft:2},[...i.changedFiles].map(e=>w().createElement(y.xu,{key:e},w().createElement(y.mj,{grey:!0},i.root),"/",a.ppath.relative(i.root,e)))),i.releaseRoots.size>0&&w().createElement(w().Fragment,null,w().createElement(y.xu,{marginTop:1,textWrap:"wrap"},"Because of those files having been modified, the following workspaces may need to be released again (note that private workspaces are also shown here, because even though they won't be published, releasing them will allow us to flag their dependents for potential re-release):"),u.size>3?w().createElement(y.xu,{marginTop:1},w().createElement(p,{workspaces:i.releaseRoots,releases:n})):null,w().createElement(y.xu,{marginTop:1,flexDirection:"column"},w().createElement(T,{active:o%2==0,radius:1,size:2,onFocusRequest:h},[...i.releaseRoots].map(e=>w().createElement(s,{key:e.cwd,workspace:e,decision:n.get(e)||d.UNDECIDED,setDecision:n=>t(e,n)}))))),u.size>0&&w().createElement(w().Fragment,null,w().createElement(y.xu,{marginTop:1,textWrap:"wrap"},"The following workspaces depend on other workspaces that have been marked for release, and thus may need to be released as well:"),w().createElement(y.xu,null,"(Press ",w().createElement(y.mj,{bold:!0,cyanBright:!0},"<tab>")," to move the focus between the workspace groups.)"),u.size>5?w().createElement(y.xu,{marginTop:1},w().createElement(p,{workspaces:u,releases:n})):null,w().createElement(y.xu,{marginTop:1,flexDirection:"column"},w().createElement(T,{active:o%2==1,radius:2,size:2,onFocusRequest:h},[...u].map(e=>w().createElement(s,{key:e.cwd,workspace:e,decision:n.get(e)||d.UNDECIDED,setDecision:n=>t(e,n)}))))))},{versionFile:i});if(void 0===m)return 1;i.releases.clear();for(const[e,n]of m)i.releases.set(e,n);await i.saveAll()}async executeStandard(){const e=await r.Configuration.find(this.context.cwd,this.context.plugins),{project:n,workspace:t}=await r.Project.find(e,this.context.cwd);if(!t)throw new u.WorkspaceRequiredError(n.cwd,this.context.cwd);await n.restoreInstallState();return(await r.StreamReport.start({configuration:e,stdout:this.context.stdout},async t=>{const i=await h(n);if(null===i||0===i.releaseRoots.size)return;if(null===i.root)throw new o.UsageError("This command can only be run on Git repositories");if(t.reportInfo(r.MessageName.UNNAMED,`Your PR was started right after ${e.format(i.baseHash.slice(0,7),"yellow")} ${e.format(i.baseTitle,"magenta")}`),i.changedFiles.size>0){t.reportInfo(r.MessageName.UNNAMED,"You have changed the following files since then:"),t.reportSeparator();for(const n of i.changedFiles)t.reportInfo(null,`${e.format(i.root,"gray")}/${a.ppath.relative(i.root,n)}`)}let u=!1,l=!1;const s=m(i);if(s.size>0){u||t.reportSeparator();for(const n of s)t.reportError(r.MessageName.UNNAMED,r.structUtils.prettyLocator(e,n.anchoredLocator)+" has been modified but doesn't have a release strategy attached");u=!0}const f=v(i);for(const[n,i]of f)l||t.reportSeparator(),t.reportError(r.MessageName.UNNAMED,`${r.structUtils.prettyLocator(e,n.anchoredLocator)} doesn't have a release strategy attached, but depends on ${r.structUtils.prettyWorkspace(e,i)} which is planned for release.`),l=!0;(u||l)&&(t.reportSeparator(),t.reportInfo(r.MessageName.UNNAMED,"This command detected that at least some workspaces have received modifications without explicit instructions as to how they had to be released (if needed)."),t.reportInfo(r.MessageName.UNNAMED,"To correct these errors, run `yarn version check --interactive` then follow the instructions."))})).exitCode()}}M.usage=o.Command.Usage({category:"Release-related commands",description:"check that all the relevant packages have been bumped",details:"\n      **Warning:** This command currently requires Git.\n\n      This command will check that all the packages covered by the files listed in argument have been properly bumped or declined to bump.\n\n      In the case of a bump, the check will also cover transitive packages - meaning that should `Foo` be bumped, a package `Bar` depending on `Foo` will require a decision as to whether `Bar` will need to be bumped. This check doesn't cross packages that have declined to bump.\n\n      In case no arguments are passed to the function, the list of modified files will be generated by comparing the HEAD against `master`.\n    ",examples:[["Check whether the modified packages need a bump","yarn version check"]]}),i([o.Command.Boolean("-i,--interactive")],M.prototype,"interactive",void 0),i([o.Command.Path("version","check")],M.prototype,"execute",null);var S=t(9440);const A=new Set(Object.values(d).filter(e=>e!==d.UNDECIDED));class x extends u.BaseCommand{constructor(){super(...arguments),this.force=!1}async execute(){const e=await r.Configuration.find(this.context.cwd,this.context.plugins),{project:n,workspace:t}=await r.Project.find(e,this.context.cwd);if(!t)throw new u.WorkspaceRequiredError(n.cwd,this.context.cwd);let i=e.get("preferDeferredVersions");this.deferred&&(i=!0),this.immediate&&(i=!1);const a=f().valid(this.strategy),l=this.strategy===d.DECLINE;let s;if(a)if(null!==t.manifest.version){const e=function(e,n){const t=f().clean(n);for(const n of Object.values(d))if(n!==d.UNDECIDED&&n!==d.DECLINE&&f().inc(e,n)===t)return n;return null}(t.manifest.version,this.strategy);s=null!==e?e:this.strategy}else s=this.strategy;else{const e=t.manifest.version;if(!l){if(null===e)throw new o.UsageError("Can't bump the version if there wasn't a version to begin with - use 0.0.0 as initial version then run the command again.");if("string"!=typeof e||!f().valid(e))throw new o.UsageError(`Can't bump the version (${e}) if it's not valid semver`)}s=this.strategy}if(!i){const e=(await p(n)).get(t);if(void 0!==e){const n=_(t.manifest.version,s);if(f().lt(n,e))throw new o.UsageError(`Can't bump the version to one that would be lower than the current deferred one (${e})`)}}const c=await h(n,{allowEmpty:!0});await c.releases.set(t,s),await c.saveAll(),i||await this.cli.run(["version","apply"])}}x.schema=S.object().shape({strategy:S.string().test({name:"strategy",message:"${path} must be a semver range or one of ${strategies}",params:{strategies:[...A].join(", ")},test:e=>null!==f().valid(e)||A.has(e)})}),x.usage=o.Command.Usage({category:"Release-related commands",description:"apply a new version to the current package",details:'\n      This command will bump the version number for the given package, following the specified strategy:\n\n      - If `major`, the first number from the semver range will be increased (`X.0.0`).\n      - If `minor`, the second number from the semver range will be increased (`0.X.0`).\n      - If `patch`, the third number from the semver range will be increased (`0.0.X`).\n      - If prefixed by `pre` (`premajor`, ...), a `-0` suffix will be set (`0.0.0-0`).\n      - If `prerelease`, the suffix will be increased (`0.0.0-X`); the third number from the semver range will also be increased if there was no suffix in the previous version.\n      - If `decline`, the nonce will be increased for `yarn version check` to pass without version bump.\n      - If a valid semver range, it will be used as new version.\n      - If unspecified, Yarn will ask you for guidance.\n\n      For more information about the `--deferred` flag, consult our documentation ("Managing Releases").\n    ',examples:[["Immediatly bump the version to the next major","yarn version major"],["Prepare the version to be bumped to the next major","yarn version major --deferred"]]}),i([o.Command.String()],x.prototype,"strategy",void 0),i([o.Command.Boolean("-d,--deferred")],x.prototype,"deferred",void 0),i([o.Command.Boolean("-i,--immediate")],x.prototype,"immediate",void 0),i([o.Command.Boolean("-f,--force")],x.prototype,"force",void 0),i([o.Command.Path("version")],x.prototype,"execute",null);const P={configuration:{changesetBaseRefs:{description:"The base git refs that the current HEAD is compared against when detecting changes. Supports git branches, tags, and commits.",type:r.SettingsType.STRING,isArray:!0,isNullable:!1,default:["master","origin/master","upstream/master"]},changesetIgnorePatterns:{description:"Array of glob patterns; files matching them will be ignored when fetching the changed files",type:r.SettingsType.STRING,default:[],isArray:!0},deferredVersionFolder:{description:"Folder where are stored the versioning files",type:r.SettingsType.ABSOLUTE_PATH,default:"./.yarn/versions"},preferDeferredVersions:{description:"If true, running `yarn version` will assume the `--deferred` flag unless `--immediate` is set",type:r.SettingsType.BOOLEAN,default:!1}},commands:[b,M,x]}},9043:(e,n,t)=>{"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r,i=(r=t(2821))&&r.__esModule?r:{default:r};const u=(e,n)=>({}.hasOwnProperty.call(e,n));n.default=(e,n={})=>{((e,n)=>{n.margin&&(e.setMargin(i.default.EDGE_TOP,n.margin),e.setMargin(i.default.EDGE_BOTTOM,n.margin),e.setMargin(i.default.EDGE_START,n.margin),e.setMargin(i.default.EDGE_END,n.margin)),n.marginX&&(e.setMargin(i.default.EDGE_START,n.marginX),e.setMargin(i.default.EDGE_END,n.marginX)),n.marginY&&(e.setMargin(i.default.EDGE_TOP,n.marginY),e.setMargin(i.default.EDGE_BOTTOM,n.marginY)),n.marginTop&&e.setMargin(i.default.EDGE_TOP,n.marginTop),n.marginBottom&&e.setMargin(i.default.EDGE_BOTTOM,n.marginBottom),n.marginLeft&&e.setMargin(i.default.EDGE_START,n.marginLeft),n.marginRight&&e.setMargin(i.default.EDGE_END,n.marginRight)})(e,n),((e,n)=>{n.padding&&(e.setPadding(i.default.EDGE_TOP,n.padding),e.setPadding(i.default.EDGE_BOTTOM,n.padding),e.setPadding(i.default.EDGE_LEFT,n.padding),e.setPadding(i.default.EDGE_RIGHT,n.padding)),n.paddingX&&(e.setPadding(i.default.EDGE_LEFT,n.paddingX),e.setPadding(i.default.EDGE_RIGHT,n.paddingX)),n.paddingY&&(e.setPadding(i.default.EDGE_TOP,n.paddingY),e.setPadding(i.default.EDGE_BOTTOM,n.paddingY)),n.paddingTop&&e.setPadding(i.default.EDGE_TOP,n.paddingTop),n.paddingBottom&&e.setPadding(i.default.EDGE_BOTTOM,n.paddingBottom),n.paddingLeft&&e.setPadding(i.default.EDGE_LEFT,n.paddingLeft),n.paddingRight&&e.setPadding(i.default.EDGE_RIGHT,n.paddingRight)})(e,n),((e,n)=>{n.flexGrow&&e.setFlexGrow(n.flexGrow),n.flexShrink&&e.setFlexShrink(n.flexShrink),n.flexDirection&&("row"===n.flexDirection&&e.setFlexDirection(i.default.FLEX_DIRECTION_ROW),"row-reverse"===n.flexDirection&&e.setFlexDirection(i.default.FLEX_DIRECTION_ROW_REVERSE),"column"===n.flexDirection&&e.setFlexDirection(i.default.FLEX_DIRECTION_COLUMN),"column-reverse"===n.flexDirection&&e.setFlexDirection(i.default.FLEX_DIRECTION_COLUMN_REVERSE)),u(n,"flexBasis")&&e.setFlexBasis(n.flexBasis),n.alignItems&&("flex-start"===n.alignItems&&e.setAlignItems(i.default.ALIGN_FLEX_START),"center"===n.alignItems&&e.setAlignItems(i.default.ALIGN_CENTER),"flex-end"===n.alignItems&&e.setAlignItems(i.default.ALIGN_FLEX_END)),n.justifyContent&&("flex-start"===n.justifyContent&&e.setJustifyContent(i.default.JUSTIFY_FLEX_START),"center"===n.justifyContent&&e.setJustifyContent(i.default.JUSTIFY_CENTER),"flex-end"===n.justifyContent&&e.setJustifyContent(i.default.JUSTIFY_FLEX_END),"space-between"===n.justifyContent&&e.setJustifyContent(i.default.JUSTIFY_SPACE_BETWEEN),"space-around"===n.justifyContent&&e.setJustifyContent(i.default.JUSTIFY_SPACE_AROUND))})(e,n),((e,n)=>{u(n,"width")&&e.setWidth(n.width),u(n,"height")&&e.setHeight(n.height),u(n,"minWidth")&&e.setMinWidth(n.minWidth),u(n,"minHeight")&&e.setMinHeight(n.minHeight)})(e,n)}},1:(e,n,t)=>{"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r=o(t(2821)),i=o(t(9043)),u=o(t(3425));function o(e){return e&&e.__esModule?e:{default:e}}const a=(e,n)=>{const{config:t,terminalWidth:o,skipStaticElements:l}=n,s=r.default.Node.create(t);e.yogaNode=s;const f=e.style||{};if("ROOT"===e.nodeName){if(s.setWidth(o||100),e.childNodes.length>0){const t=e.childNodes.filter(e=>!l||!e.unstable__static);for(const[e,r]of Object.entries(t)){const t=a(r,n).yogaNode;s.insertChild(t,e)}}return e}if((0,i.default)(s,f),e.textContent||e.nodeValue){const{width:n,height:t}=(0,u.default)(e.textContent||e.nodeValue);return s.setWidth(f.width||n),s.setHeight(f.height||t),e}if(Array.isArray(e.childNodes)&&e.childNodes.length>0){const t=e.childNodes.filter(e=>!l||!e.unstable__static);for(const[e,r]of Object.entries(t)){const{yogaNode:t}=a(r,n);s.insertChild(t,e)}}return e};var l=a;n.default=l},1752:(e,n,t)=>{"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r=f(t(1058)),i=function(e){if(e&&e.__esModule)return e;var n={};if(null!=e)for(var t in e)if(Object.prototype.hasOwnProperty.call(e,t)){var r=Object.defineProperty&&Object.getOwnPropertyDescriptor?Object.getOwnPropertyDescriptor(e,t):{};r.get||r.set?Object.defineProperty(n,t,r):n[t]=e[t]}return n.default=e,n}(t(7382)),u=f(t(6271)),o=f(t(1305)),a=f(t(4974)),l=f(t(7454)),s=f(t(3742));function f(e){return e&&e.__esModule?e:{default:e}}function c(e,n,t){return n in e?Object.defineProperty(e,n,{value:t,enumerable:!0,configurable:!0,writable:!0}):e[n]=t,e}class d extends i.PureComponent{isRawModeSupported(){return this.props.stdin.isTTY}constructor(){super(),c(this,"handleSetRawMode",e=>{const{stdin:n}=this.props;if(!this.isRawModeSupported())throw n===process.stdin?new Error("Raw mode is not supported on the current process.stdin, which Ink uses as input stream by default.\nRead about how to prevent this error on https://github.com/vadimdemedes/ink/#israwmodesupported"):new Error("Raw mode is not supported on the stdin provided to Ink.\nRead about how to prevent this error on https://github.com/vadimdemedes/ink/#israwmodesupported");if(n.setEncoding("utf8"),e)return 0===this.rawModeEnabledCount&&(n.addListener("data",this.handleInput),n.resume(),n.setRawMode(!0),r.default.emitKeypressEvents(n)),void this.rawModeEnabledCount++;0==--this.rawModeEnabledCount&&(n.setRawMode(!1),n.removeListener("data",this.handleInput),n.pause())}),c(this,"handleInput",e=>{""===e&&this.props.exitOnCtrlC&&this.handleExit()}),c(this,"handleExit",e=>{this.isRawModeSupported()&&this.handleSetRawMode(!1),this.props.onExit(e)}),this.rawModeEnabledCount=0}render(){return i.default.createElement(a.default.Provider,{value:{exit:this.handleExit}},i.default.createElement(l.default.Provider,{value:{stdin:this.props.stdin,setRawMode:this.handleSetRawMode,isRawModeSupported:this.isRawModeSupported()}},i.default.createElement(s.default.Provider,{value:{stdout:this.props.stdout}},this.props.children)))}componentDidMount(){o.default.hide(this.props.stdout)}componentWillUnmount(){o.default.show(this.props.stdout),this.isRawModeSupported()&&this.handleSetRawMode(!1)}componentDidCatch(e){this.handleExit(e)}}n.default=d,c(d,"propTypes",{children:u.default.node.isRequired,stdin:u.default.object.isRequired,stdout:u.default.object.isRequired,exitOnCtrlC:u.default.bool.isRequired,onExit:u.default.func.isRequired})},4974:(e,n,t)=>{"use strict";var r;Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var i=((r=t(7382))&&r.__esModule?r:{default:r}).default.createContext({exit(){}});n.default=i},522:(e,n,t)=>{"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r,i=function(e){if(e&&e.__esModule)return e;var n={};if(null!=e)for(var t in e)if(Object.prototype.hasOwnProperty.call(e,t)){var r=Object.defineProperty&&Object.getOwnPropertyDescriptor?Object.getOwnPropertyDescriptor(e,t):{};r.get||r.set?Object.defineProperty(n,t,r):n[t]=e[t]}return n.default=e,n}(t(7382)),u=(r=t(6271))&&r.__esModule?r:{default:r};function o(e,n){if(null==e)return{};var t,r,i=function(e,n){if(null==e)return{};var t,r,i={},u=Object.keys(e);for(r=0;r<u.length;r++)t=u[r],n.indexOf(t)>=0||(i[t]=e[t]);return i}(e,n);if(Object.getOwnPropertySymbols){var u=Object.getOwnPropertySymbols(e);for(r=0;r<u.length;r++)t=u[r],n.indexOf(t)>=0||Object.prototype.propertyIsEnumerable.call(e,t)&&(i[t]=e[t])}return i}function a(e,n,t){return n in e?Object.defineProperty(e,n,{value:t,enumerable:!0,configurable:!0,writable:!0}):e[n]=t,e}class l extends i.PureComponent{constructor(){super(),this.nodeRef=i.default.createRef()}render(){const e=this.props,{children:n,unstable__transformChildren:t}=e,r=o(e,["children","unstable__transformChildren"]);return i.default.createElement("div",{ref:this.nodeRef,style:r,unstable__transformChildren:t},n)}unstable__getComputedWidth(){return this.nodeRef.current.yogaNode.getComputedWidth()}}n.default=l,a(l,"propTypes",{margin:u.default.number,marginX:u.default.number,marginY:u.default.number,marginTop:u.default.number,marginBottom:u.default.number,marginLeft:u.default.number,marginRight:u.default.number,padding:u.default.number,paddingX:u.default.number,paddingY:u.default.number,paddingTop:u.default.number,paddingBottom:u.default.number,paddingLeft:u.default.number,paddingRight:u.default.number,width:u.default.oneOfType([u.default.number,u.default.string]),minWidth:u.default.number,height:u.default.oneOfType([u.default.number,u.default.string]),minHeight:u.default.number,flexGrow:u.default.number,flexShrink:u.default.number,flexDirection:u.default.oneOf(["row","row-reverse","column","column-reverse"]),flexBasis:u.default.oneOfType([u.default.number,u.default.string]),alignItems:u.default.oneOf(["flex-start","center","flex-end"]),justifyContent:u.default.oneOf(["flex-start","center","flex-end","space-between","space-around"]),textWrap:u.default.oneOf(["wrap","truncate","truncate-start","truncate-middle","truncate-end"]),unstable__transformChildren:u.default.func,children:u.default.node}),a(l,"defaultProps",{flexDirection:"row",flexGrow:0,flexShrink:1})},3862:(e,n,t)=>{"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r=a(t(7382)),i=a(t(6271)),u=a(t(3810)),o=a(t(9244));function a(e){return e&&e.__esModule?e:{default:e}}function l(e,n){if(null==e)return{};var t,r,i=function(e,n){if(null==e)return{};var t,r,i={},u=Object.keys(e);for(r=0;r<u.length;r++)t=u[r],n.indexOf(t)>=0||(i[t]=e[t]);return i}(e,n);if(Object.getOwnPropertySymbols){var u=Object.getOwnPropertySymbols(e);for(r=0;r<u.length;r++)t=u[r],n.indexOf(t)>=0||Object.prototype.propertyIsEnumerable.call(e,t)&&(i[t]=e[t])}return i}const s=["hex","hsl","hsv","hwb","rgb","keyword","bgHex","bgHsl","bgHsv","bgHwb","bgRgb","bgKeyword"],f=e=>{let{children:n}=e,t=l(e,["children"]);return r.default.createElement("span",{style:{flexDirection:"row"},unstable__transformChildren:e=>(Object.keys(t).forEach(n=>{t[n]&&(s.includes(n)?e=o.default[n](...(0,u.default)(t[n]))(e):"function"==typeof o.default[n]&&(e=o.default[n](e)))}),e)},n)};f.propTypes={children:i.default.node.isRequired};var c=f;n.default=c},8075:(e,n,t)=>{"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r,i=function(e){if(e&&e.__esModule)return e;var n={};if(null!=e)for(var t in e)if(Object.prototype.hasOwnProperty.call(e,t)){var r=Object.defineProperty&&Object.getOwnPropertyDescriptor?Object.getOwnPropertyDescriptor(e,t):{};r.get||r.set?Object.defineProperty(n,t,r):n[t]=e[t]}return n.default=e,n}(t(7382)),u=(r=t(6271))&&r.__esModule?r:{default:r};function o(e,n){if(null==e)return{};var t,r,i=function(e,n){if(null==e)return{};var t,r,i={},u=Object.keys(e);for(r=0;r<u.length;r++)t=u[r],n.indexOf(t)>=0||(i[t]=e[t]);return i}(e,n);if(Object.getOwnPropertySymbols){var u=Object.getOwnPropertySymbols(e);for(r=0;r<u.length;r++)t=u[r],n.indexOf(t)>=0||Object.prototype.propertyIsEnumerable.call(e,t)&&(i[t]=e[t])}return i}function a(e,n,t){return n in e?Object.defineProperty(e,n,{value:t,enumerable:!0,configurable:!0,writable:!0}):e[n]=t,e}const l=e=>Array.isArray(e)?e:[e];class s extends i.Component{constructor(...e){super(...e),a(this,"state",{lastIndex:null})}render(){const e=this.props,{children:n}=e,t=o(e,["children"]),{lastIndex:r}=this.state;let u=n;return"number"==typeof r&&(u=l(n).slice(r)),i.default.createElement("div",{unstable__static:!0,style:t},u)}componentDidMount(){this.saveLastIndex(this.props.children)}componentDidUpdate(e,n){n.lastIndex===this.state.lastIndex&&this.saveLastIndex(this.props.children)}saveLastIndex(e){const n=l(e).length;this.state.lastIndex!==n&&this.setState({lastIndex:n})}}n.default=s,a(s,"propTypes",{children:u.default.node})},7454:(e,n,t)=>{"use strict";var r;Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var i=((r=t(7382))&&r.__esModule?r:{default:r}).default.createContext({stdin:void 0,setRawMode:void 0});n.default=i},3742:(e,n,t)=>{"use strict";var r;Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var i=((r=t(7382))&&r.__esModule?r:{default:r}).default.createContext({stdout:void 0});n.default=i},4127:(e,n,t)=>{"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r=o(t(7382)),i=o(t(6271)),u=o(t(9244));function o(e){return e&&e.__esModule?e:{default:e}}const a=({bold:e,italic:n,underline:t,strikethrough:i,children:o,unstable__transformChildren:a})=>r.default.createElement("span",{style:{flexDirection:"row"},unstable__transformChildren:r=>(e&&(r=u.default.bold(r)),n&&(r=u.default.italic(r)),t&&(r=u.default.underline(r)),i&&(r=u.default.strikethrough(r)),a&&(r=a(r)),r)},o);a.propTypes={bold:i.default.bool,italic:i.default.bool,underline:i.default.bool,strikethrough:i.default.bool,children:i.default.node.isRequired,unstable__transformChildren:i.default.func},a.defaultProps={bold:!1,italic:!1,underline:!1,strikethrough:!1,unstable__transformChildren:void 0};var l=a;n.default=l},3976:(e,n)=>{"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.createTextNode=n.setAttribute=n.removeChildNode=n.insertBeforeNode=n.appendStaticNode=n.appendChildNode=n.createNode=void 0;n.createNode=e=>({nodeName:e.toUpperCase(),style:{},attributes:{},childNodes:[],parentNode:null});n.appendChildNode=(e,n)=>{n.parentNode&&t(n.parentNode,n),n.parentNode=e,e.childNodes.push(n)};n.appendStaticNode=(e,n)=>{e.childNodes.push(n)};n.insertBeforeNode=(e,n,r)=>{n.parentNode&&t(n.parentNode,n),n.parentNode=e;const i=e.childNodes.indexOf(r);i>=0?e.childNodes.splice(i,0,n):e.childNodes.push(n)};const t=(e,n)=>{n.parentNode=null;const t=e.childNodes.indexOf(n);t>=0&&e.childNodes.splice(t,1)};n.removeChildNode=t;n.setAttribute=(e,n,t)=>{e.attributes[n]=t};n.createTextNode=e=>({nodeName:"#text",nodeValue:e})},4431:(e,n)=>{"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;n.default=e=>e.getComputedWidth()-2*e.getComputedPadding()},4930:(e,n,t)=>{"use strict";Object.defineProperty(n,"sY",{enumerable:!0,get:function(){return r.default}}),Object.defineProperty(n,"xu",{enumerable:!0,get:function(){return i.default}}),Object.defineProperty(n,"mj",{enumerable:!0,get:function(){return o.default}}),Object.defineProperty(n,"Il",{enumerable:!0,get:function(){return a.default}}),Object.defineProperty(n,"m6",{enumerable:!0,get:function(){return l.default}});var r=c(t(4763)),i=c(t(522)),u=c(t(4127)),o=c(t(3862)),a=c(t(4974)),l=c(t(7454)),s=c(t(3742)),f=c(t(8075));function c(e){return e&&e.__esModule?e:{default:e}}},7018:(e,n,t)=>{"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r=h(t(7382)),i=h(t(4623)),u=h(t(2939)),o=h(t(4046)),a=h(t(2738)),l=h(t(6458)),s=h(t(7190)),f=h(t(9646)),c=t(3976),d=h(t(4455)),p=h(t(1752));function h(e){return e&&e.__esModule?e:{default:e}}n.default=class{constructor(e){(0,u.default)(this),this.options=e,this.rootNode=(0,c.createNode)("root"),this.rootNode.onRender=this.onRender,this.renderer=(0,f.default)({terminalWidth:e.stdout.columns}),this.log=o.default.create(e.stdout),this.throttledLog=e.debug?this.log:(0,i.default)(this.log,{leading:!0,trailing:!0}),this.isUnmounted=!1,this.lastOutput="",this.fullStaticOutput="",this.container=s.default.createContainer(this.rootNode,!1,!1),this.exitPromise=new Promise((e,n)=>{this.resolveExitPromise=e,this.rejectExitPromise=n}),this.unsubscribeExit=(0,l.default)(this.unmount,{alwaysLast:!1})}onRender(){if(this.isUnmounted)return;const{output:e,staticOutput:n}=this.renderer(this.rootNode),t=n&&"\n"!==n;if(this.options.debug)return t&&(this.fullStaticOutput+=n),void this.options.stdout.write(this.fullStaticOutput+e);t&&(a.default||this.log.clear(),this.options.stdout.write(n),a.default||this.log(e)),e!==this.lastOutput&&(a.default||this.throttledLog(e),this.lastOutput=e)}render(e){const n=r.default.createElement(p.default,{stdin:this.options.stdin,stdout:this.options.stdout,exitOnCtrlC:this.options.exitOnCtrlC,onExit:this.unmount},e);s.default.updateContainer(n,this.container)}unmount(e){this.isUnmounted||(this.onRender(),this.unsubscribeExit(),a.default?this.options.stdout.write(this.lastOutput+"\n"):this.options.debug||this.log.done(),this.isUnmounted=!0,s.default.updateContainer(null,this.container),d.default.delete(this.options.stdout),e instanceof Error?this.rejectExitPromise(e):this.resolveExitPromise())}waitUntilExit(){return this.exitPromise}}},4455:(e,n)=>{"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var t=new WeakMap;n.default=t},3425:(e,n,t)=>{"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r,i=(r=t(128))&&r.__esModule?r:{default:r};n.default=e=>({width:(0,i.default)(e),height:e.split("\n").length})},6734:(e,n,t)=>{"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r=u(t(2989)),i=u(t(7498));function u(e){return e&&e.__esModule?e:{default:e}}n.default=class{constructor({width:e,height:n}){const t=[];for(let r=0;r<n;r++)t.push(" ".repeat(e));this.output=t}write(e,n,t,{transformers:u}){if(!t)return;const o=t.split("\n");let a=0;for(let t of o){const o=(0,r.default)(t),l=this.output[n+a];if(l){for(const e of u)t=e(t);this.output[n+a]=(0,i.default)(l,0,e)+t+(0,i.default)(l,e+o),a++}}}get(){return this.output.map(e=>e.trimRight()).join("\n")}}},7190:(e,n,t)=>{"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r,i=t(5201),u=(r=t(9437))&&r.__esModule?r:{default:r},o=t(3976);const a={schedulePassiveEffects:i.unstable_scheduleCallback,cancelPassiveEffects:i.unstable_cancelCallback,now:Date.now,getRootHostContext:()=>!0,prepareForCommit:()=>{},resetAfterCommit:e=>{e.onRender()},getChildHostContext:()=>!0,shouldSetTextContent:(e,n)=>"string"==typeof n.children||"number"==typeof n.children,createInstance:(e,n)=>{const t=(0,o.createNode)(e);for(const[r,i]of Object.entries(n))if("children"===r){if("string"==typeof i||"number"==typeof i){if("div"===e){const e=(0,o.createNode)("div");e.textContent=String(i),(0,o.appendChildNode)(t,e)}"span"===e&&(t.textContent=String(i))}}else"style"===r?Object.assign(t.style,i):"unstable__transformChildren"===r?t.unstable__transformChildren=i:"unstable__static"===r?t.unstable__static=!0:(0,o.setAttribute)(t,r,i);return t},createTextInstance:o.createTextNode,resetTextContent:e=>{if(e.textContent&&(e.textContent=""),e.childNodes.length>0)for(const n of e.childNodes)n.yogaNode.free(),(0,o.removeChildNode)(e,n)},getPublicInstance:e=>e,appendInitialChild:o.appendChildNode,appendChild:o.appendChildNode,insertBefore:o.insertBeforeNode,finalizeInitialChildren:()=>{},supportsMutation:!0,appendChildToContainer:o.appendChildNode,insertInContainerBefore:o.insertBeforeNode,removeChildFromContainer:o.removeChildNode,prepareUpdate:()=>!0,commitUpdate:(e,n,t,r,i)=>{for(const[n,r]of Object.entries(i))if("children"===n){if("string"==typeof r||"number"==typeof r){if("div"===t)if(0===e.childNodes.length){const n=(0,o.createNode)("div");n.textContent=String(r),(0,o.appendChildNode)(e,n)}else e.childNodes[0].textContent=String(r);"span"===t&&(e.textContent=String(r))}}else"style"===n?Object.assign(e.style,r):"unstable__transformChildren"===n?e.unstable__transformChildren=r:"unstable__static"===n?e.unstable__static=!0:(0,o.setAttribute)(e,n,r)},commitTextUpdate:(e,n,t)=>{"#text"===e.nodeName?e.nodeValue=t:e.textContent=t},removeChild:o.removeChildNode};var l=(0,u.default)(a);n.default=l},3496:(e,n,t)=>{"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r=o(t(128)),i=o(t(335)),u=o(t(4431));function o(e){return e&&e.__esModule?e:{default:e}}const a=e=>{if("#text"===e.nodeName)return!0;if("SPAN"===e.nodeName){if(e.textContent)return!0;if(Array.isArray(e.childNodes))return e.childNodes.every(a)}return!1},l=e=>{let n="";for(const t of e.childNodes){let e;"#text"===t.nodeName&&(e=t.nodeValue),"SPAN"===t.nodeName&&(e=t.textContent||l(t)),t.unstable__transformChildren&&(e=t.unstable__transformChildren(e)),n+=e}return n},s=(e,n,{offsetX:t=0,offsetY:o=0,transformers:f=[],skipStaticElements:c})=>{if(e.unstable__static&&c)return;const{yogaNode:d}=e,p=t+d.getComputedLeft(),h=o+d.getComputedTop();let m=f;if(e.unstable__transformChildren&&(m=[e.unstable__transformChildren,...f]),e.textContent){let t=e.textContent;if(e.parentNode.style.textWrap){const n=(0,r.default)(t),o=(0,u.default)(e.parentNode.yogaNode);n>o&&(t=(0,i.default)(t,o,{textWrap:e.parentNode.style.textWrap}))}n.write(p,h,t,{transformers:m})}else if("#text"!==e.nodeName){if(Array.isArray(e.childNodes)&&e.childNodes.length>0){if("row"===e.style.flexDirection&&e.childNodes.every(a)){let t=l(e);if(e.style.textWrap){const n=(0,r.default)(t),o=(0,u.default)(d);n>o&&(t=(0,i.default)(t,o,{textWrap:e.style.textWrap}))}return void n.write(p,h,t,{transformers:m})}for(const t of e.childNodes)s(t,n,{offsetX:p,offsetY:h,transformers:m,skipStaticElements:c})}}else n.write(p,h,e.nodeValue,{transformers:m})};var f=s;n.default=f},4763:(e,n,t)=>{"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r=u(t(7018)),i=u(t(4455));function u(e){return e&&e.__esModule?e:{default:e}}function o(e,n,t){return n in e?Object.defineProperty(e,n,{value:t,enumerable:!0,configurable:!0,writable:!0}):e[n]=t,e}n.default=(e,n={})=>{let t;return"function"==typeof n.write&&(n={stdout:n,stdin:process.stdin}),n=function(e){for(var n=1;n<arguments.length;n++){var t=null!=arguments[n]?arguments[n]:{},r=Object.keys(t);"function"==typeof Object.getOwnPropertySymbols&&(r=r.concat(Object.getOwnPropertySymbols(t).filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable})))),r.forEach((function(n){o(e,n,t[n])}))}return e}({stdout:process.stdout,stdin:process.stdin,debug:!1,exitOnCtrlC:!0},n),i.default.has(n.stdout)?t=i.default.get(n.stdout):(t=new r.default(n),i.default.set(n.stdout,t)),t.render(e),{rerender:t.render,unmount:()=>t.unmount(),waitUntilExit:t.waitUntilExit,cleanup:()=>i.default.delete(n.stdout)}}},9646:(e,n,t)=>{"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r=c(t(2821)),i=c(t(6734)),u=t(3976),o=c(t(1)),a=c(t(3496)),l=c(t(3425)),s=c(t(335)),f=c(t(4431));function c(e){return e&&e.__esModule?e:{default:e}}const d=e=>{if(e.textContent&&"string"==typeof e.parentNode.style.textWrap){const{yogaNode:n}=e,t=e.parentNode.yogaNode,r=(0,f.default)(t);if(n.getComputedWidth()>r){const{textWrap:t}=e.parentNode.style,i=(0,s.default)(e.textContent,r,{textWrap:t}),{width:u,height:o}=(0,l.default)(i);n.setWidth(u),n.setHeight(o)}}else if(Array.isArray(e.childNodes)&&e.childNodes.length>0)for(const n of e.childNodes)d(n)},p=e=>{const n=[];for(const t of e.childNodes)t.unstable__static&&n.push(t),Array.isArray(t.childNodes)&&t.childNodes.length>0&&n.push(...p(t));return n};n.default=({terminalWidth:e})=>{const n=r.default.Config.create();let t,l;return s=>{t&&t.freeRecursive(),l&&l.freeRecursive();const f=p(s);let c;if(f.length,1===f.length){const t=(0,u.createNode)("root");(0,u.appendStaticNode)(t,f[0]);const{yogaNode:s}=(0,o.default)(t,{config:n,terminalWidth:e,skipStaticElements:!1});s.calculateLayout(r.default.UNDEFINED,r.default.UNDEFINED,r.default.DIRECTION_LTR),d(t),s.calculateLayout(r.default.UNDEFINED,r.default.UNDEFINED,r.default.DIRECTION_LTR),l=s,c=new i.default({width:s.getComputedWidth(),height:s.getComputedHeight()}),(0,a.default)(t,c,{skipStaticElements:!1})}const{yogaNode:h}=(0,o.default)(s,{config:n,terminalWidth:e,skipStaticElements:!0});h.calculateLayout(r.default.UNDEFINED,r.default.UNDEFINED,r.default.DIRECTION_LTR),d(s),h.calculateLayout(r.default.UNDEFINED,r.default.UNDEFINED,r.default.DIRECTION_LTR),t=h;const m=new i.default({width:h.getComputedWidth(),height:h.getComputedHeight()});return(0,a.default)(s,m,{skipStaticElements:!0}),{output:m.get(),staticOutput:c?c.get()+"\n":void 0}}}},335:(e,n,t)=>{"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r=u(t(5449)),i=u(t(4093));function u(e){return e&&e.__esModule?e:{default:e}}n.default=(e,n,{textWrap:t}={})=>{if("wrap"===t)return(0,r.default)(e,n,{trim:!1,hard:!0});if(String(t).startsWith("truncate")){let r;return"truncate"!==t&&"truncate-end"!==t||(r="end"),"truncate-middle"===t&&(r="middle"),"truncate-start"===t&&(r="start"),(0,i.default)(e,n,{position:r})}return e}},5591:(e,n,t)=>{
/** @license React v0.20.4
 * react-reconciler.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
e.exports=function n(r){"use strict";var i=t(9381),u=t(7382),o=t(5201);function a(e,n,t,r,i,u,o,a){if(!e){if(e=void 0,void 0===n)e=Error("Minified exception occurred; use the non-minified dev environment for the full error message and additional helpful warnings.");else{var l=[t,r,i,u,o,a],s=0;(e=Error(n.replace(/%s/g,(function(){return l[s++]})))).name="Invariant Violation"}throw e.framesToPop=1,e}}function l(e){for(var n=arguments.length-1,t="https://reactjs.org/docs/error-decoder.html?invariant="+e,r=0;r<n;r++)t+="&args[]="+encodeURIComponent(arguments[r+1]);a(!1,"Minified React error #"+e+"; visit %s for the full message or use the non-minified dev environment for full errors and additional helpful warnings. ",t)}var s=u.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED;s.hasOwnProperty("ReactCurrentDispatcher")||(s.ReactCurrentDispatcher={current:null});var f="function"==typeof Symbol&&Symbol.for,c=f?Symbol.for("react.element"):60103,d=f?Symbol.for("react.portal"):60106,p=f?Symbol.for("react.fragment"):60107,h=f?Symbol.for("react.strict_mode"):60108,m=f?Symbol.for("react.profiler"):60114,v=f?Symbol.for("react.provider"):60109,_=f?Symbol.for("react.context"):60110,b=f?Symbol.for("react.concurrent_mode"):60111,g=f?Symbol.for("react.forward_ref"):60112,y=f?Symbol.for("react.suspense"):60113,D=f?Symbol.for("react.memo"):60115,w=f?Symbol.for("react.lazy"):60116,E="function"==typeof Symbol&&Symbol.iterator;function T(e){return null===e||"object"!=typeof e?null:"function"==typeof(e=E&&e[E]||e["@@iterator"])?e:null}function C(e){if(null==e)return null;if("function"==typeof e)return e.displayName||e.name||null;if("string"==typeof e)return e;switch(e){case b:return"ConcurrentMode";case p:return"Fragment";case d:return"Portal";case m:return"Profiler";case h:return"StrictMode";case y:return"Suspense"}if("object"==typeof e)switch(e.$$typeof){case _:return"Context.Consumer";case v:return"Context.Provider";case g:var n=e.render;return n=n.displayName||n.name||"",e.displayName||(""!==n?"ForwardRef("+n+")":"ForwardRef");case D:return C(e.type);case w:if(e=1===e._status?e._result:null)return C(e)}return null}function k(e){var n=e;if(e.alternate)for(;n.return;)n=n.return;else{if(0!=(2&n.effectTag))return 1;for(;n.return;)if(0!=(2&(n=n.return).effectTag))return 1}return 3===n.tag?2:3}function M(e){2!==k(e)&&l("188")}function S(e){var n=e.alternate;if(!n)return 3===(n=k(e))&&l("188"),1===n?null:e;for(var t=e,r=n;;){var i=t.return,u=i?i.alternate:null;if(!i||!u)break;if(i.child===u.child){for(var o=i.child;o;){if(o===t)return M(i),e;if(o===r)return M(i),n;o=o.sibling}l("188")}if(t.return!==r.return)t=i,r=u;else{o=!1;for(var a=i.child;a;){if(a===t){o=!0,t=i,r=u;break}if(a===r){o=!0,r=i,t=u;break}a=a.sibling}if(!o){for(a=u.child;a;){if(a===t){o=!0,t=u,r=i;break}if(a===r){o=!0,r=u,t=i;break}a=a.sibling}o||l("189")}}t.alternate!==r&&l("190")}return 3!==t.tag&&l("188"),t.stateNode.current===t?e:n}function A(e){if(!(e=S(e)))return null;for(var n=e;;){if(5===n.tag||6===n.tag)return n;if(n.child)n.child.return=n,n=n.child;else{if(n===e)break;for(;!n.sibling;){if(!n.return||n.return===e)return null;n=n.return}n.sibling.return=n.return,n=n.sibling}}return null}var x=r.getPublicInstance,P=r.getRootHostContext,R=r.getChildHostContext,N=r.prepareForCommit,F=r.resetAfterCommit,O=r.createInstance,L=r.appendInitialChild,I=r.finalizeInitialChildren,B=r.prepareUpdate,U=r.shouldSetTextContent,j=r.shouldDeprioritizeSubtree,W=r.createTextInstance,z=r.scheduleDeferredCallback,H=r.cancelDeferredCallback,G=r.shouldYield,Y=r.setTimeout,q=r.clearTimeout,V=r.noTimeout,$=r.schedulePassiveEffects,X=r.cancelPassiveEffects,K=r.now,J=r.isPrimaryRenderer,Q=r.supportsMutation,Z=r.supportsPersistence,ee=r.supportsHydration,ne=r.appendChild,te=r.appendChildToContainer,re=r.commitTextUpdate,ie=r.commitMount,ue=r.commitUpdate,oe=r.insertBefore,ae=r.insertInContainerBefore,le=r.removeChild,se=r.removeChildFromContainer,fe=r.resetTextContent,ce=r.hideInstance,de=r.hideTextInstance,pe=r.unhideInstance,he=r.unhideTextInstance,me=r.cloneInstance,ve=r.createContainerChildSet,_e=r.appendChildToContainerChildSet,be=r.finalizeContainerChildren,ge=r.replaceContainerChildren,ye=r.cloneHiddenInstance,De=r.cloneUnhiddenInstance,we=r.createHiddenTextInstance,Ee=r.canHydrateInstance,Te=r.canHydrateTextInstance,Ce=r.getNextHydratableSibling,ke=r.getFirstHydratableChild,Me=r.hydrateInstance,Se=r.hydrateTextInstance,Ae=/^(.*)[\\\/]/;function xe(e){var n="";do{e:switch(e.tag){case 3:case 4:case 6:case 7:case 10:case 9:var t="";break e;default:var r=e._debugOwner,i=e._debugSource,u=C(e.type);t=null,r&&(t=C(r.type)),r=u,u="",i?u=" (at "+i.fileName.replace(Ae,"")+":"+i.lineNumber+")":t&&(u=" (created by "+t+")"),t="\n    in "+(r||"Unknown")+u}n+=t,e=e.return}while(e);return n}new Set;var Pe=[],Re=-1;function Ne(e){0>Re||(e.current=Pe[Re],Pe[Re]=null,Re--)}function Fe(e,n){Re++,Pe[Re]=e.current,e.current=n}var Oe={},Le={current:Oe},Ie={current:!1},Be=Oe;function Ue(e,n){var t=e.type.contextTypes;if(!t)return Oe;var r=e.stateNode;if(r&&r.__reactInternalMemoizedUnmaskedChildContext===n)return r.__reactInternalMemoizedMaskedChildContext;var i,u={};for(i in t)u[i]=n[i];return r&&((e=e.stateNode).__reactInternalMemoizedUnmaskedChildContext=n,e.__reactInternalMemoizedMaskedChildContext=u),u}function je(e){return null!=(e=e.childContextTypes)}function We(e){Ne(Ie),Ne(Le)}function ze(e){Ne(Ie),Ne(Le)}function He(e,n,t){Le.current!==Oe&&l("168"),Fe(Le,n),Fe(Ie,t)}function Ge(e,n,t){var r=e.stateNode;if(e=n.childContextTypes,"function"!=typeof r.getChildContext)return t;for(var u in r=r.getChildContext())u in e||l("108",C(n)||"Unknown",u);return i({},t,r)}function Ye(e){var n=e.stateNode;return n=n&&n.__reactInternalMemoizedMergedChildContext||Oe,Be=Le.current,Fe(Le,n),Fe(Ie,Ie.current),!0}function qe(e,n,t){var r=e.stateNode;r||l("169"),t?(n=Ge(e,n,Be),r.__reactInternalMemoizedMergedChildContext=n,Ne(Ie),Ne(Le),Fe(Le,n)):Ne(Ie),Fe(Ie,t)}var Ve=null,$e=null;function Xe(e){return function(n){try{return e(n)}catch(e){}}}function Ke(e,n,t,r){this.tag=e,this.key=t,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.ref=null,this.pendingProps=n,this.contextDependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=r,this.effectTag=0,this.lastEffect=this.firstEffect=this.nextEffect=null,this.childExpirationTime=this.expirationTime=0,this.alternate=null}function Je(e,n,t,r){return new Ke(e,n,t,r)}function Qe(e){return!(!(e=e.prototype)||!e.isReactComponent)}function Ze(e,n){var t=e.alternate;return null===t?((t=Je(e.tag,n,e.key,e.mode)).elementType=e.elementType,t.type=e.type,t.stateNode=e.stateNode,t.alternate=e,e.alternate=t):(t.pendingProps=n,t.effectTag=0,t.nextEffect=null,t.firstEffect=null,t.lastEffect=null),t.childExpirationTime=e.childExpirationTime,t.expirationTime=e.expirationTime,t.child=e.child,t.memoizedProps=e.memoizedProps,t.memoizedState=e.memoizedState,t.updateQueue=e.updateQueue,t.contextDependencies=e.contextDependencies,t.sibling=e.sibling,t.index=e.index,t.ref=e.ref,t}function en(e,n,t,r,i,u){var o=2;if(r=e,"function"==typeof e)Qe(e)&&(o=1);else if("string"==typeof e)o=5;else e:switch(e){case p:return nn(t.children,i,u,n);case b:return tn(t,3|i,u,n);case h:return tn(t,2|i,u,n);case m:return(e=Je(12,t,n,4|i)).elementType=m,e.type=m,e.expirationTime=u,e;case y:return(e=Je(13,t,n,i)).elementType=y,e.type=y,e.expirationTime=u,e;default:if("object"==typeof e&&null!==e)switch(e.$$typeof){case v:o=10;break e;case _:o=9;break e;case g:o=11;break e;case D:o=14;break e;case w:o=16,r=null;break e}l("130",null==e?e:typeof e,"")}return(n=Je(o,t,n,i)).elementType=e,n.type=r,n.expirationTime=u,n}function nn(e,n,t,r){return(e=Je(7,e,r,n)).expirationTime=t,e}function tn(e,n,t,r){return e=Je(8,e,r,n),n=0==(1&n)?h:b,e.elementType=n,e.type=n,e.expirationTime=t,e}function rn(e,n,t){return(e=Je(6,e,null,n)).expirationTime=t,e}function un(e,n,t){return(n=Je(4,null!==e.children?e.children:[],e.key,n)).expirationTime=t,n.stateNode={containerInfo:e.containerInfo,pendingChildren:null,implementation:e.implementation},n}function on(e,n){e.didError=!1;var t=e.earliestPendingTime;0===t?e.earliestPendingTime=e.latestPendingTime=n:t<n?e.earliestPendingTime=n:e.latestPendingTime>n&&(e.latestPendingTime=n),sn(n,e)}function an(e,n){e.didError=!1,e.latestPingedTime>=n&&(e.latestPingedTime=0);var t=e.earliestPendingTime,r=e.latestPendingTime;t===n?e.earliestPendingTime=r===n?e.latestPendingTime=0:r:r===n&&(e.latestPendingTime=t),t=e.earliestSuspendedTime,r=e.latestSuspendedTime,0===t?e.earliestSuspendedTime=e.latestSuspendedTime=n:t<n?e.earliestSuspendedTime=n:r>n&&(e.latestSuspendedTime=n),sn(n,e)}function ln(e,n){var t=e.earliestPendingTime;return t>n&&(n=t),(e=e.earliestSuspendedTime)>n&&(n=e),n}function sn(e,n){var t=n.earliestSuspendedTime,r=n.latestSuspendedTime,i=n.earliestPendingTime,u=n.latestPingedTime;0===(i=0!==i?i:u)&&(0===e||r<e)&&(i=r),0!==(e=i)&&t>e&&(e=t),n.nextExpirationTimeToWorkOn=i,n.expirationTime=e}function fn(e,n){return e===n&&(0!==e||1/e==1/n)||e!=e&&n!=n}var cn=Object.prototype.hasOwnProperty;function dn(e,n){if(fn(e,n))return!0;if("object"!=typeof e||null===e||"object"!=typeof n||null===n)return!1;var t=Object.keys(e),r=Object.keys(n);if(t.length!==r.length)return!1;for(r=0;r<t.length;r++)if(!cn.call(n,t[r])||!fn(e[t[r]],n[t[r]]))return!1;return!0}function pn(e,n){if(e&&e.defaultProps)for(var t in n=i({},n),e=e.defaultProps)void 0===n[t]&&(n[t]=e[t]);return n}var hn=(new u.Component).refs;function mn(e,n,t,r){t=null==(t=t(r,n=e.memoizedState))?n:i({},n,t),e.memoizedState=t,null!==(r=e.updateQueue)&&0===e.expirationTime&&(r.baseState=t)}var vn={isMounted:function(e){return!!(e=e._reactInternalFiber)&&2===k(e)},enqueueSetState:function(e,n,t){e=e._reactInternalFiber;var r=Mi(),i=Kt(r=Qr(r,e));i.payload=n,null!=t&&(i.callback=t),qr(),Qt(e,i),ti(e,r)},enqueueReplaceState:function(e,n,t){e=e._reactInternalFiber;var r=Mi(),i=Kt(r=Qr(r,e));i.tag=Yt,i.payload=n,null!=t&&(i.callback=t),qr(),Qt(e,i),ti(e,r)},enqueueForceUpdate:function(e,n){e=e._reactInternalFiber;var t=Mi(),r=Kt(t=Qr(t,e));r.tag=qt,null!=n&&(r.callback=n),qr(),Qt(e,r),ti(e,t)}};function _n(e,n,t,r,i,u,o){return"function"==typeof(e=e.stateNode).shouldComponentUpdate?e.shouldComponentUpdate(r,u,o):!n.prototype||!n.prototype.isPureReactComponent||(!dn(t,r)||!dn(i,u))}function bn(e,n,t){var r=!1,i=Oe,u=n.contextType;return"object"==typeof u&&null!==u?u=Gt(u):(i=je(n)?Be:Le.current,u=(r=null!=(r=n.contextTypes))?Ue(e,i):Oe),n=new n(t,u),e.memoizedState=null!==n.state&&void 0!==n.state?n.state:null,n.updater=vn,e.stateNode=n,n._reactInternalFiber=e,r&&((e=e.stateNode).__reactInternalMemoizedUnmaskedChildContext=i,e.__reactInternalMemoizedMaskedChildContext=u),n}function gn(e,n,t,r){e=n.state,"function"==typeof n.componentWillReceiveProps&&n.componentWillReceiveProps(t,r),"function"==typeof n.UNSAFE_componentWillReceiveProps&&n.UNSAFE_componentWillReceiveProps(t,r),n.state!==e&&vn.enqueueReplaceState(n,n.state,null)}function yn(e,n,t,r){var i=e.stateNode;i.props=t,i.state=e.memoizedState,i.refs=hn;var u=n.contextType;"object"==typeof u&&null!==u?i.context=Gt(u):(u=je(n)?Be:Le.current,i.context=Ue(e,u)),null!==(u=e.updateQueue)&&(tr(e,u,t,i,r),i.state=e.memoizedState),"function"==typeof(u=n.getDerivedStateFromProps)&&(mn(e,n,u,t),i.state=e.memoizedState),"function"==typeof n.getDerivedStateFromProps||"function"==typeof i.getSnapshotBeforeUpdate||"function"!=typeof i.UNSAFE_componentWillMount&&"function"!=typeof i.componentWillMount||(n=i.state,"function"==typeof i.componentWillMount&&i.componentWillMount(),"function"==typeof i.UNSAFE_componentWillMount&&i.UNSAFE_componentWillMount(),n!==i.state&&vn.enqueueReplaceState(i,i.state,null),null!==(u=e.updateQueue)&&(tr(e,u,t,i,r),i.state=e.memoizedState)),"function"==typeof i.componentDidMount&&(e.effectTag|=4)}var Dn=Array.isArray;function wn(e,n,t){if(null!==(e=t.ref)&&"function"!=typeof e&&"object"!=typeof e){if(t._owner){t=t._owner;var r=void 0;t&&(1!==t.tag&&l("309"),r=t.stateNode),r||l("147",e);var i=""+e;return null!==n&&null!==n.ref&&"function"==typeof n.ref&&n.ref._stringRef===i?n.ref:((n=function(e){var n=r.refs;n===hn&&(n=r.refs={}),null===e?delete n[i]:n[i]=e})._stringRef=i,n)}"string"!=typeof e&&l("284"),t._owner||l("290",e)}return e}function En(e,n){"textarea"!==e.type&&l("31","[object Object]"===Object.prototype.toString.call(n)?"object with keys {"+Object.keys(n).join(", ")+"}":n,"")}function Tn(e){function n(n,t){if(e){var r=n.lastEffect;null!==r?(r.nextEffect=t,n.lastEffect=t):n.firstEffect=n.lastEffect=t,t.nextEffect=null,t.effectTag=8}}function t(t,r){if(!e)return null;for(;null!==r;)n(t,r),r=r.sibling;return null}function r(e,n){for(e=new Map;null!==n;)null!==n.key?e.set(n.key,n):e.set(n.index,n),n=n.sibling;return e}function i(e,n,t){return(e=Ze(e,n)).index=0,e.sibling=null,e}function u(n,t,r){return n.index=r,e?null!==(r=n.alternate)?(r=r.index)<t?(n.effectTag=2,t):r:(n.effectTag=2,t):t}function o(n){return e&&null===n.alternate&&(n.effectTag=2),n}function a(e,n,t,r){return null===n||6!==n.tag?((n=rn(t,e.mode,r)).return=e,n):((n=i(n,t)).return=e,n)}function s(e,n,t,r){return null!==n&&n.elementType===t.type?((r=i(n,t.props)).ref=wn(e,n,t),r.return=e,r):((r=en(t.type,t.key,t.props,null,e.mode,r)).ref=wn(e,n,t),r.return=e,r)}function f(e,n,t,r){return null===n||4!==n.tag||n.stateNode.containerInfo!==t.containerInfo||n.stateNode.implementation!==t.implementation?((n=un(t,e.mode,r)).return=e,n):((n=i(n,t.children||[])).return=e,n)}function h(e,n,t,r,u){return null===n||7!==n.tag?((n=nn(t,e.mode,r,u)).return=e,n):((n=i(n,t)).return=e,n)}function m(e,n,t){if("string"==typeof n||"number"==typeof n)return(n=rn(""+n,e.mode,t)).return=e,n;if("object"==typeof n&&null!==n){switch(n.$$typeof){case c:return(t=en(n.type,n.key,n.props,null,e.mode,t)).ref=wn(e,null,n),t.return=e,t;case d:return(n=un(n,e.mode,t)).return=e,n}if(Dn(n)||T(n))return(n=nn(n,e.mode,t,null)).return=e,n;En(e,n)}return null}function v(e,n,t,r){var i=null!==n?n.key:null;if("string"==typeof t||"number"==typeof t)return null!==i?null:a(e,n,""+t,r);if("object"==typeof t&&null!==t){switch(t.$$typeof){case c:return t.key===i?t.type===p?h(e,n,t.props.children,r,i):s(e,n,t,r):null;case d:return t.key===i?f(e,n,t,r):null}if(Dn(t)||T(t))return null!==i?null:h(e,n,t,r,null);En(e,t)}return null}function _(e,n,t,r,i){if("string"==typeof r||"number"==typeof r)return a(n,e=e.get(t)||null,""+r,i);if("object"==typeof r&&null!==r){switch(r.$$typeof){case c:return e=e.get(null===r.key?t:r.key)||null,r.type===p?h(n,e,r.props.children,i,r.key):s(n,e,r,i);case d:return f(n,e=e.get(null===r.key?t:r.key)||null,r,i)}if(Dn(r)||T(r))return h(n,e=e.get(t)||null,r,i,null);En(n,r)}return null}function b(i,o,a,l){for(var s=null,f=null,c=o,d=o=0,p=null;null!==c&&d<a.length;d++){c.index>d?(p=c,c=null):p=c.sibling;var h=v(i,c,a[d],l);if(null===h){null===c&&(c=p);break}e&&c&&null===h.alternate&&n(i,c),o=u(h,o,d),null===f?s=h:f.sibling=h,f=h,c=p}if(d===a.length)return t(i,c),s;if(null===c){for(;d<a.length;d++)(c=m(i,a[d],l))&&(o=u(c,o,d),null===f?s=c:f.sibling=c,f=c);return s}for(c=r(i,c);d<a.length;d++)(p=_(c,i,d,a[d],l))&&(e&&null!==p.alternate&&c.delete(null===p.key?d:p.key),o=u(p,o,d),null===f?s=p:f.sibling=p,f=p);return e&&c.forEach((function(e){return n(i,e)})),s}function g(i,o,a,s){var f=T(a);"function"!=typeof f&&l("150"),null==(a=f.call(a))&&l("151");for(var c=f=null,d=o,p=o=0,h=null,b=a.next();null!==d&&!b.done;p++,b=a.next()){d.index>p?(h=d,d=null):h=d.sibling;var g=v(i,d,b.value,s);if(null===g){d||(d=h);break}e&&d&&null===g.alternate&&n(i,d),o=u(g,o,p),null===c?f=g:c.sibling=g,c=g,d=h}if(b.done)return t(i,d),f;if(null===d){for(;!b.done;p++,b=a.next())null!==(b=m(i,b.value,s))&&(o=u(b,o,p),null===c?f=b:c.sibling=b,c=b);return f}for(d=r(i,d);!b.done;p++,b=a.next())null!==(b=_(d,i,p,b.value,s))&&(e&&null!==b.alternate&&d.delete(null===b.key?p:b.key),o=u(b,o,p),null===c?f=b:c.sibling=b,c=b);return e&&d.forEach((function(e){return n(i,e)})),f}return function(e,r,u,a){var s="object"==typeof u&&null!==u&&u.type===p&&null===u.key;s&&(u=u.props.children);var f="object"==typeof u&&null!==u;if(f)switch(u.$$typeof){case c:e:{for(f=u.key,s=r;null!==s;){if(s.key===f){if(7===s.tag?u.type===p:s.elementType===u.type){t(e,s.sibling),(r=i(s,u.type===p?u.props.children:u.props)).ref=wn(e,s,u),r.return=e,e=r;break e}t(e,s);break}n(e,s),s=s.sibling}u.type===p?((r=nn(u.props.children,e.mode,a,u.key)).return=e,e=r):((a=en(u.type,u.key,u.props,null,e.mode,a)).ref=wn(e,r,u),a.return=e,e=a)}return o(e);case d:e:{for(s=u.key;null!==r;){if(r.key===s){if(4===r.tag&&r.stateNode.containerInfo===u.containerInfo&&r.stateNode.implementation===u.implementation){t(e,r.sibling),(r=i(r,u.children||[])).return=e,e=r;break e}t(e,r);break}n(e,r),r=r.sibling}(r=un(u,e.mode,a)).return=e,e=r}return o(e)}if("string"==typeof u||"number"==typeof u)return u=""+u,null!==r&&6===r.tag?(t(e,r.sibling),(r=i(r,u)).return=e,e=r):(t(e,r),(r=rn(u,e.mode,a)).return=e,e=r),o(e);if(Dn(u))return b(e,r,u,a);if(T(u))return g(e,r,u,a);if(f&&En(e,u),void 0===u&&!s)switch(e.tag){case 1:case 0:l("152",(a=e.type).displayName||a.name||"Component")}return t(e,r)}}var Cn=Tn(!0),kn=Tn(!1),Mn={},Sn={current:Mn},An={current:Mn},xn={current:Mn};function Pn(e){return e===Mn&&l("174"),e}function Rn(e,n){Fe(xn,n),Fe(An,e),Fe(Sn,Mn),n=P(n),Ne(Sn),Fe(Sn,n)}function Nn(e){Ne(Sn),Ne(An),Ne(xn)}function Fn(){return Pn(Sn.current)}function On(e){var n=Pn(xn.current),t=Pn(Sn.current);t!==(n=R(t,e.type,n))&&(Fe(An,e),Fe(Sn,n))}function Ln(e){An.current===e&&(Ne(Sn),Ne(An))}var In=s.ReactCurrentDispatcher,Bn=0,Un=null,jn=null,Wn=null,zn=null,Hn=null,Gn=null,Yn=0,qn=null,Vn=0,$n=!1,Xn=null,Kn=0;function Jn(){l("321")}function Qn(e,n){if(null===n)return!1;for(var t=0;t<n.length&&t<e.length;t++)if(!fn(e[t],n[t]))return!1;return!0}function Zn(e,n,t,r,i,u){if(Bn=u,Un=n,Wn=null!==e?e.memoizedState:null,In.current=null===Wn?dt:pt,n=t(r,i),$n){do{$n=!1,Kn+=1,Wn=null!==e?e.memoizedState:null,Gn=zn,qn=Hn=jn=null,In.current=pt,n=t(r,i)}while($n);Xn=null,Kn=0}return In.current=ct,(e=Un).memoizedState=zn,e.expirationTime=Yn,e.updateQueue=qn,e.effectTag|=Vn,e=null!==jn&&null!==jn.next,Bn=0,Gn=Hn=zn=Wn=jn=Un=null,Yn=0,qn=null,Vn=0,e&&l("300"),n}function et(){In.current=ct,Bn=0,Gn=Hn=zn=Wn=jn=Un=null,Yn=0,qn=null,Vn=0,$n=!1,Xn=null,Kn=0}function nt(){var e={memoizedState:null,baseState:null,queue:null,baseUpdate:null,next:null};return null===Hn?zn=Hn=e:Hn=Hn.next=e,Hn}function tt(){if(null!==Gn)Gn=(Hn=Gn).next,Wn=null!==(jn=Wn)?jn.next:null;else{null===Wn&&l("310");var e={memoizedState:(jn=Wn).memoizedState,baseState:jn.baseState,queue:jn.queue,baseUpdate:jn.baseUpdate,next:null};Hn=null===Hn?zn=e:Hn.next=e,Wn=jn.next}return Hn}function rt(e,n){return"function"==typeof n?n(e):n}function it(e){var n=tt(),t=n.queue;if(null===t&&l("311"),t.lastRenderedReducer=e,0<Kn){var r=t.dispatch;if(null!==Xn){var i=Xn.get(t);if(void 0!==i){Xn.delete(t);var u=n.memoizedState;do{u=e(u,i.action),i=i.next}while(null!==i);return fn(u,n.memoizedState)||(Tt=!0),n.memoizedState=u,n.baseUpdate===t.last&&(n.baseState=u),t.lastRenderedState=u,[u,r]}}return[n.memoizedState,r]}r=t.last;var o=n.baseUpdate;if(u=n.baseState,null!==o?(null!==r&&(r.next=null),r=o.next):r=null!==r?r.next:null,null!==r){var a=i=null,s=r,f=!1;do{var c=s.expirationTime;c<Bn?(f||(f=!0,a=o,i=u),c>Yn&&(Yn=c)):u=s.eagerReducer===e?s.eagerState:e(u,s.action),o=s,s=s.next}while(null!==s&&s!==r);f||(a=o,i=u),fn(u,n.memoizedState)||(Tt=!0),n.memoizedState=u,n.baseUpdate=a,n.baseState=i,t.lastRenderedState=u}return[n.memoizedState,t.dispatch]}function ut(e,n,t,r){return e={tag:e,create:n,destroy:t,deps:r,next:null},null===qn?(qn={lastEffect:null}).lastEffect=e.next=e:null===(n=qn.lastEffect)?qn.lastEffect=e.next=e:(t=n.next,n.next=e,e.next=t,qn.lastEffect=e),e}function ot(e,n,t,r){var i=nt();Vn|=e,i.memoizedState=ut(n,t,void 0,void 0===r?null:r)}function at(e,n,t,r){var i=tt();r=void 0===r?null:r;var u=void 0;if(null!==jn){var o=jn.memoizedState;if(u=o.destroy,null!==r&&Qn(r,o.deps))return void ut(0,t,u,r)}Vn|=e,i.memoizedState=ut(n,t,u,r)}function lt(e,n){return"function"==typeof n?(e=e(),n(e),function(){n(null)}):null!=n?(e=e(),n.current=e,function(){n.current=null}):void 0}function st(){}function ft(e,n,t){25>Kn||l("301");var r=e.alternate;if(e===Un||null!==r&&r===Un)if($n=!0,e={expirationTime:Bn,action:t,eagerReducer:null,eagerState:null,next:null},null===Xn&&(Xn=new Map),void 0===(t=Xn.get(n)))Xn.set(n,e);else{for(n=t;null!==n.next;)n=n.next;n.next=e}else{qr();var i=Mi(),u={expirationTime:i=Qr(i,e),action:t,eagerReducer:null,eagerState:null,next:null},o=n.last;if(null===o)u.next=u;else{var a=o.next;null!==a&&(u.next=a),o.next=u}if(n.last=u,0===e.expirationTime&&(null===r||0===r.expirationTime)&&null!==(r=n.lastRenderedReducer))try{var s=n.lastRenderedState,f=r(s,t);if(u.eagerReducer=r,u.eagerState=f,fn(f,s))return}catch(e){}ti(e,i)}}var ct={readContext:Gt,useCallback:Jn,useContext:Jn,useEffect:Jn,useImperativeHandle:Jn,useLayoutEffect:Jn,useMemo:Jn,useReducer:Jn,useRef:Jn,useState:Jn,useDebugValue:Jn},dt={readContext:Gt,useCallback:function(e,n){return nt().memoizedState=[e,void 0===n?null:n],e},useContext:Gt,useEffect:function(e,n){return ot(516,192,e,n)},useImperativeHandle:function(e,n,t){return t=null!=t?t.concat([e]):null,ot(4,36,lt.bind(null,n,e),t)},useLayoutEffect:function(e,n){return ot(4,36,e,n)},useMemo:function(e,n){var t=nt();return n=void 0===n?null:n,e=e(),t.memoizedState=[e,n],e},useReducer:function(e,n,t){var r=nt();return n=void 0!==t?t(n):n,r.memoizedState=r.baseState=n,e=(e=r.queue={last:null,dispatch:null,lastRenderedReducer:e,lastRenderedState:n}).dispatch=ft.bind(null,Un,e),[r.memoizedState,e]},useRef:function(e){return e={current:e},nt().memoizedState=e},useState:function(e){var n=nt();return"function"==typeof e&&(e=e()),n.memoizedState=n.baseState=e,e=(e=n.queue={last:null,dispatch:null,lastRenderedReducer:rt,lastRenderedState:e}).dispatch=ft.bind(null,Un,e),[n.memoizedState,e]},useDebugValue:st},pt={readContext:Gt,useCallback:function(e,n){var t=tt();n=void 0===n?null:n;var r=t.memoizedState;return null!==r&&null!==n&&Qn(n,r[1])?r[0]:(t.memoizedState=[e,n],e)},useContext:Gt,useEffect:function(e,n){return at(516,192,e,n)},useImperativeHandle:function(e,n,t){return t=null!=t?t.concat([e]):null,at(4,36,lt.bind(null,n,e),t)},useLayoutEffect:function(e,n){return at(4,36,e,n)},useMemo:function(e,n){var t=tt();n=void 0===n?null:n;var r=t.memoizedState;return null!==r&&null!==n&&Qn(n,r[1])?r[0]:(e=e(),t.memoizedState=[e,n],e)},useReducer:it,useRef:function(){return tt().memoizedState},useState:function(e){return it(rt)},useDebugValue:st},ht=null,mt=null,vt=!1;function _t(e,n){var t=Je(5,null,null,0);t.elementType="DELETED",t.type="DELETED",t.stateNode=n,t.return=e,t.effectTag=8,null!==e.lastEffect?(e.lastEffect.nextEffect=t,e.lastEffect=t):e.firstEffect=e.lastEffect=t}function bt(e,n){switch(e.tag){case 5:return null!==(n=Ee(n,e.type,e.pendingProps))&&(e.stateNode=n,!0);case 6:return null!==(n=Te(n,e.pendingProps))&&(e.stateNode=n,!0);case 13:default:return!1}}function gt(e){if(vt){var n=mt;if(n){var t=n;if(!bt(e,n)){if(!(n=Ce(t))||!bt(e,n))return e.effectTag|=2,vt=!1,void(ht=e);_t(ht,t)}ht=e,mt=ke(n)}else e.effectTag|=2,vt=!1,ht=e}}function yt(e){for(e=e.return;null!==e&&5!==e.tag&&3!==e.tag&&18!==e.tag;)e=e.return;ht=e}function Dt(e){if(!ee||e!==ht)return!1;if(!vt)return yt(e),vt=!0,!1;var n=e.type;if(5!==e.tag||"head"!==n&&"body"!==n&&!U(n,e.memoizedProps))for(n=mt;n;)_t(e,n),n=Ce(n);return yt(e),mt=ht?Ce(e.stateNode):null,!0}function wt(){ee&&(mt=ht=null,vt=!1)}var Et=s.ReactCurrentOwner,Tt=!1;function Ct(e,n,t,r){n.child=null===e?kn(n,null,t,r):Cn(n,e.child,t,r)}function kt(e,n,t,r,i){t=t.render;var u=n.ref;return Ht(n,i),r=Zn(e,n,t,r,u,i),null===e||Tt?(n.effectTag|=1,Ct(e,n,r,i),n.child):(n.updateQueue=e.updateQueue,n.effectTag&=-517,e.expirationTime<=i&&(e.expirationTime=0),Ot(e,n,i))}function Mt(e,n,t,r,i,u){if(null===e){var o=t.type;return"function"!=typeof o||Qe(o)||void 0!==o.defaultProps||null!==t.compare||void 0!==t.defaultProps?((e=en(t.type,null,r,null,n.mode,u)).ref=n.ref,e.return=n,n.child=e):(n.tag=15,n.type=o,St(e,n,o,r,i,u))}return o=e.child,i<u&&(i=o.memoizedProps,(t=null!==(t=t.compare)?t:dn)(i,r)&&e.ref===n.ref)?Ot(e,n,u):(n.effectTag|=1,(e=Ze(o,r)).ref=n.ref,e.return=n,n.child=e)}function St(e,n,t,r,i,u){return null!==e&&dn(e.memoizedProps,r)&&e.ref===n.ref&&(Tt=!1,i<u)?Ot(e,n,u):xt(e,n,t,r,u)}function At(e,n){var t=n.ref;(null===e&&null!==t||null!==e&&e.ref!==t)&&(n.effectTag|=128)}function xt(e,n,t,r,i){var u=je(t)?Be:Le.current;return u=Ue(n,u),Ht(n,i),t=Zn(e,n,t,r,u,i),null===e||Tt?(n.effectTag|=1,Ct(e,n,t,i),n.child):(n.updateQueue=e.updateQueue,n.effectTag&=-517,e.expirationTime<=i&&(e.expirationTime=0),Ot(e,n,i))}function Pt(e,n,t,r,i){if(je(t)){var u=!0;Ye(n)}else u=!1;if(Ht(n,i),null===n.stateNode)null!==e&&(e.alternate=null,n.alternate=null,n.effectTag|=2),bn(n,t,r),yn(n,t,r,i),r=!0;else if(null===e){var o=n.stateNode,a=n.memoizedProps;o.props=a;var l=o.context,s=t.contextType;"object"==typeof s&&null!==s?s=Gt(s):s=Ue(n,s=je(t)?Be:Le.current);var f=t.getDerivedStateFromProps,c="function"==typeof f||"function"==typeof o.getSnapshotBeforeUpdate;c||"function"!=typeof o.UNSAFE_componentWillReceiveProps&&"function"!=typeof o.componentWillReceiveProps||(a!==r||l!==s)&&gn(n,o,r,s),Vt=!1;var d=n.memoizedState;l=o.state=d;var p=n.updateQueue;null!==p&&(tr(n,p,r,o,i),l=n.memoizedState),a!==r||d!==l||Ie.current||Vt?("function"==typeof f&&(mn(n,t,f,r),l=n.memoizedState),(a=Vt||_n(n,t,a,r,d,l,s))?(c||"function"!=typeof o.UNSAFE_componentWillMount&&"function"!=typeof o.componentWillMount||("function"==typeof o.componentWillMount&&o.componentWillMount(),"function"==typeof o.UNSAFE_componentWillMount&&o.UNSAFE_componentWillMount()),"function"==typeof o.componentDidMount&&(n.effectTag|=4)):("function"==typeof o.componentDidMount&&(n.effectTag|=4),n.memoizedProps=r,n.memoizedState=l),o.props=r,o.state=l,o.context=s,r=a):("function"==typeof o.componentDidMount&&(n.effectTag|=4),r=!1)}else o=n.stateNode,a=n.memoizedProps,o.props=n.type===n.elementType?a:pn(n.type,a),l=o.context,"object"==typeof(s=t.contextType)&&null!==s?s=Gt(s):s=Ue(n,s=je(t)?Be:Le.current),(c="function"==typeof(f=t.getDerivedStateFromProps)||"function"==typeof o.getSnapshotBeforeUpdate)||"function"!=typeof o.UNSAFE_componentWillReceiveProps&&"function"!=typeof o.componentWillReceiveProps||(a!==r||l!==s)&&gn(n,o,r,s),Vt=!1,l=n.memoizedState,d=o.state=l,null!==(p=n.updateQueue)&&(tr(n,p,r,o,i),d=n.memoizedState),a!==r||l!==d||Ie.current||Vt?("function"==typeof f&&(mn(n,t,f,r),d=n.memoizedState),(f=Vt||_n(n,t,a,r,l,d,s))?(c||"function"!=typeof o.UNSAFE_componentWillUpdate&&"function"!=typeof o.componentWillUpdate||("function"==typeof o.componentWillUpdate&&o.componentWillUpdate(r,d,s),"function"==typeof o.UNSAFE_componentWillUpdate&&o.UNSAFE_componentWillUpdate(r,d,s)),"function"==typeof o.componentDidUpdate&&(n.effectTag|=4),"function"==typeof o.getSnapshotBeforeUpdate&&(n.effectTag|=256)):("function"!=typeof o.componentDidUpdate||a===e.memoizedProps&&l===e.memoizedState||(n.effectTag|=4),"function"!=typeof o.getSnapshotBeforeUpdate||a===e.memoizedProps&&l===e.memoizedState||(n.effectTag|=256),n.memoizedProps=r,n.memoizedState=d),o.props=r,o.state=d,o.context=s,r=f):("function"!=typeof o.componentDidUpdate||a===e.memoizedProps&&l===e.memoizedState||(n.effectTag|=4),"function"!=typeof o.getSnapshotBeforeUpdate||a===e.memoizedProps&&l===e.memoizedState||(n.effectTag|=256),r=!1);return Rt(e,n,t,r,u,i)}function Rt(e,n,t,r,i,u){At(e,n);var o=0!=(64&n.effectTag);if(!r&&!o)return i&&qe(n,t,!1),Ot(e,n,u);r=n.stateNode,Et.current=n;var a=o&&"function"!=typeof t.getDerivedStateFromError?null:r.render();return n.effectTag|=1,null!==e&&o?(n.child=Cn(n,e.child,null,u),n.child=Cn(n,null,a,u)):Ct(e,n,a,u),n.memoizedState=r.state,i&&qe(n,t,!0),n.child}function Nt(e){var n=e.stateNode;n.pendingContext?He(0,n.pendingContext,n.pendingContext!==n.context):n.context&&He(0,n.context,!1),Rn(e,n.containerInfo)}function Ft(e,n,t){var r=n.mode,i=n.pendingProps,u=n.memoizedState;if(0==(64&n.effectTag)){u=null;var o=!1}else u={timedOutAt:null!==u?u.timedOutAt:0},o=!0,n.effectTag&=-65;if(null===e)if(o){var a=i.fallback;e=nn(null,r,0,null),0==(1&n.mode)&&(e.child=null!==n.memoizedState?n.child.child:n.child),r=nn(a,r,t,null),e.sibling=r,(t=e).return=r.return=n}else t=r=kn(n,null,i.children,t);else null!==e.memoizedState?(a=(r=e.child).sibling,o?(t=i.fallback,i=Ze(r,r.pendingProps),0==(1&n.mode)&&((o=null!==n.memoizedState?n.child.child:n.child)!==r.child&&(i.child=o)),r=i.sibling=Ze(a,t,a.expirationTime),t=i,i.childExpirationTime=0,t.return=r.return=n):t=r=Cn(n,r.child,i.children,t)):(a=e.child,o?(o=i.fallback,(i=nn(null,r,0,null)).child=a,0==(1&n.mode)&&(i.child=null!==n.memoizedState?n.child.child:n.child),(r=i.sibling=nn(o,r,t,null)).effectTag|=2,t=i,i.childExpirationTime=0,t.return=r.return=n):r=t=Cn(n,a,i.children,t)),n.stateNode=e.stateNode;return n.memoizedState=u,n.child=t,r}function Ot(e,n,t){if(null!==e&&(n.contextDependencies=e.contextDependencies),n.childExpirationTime<t)return null;if(null!==e&&n.child!==e.child&&l("153"),null!==n.child){for(t=Ze(e=n.child,e.pendingProps,e.expirationTime),n.child=t,t.return=n;null!==e.sibling;)e=e.sibling,(t=t.sibling=Ze(e,e.pendingProps,e.expirationTime)).return=n;t.sibling=null}return n.child}function Lt(e,n,t){var r=n.expirationTime;if(null!==e){if(e.memoizedProps!==n.pendingProps||Ie.current)Tt=!0;else if(r<t){switch(Tt=!1,n.tag){case 3:Nt(n),wt();break;case 5:On(n);break;case 1:je(n.type)&&Ye(n);break;case 4:Rn(n,n.stateNode.containerInfo);break;case 10:Wt(n,n.memoizedProps.value);break;case 13:if(null!==n.memoizedState)return 0!==(r=n.child.childExpirationTime)&&r>=t?Ft(e,n,t):null!==(n=Ot(e,n,t))?n.sibling:null}return Ot(e,n,t)}}else Tt=!1;switch(n.expirationTime=0,n.tag){case 2:r=n.elementType,null!==e&&(e.alternate=null,n.alternate=null,n.effectTag|=2),e=n.pendingProps;var i=Ue(n,Le.current);if(Ht(n,t),i=Zn(null,n,r,e,i,t),n.effectTag|=1,"object"==typeof i&&null!==i&&"function"==typeof i.render&&void 0===i.$$typeof){if(n.tag=1,et(),je(r)){var u=!0;Ye(n)}else u=!1;n.memoizedState=null!==i.state&&void 0!==i.state?i.state:null;var o=r.getDerivedStateFromProps;"function"==typeof o&&mn(n,r,o,e),i.updater=vn,n.stateNode=i,i._reactInternalFiber=n,yn(n,r,e,t),n=Rt(null,n,r,!0,u,t)}else n.tag=0,Ct(null,n,i,t),n=n.child;return n;case 16:switch(i=n.elementType,null!==e&&(e.alternate=null,n.alternate=null,n.effectTag|=2),u=n.pendingProps,e=function(e){var n=e._result;switch(e._status){case 1:return n;case 2:case 0:throw n;default:switch(e._status=0,(n=(n=e._ctor)()).then((function(n){0===e._status&&(n=n.default,e._status=1,e._result=n)}),(function(n){0===e._status&&(e._status=2,e._result=n)})),e._status){case 1:return e._result;case 2:throw e._result}throw e._result=n,n}}(i),n.type=e,i=n.tag=function(e){if("function"==typeof e)return Qe(e)?1:0;if(null!=e){if((e=e.$$typeof)===g)return 11;if(e===D)return 14}return 2}(e),u=pn(e,u),o=void 0,i){case 0:o=xt(null,n,e,u,t);break;case 1:o=Pt(null,n,e,u,t);break;case 11:o=kt(null,n,e,u,t);break;case 14:o=Mt(null,n,e,pn(e.type,u),r,t);break;default:l("306",e,"")}return o;case 0:return r=n.type,i=n.pendingProps,xt(e,n,r,i=n.elementType===r?i:pn(r,i),t);case 1:return r=n.type,i=n.pendingProps,Pt(e,n,r,i=n.elementType===r?i:pn(r,i),t);case 3:return Nt(n),null===(r=n.updateQueue)&&l("282"),i=null!==(i=n.memoizedState)?i.element:null,tr(n,r,n.pendingProps,null,t),(r=n.memoizedState.element)===i?(wt(),n=Ot(e,n,t)):(i=n.stateNode,(i=(null===e||null===e.child)&&i.hydrate)&&(ee?(mt=ke(n.stateNode.containerInfo),ht=n,i=vt=!0):i=!1),i?(n.effectTag|=2,n.child=kn(n,null,r,t)):(Ct(e,n,r,t),wt()),n=n.child),n;case 5:return On(n),null===e&&gt(n),r=n.type,i=n.pendingProps,u=null!==e?e.memoizedProps:null,o=i.children,U(r,i)?o=null:null!==u&&U(r,u)&&(n.effectTag|=16),At(e,n),1!==t&&1&n.mode&&j(r,i)?(n.expirationTime=n.childExpirationTime=1,n=null):(Ct(e,n,o,t),n=n.child),n;case 6:return null===e&&gt(n),null;case 13:return Ft(e,n,t);case 4:return Rn(n,n.stateNode.containerInfo),r=n.pendingProps,null===e?n.child=Cn(n,null,r,t):Ct(e,n,r,t),n.child;case 11:return r=n.type,i=n.pendingProps,kt(e,n,r,i=n.elementType===r?i:pn(r,i),t);case 7:return Ct(e,n,n.pendingProps,t),n.child;case 8:case 12:return Ct(e,n,n.pendingProps.children,t),n.child;case 10:e:{if(r=n.type._context,i=n.pendingProps,o=n.memoizedProps,Wt(n,u=i.value),null!==o){var a=o.value;if(0===(u=fn(a,u)?0:0|("function"==typeof r._calculateChangedBits?r._calculateChangedBits(a,u):1073741823))){if(o.children===i.children&&!Ie.current){n=Ot(e,n,t);break e}}else for(null!==(a=n.child)&&(a.return=n);null!==a;){var s=a.contextDependencies;if(null!==s){o=a.child;for(var f=s.first;null!==f;){if(f.context===r&&0!=(f.observedBits&u)){1===a.tag&&((f=Kt(t)).tag=qt,Qt(a,f)),a.expirationTime<t&&(a.expirationTime=t),null!==(f=a.alternate)&&f.expirationTime<t&&(f.expirationTime=t),f=t;for(var c=a.return;null!==c;){var d=c.alternate;if(c.childExpirationTime<f)c.childExpirationTime=f,null!==d&&d.childExpirationTime<f&&(d.childExpirationTime=f);else{if(!(null!==d&&d.childExpirationTime<f))break;d.childExpirationTime=f}c=c.return}s.expirationTime<t&&(s.expirationTime=t);break}f=f.next}}else o=10===a.tag&&a.type===n.type?null:a.child;if(null!==o)o.return=a;else for(o=a;null!==o;){if(o===n){o=null;break}if(null!==(a=o.sibling)){a.return=o.return,o=a;break}o=o.return}a=o}}Ct(e,n,i.children,t),n=n.child}return n;case 9:return i=n.type,r=(u=n.pendingProps).children,Ht(n,t),r=r(i=Gt(i,u.unstable_observedBits)),n.effectTag|=1,Ct(e,n,r,t),n.child;case 14:return u=pn(i=n.type,n.pendingProps),Mt(e,n,i,u=pn(i.type,u),r,t);case 15:return St(e,n,n.type,n.pendingProps,r,t);case 17:return r=n.type,i=n.pendingProps,i=n.elementType===r?i:pn(r,i),null!==e&&(e.alternate=null,n.alternate=null,n.effectTag|=2),n.tag=1,je(r)?(e=!0,Ye(n)):e=!1,Ht(n,t),bn(n,r,i),yn(n,r,i,t),Rt(null,n,r,!0,e,t)}l("156")}var It={current:null},Bt=null,Ut=null,jt=null;function Wt(e,n){var t=e.type._context;J?(Fe(It,t._currentValue),t._currentValue=n):(Fe(It,t._currentValue2),t._currentValue2=n)}function zt(e){var n=It.current;Ne(It),e=e.type._context,J?e._currentValue=n:e._currentValue2=n}function Ht(e,n){Bt=e,jt=Ut=null;var t=e.contextDependencies;null!==t&&t.expirationTime>=n&&(Tt=!0),e.contextDependencies=null}function Gt(e,n){return jt!==e&&!1!==n&&0!==n&&("number"==typeof n&&1073741823!==n||(jt=e,n=1073741823),n={context:e,observedBits:n,next:null},null===Ut?(null===Bt&&l("308"),Ut=n,Bt.contextDependencies={first:n,expirationTime:0}):Ut=Ut.next=n),J?e._currentValue:e._currentValue2}var Yt=1,qt=2,Vt=!1;function $t(e){return{baseState:e,firstUpdate:null,lastUpdate:null,firstCapturedUpdate:null,lastCapturedUpdate:null,firstEffect:null,lastEffect:null,firstCapturedEffect:null,lastCapturedEffect:null}}function Xt(e){return{baseState:e.baseState,firstUpdate:e.firstUpdate,lastUpdate:e.lastUpdate,firstCapturedUpdate:null,lastCapturedUpdate:null,firstEffect:null,lastEffect:null,firstCapturedEffect:null,lastCapturedEffect:null}}function Kt(e){return{expirationTime:e,tag:0,payload:null,callback:null,next:null,nextEffect:null}}function Jt(e,n){null===e.lastUpdate?e.firstUpdate=e.lastUpdate=n:(e.lastUpdate.next=n,e.lastUpdate=n)}function Qt(e,n){var t=e.alternate;if(null===t){var r=e.updateQueue,i=null;null===r&&(r=e.updateQueue=$t(e.memoizedState))}else r=e.updateQueue,i=t.updateQueue,null===r?null===i?(r=e.updateQueue=$t(e.memoizedState),i=t.updateQueue=$t(t.memoizedState)):r=e.updateQueue=Xt(i):null===i&&(i=t.updateQueue=Xt(r));null===i||r===i?Jt(r,n):null===r.lastUpdate||null===i.lastUpdate?(Jt(r,n),Jt(i,n)):(Jt(r,n),i.lastUpdate=n)}function Zt(e,n){var t=e.updateQueue;null===(t=null===t?e.updateQueue=$t(e.memoizedState):er(e,t)).lastCapturedUpdate?t.firstCapturedUpdate=t.lastCapturedUpdate=n:(t.lastCapturedUpdate.next=n,t.lastCapturedUpdate=n)}function er(e,n){var t=e.alternate;return null!==t&&n===t.updateQueue&&(n=e.updateQueue=Xt(n)),n}function nr(e,n,t,r,u,o){switch(t.tag){case Yt:return"function"==typeof(e=t.payload)?e.call(o,r,u):e;case 3:e.effectTag=-2049&e.effectTag|64;case 0:if(null==(u="function"==typeof(e=t.payload)?e.call(o,r,u):e))break;return i({},r,u);case qt:Vt=!0}return r}function tr(e,n,t,r,i){Vt=!1;for(var u=(n=er(e,n)).baseState,o=null,a=0,l=n.firstUpdate,s=u;null!==l;){var f=l.expirationTime;f<i?(null===o&&(o=l,u=s),a<f&&(a=f)):(s=nr(e,0,l,s,t,r),null!==l.callback&&(e.effectTag|=32,l.nextEffect=null,null===n.lastEffect?n.firstEffect=n.lastEffect=l:(n.lastEffect.nextEffect=l,n.lastEffect=l))),l=l.next}for(f=null,l=n.firstCapturedUpdate;null!==l;){var c=l.expirationTime;c<i?(null===f&&(f=l,null===o&&(u=s)),a<c&&(a=c)):(s=nr(e,0,l,s,t,r),null!==l.callback&&(e.effectTag|=32,l.nextEffect=null,null===n.lastCapturedEffect?n.firstCapturedEffect=n.lastCapturedEffect=l:(n.lastCapturedEffect.nextEffect=l,n.lastCapturedEffect=l))),l=l.next}null===o&&(n.lastUpdate=null),null===f?n.lastCapturedUpdate=null:e.effectTag|=32,null===o&&null===f&&(u=s),n.baseState=u,n.firstUpdate=o,n.firstCapturedUpdate=f,e.expirationTime=a,e.memoizedState=s}function rr(e,n,t){null!==n.firstCapturedUpdate&&(null!==n.lastUpdate&&(n.lastUpdate.next=n.firstCapturedUpdate,n.lastUpdate=n.lastCapturedUpdate),n.firstCapturedUpdate=n.lastCapturedUpdate=null),ir(n.firstEffect,t),n.firstEffect=n.lastEffect=null,ir(n.firstCapturedEffect,t),n.firstCapturedEffect=n.lastCapturedEffect=null}function ir(e,n){for(;null!==e;){var t=e.callback;if(null!==t){e.callback=null;var r=n;"function"!=typeof t&&l("191",t),t.call(r)}e=e.nextEffect}}function ur(e,n){return{value:e,source:n,stack:xe(n)}}function or(e){e.effectTag|=4}var ar=void 0,lr=void 0,sr=void 0,fr=void 0;if(Q)ar=function(e,n){for(var t=n.child;null!==t;){if(5===t.tag||6===t.tag)L(e,t.stateNode);else if(4!==t.tag&&null!==t.child){t.child.return=t,t=t.child;continue}if(t===n)break;for(;null===t.sibling;){if(null===t.return||t.return===n)return;t=t.return}t.sibling.return=t.return,t=t.sibling}},lr=function(){},sr=function(e,n,t,r,i){if((e=e.memoizedProps)!==r){var u=n.stateNode,o=Fn();t=B(u,t,e,r,i,o),(n.updateQueue=t)&&or(n)}},fr=function(e,n,t,r){t!==r&&or(n)};else if(Z){ar=function(e,n,t,r){for(var i=n.child;null!==i;){e:if(5===i.tag){var u=i.stateNode;if(t){var o=i.memoizedProps,a=i.type;u=r?ye(u,a,o,i):De(u,a,o,i),i.stateNode=u}L(e,u)}else if(6===i.tag)u=i.stateNode,t&&(u=i.memoizedProps,o=Pn(xn.current),a=Fn(),u=r?we(u,o,a,n):W(u,o,a,n),i.stateNode=u),L(e,u);else if(4!==i.tag){if(13===i.tag&&(null!==(o=i.alternate)&&(u=null!==i.memoizedState,null!==o.memoizedState!==u))){null!==(o=u?i.child:i)&&ar(e,o,!0,u);break e}if(null!==i.child){i.child.return=i,i=i.child;continue}}if(i===n)break;for(;null===i.sibling;){if(null===i.return||i.return===n)return;i=i.return}i.sibling.return=i.return,i=i.sibling}};var cr=function(e,n,t,r){for(var i=n.child;null!==i;){e:if(5===i.tag){var u=i.stateNode;if(t){var o=i.memoizedProps,a=i.type;u=r?ye(u,a,o,i):De(u,a,o,i),i.stateNode=u}_e(e,u)}else if(6===i.tag)u=i.stateNode,t&&(u=i.memoizedProps,o=Pn(xn.current),a=Fn(),u=r?we(u,o,a,n):W(u,o,a,n),i.stateNode=u),_e(e,u);else if(4!==i.tag){if(13===i.tag&&(null!==(o=i.alternate)&&(u=null!==i.memoizedState,null!==o.memoizedState!==u))){null!==(o=u?i.child:i)&&cr(e,o,!0,u);break e}if(null!==i.child){i.child.return=i,i=i.child;continue}}if(i===n)break;for(;null===i.sibling;){if(null===i.return||i.return===n)return;i=i.return}i.sibling.return=i.return,i=i.sibling}};lr=function(e){var n=e.stateNode;if(null!==e.firstEffect){var t=n.containerInfo,r=ve(t);cr(r,e,!1,!1),n.pendingChildren=r,or(e),be(t,r)}},sr=function(e,n,t,r,i){var u=e.stateNode,o=e.memoizedProps;if((e=null===n.firstEffect)&&o===r)n.stateNode=u;else{var a=n.stateNode,l=Fn(),s=null;o!==r&&(s=B(a,t,o,r,i,l)),e&&null===s?n.stateNode=u:(u=me(u,s,t,o,r,n,e,a),I(u,t,r,i,l)&&or(n),n.stateNode=u,e?or(n):ar(u,n,!1,!1))}},fr=function(e,n,t,r){t!==r&&(e=Pn(xn.current),t=Fn(),n.stateNode=W(r,e,t,n),or(n))}}else lr=function(){},sr=function(){},fr=function(){};var dr="function"==typeof WeakSet?WeakSet:Set;function pr(e,n){var t=n.source,r=n.stack;null===r&&null!==t&&(r=xe(t)),null!==t&&C(t.type),n=n.value,null!==e&&1===e.tag&&C(e.type);try{console.error(n)}catch(e){setTimeout((function(){throw e}))}}function hr(e){var n=e.ref;if(null!==n)if("function"==typeof n)try{n(null)}catch(n){Jr(e,n)}else n.current=null}function mr(e,n,t){if(null!==(t=null!==(t=t.updateQueue)?t.lastEffect:null)){var r=t=t.next;do{if(0!=(r.tag&e)){var i=r.destroy;r.destroy=void 0,void 0!==i&&i()}0!=(r.tag&n)&&(i=r.create,r.destroy=i()),r=r.next}while(r!==t)}}function vr(e){switch("function"==typeof $e&&$e(e),e.tag){case 0:case 11:case 14:case 15:var n=e.updateQueue;if(null!==n&&null!==(n=n.lastEffect)){var t=n=n.next;do{var r=t.destroy;if(void 0!==r){var i=e;try{r()}catch(e){Jr(i,e)}}t=t.next}while(t!==n)}break;case 1:if(hr(e),"function"==typeof(n=e.stateNode).componentWillUnmount)try{n.props=e.memoizedProps,n.state=e.memoizedState,n.componentWillUnmount()}catch(n){Jr(e,n)}break;case 5:hr(e);break;case 4:Q?yr(e):Z&&Z&&(e=e.stateNode.containerInfo,n=ve(e),ge(e,n))}}function _r(e){for(var n=e;;)if(vr(n),null===n.child||Q&&4===n.tag){if(n===e)break;for(;null===n.sibling;){if(null===n.return||n.return===e)return;n=n.return}n.sibling.return=n.return,n=n.sibling}else n.child.return=n,n=n.child}function br(e){return 5===e.tag||3===e.tag||4===e.tag}function gr(e){if(Q){e:{for(var n=e.return;null!==n;){if(br(n)){var t=n;break e}n=n.return}l("160"),t=void 0}var r=n=void 0;switch(t.tag){case 5:n=t.stateNode,r=!1;break;case 3:case 4:n=t.stateNode.containerInfo,r=!0;break;default:l("161")}16&t.effectTag&&(fe(n),t.effectTag&=-17);e:n:for(t=e;;){for(;null===t.sibling;){if(null===t.return||br(t.return)){t=null;break e}t=t.return}for(t.sibling.return=t.return,t=t.sibling;5!==t.tag&&6!==t.tag&&18!==t.tag;){if(2&t.effectTag)continue n;if(null===t.child||4===t.tag)continue n;t.child.return=t,t=t.child}if(!(2&t.effectTag)){t=t.stateNode;break e}}for(var i=e;;){if(5===i.tag||6===i.tag)t?r?ae(n,i.stateNode,t):oe(n,i.stateNode,t):r?te(n,i.stateNode):ne(n,i.stateNode);else if(4!==i.tag&&null!==i.child){i.child.return=i,i=i.child;continue}if(i===e)break;for(;null===i.sibling;){if(null===i.return||i.return===e)return;i=i.return}i.sibling.return=i.return,i=i.sibling}}}function yr(e){for(var n=e,t=!1,r=void 0,i=void 0;;){if(!t){t=n.return;e:for(;;){switch(null===t&&l("160"),t.tag){case 5:r=t.stateNode,i=!1;break e;case 3:case 4:r=t.stateNode.containerInfo,i=!0;break e}t=t.return}t=!0}if(5===n.tag||6===n.tag)_r(n),i?se(r,n.stateNode):le(r,n.stateNode);else if(4===n.tag){if(null!==n.child){r=n.stateNode.containerInfo,i=!0,n.child.return=n,n=n.child;continue}}else if(vr(n),null!==n.child){n.child.return=n,n=n.child;continue}if(n===e)break;for(;null===n.sibling;){if(null===n.return||n.return===e)return;4===(n=n.return).tag&&(t=!1)}n.sibling.return=n.return,n=n.sibling}}function Dr(e,n){if(Q)switch(n.tag){case 0:case 11:case 14:case 15:mr(4,8,n);break;case 1:break;case 5:var t=n.stateNode;if(null!=t){var r=n.memoizedProps;e=null!==e?e.memoizedProps:r;var i=n.type,u=n.updateQueue;n.updateQueue=null,null!==u&&ue(t,u,i,e,r,n)}break;case 6:null===n.stateNode&&l("162"),t=n.memoizedProps,re(n.stateNode,null!==e?e.memoizedProps:t,t);break;case 3:case 12:break;case 13:if(t=n.memoizedState,r=void 0,e=n,null===t?r=!1:(r=!0,e=n.child,0===t.timedOutAt&&(t.timedOutAt=Mi())),null!==e&&function(e,n){if(Q)for(var t=e;;){if(5===t.tag){var r=t.stateNode;n?ce(r):pe(t.stateNode,t.memoizedProps)}else if(6===t.tag)r=t.stateNode,n?de(r):he(r,t.memoizedProps);else{if(13===t.tag&&null!==t.memoizedState){(r=t.child.sibling).return=t,t=r;continue}if(null!==t.child){t.child.return=t,t=t.child;continue}}if(t===e)break;for(;null===t.sibling;){if(null===t.return||t.return===e)return;t=t.return}t.sibling.return=t.return,t=t.sibling}}(e,r),null!==(t=n.updateQueue)){n.updateQueue=null;var o=n.stateNode;null===o&&(o=n.stateNode=new dr),t.forEach((function(e){var t=ei.bind(null,n,e);o.has(e)||(o.add(e),e.then(t,t))}))}break;case 17:break;default:l("163")}else{switch(n.tag){case 0:case 11:case 14:case 15:return void mr(4,8,n)}!function(e){if(Z)switch(e.tag){case 1:case 5:case 6:break;case 3:case 4:e=e.stateNode,ge(e.containerInfo,e.pendingChildren);break;default:l("163")}}(n)}}var wr="function"==typeof WeakMap?WeakMap:Map;function Er(e,n,t){(t=Kt(t)).tag=3,t.payload={element:null};var r=n.value;return t.callback=function(){Ii(r),pr(e,n)},t}function Tr(e,n,t){(t=Kt(t)).tag=3;var r=e.type.getDerivedStateFromError;if("function"==typeof r){var i=n.value;t.payload=function(){return r(i)}}var u=e.stateNode;return null!==u&&"function"==typeof u.componentDidCatch&&(t.callback=function(){"function"!=typeof r&&(null===jr?jr=new Set([this]):jr.add(this));var t=n.value,i=n.stack;pr(e,n),this.componentDidCatch(t,{componentStack:null!==i?i:""})}),t}function Cr(e){switch(e.tag){case 1:je(e.type)&&We();var n=e.effectTag;return 2048&n?(e.effectTag=-2049&n|64,e):null;case 3:return Nn(),ze(),0!=(64&(n=e.effectTag))&&l("285"),e.effectTag=-2049&n|64,e;case 5:return Ln(e),null;case 13:return 2048&(n=e.effectTag)?(e.effectTag=-2049&n|64,e):null;case 18:return null;case 4:return Nn(),null;case 10:return zt(e),null;default:return null}}var kr=s.ReactCurrentDispatcher,Mr=s.ReactCurrentOwner,Sr=1073741822,Ar=!1,xr=null,Pr=null,Rr=0,Nr=-1,Fr=!1,Or=null,Lr=!1,Ir=null,Br=null,Ur=null,jr=null;function Wr(){if(null!==xr)for(var e=xr.return;null!==e;){var n=e;switch(n.tag){case 1:var t=n.type.childContextTypes;null!=t&&We();break;case 3:Nn(),ze();break;case 5:Ln(n);break;case 4:Nn();break;case 10:zt(n)}e=e.return}Pr=null,Rr=0,Nr=-1,Fr=!1,xr=null}function zr(){for(;null!==Or;){var e=Or.effectTag;if(16&e&&Q&&fe(Or.stateNode),128&e){var n=Or.alternate;null!==n&&(null!==(n=n.ref)&&("function"==typeof n?n(null):n.current=null))}switch(14&e){case 2:gr(Or),Or.effectTag&=-3;break;case 6:gr(Or),Or.effectTag&=-3,Dr(Or.alternate,Or);break;case 4:Dr(Or.alternate,Or);break;case 8:e=Or,Q?yr(e):_r(e),e.return=null,e.child=null,e.memoizedState=null,e.updateQueue=null,null!==(e=e.alternate)&&(e.return=null,e.child=null,e.memoizedState=null,e.updateQueue=null)}Or=Or.nextEffect}}function Hr(){for(;null!==Or;){if(256&Or.effectTag)e:{var e=Or.alternate,n=Or;switch(n.tag){case 0:case 11:case 15:mr(2,0,n);break e;case 1:if(256&n.effectTag&&null!==e){var t=e.memoizedProps,r=e.memoizedState;n=(e=n.stateNode).getSnapshotBeforeUpdate(n.elementType===n.type?t:pn(n.type,t),r),e.__reactInternalSnapshotBeforeUpdate=n}break e;case 3:case 5:case 6:case 4:case 17:break e;default:l("163")}}Or=Or.nextEffect}}function Gr(e,n){for(;null!==Or;){var t=Or.effectTag;if(36&t){var r=Or.alternate,i=Or,u=n;switch(i.tag){case 0:case 11:case 15:mr(16,32,i);break;case 1:var o=i.stateNode;if(4&i.effectTag)if(null===r)o.componentDidMount();else{var a=i.elementType===i.type?r.memoizedProps:pn(i.type,r.memoizedProps);o.componentDidUpdate(a,r.memoizedState,o.__reactInternalSnapshotBeforeUpdate)}null!==(r=i.updateQueue)&&rr(0,r,o);break;case 3:if(null!==(r=i.updateQueue)){if(o=null,null!==i.child)switch(i.child.tag){case 5:o=x(i.child.stateNode);break;case 1:o=i.child.stateNode}rr(0,r,o)}break;case 5:u=i.stateNode,null===r&&4&i.effectTag&&ie(u,i.type,i.memoizedProps,i);break;case 6:case 4:case 12:case 13:case 17:break;default:l("163")}}if(128&t&&null!==(i=Or.ref)){switch(u=Or.stateNode,Or.tag){case 5:u=x(u)}"function"==typeof i?i(u):i.current=u}512&t&&(Ir=e),Or=Or.nextEffect}}function Yr(e,n){Ur=Br=Ir=null;var t=li;li=!0;do{if(512&n.effectTag){var r=!1,i=void 0;try{var u=n;mr(128,0,u),mr(0,64,u)}catch(e){r=!0,i=e}r&&Jr(n,i)}n=n.nextEffect}while(null!==n);li=t,0!==(t=e.expirationTime)&&Si(e,t),hi||li||Ni(1073741823,!1)}function qr(){null!==Br&&X(Br),null!==Ur&&Ur()}function Vr(e,n){Lr=Ar=!0,e.current===n&&l("177");var t=e.pendingCommitExpirationTime;0===t&&l("261"),e.pendingCommitExpirationTime=0;var r=n.expirationTime,i=n.childExpirationTime;for(function(e,n){if(e.didError=!1,0===n)e.earliestPendingTime=0,e.latestPendingTime=0,e.earliestSuspendedTime=0,e.latestSuspendedTime=0,e.latestPingedTime=0;else{n<e.latestPingedTime&&(e.latestPingedTime=0);var t=e.latestPendingTime;0!==t&&(t>n?e.earliestPendingTime=e.latestPendingTime=0:e.earliestPendingTime>n&&(e.earliestPendingTime=e.latestPendingTime)),0===(t=e.earliestSuspendedTime)?on(e,n):n<e.latestSuspendedTime?(e.earliestSuspendedTime=0,e.latestSuspendedTime=0,e.latestPingedTime=0,on(e,n)):n>t&&on(e,n)}sn(0,e)}(e,i>r?i:r),Mr.current=null,r=void 0,1<n.effectTag?null!==n.lastEffect?(n.lastEffect.nextEffect=n,r=n.firstEffect):r=n:r=n.firstEffect,N(e.containerInfo),Or=r;null!==Or;){i=!1;var u=void 0;try{Hr()}catch(e){i=!0,u=e}i&&(null===Or&&l("178"),Jr(Or,u),null!==Or&&(Or=Or.nextEffect))}for(Or=r;null!==Or;){i=!1,u=void 0;try{zr()}catch(e){i=!0,u=e}i&&(null===Or&&l("178"),Jr(Or,u),null!==Or&&(Or=Or.nextEffect))}for(F(e.containerInfo),e.current=n,Or=r;null!==Or;){i=!1,u=void 0;try{Gr(e,t)}catch(e){i=!0,u=e}i&&(null===Or&&l("178"),Jr(Or,u),null!==Or&&(Or=Or.nextEffect))}if(null!==r&&null!==Ir){var a=Yr.bind(null,e,r);Br=o.unstable_runWithPriority(o.unstable_NormalPriority,(function(){return $(a)})),Ur=a}Ar=Lr=!1,"function"==typeof Ve&&Ve(n.stateNode),t=n.expirationTime,0===(n=(n=n.childExpirationTime)>t?n:t)&&(jr=null),function(e,n){e.expirationTime=n,e.finishedWork=null}(e,n)}function $r(e){for(;;){var n=e.alternate,t=e.return,r=e.sibling;if(0==(1024&e.effectTag)){xr=e;e:{var i=n,u=Rr,o=(n=e).pendingProps;switch(n.tag){case 2:case 16:break;case 15:case 0:break;case 1:je(n.type)&&We();break;case 3:Nn(),ze(),(o=n.stateNode).pendingContext&&(o.context=o.pendingContext,o.pendingContext=null),null!==i&&null!==i.child||(Dt(n),n.effectTag&=-3),lr(n);break;case 5:Ln(n),u=Pn(xn.current);var a=n.type;if(null!==i&&null!=n.stateNode)sr(i,n,a,o,u),i.ref!==n.ref&&(n.effectTag|=128);else if(o){if(i=Fn(),Dt(n))o=n,ee||l("175"),i=Me(o.stateNode,o.type,o.memoizedProps,u,i,o),o.updateQueue=i,(i=null!==i)&&or(n);else{var s=O(a,o,u,i,n);ar(s,n,!1,!1),I(s,a,o,u,i)&&or(n),n.stateNode=s}null!==n.ref&&(n.effectTag|=128)}else null===n.stateNode&&l("166");break;case 6:i&&null!=n.stateNode?fr(i,n,i.memoizedProps,o):("string"!=typeof o&&(null===n.stateNode&&l("166")),i=Pn(xn.current),u=Fn(),Dt(n)?(i=n,ee||l("176"),(i=Se(i.stateNode,i.memoizedProps,i))&&or(n)):n.stateNode=W(o,i,u,n));break;case 11:break;case 13:if(o=n.memoizedState,0!=(64&n.effectTag)){n.expirationTime=u,xr=n;break e}o=null!==o,u=null!==i&&null!==i.memoizedState,null!==i&&!o&&u&&(null!==(i=i.child.sibling)&&(null!==(a=n.firstEffect)?(n.firstEffect=i,i.nextEffect=a):(n.firstEffect=n.lastEffect=i,i.nextEffect=null),i.effectTag=8)),(o||u)&&(n.effectTag|=4);break;case 7:case 8:case 12:break;case 4:Nn(),lr(n);break;case 10:zt(n);break;case 9:case 14:break;case 17:je(n.type)&&We();break;case 18:break;default:l("156")}xr=null}if(n=e,1===Rr||1!==n.childExpirationTime){for(i=0,o=n.child;null!==o;)(u=o.expirationTime)>i&&(i=u),(a=o.childExpirationTime)>i&&(i=a),o=o.sibling;n.childExpirationTime=i}if(null!==xr)return xr;null!==t&&0==(1024&t.effectTag)&&(null===t.firstEffect&&(t.firstEffect=e.firstEffect),null!==e.lastEffect&&(null!==t.lastEffect&&(t.lastEffect.nextEffect=e.firstEffect),t.lastEffect=e.lastEffect),1<e.effectTag&&(null!==t.lastEffect?t.lastEffect.nextEffect=e:t.firstEffect=e,t.lastEffect=e))}else{if(null!==(e=Cr(e)))return e.effectTag&=1023,e;null!==t&&(t.firstEffect=t.lastEffect=null,t.effectTag|=1024)}if(null!==r)return r;if(null===t)break;e=t}return null}function Xr(e){var n=Lt(e.alternate,e,Rr);return e.memoizedProps=e.pendingProps,null===n&&(n=$r(e)),Mr.current=null,n}function Kr(e,n){Ar&&l("243"),qr(),Ar=!0;var t=kr.current;kr.current=ct;var r=e.nextExpirationTimeToWorkOn;r===Rr&&e===Pr&&null!==xr||(Wr(),Rr=r,xr=Ze((Pr=e).current,null),e.pendingCommitExpirationTime=0);for(var i=!1;;){try{if(n)for(;null!==xr&&!Pi();)xr=Xr(xr);else for(;null!==xr;)xr=Xr(xr)}catch(n){if(jt=Ut=Bt=null,et(),null===xr)i=!0,Ii(n);else{null===xr&&l("271");var u=xr,o=u.return;if(null!==o){e:{var a=e,s=o,f=u,c=n;if(o=Rr,f.effectTag|=1024,f.firstEffect=f.lastEffect=null,null!==c&&"object"==typeof c&&"function"==typeof c.then){var d=c;c=s;var p=-1,h=-1;do{if(13===c.tag){var m=c.alternate;if(null!==m&&null!==(m=m.memoizedState)){h=10*(1073741822-m.timedOutAt);break}"number"==typeof(m=c.pendingProps.maxDuration)&&(0>=m?p=0:(-1===p||m<p)&&(p=m))}c=c.return}while(null!==c);c=s;do{if((m=13===c.tag)&&(m=void 0!==c.memoizedProps.fallback&&null===c.memoizedState),m){if(null===(s=c.updateQueue)?((s=new Set).add(d),c.updateQueue=s):s.add(d),0==(1&c.mode)){c.effectTag|=64,f.effectTag&=-1957,1===f.tag&&(null===f.alternate?f.tag=17:((o=Kt(1073741823)).tag=qt,Qt(f,o))),f.expirationTime=1073741823;break e}s=o;var v=(f=a).pingCache;null===v?(v=f.pingCache=new wr,m=new Set,v.set(d,m)):void 0===(m=v.get(d))&&(m=new Set,v.set(d,m)),m.has(s)||(m.add(s),f=Zr.bind(null,f,d,s),d.then(f,f)),-1===p?a=1073741823:(-1===h&&(h=10*(1073741822-ln(a,o))-5e3),a=h+p),0<=a&&Nr<a&&(Nr=a),c.effectTag|=2048,c.expirationTime=o;break e}c=c.return}while(null!==c);c=Error((C(f.type)||"A React component")+" suspended while rendering, but no fallback UI was specified.\n\nAdd a <Suspense fallback=...> component higher in the tree to provide a loading indicator or placeholder to display."+xe(f))}Fr=!0,c=ur(c,f),a=s;do{switch(a.tag){case 3:a.effectTag|=2048,a.expirationTime=o,Zt(a,o=Er(a,c,o));break e;case 1:if(p=c,h=a.type,f=a.stateNode,0==(64&a.effectTag)&&("function"==typeof h.getDerivedStateFromError||null!==f&&"function"==typeof f.componentDidCatch&&(null===jr||!jr.has(f)))){a.effectTag|=2048,a.expirationTime=o,Zt(a,o=Tr(a,p,o));break e}}a=a.return}while(null!==a)}xr=$r(u);continue}i=!0,Ii(n)}}break}if(Ar=!1,kr.current=t,jt=Ut=Bt=null,et(),i)Pr=null,e.finishedWork=null;else if(null!==xr)e.finishedWork=null;else{if(null===(t=e.current.alternate)&&l("281"),Pr=null,Fr){if(i=e.latestPendingTime,u=e.latestSuspendedTime,o=e.latestPingedTime,0!==i&&i<r||0!==u&&u<r||0!==o&&o<r)return an(e,r),void Ci(e,t,r,e.expirationTime,-1);if(!e.didError&&n)return e.didError=!0,r=e.nextExpirationTimeToWorkOn=r,n=e.expirationTime=1073741823,void Ci(e,t,r,n,-1)}n&&-1!==Nr?(an(e,r),(n=10*(1073741822-ln(e,r)))<Nr&&(Nr=n),n=10*(1073741822-Mi()),n=Nr-n,Ci(e,t,r,e.expirationTime,0>n?0:n)):(e.pendingCommitExpirationTime=r,e.finishedWork=t)}}function Jr(e,n){for(var t=e.return;null!==t;){switch(t.tag){case 1:var r=t.stateNode;if("function"==typeof t.type.getDerivedStateFromError||"function"==typeof r.componentDidCatch&&(null===jr||!jr.has(r)))return Qt(t,e=Tr(t,e=ur(n,e),1073741823)),void ti(t,1073741823);break;case 3:return Qt(t,e=Er(t,e=ur(n,e),1073741823)),void ti(t,1073741823)}t=t.return}3===e.tag&&(Qt(e,t=Er(e,t=ur(n,e),1073741823)),ti(e,1073741823))}function Qr(e,n){var t=o.unstable_getCurrentPriorityLevel(),r=void 0;if(0==(1&n.mode))r=1073741823;else if(Ar&&!Lr)r=Rr;else{switch(t){case o.unstable_ImmediatePriority:r=1073741823;break;case o.unstable_UserBlockingPriority:r=1073741822-10*(1+((1073741822-e+15)/10|0));break;case o.unstable_NormalPriority:r=1073741822-25*(1+((1073741822-e+500)/25|0));break;case o.unstable_LowPriority:case o.unstable_IdlePriority:r=1;break;default:l("313")}null!==Pr&&r===Rr&&--r}return t===o.unstable_UserBlockingPriority&&(0===ci||r<ci)&&(ci=r),r}function Zr(e,n,t){var r=e.pingCache;null!==r&&r.delete(n),null!==Pr&&Rr===t?Pr=null:(n=e.earliestSuspendedTime,r=e.latestSuspendedTime,0!==n&&t<=n&&t>=r&&(e.didError=!1,(0===(n=e.latestPingedTime)||n>t)&&(e.latestPingedTime=t),sn(t,e),0!==(t=e.expirationTime)&&Si(e,t)))}function ei(e,n){var t=e.stateNode;null!==t&&t.delete(n),null!==(e=ni(e,n=Qr(n=Mi(),e)))&&(on(e,n),0!==(n=e.expirationTime)&&Si(e,n))}function ni(e,n){e.expirationTime<n&&(e.expirationTime=n);var t=e.alternate;null!==t&&t.expirationTime<n&&(t.expirationTime=n);var r=e.return,i=null;if(null===r&&3===e.tag)i=e.stateNode;else for(;null!==r;){if(t=r.alternate,r.childExpirationTime<n&&(r.childExpirationTime=n),null!==t&&t.childExpirationTime<n&&(t.childExpirationTime=n),null===r.return&&3===r.tag){i=r.stateNode;break}r=r.return}return i}function ti(e,n){null!==(e=ni(e,n))&&(!Ar&&0!==Rr&&n>Rr&&Wr(),on(e,n),Ar&&!Lr&&Pr===e||Si(e,e.expirationTime),Di>yi&&(Di=0,l("185")))}function ri(e,n,t,r,i){return o.unstable_runWithPriority(o.unstable_ImmediatePriority,(function(){return e(n,t,r,i)}))}var ii=null,ui=null,oi=0,ai=void 0,li=!1,si=null,fi=0,ci=0,di=!1,pi=null,hi=!1,mi=!1,vi=null,_i=K(),bi=1073741822-(_i/10|0),gi=bi,yi=50,Di=0,wi=null;function Ei(){bi=1073741822-((K()-_i)/10|0)}function Ti(e,n){if(0!==oi){if(n<oi)return;null!==ai&&H(ai)}oi=n,e=K()-_i,ai=z(Ri,{timeout:10*(1073741822-n)-e})}function Ci(e,n,t,r,i){e.expirationTime=r,0!==i||Pi()?0<i&&(e.timeoutHandle=Y(ki.bind(null,e,n,t),i)):(e.pendingCommitExpirationTime=t,e.finishedWork=n)}function ki(e,n,t){e.pendingCommitExpirationTime=t,e.finishedWork=n,Ei(),gi=bi,Fi(e,t)}function Mi(){return li||(Ai(),0!==fi&&1!==fi||(Ei(),gi=bi)),gi}function Si(e,n){null===e.nextScheduledRoot?(e.expirationTime=n,null===ui?(ii=ui=e,e.nextScheduledRoot=e):(ui=ui.nextScheduledRoot=e).nextScheduledRoot=ii):n>e.expirationTime&&(e.expirationTime=n),li||(hi?mi&&(si=e,fi=1073741823,Oi(e,1073741823,!1)):1073741823===n?Ni(1073741823,!1):Ti(e,n))}function Ai(){var e=0,n=null;if(null!==ui)for(var t=ui,r=ii;null!==r;){var i=r.expirationTime;if(0===i){if((null===t||null===ui)&&l("244"),r===r.nextScheduledRoot){ii=ui=r.nextScheduledRoot=null;break}if(r===ii)ii=i=r.nextScheduledRoot,ui.nextScheduledRoot=i,r.nextScheduledRoot=null;else{if(r===ui){(ui=t).nextScheduledRoot=ii,r.nextScheduledRoot=null;break}t.nextScheduledRoot=r.nextScheduledRoot,r.nextScheduledRoot=null}r=t.nextScheduledRoot}else{if(i>e&&(e=i,n=r),r===ui)break;if(1073741823===e)break;t=r,r=r.nextScheduledRoot}}si=n,fi=e}var xi=!1;function Pi(){return!!xi||!!G()&&(xi=!0)}function Ri(){try{if(!Pi()&&null!==ii){Ei();var e=ii;do{var n=e.expirationTime;0!==n&&bi<=n&&(e.nextExpirationTimeToWorkOn=bi),e=e.nextScheduledRoot}while(e!==ii)}Ni(0,!0)}finally{xi=!1}}function Ni(e,n){if(Ai(),n)for(Ei(),gi=bi;null!==si&&0!==fi&&e<=fi&&!(xi&&bi>fi);)Oi(si,fi,bi>fi),Ai(),Ei(),gi=bi;else for(;null!==si&&0!==fi&&e<=fi;)Oi(si,fi,!1),Ai();if(n&&(oi=0,ai=null),0!==fi&&Ti(si,fi),Di=0,wi=null,null!==vi)for(e=vi,vi=null,n=0;n<e.length;n++){var t=e[n];try{t._onComplete()}catch(e){di||(di=!0,pi=e)}}if(di)throw e=pi,pi=null,di=!1,e}function Fi(e,n){li&&l("253"),si=e,fi=n,Oi(e,n,!1),Ni(1073741823,!1)}function Oi(e,n,t){if(li&&l("245"),li=!0,t){var r=e.finishedWork;null!==r?Li(e,r,n):(e.finishedWork=null,(r=e.timeoutHandle)!==V&&(e.timeoutHandle=V,q(r)),Kr(e,t),null!==(r=e.finishedWork)&&(Pi()?e.finishedWork=r:Li(e,r,n)))}else null!==(r=e.finishedWork)?Li(e,r,n):(e.finishedWork=null,(r=e.timeoutHandle)!==V&&(e.timeoutHandle=V,q(r)),Kr(e,t),null!==(r=e.finishedWork)&&Li(e,r,n));li=!1}function Li(e,n,t){var r=e.firstBatch;if(null!==r&&r._expirationTime>=t&&(null===vi?vi=[r]:vi.push(r),r._defer))return e.finishedWork=n,void(e.expirationTime=0);e.finishedWork=null,e===wi?Di++:(wi=e,Di=0),o.unstable_runWithPriority(o.unstable_ImmediatePriority,(function(){Vr(e,n)}))}function Ii(e){null===si&&l("246"),si.expirationTime=0,di||(di=!0,pi=e)}function Bi(e,n,t,r,i){var u=n.current;e:if(t){n:{2===k(t=t._reactInternalFiber)&&1===t.tag||l("170");var o=t;do{switch(o.tag){case 3:o=o.stateNode.context;break n;case 1:if(je(o.type)){o=o.stateNode.__reactInternalMemoizedMergedChildContext;break n}}o=o.return}while(null!==o);l("171"),o=void 0}if(1===t.tag){var a=t.type;if(je(a)){t=Ge(t,a,o);break e}}t=o}else t=Oe;return null===n.context?n.context=t:n.pendingContext=t,n=i,(i=Kt(r)).payload={element:e},null!==(n=void 0===n?null:n)&&(i.callback=n),qr(),Qt(u,i),ti(u,r),r}function Ui(e){var n=e._reactInternalFiber;return void 0===n&&("function"==typeof e.render?l("188"):l("268",Object.keys(e))),null===(e=A(n))?null:e.stateNode}var ji={updateContainerAtExpirationTime:Bi,createContainer:function(e,n,t){return e={current:n=Je(3,null,null,n?3:0),containerInfo:e,pendingChildren:null,pingCache:null,earliestPendingTime:0,latestPendingTime:0,earliestSuspendedTime:0,latestSuspendedTime:0,latestPingedTime:0,didError:!1,pendingCommitExpirationTime:0,finishedWork:null,timeoutHandle:V,context:null,pendingContext:null,hydrate:t,nextExpirationTimeToWorkOn:0,expirationTime:0,firstBatch:null,nextScheduledRoot:null},n.stateNode=e},updateContainer:function(e,n,t,r){var i=n.current;return Bi(e,n,t,i=Qr(Mi(),i),r)},flushRoot:Fi,requestWork:Si,computeUniqueAsyncExpiration:function(){var e=1073741822-25*(1+((1073741822-Mi()+500)/25|0));return e>=Sr&&(e=Sr-1),Sr=e},batchedUpdates:function(e,n){var t=hi;hi=!0;try{return e(n)}finally{(hi=t)||li||Ni(1073741823,!1)}},unbatchedUpdates:function(e,n){if(hi&&!mi){mi=!0;try{return e(n)}finally{mi=!1}}return e(n)},deferredUpdates:o.unstable_next,syncUpdates:ri,interactiveUpdates:function(e,n,t){hi||li||0===ci||(Ni(ci,!1),ci=0);var r=hi;hi=!0;try{return o.unstable_runWithPriority(o.unstable_UserBlockingPriority,(function(){return e(n,t)}))}finally{(hi=r)||li||Ni(1073741823,!1)}},flushInteractiveUpdates:function(){li||0===ci||(Ni(ci,!1),ci=0)},flushControlled:function(e){var n=hi;hi=!0;try{ri(e)}finally{(hi=n)||li||Ni(1073741823,!1)}},flushSync:function(e,n){li&&l("187");var t=hi;hi=!0;try{return ri(e,n)}finally{hi=t,Ni(1073741823,!1)}},getPublicRootInstance:function(e){if(!(e=e.current).child)return null;switch(e.child.tag){case 5:return x(e.child.stateNode);default:return e.child.stateNode}},findHostInstance:Ui,findHostInstanceWithWarning:function(e){return Ui(e)},findHostInstanceWithNoPortals:function(e){return null===(e=function(e){if(!(e=S(e)))return null;for(var n=e;;){if(5===n.tag||6===n.tag)return n;if(n.child&&4!==n.tag)n.child.return=n,n=n.child;else{if(n===e)break;for(;!n.sibling;){if(!n.return||n.return===e)return null;n=n.return}n.sibling.return=n.return,n=n.sibling}}return null}(e))?null:e.stateNode},injectIntoDevTools:function(e){var n=e.findFiberByHostInstance;return function(e){if("undefined"==typeof __REACT_DEVTOOLS_GLOBAL_HOOK__)return!1;var n=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(n.isDisabled||!n.supportsFiber)return!0;try{var t=n.inject(e);Ve=Xe((function(e){return n.onCommitFiberRoot(t,e)})),$e=Xe((function(e){return n.onCommitFiberUnmount(t,e)}))}catch(e){}return!0}(i({},e,{overrideProps:null,currentDispatcherRef:s.ReactCurrentDispatcher,findHostInstanceByFiber:function(e){return null===(e=A(e))?null:e.stateNode},findFiberByHostInstance:function(e){return n?n(e):null}}))}};e.exports=ji.default||ji;var Wi=e.exports;return e.exports=n,Wi}},9437:(e,n,t)=>{"use strict";e.exports=t(5591)},327:e=>{"use strict";const n=e.exports,t="[",r="]",i="",u=";",o="Apple_Terminal"===process.env.TERM_PROGRAM;n.cursorTo=(e,n)=>{if("number"!=typeof e)throw new TypeError("The `x` argument is required");return"number"!=typeof n?t+(e+1)+"G":t+(n+1)+";"+(e+1)+"H"},n.cursorMove=(e,n)=>{if("number"!=typeof e)throw new TypeError("The `x` argument is required");let r="";return e<0?r+=t+-e+"D":e>0&&(r+=t+e+"C"),n<0?r+=t+-n+"A":n>0&&(r+=t+n+"B"),r},n.cursorUp=e=>t+("number"==typeof e?e:1)+"A",n.cursorDown=e=>t+("number"==typeof e?e:1)+"B",n.cursorForward=e=>t+("number"==typeof e?e:1)+"C",n.cursorBackward=e=>t+("number"==typeof e?e:1)+"D",n.cursorLeft="[G",n.cursorSavePosition=t+(o?"7":"s"),n.cursorRestorePosition=t+(o?"8":"u"),n.cursorGetPosition="[6n",n.cursorNextLine="[E",n.cursorPrevLine="[F",n.cursorHide="[?25l",n.cursorShow="[?25h",n.eraseLines=e=>{let t="";for(let r=0;r<e;r++)t+=n.eraseLine+(r<e-1?n.cursorUp():"");return e&&(t+=n.cursorLeft),t},n.eraseEndLine="[K",n.eraseStartLine="[1K",n.eraseLine="[2K",n.eraseDown="[J",n.eraseUp="[1J",n.eraseScreen="[2J",n.scrollUp="[S",n.scrollDown="[T",n.clearScreen="c",n.clearTerminal="win32"===process.platform?n.eraseScreen+"[0f":n.eraseScreen+"[3J[H",n.beep=i,n.link=(e,n)=>[r,"8",u,u,n,i,e,r,"8",u,u,i].join(""),n.image=(e,n)=>{let t=r+"1337;File=inline=1";return(n=n||{}).width&&(t+=";width="+n.width),n.height&&(t+=";height="+n.height),!1===n.preserveAspectRatio&&(t+=";preserveAspectRatio=0"),t+":"+e.toString("base64")+i},n.iTerm={},n.iTerm.setCwd=e=>r+"50;CurrentDir="+(e||process.cwd())+i},7788:e=>{"use strict";e.exports=()=>{const e=["[\\u001B\\u009B][[\\]()#;?]*(?:(?:(?:[a-zA-Z\\d]*(?:;[a-zA-Z\\d]*)*)?\\u0007)","(?:(?:\\d{1,4}(?:;\\d{0,4})*)?[\\dA-PRZcf-ntqry=><~]))"].join("|");return new RegExp(e,"g")}},5378:e=>{"use strict";e.exports=e=>{e=Object.assign({onlyFirst:!1},e);const n=["[\\u001B\\u009B][[\\]()#;?]*(?:(?:(?:[a-zA-Z\\d]*(?:;[-a-zA-Z\\d\\/#&.:=?%@~_]*)*)?\\u0007)","(?:(?:\\d{1,4}(?:;\\d{0,4})*)?[\\dA-PR-TZcf-ntqry=><~]))"].join("|");return new RegExp(n,e.onlyFirst?void 0:"g")}},5256:(e,n,t)=>{"use strict";e=t.nmd(e);const r=t(7410),i=(e,n)=>function(){const t=e.apply(r,arguments);return`[${t+n}m`},u=(e,n)=>function(){const t=e.apply(r,arguments);return`[${38+n};5;${t}m`},o=(e,n)=>function(){const t=e.apply(r,arguments);return`[${38+n};2;${t[0]};${t[1]};${t[2]}m`};Object.defineProperty(e,"exports",{enumerable:!0,get:function(){const e=new Map,n={modifier:{reset:[0,0],bold:[1,22],dim:[2,22],italic:[3,23],underline:[4,24],inverse:[7,27],hidden:[8,28],strikethrough:[9,29]},color:{black:[30,39],red:[31,39],green:[32,39],yellow:[33,39],blue:[34,39],magenta:[35,39],cyan:[36,39],white:[37,39],gray:[90,39],redBright:[91,39],greenBright:[92,39],yellowBright:[93,39],blueBright:[94,39],magentaBright:[95,39],cyanBright:[96,39],whiteBright:[97,39]},bgColor:{bgBlack:[40,49],bgRed:[41,49],bgGreen:[42,49],bgYellow:[43,49],bgBlue:[44,49],bgMagenta:[45,49],bgCyan:[46,49],bgWhite:[47,49],bgBlackBright:[100,49],bgRedBright:[101,49],bgGreenBright:[102,49],bgYellowBright:[103,49],bgBlueBright:[104,49],bgMagentaBright:[105,49],bgCyanBright:[106,49],bgWhiteBright:[107,49]}};n.color.grey=n.color.gray;for(const t of Object.keys(n)){const r=n[t];for(const t of Object.keys(r)){const i=r[t];n[t]={open:`[${i[0]}m`,close:`[${i[1]}m`},r[t]=n[t],e.set(i[0],i[1])}Object.defineProperty(n,t,{value:r,enumerable:!1}),Object.defineProperty(n,"codes",{value:e,enumerable:!1})}const t=e=>e,a=(e,n,t)=>[e,n,t];n.color.close="[39m",n.bgColor.close="[49m",n.color.ansi={ansi:i(t,0)},n.color.ansi256={ansi256:u(t,0)},n.color.ansi16m={rgb:o(a,0)},n.bgColor.ansi={ansi:i(t,10)},n.bgColor.ansi256={ansi256:u(t,10)},n.bgColor.ansi16m={rgb:o(a,10)};for(let e of Object.keys(r)){if("object"!=typeof r[e])continue;const t=r[e];"ansi16"===e&&(e="ansi"),"ansi16"in t&&(n.color.ansi[e]=i(t.ansi16,0),n.bgColor.ansi[e]=i(t.ansi16,10)),"ansi256"in t&&(n.color.ansi256[e]=u(t.ansi256,0),n.bgColor.ansi256[e]=u(t.ansi256,10)),"rgb"in t&&(n.color.ansi16m[e]=o(t.rgb,0),n.bgColor.ansi16m[e]=o(t.rgb,10))}return n}})},3810:e=>{"use strict";e.exports=function(e){return null==e?[]:Array.isArray(e)?e:[e]}},5640:e=>{"use strict";e.exports=e=>e&&e.exact?new RegExp("^[\ud800-\udbff][\udc00-\udfff]$"):new RegExp("[\ud800-\udbff][\udc00-\udfff]","g")},2939:(e,n,t)=>{"use strict";e=t.nmd(e);e.exports=(e,n)=>{n=Object.assign({},n);const t=e=>{const t=n=>"string"==typeof n?e===n:n.test(e);return n.include?n.include.some(t):!n.exclude||!n.exclude.some(t)};for(const[n,r]of(e=>{const n=new Set;do{for(const t of Reflect.ownKeys(e))n.add([e,t])}while((e=Reflect.getPrototypeOf(e))&&e!==Object.prototype);return n})(e.constructor.prototype)){if("constructor"===r||!t(r))continue;const i=Reflect.getOwnPropertyDescriptor(n,r);i&&"function"==typeof i.value&&(e[r]=e[r].bind(e))}return e};const r=["componentWillMount","UNSAFE_componentWillMount","render","getSnapshotBeforeUpdate","componentDidMount","componentWillReceiveProps","UNSAFE_componentWillReceiveProps","shouldComponentUpdate","componentWillUpdate","UNSAFE_componentWillUpdate","componentDidUpdate","componentWillUnmount","componentDidCatch","setState","forceUpdate"];e.exports.react=(n,t)=>((t=Object.assign({},t)).exclude=(t.exclude||[]).concat(r),e.exports(n,t))},9244:(e,n,t)=>{"use strict";const r=t(6349),i=t(5256),u=t(5180).stdout,o=t(2831),a="win32"===process.platform&&!(process.env.TERM||"").toLowerCase().startsWith("xterm"),l=["ansi","ansi","ansi256","ansi16m"],s=new Set(["gray"]),f=Object.create(null);function c(e,n){n=n||{};const t=u?u.level:0;e.level=void 0===n.level?t:n.level,e.enabled="enabled"in n?n.enabled:e.level>0}function d(e){if(!this||!(this instanceof d)||this.template){const n={};return c(n,e),n.template=function(){const e=[].slice.call(arguments);return v.apply(null,[n.template].concat(e))},Object.setPrototypeOf(n,d.prototype),Object.setPrototypeOf(n.template,n),n.template.constructor=d,n.template}c(this,e)}a&&(i.blue.open="[94m");for(const e of Object.keys(i))i[e].closeRe=new RegExp(r(i[e].close),"g"),f[e]={get(){const n=i[e];return h.call(this,this._styles?this._styles.concat(n):[n],this._empty,e)}};f.visible={get(){return h.call(this,this._styles||[],!0,"visible")}},i.color.closeRe=new RegExp(r(i.color.close),"g");for(const e of Object.keys(i.color.ansi))s.has(e)||(f[e]={get(){const n=this.level;return function(){const t=i.color[l[n]][e].apply(null,arguments),r={open:t,close:i.color.close,closeRe:i.color.closeRe};return h.call(this,this._styles?this._styles.concat(r):[r],this._empty,e)}}});i.bgColor.closeRe=new RegExp(r(i.bgColor.close),"g");for(const e of Object.keys(i.bgColor.ansi)){if(s.has(e))continue;f["bg"+e[0].toUpperCase()+e.slice(1)]={get(){const n=this.level;return function(){const t=i.bgColor[l[n]][e].apply(null,arguments),r={open:t,close:i.bgColor.close,closeRe:i.bgColor.closeRe};return h.call(this,this._styles?this._styles.concat(r):[r],this._empty,e)}}}}const p=Object.defineProperties(()=>{},f);function h(e,n,t){const r=function(){return m.apply(r,arguments)};r._styles=e,r._empty=n;const i=this;return Object.defineProperty(r,"level",{enumerable:!0,get:()=>i.level,set(e){i.level=e}}),Object.defineProperty(r,"enabled",{enumerable:!0,get:()=>i.enabled,set(e){i.enabled=e}}),r.hasGrey=this.hasGrey||"gray"===t||"grey"===t,r.__proto__=p,r}function m(){const e=arguments,n=e.length;let t=String(arguments[0]);if(0===n)return"";if(n>1)for(let r=1;r<n;r++)t+=" "+e[r];if(!this.enabled||this.level<=0||!t)return this._empty?"":t;const r=i.dim.open;a&&this.hasGrey&&(i.dim.open="");for(const e of this._styles.slice().reverse())t=e.open+t.replace(e.closeRe,e.open)+e.close,t=t.replace(/\r?\n/g,`${e.close}$&${e.open}`);return i.dim.open=r,t}function v(e,n){if(!Array.isArray(n))return[].slice.call(arguments,1).join(" ");const t=[].slice.call(arguments,2),r=[n.raw[0]];for(let e=1;e<n.length;e++)r.push(String(t[e-1]).replace(/[{}\\]/g,"\\$&")),r.push(String(n.raw[e]));return o(e,r.join(""))}Object.defineProperties(d.prototype,f),e.exports=d(),e.exports.supportsColor=u,e.exports.default=e.exports},2831:e=>{"use strict";const n=/(?:\\(u[a-f\d]{4}|x[a-f\d]{2}|.))|(?:\{(~)?(\w+(?:\([^)]*\))?(?:\.\w+(?:\([^)]*\))?)*)(?:[ \t]|(?=\r?\n)))|(\})|((?:.|[\r\n\f])+?)/gi,t=/(?:^|\.)(\w+)(?:\(([^)]*)\))?/g,r=/^(['"])((?:\\.|(?!\1)[^\\])*)\1$/,i=/\\(u[a-f\d]{4}|x[a-f\d]{2}|.)|([^\\])/gi,u=new Map([["n","\n"],["r","\r"],["t","\t"],["b","\b"],["f","\f"],["v","\v"],["0","\0"],["\\","\\"],["e",""],["a",""]]);function o(e){return"u"===e[0]&&5===e.length||"x"===e[0]&&3===e.length?String.fromCharCode(parseInt(e.slice(1),16)):u.get(e)||e}function a(e,n){const t=[],u=n.trim().split(/\s*,\s*/g);let a;for(const n of u)if(isNaN(n)){if(!(a=n.match(r)))throw new Error(`Invalid Chalk template style argument: ${n} (in style '${e}')`);t.push(a[2].replace(i,(e,n,t)=>n?o(n):t))}else t.push(Number(n));return t}function l(e){t.lastIndex=0;const n=[];let r;for(;null!==(r=t.exec(e));){const e=r[1];if(r[2]){const t=a(e,r[2]);n.push([e].concat(t))}else n.push([e])}return n}function s(e,n){const t={};for(const e of n)for(const n of e.styles)t[n[0]]=e.inverse?null:n.slice(1);let r=e;for(const e of Object.keys(t))if(Array.isArray(t[e])){if(!(e in r))throw new Error("Unknown Chalk style: "+e);r=t[e].length>0?r[e].apply(r,t[e]):r[e]}return r}e.exports=(e,t)=>{const r=[],i=[];let u=[];if(t.replace(n,(n,t,a,f,c,d)=>{if(t)u.push(o(t));else if(f){const n=u.join("");u=[],i.push(0===r.length?n:s(e,r)(n)),r.push({inverse:a,styles:l(f)})}else if(c){if(0===r.length)throw new Error("Found extraneous } in Chalk template literal");i.push(s(e,r)(u.join(""))),u=[],r.pop()}else u.push(d)}),i.push(u.join("")),r.length>0){const e=`Chalk template literal is missing ${r.length} closing bracket${1===r.length?"":"s"} (\`}\`)`;throw new Error(e)}return i.join("")}},5864:(e,n,t)=>{"use strict";var r=t(5832),i=process.env;function u(e){return"string"==typeof e?!!i[e]:Object.keys(e).every((function(n){return i[n]===e[n]}))}Object.defineProperty(n,"_vendors",{value:r.map((function(e){return e.constant}))}),n.name=null,n.isPR=null,r.forEach((function(e){var t=(Array.isArray(e.env)?e.env:[e.env]).every((function(e){return u(e)}));if(n[e.constant]=t,t)switch(n.name=e.name,typeof e.pr){case"string":n.isPR=!!i[e.pr];break;case"object":"env"in e.pr?n.isPR=e.pr.env in i&&i[e.pr.env]!==e.pr.ne:"any"in e.pr?n.isPR=e.pr.any.some((function(e){return!!i[e]})):n.isPR=u(e.pr);break;default:n.isPR=null}})),n.isCI=!!(i.CI||i.CONTINUOUS_INTEGRATION||i.BUILD_NUMBER||i.RUN_ID||n.name)},5832:e=>{"use strict";e.exports=JSON.parse('[{"name":"AppVeyor","constant":"APPVEYOR","env":"APPVEYOR","pr":"APPVEYOR_PULL_REQUEST_NUMBER"},{"name":"Azure Pipelines","constant":"AZURE_PIPELINES","env":"SYSTEM_TEAMFOUNDATIONCOLLECTIONURI","pr":"SYSTEM_PULLREQUEST_PULLREQUESTID"},{"name":"Bamboo","constant":"BAMBOO","env":"bamboo_planKey"},{"name":"Bitbucket Pipelines","constant":"BITBUCKET","env":"BITBUCKET_COMMIT","pr":"BITBUCKET_PR_ID"},{"name":"Bitrise","constant":"BITRISE","env":"BITRISE_IO","pr":"BITRISE_PULL_REQUEST"},{"name":"Buddy","constant":"BUDDY","env":"BUDDY_WORKSPACE_ID","pr":"BUDDY_EXECUTION_PULL_REQUEST_ID"},{"name":"Buildkite","constant":"BUILDKITE","env":"BUILDKITE","pr":{"env":"BUILDKITE_PULL_REQUEST","ne":"false"}},{"name":"CircleCI","constant":"CIRCLE","env":"CIRCLECI","pr":"CIRCLE_PULL_REQUEST"},{"name":"Cirrus CI","constant":"CIRRUS","env":"CIRRUS_CI","pr":"CIRRUS_PR"},{"name":"AWS CodeBuild","constant":"CODEBUILD","env":"CODEBUILD_BUILD_ARN"},{"name":"Codeship","constant":"CODESHIP","env":{"CI_NAME":"codeship"}},{"name":"Drone","constant":"DRONE","env":"DRONE","pr":{"DRONE_BUILD_EVENT":"pull_request"}},{"name":"dsari","constant":"DSARI","env":"DSARI"},{"name":"GitLab CI","constant":"GITLAB","env":"GITLAB_CI"},{"name":"GoCD","constant":"GOCD","env":"GO_PIPELINE_LABEL"},{"name":"Hudson","constant":"HUDSON","env":"HUDSON_URL"},{"name":"Jenkins","constant":"JENKINS","env":["JENKINS_URL","BUILD_ID"],"pr":{"any":["ghprbPullId","CHANGE_ID"]}},{"name":"Magnum CI","constant":"MAGNUM","env":"MAGNUM"},{"name":"Netlify CI","constant":"NETLIFY","env":"NETLIFY_BUILD_BASE","pr":{"env":"PULL_REQUEST","ne":"false"}},{"name":"Sail CI","constant":"SAIL","env":"SAILCI","pr":"SAIL_PULL_REQUEST_NUMBER"},{"name":"Semaphore","constant":"SEMAPHORE","env":"SEMAPHORE","pr":"PULL_REQUEST_NUMBER"},{"name":"Shippable","constant":"SHIPPABLE","env":"SHIPPABLE","pr":{"IS_PULL_REQUEST":"true"}},{"name":"Solano CI","constant":"SOLANO","env":"TDDIUM","pr":"TDDIUM_PR_ID"},{"name":"Strider CD","constant":"STRIDER","env":"STRIDER"},{"name":"TaskCluster","constant":"TASKCLUSTER","env":["TASK_ID","RUN_ID"]},{"name":"TeamCity","constant":"TEAMCITY","env":"TEAMCITY_VERSION"},{"name":"Travis CI","constant":"TRAVIS","env":"TRAVIS","pr":{"env":"TRAVIS_PULL_REQUEST","ne":"false"}}]')},1305:(e,n,t)=>{"use strict";const r=t(2428);let i=!1;n.show=e=>{const n=e||process.stderr;n.isTTY&&(i=!1,n.write("[?25h"))},n.hide=e=>{const n=e||process.stderr;n.isTTY&&(r(),i=!0,n.write("[?25l"))},n.toggle=(e,t)=>{void 0!==e&&(i=e),i?n.show(t):n.hide(t)}},4093:(e,n,t)=>{"use strict";const r=t(7498),i=t(5478);e.exports=(e,n,t)=>{const u=(t=Object.assign({position:"end"},t)).position;if("string"!=typeof e)throw new TypeError("Expected `input` to be a string, got "+typeof e);if("number"!=typeof n)throw new TypeError("Expected `columns` to be a number, got "+typeof n);if(n<1)return"";if(1===n)return"…";const o=i(e);if(o<=n)return e;if("start"===u)return"…"+r(e,o-n+1,o);if("middle"===u){const t=Math.floor(n/2);return r(e,0,t)+"…"+r(e,o-(n-t)+1,o)}if("end"===u)return r(e,0,n-1)+"…";throw new Error("Expected `options.position` to be either `start`, `middle` or `end`, got "+u)}},9486:(e,n,t)=>{var r=t(3110),i={};for(var u in r)r.hasOwnProperty(u)&&(i[r[u]]=u);var o=e.exports={rgb:{channels:3,labels:"rgb"},hsl:{channels:3,labels:"hsl"},hsv:{channels:3,labels:"hsv"},hwb:{channels:3,labels:"hwb"},cmyk:{channels:4,labels:"cmyk"},xyz:{channels:3,labels:"xyz"},lab:{channels:3,labels:"lab"},lch:{channels:3,labels:"lch"},hex:{channels:1,labels:["hex"]},keyword:{channels:1,labels:["keyword"]},ansi16:{channels:1,labels:["ansi16"]},ansi256:{channels:1,labels:["ansi256"]},hcg:{channels:3,labels:["h","c","g"]},apple:{channels:3,labels:["r16","g16","b16"]},gray:{channels:1,labels:["gray"]}};for(var a in o)if(o.hasOwnProperty(a)){if(!("channels"in o[a]))throw new Error("missing channels property: "+a);if(!("labels"in o[a]))throw new Error("missing channel labels property: "+a);if(o[a].labels.length!==o[a].channels)throw new Error("channel and label counts mismatch: "+a);var l=o[a].channels,s=o[a].labels;delete o[a].channels,delete o[a].labels,Object.defineProperty(o[a],"channels",{value:l}),Object.defineProperty(o[a],"labels",{value:s})}o.rgb.hsl=function(e){var n,t,r=e[0]/255,i=e[1]/255,u=e[2]/255,o=Math.min(r,i,u),a=Math.max(r,i,u),l=a-o;return a===o?n=0:r===a?n=(i-u)/l:i===a?n=2+(u-r)/l:u===a&&(n=4+(r-i)/l),(n=Math.min(60*n,360))<0&&(n+=360),t=(o+a)/2,[n,100*(a===o?0:t<=.5?l/(a+o):l/(2-a-o)),100*t]},o.rgb.hsv=function(e){var n,t,r,i,u,o=e[0]/255,a=e[1]/255,l=e[2]/255,s=Math.max(o,a,l),f=s-Math.min(o,a,l),c=function(e){return(s-e)/6/f+.5};return 0===f?i=u=0:(u=f/s,n=c(o),t=c(a),r=c(l),o===s?i=r-t:a===s?i=1/3+n-r:l===s&&(i=2/3+t-n),i<0?i+=1:i>1&&(i-=1)),[360*i,100*u,100*s]},o.rgb.hwb=function(e){var n=e[0],t=e[1],r=e[2];return[o.rgb.hsl(e)[0],100*(1/255*Math.min(n,Math.min(t,r))),100*(r=1-1/255*Math.max(n,Math.max(t,r)))]},o.rgb.cmyk=function(e){var n,t=e[0]/255,r=e[1]/255,i=e[2]/255;return[100*((1-t-(n=Math.min(1-t,1-r,1-i)))/(1-n)||0),100*((1-r-n)/(1-n)||0),100*((1-i-n)/(1-n)||0),100*n]},o.rgb.keyword=function(e){var n=i[e];if(n)return n;var t,u,o,a=1/0;for(var l in r)if(r.hasOwnProperty(l)){var s=r[l],f=(u=e,o=s,Math.pow(u[0]-o[0],2)+Math.pow(u[1]-o[1],2)+Math.pow(u[2]-o[2],2));f<a&&(a=f,t=l)}return t},o.keyword.rgb=function(e){return r[e]},o.rgb.xyz=function(e){var n=e[0]/255,t=e[1]/255,r=e[2]/255;return[100*(.4124*(n=n>.04045?Math.pow((n+.055)/1.055,2.4):n/12.92)+.3576*(t=t>.04045?Math.pow((t+.055)/1.055,2.4):t/12.92)+.1805*(r=r>.04045?Math.pow((r+.055)/1.055,2.4):r/12.92)),100*(.2126*n+.7152*t+.0722*r),100*(.0193*n+.1192*t+.9505*r)]},o.rgb.lab=function(e){var n=o.rgb.xyz(e),t=n[0],r=n[1],i=n[2];return r/=100,i/=108.883,t=(t/=95.047)>.008856?Math.pow(t,1/3):7.787*t+16/116,[116*(r=r>.008856?Math.pow(r,1/3):7.787*r+16/116)-16,500*(t-r),200*(r-(i=i>.008856?Math.pow(i,1/3):7.787*i+16/116))]},o.hsl.rgb=function(e){var n,t,r,i,u,o=e[0]/360,a=e[1]/100,l=e[2]/100;if(0===a)return[u=255*l,u,u];n=2*l-(t=l<.5?l*(1+a):l+a-l*a),i=[0,0,0];for(var s=0;s<3;s++)(r=o+1/3*-(s-1))<0&&r++,r>1&&r--,u=6*r<1?n+6*(t-n)*r:2*r<1?t:3*r<2?n+(t-n)*(2/3-r)*6:n,i[s]=255*u;return i},o.hsl.hsv=function(e){var n=e[0],t=e[1]/100,r=e[2]/100,i=t,u=Math.max(r,.01);return t*=(r*=2)<=1?r:2-r,i*=u<=1?u:2-u,[n,100*(0===r?2*i/(u+i):2*t/(r+t)),100*((r+t)/2)]},o.hsv.rgb=function(e){var n=e[0]/60,t=e[1]/100,r=e[2]/100,i=Math.floor(n)%6,u=n-Math.floor(n),o=255*r*(1-t),a=255*r*(1-t*u),l=255*r*(1-t*(1-u));switch(r*=255,i){case 0:return[r,l,o];case 1:return[a,r,o];case 2:return[o,r,l];case 3:return[o,a,r];case 4:return[l,o,r];case 5:return[r,o,a]}},o.hsv.hsl=function(e){var n,t,r,i=e[0],u=e[1]/100,o=e[2]/100,a=Math.max(o,.01);return r=(2-u)*o,t=u*a,[i,100*(t=(t/=(n=(2-u)*a)<=1?n:2-n)||0),100*(r/=2)]},o.hwb.rgb=function(e){var n,t,r,i,u,o,a,l=e[0]/360,s=e[1]/100,f=e[2]/100,c=s+f;switch(c>1&&(s/=c,f/=c),r=6*l-(n=Math.floor(6*l)),0!=(1&n)&&(r=1-r),i=s+r*((t=1-f)-s),n){default:case 6:case 0:u=t,o=i,a=s;break;case 1:u=i,o=t,a=s;break;case 2:u=s,o=t,a=i;break;case 3:u=s,o=i,a=t;break;case 4:u=i,o=s,a=t;break;case 5:u=t,o=s,a=i}return[255*u,255*o,255*a]},o.cmyk.rgb=function(e){var n=e[0]/100,t=e[1]/100,r=e[2]/100,i=e[3]/100;return[255*(1-Math.min(1,n*(1-i)+i)),255*(1-Math.min(1,t*(1-i)+i)),255*(1-Math.min(1,r*(1-i)+i))]},o.xyz.rgb=function(e){var n,t,r,i=e[0]/100,u=e[1]/100,o=e[2]/100;return t=-.9689*i+1.8758*u+.0415*o,r=.0557*i+-.204*u+1.057*o,n=(n=3.2406*i+-1.5372*u+-.4986*o)>.0031308?1.055*Math.pow(n,1/2.4)-.055:12.92*n,t=t>.0031308?1.055*Math.pow(t,1/2.4)-.055:12.92*t,r=r>.0031308?1.055*Math.pow(r,1/2.4)-.055:12.92*r,[255*(n=Math.min(Math.max(0,n),1)),255*(t=Math.min(Math.max(0,t),1)),255*(r=Math.min(Math.max(0,r),1))]},o.xyz.lab=function(e){var n=e[0],t=e[1],r=e[2];return t/=100,r/=108.883,n=(n/=95.047)>.008856?Math.pow(n,1/3):7.787*n+16/116,[116*(t=t>.008856?Math.pow(t,1/3):7.787*t+16/116)-16,500*(n-t),200*(t-(r=r>.008856?Math.pow(r,1/3):7.787*r+16/116))]},o.lab.xyz=function(e){var n,t,r,i=e[0];n=e[1]/500+(t=(i+16)/116),r=t-e[2]/200;var u=Math.pow(t,3),o=Math.pow(n,3),a=Math.pow(r,3);return t=u>.008856?u:(t-16/116)/7.787,n=o>.008856?o:(n-16/116)/7.787,r=a>.008856?a:(r-16/116)/7.787,[n*=95.047,t*=100,r*=108.883]},o.lab.lch=function(e){var n,t=e[0],r=e[1],i=e[2];return(n=360*Math.atan2(i,r)/2/Math.PI)<0&&(n+=360),[t,Math.sqrt(r*r+i*i),n]},o.lch.lab=function(e){var n,t=e[0],r=e[1];return n=e[2]/360*2*Math.PI,[t,r*Math.cos(n),r*Math.sin(n)]},o.rgb.ansi16=function(e){var n=e[0],t=e[1],r=e[2],i=1 in arguments?arguments[1]:o.rgb.hsv(e)[2];if(0===(i=Math.round(i/50)))return 30;var u=30+(Math.round(r/255)<<2|Math.round(t/255)<<1|Math.round(n/255));return 2===i&&(u+=60),u},o.hsv.ansi16=function(e){return o.rgb.ansi16(o.hsv.rgb(e),e[2])},o.rgb.ansi256=function(e){var n=e[0],t=e[1],r=e[2];return n===t&&t===r?n<8?16:n>248?231:Math.round((n-8)/247*24)+232:16+36*Math.round(n/255*5)+6*Math.round(t/255*5)+Math.round(r/255*5)},o.ansi16.rgb=function(e){var n=e%10;if(0===n||7===n)return e>50&&(n+=3.5),[n=n/10.5*255,n,n];var t=.5*(1+~~(e>50));return[(1&n)*t*255,(n>>1&1)*t*255,(n>>2&1)*t*255]},o.ansi256.rgb=function(e){if(e>=232){var n=10*(e-232)+8;return[n,n,n]}var t;return e-=16,[Math.floor(e/36)/5*255,Math.floor((t=e%36)/6)/5*255,t%6/5*255]},o.rgb.hex=function(e){var n=(((255&Math.round(e[0]))<<16)+((255&Math.round(e[1]))<<8)+(255&Math.round(e[2]))).toString(16).toUpperCase();return"000000".substring(n.length)+n},o.hex.rgb=function(e){var n=e.toString(16).match(/[a-f0-9]{6}|[a-f0-9]{3}/i);if(!n)return[0,0,0];var t=n[0];3===n[0].length&&(t=t.split("").map((function(e){return e+e})).join(""));var r=parseInt(t,16);return[r>>16&255,r>>8&255,255&r]},o.rgb.hcg=function(e){var n,t=e[0]/255,r=e[1]/255,i=e[2]/255,u=Math.max(Math.max(t,r),i),o=Math.min(Math.min(t,r),i),a=u-o;return n=a<=0?0:u===t?(r-i)/a%6:u===r?2+(i-t)/a:4+(t-r)/a+4,n/=6,[360*(n%=1),100*a,100*(a<1?o/(1-a):0)]},o.hsl.hcg=function(e){var n=e[1]/100,t=e[2]/100,r=1,i=0;return(r=t<.5?2*n*t:2*n*(1-t))<1&&(i=(t-.5*r)/(1-r)),[e[0],100*r,100*i]},o.hsv.hcg=function(e){var n=e[1]/100,t=e[2]/100,r=n*t,i=0;return r<1&&(i=(t-r)/(1-r)),[e[0],100*r,100*i]},o.hcg.rgb=function(e){var n=e[0]/360,t=e[1]/100,r=e[2]/100;if(0===t)return[255*r,255*r,255*r];var i,u=[0,0,0],o=n%1*6,a=o%1,l=1-a;switch(Math.floor(o)){case 0:u[0]=1,u[1]=a,u[2]=0;break;case 1:u[0]=l,u[1]=1,u[2]=0;break;case 2:u[0]=0,u[1]=1,u[2]=a;break;case 3:u[0]=0,u[1]=l,u[2]=1;break;case 4:u[0]=a,u[1]=0,u[2]=1;break;default:u[0]=1,u[1]=0,u[2]=l}return i=(1-t)*r,[255*(t*u[0]+i),255*(t*u[1]+i),255*(t*u[2]+i)]},o.hcg.hsv=function(e){var n=e[1]/100,t=n+e[2]/100*(1-n),r=0;return t>0&&(r=n/t),[e[0],100*r,100*t]},o.hcg.hsl=function(e){var n=e[1]/100,t=e[2]/100*(1-n)+.5*n,r=0;return t>0&&t<.5?r=n/(2*t):t>=.5&&t<1&&(r=n/(2*(1-t))),[e[0],100*r,100*t]},o.hcg.hwb=function(e){var n=e[1]/100,t=n+e[2]/100*(1-n);return[e[0],100*(t-n),100*(1-t)]},o.hwb.hcg=function(e){var n=e[1]/100,t=1-e[2]/100,r=t-n,i=0;return r<1&&(i=(t-r)/(1-r)),[e[0],100*r,100*i]},o.apple.rgb=function(e){return[e[0]/65535*255,e[1]/65535*255,e[2]/65535*255]},o.rgb.apple=function(e){return[e[0]/255*65535,e[1]/255*65535,e[2]/255*65535]},o.gray.rgb=function(e){return[e[0]/100*255,e[0]/100*255,e[0]/100*255]},o.gray.hsl=o.gray.hsv=function(e){return[0,0,e[0]]},o.gray.hwb=function(e){return[0,100,e[0]]},o.gray.cmyk=function(e){return[0,0,0,e[0]]},o.gray.lab=function(e){return[e[0],0,0]},o.gray.hex=function(e){var n=255&Math.round(e[0]/100*255),t=((n<<16)+(n<<8)+n).toString(16).toUpperCase();return"000000".substring(t.length)+t},o.rgb.gray=function(e){return[(e[0]+e[1]+e[2])/3/255*100]}},7410:(e,n,t)=>{var r=t(9486),i=t(9445),u={};Object.keys(r).forEach((function(e){u[e]={},Object.defineProperty(u[e],"channels",{value:r[e].channels}),Object.defineProperty(u[e],"labels",{value:r[e].labels});var n=i(e);Object.keys(n).forEach((function(t){var r=n[t];u[e][t]=function(e){var n=function(n){if(null==n)return n;arguments.length>1&&(n=Array.prototype.slice.call(arguments));var t=e(n);if("object"==typeof t)for(var r=t.length,i=0;i<r;i++)t[i]=Math.round(t[i]);return t};return"conversion"in e&&(n.conversion=e.conversion),n}(r),u[e][t].raw=function(e){var n=function(n){return null==n?n:(arguments.length>1&&(n=Array.prototype.slice.call(arguments)),e(n))};return"conversion"in e&&(n.conversion=e.conversion),n}(r)}))})),e.exports=u},9445:(e,n,t)=>{var r=t(9486);function i(e){var n=function(){for(var e={},n=Object.keys(r),t=n.length,i=0;i<t;i++)e[n[i]]={distance:-1,parent:null};return e}(),t=[e];for(n[e].distance=0;t.length;)for(var i=t.pop(),u=Object.keys(r[i]),o=u.length,a=0;a<o;a++){var l=u[a],s=n[l];-1===s.distance&&(s.distance=n[i].distance+1,s.parent=i,t.unshift(l))}return n}function u(e,n){return function(t){return n(e(t))}}function o(e,n){for(var t=[n[e].parent,e],i=r[n[e].parent][e],o=n[e].parent;n[o].parent;)t.unshift(n[o].parent),i=u(r[n[o].parent][o],i),o=n[o].parent;return i.conversion=t,i}e.exports=function(e){for(var n=i(e),t={},r=Object.keys(n),u=r.length,a=0;a<u;a++){var l=r[a];null!==n[l].parent&&(t[l]=o(l,n))}return t}},3110:e=>{"use strict";e.exports={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]}},2517:e=>{"use strict";e.exports=function(){return/\uD83C\uDFF4(?:\uDB40\uDC67\uDB40\uDC62(?:\uDB40\uDC65\uDB40\uDC6E\uDB40\uDC67|\uDB40\uDC77\uDB40\uDC6C\uDB40\uDC73|\uDB40\uDC73\uDB40\uDC63\uDB40\uDC74)\uDB40\uDC7F|\u200D\u2620\uFE0F)|\uD83D\uDC69\u200D\uD83D\uDC69\u200D(?:\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67]))|\uD83D\uDC68(?:\u200D(?:\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83D\uDC68|(?:\uD83D[\uDC68\uDC69])\u200D(?:\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67]))|\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDB0-\uDDB3])|(?:\uD83C[\uDFFB-\uDFFF])\u200D(?:\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDB0-\uDDB3]))|\uD83D\uDC69\u200D(?:\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D(?:\uD83D[\uDC68\uDC69])|\uD83D[\uDC68\uDC69])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDB0-\uDDB3])|\uD83D\uDC69\u200D\uD83D\uDC66\u200D\uD83D\uDC66|(?:\uD83D\uDC41\uFE0F\u200D\uD83D\uDDE8|\uD83D\uDC69(?:\uD83C[\uDFFB-\uDFFF])\u200D[\u2695\u2696\u2708]|\uD83D\uDC68(?:(?:\uD83C[\uDFFB-\uDFFF])\u200D[\u2695\u2696\u2708]|\u200D[\u2695\u2696\u2708])|(?:(?:\u26F9|\uD83C[\uDFCB\uDFCC]|\uD83D\uDD75)\uFE0F|\uD83D\uDC6F|\uD83E[\uDD3C\uDDDE\uDDDF])\u200D[\u2640\u2642]|(?:\u26F9|\uD83C[\uDFCB\uDFCC]|\uD83D\uDD75)(?:\uD83C[\uDFFB-\uDFFF])\u200D[\u2640\u2642]|(?:\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDD6-\uDDDD])(?:(?:\uD83C[\uDFFB-\uDFFF])\u200D[\u2640\u2642]|\u200D[\u2640\u2642])|\uD83D\uDC69\u200D[\u2695\u2696\u2708])\uFE0F|\uD83D\uDC69\u200D\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67])|\uD83D\uDC69\u200D\uD83D\uDC69\u200D(?:\uD83D[\uDC66\uDC67])|\uD83D\uDC68(?:\u200D(?:(?:\uD83D[\uDC68\uDC69])\u200D(?:\uD83D[\uDC66\uDC67])|\uD83D[\uDC66\uDC67])|\uD83C[\uDFFB-\uDFFF])|\uD83C\uDFF3\uFE0F\u200D\uD83C\uDF08|\uD83D\uDC69\u200D\uD83D\uDC67|\uD83D\uDC69(?:\uD83C[\uDFFB-\uDFFF])\u200D(?:\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDB0-\uDDB3])|\uD83D\uDC69\u200D\uD83D\uDC66|\uD83C\uDDF6\uD83C\uDDE6|\uD83C\uDDFD\uD83C\uDDF0|\uD83C\uDDF4\uD83C\uDDF2|\uD83D\uDC69(?:\uD83C[\uDFFB-\uDFFF])|\uD83C\uDDED(?:\uD83C[\uDDF0\uDDF2\uDDF3\uDDF7\uDDF9\uDDFA])|\uD83C\uDDEC(?:\uD83C[\uDDE6\uDDE7\uDDE9-\uDDEE\uDDF1-\uDDF3\uDDF5-\uDDFA\uDDFC\uDDFE])|\uD83C\uDDEA(?:\uD83C[\uDDE6\uDDE8\uDDEA\uDDEC\uDDED\uDDF7-\uDDFA])|\uD83C\uDDE8(?:\uD83C[\uDDE6\uDDE8\uDDE9\uDDEB-\uDDEE\uDDF0-\uDDF5\uDDF7\uDDFA-\uDDFF])|\uD83C\uDDF2(?:\uD83C[\uDDE6\uDDE8-\uDDED\uDDF0-\uDDFF])|\uD83C\uDDF3(?:\uD83C[\uDDE6\uDDE8\uDDEA-\uDDEC\uDDEE\uDDF1\uDDF4\uDDF5\uDDF7\uDDFA\uDDFF])|\uD83C\uDDFC(?:\uD83C[\uDDEB\uDDF8])|\uD83C\uDDFA(?:\uD83C[\uDDE6\uDDEC\uDDF2\uDDF3\uDDF8\uDDFE\uDDFF])|\uD83C\uDDF0(?:\uD83C[\uDDEA\uDDEC-\uDDEE\uDDF2\uDDF3\uDDF5\uDDF7\uDDFC\uDDFE\uDDFF])|\uD83C\uDDEF(?:\uD83C[\uDDEA\uDDF2\uDDF4\uDDF5])|\uD83C\uDDF8(?:\uD83C[\uDDE6-\uDDEA\uDDEC-\uDDF4\uDDF7-\uDDF9\uDDFB\uDDFD-\uDDFF])|\uD83C\uDDEE(?:\uD83C[\uDDE8-\uDDEA\uDDF1-\uDDF4\uDDF6-\uDDF9])|\uD83C\uDDFF(?:\uD83C[\uDDE6\uDDF2\uDDFC])|\uD83C\uDDEB(?:\uD83C[\uDDEE-\uDDF0\uDDF2\uDDF4\uDDF7])|\uD83C\uDDF5(?:\uD83C[\uDDE6\uDDEA-\uDDED\uDDF0-\uDDF3\uDDF7-\uDDF9\uDDFC\uDDFE])|\uD83C\uDDE9(?:\uD83C[\uDDEA\uDDEC\uDDEF\uDDF0\uDDF2\uDDF4\uDDFF])|\uD83C\uDDF9(?:\uD83C[\uDDE6\uDDE8\uDDE9\uDDEB-\uDDED\uDDEF-\uDDF4\uDDF7\uDDF9\uDDFB\uDDFC\uDDFF])|\uD83C\uDDE7(?:\uD83C[\uDDE6\uDDE7\uDDE9-\uDDEF\uDDF1-\uDDF4\uDDF6-\uDDF9\uDDFB\uDDFC\uDDFE\uDDFF])|[#\*0-9]\uFE0F\u20E3|\uD83C\uDDF1(?:\uD83C[\uDDE6-\uDDE8\uDDEE\uDDF0\uDDF7-\uDDFB\uDDFE])|\uD83C\uDDE6(?:\uD83C[\uDDE8-\uDDEC\uDDEE\uDDF1\uDDF2\uDDF4\uDDF6-\uDDFA\uDDFC\uDDFD\uDDFF])|\uD83C\uDDF7(?:\uD83C[\uDDEA\uDDF4\uDDF8\uDDFA\uDDFC])|\uD83C\uDDFB(?:\uD83C[\uDDE6\uDDE8\uDDEA\uDDEC\uDDEE\uDDF3\uDDFA])|\uD83C\uDDFE(?:\uD83C[\uDDEA\uDDF9])|(?:\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDD6-\uDDDD])(?:\uD83C[\uDFFB-\uDFFF])|(?:\u26F9|\uD83C[\uDFCB\uDFCC]|\uD83D\uDD75)(?:\uD83C[\uDFFB-\uDFFF])|(?:[\u261D\u270A-\u270D]|\uD83C[\uDF85\uDFC2\uDFC7]|\uD83D[\uDC42\uDC43\uDC46-\uDC50\uDC66\uDC67\uDC70\uDC72\uDC74-\uDC76\uDC78\uDC7C\uDC83\uDC85\uDCAA\uDD74\uDD7A\uDD90\uDD95\uDD96\uDE4C\uDE4F\uDEC0\uDECC]|\uD83E[\uDD18-\uDD1C\uDD1E\uDD1F\uDD30-\uDD36\uDDB5\uDDB6\uDDD1-\uDDD5])(?:\uD83C[\uDFFB-\uDFFF])|(?:[\u231A\u231B\u23E9-\u23EC\u23F0\u23F3\u25FD\u25FE\u2614\u2615\u2648-\u2653\u267F\u2693\u26A1\u26AA\u26AB\u26BD\u26BE\u26C4\u26C5\u26CE\u26D4\u26EA\u26F2\u26F3\u26F5\u26FA\u26FD\u2705\u270A\u270B\u2728\u274C\u274E\u2753-\u2755\u2757\u2795-\u2797\u27B0\u27BF\u2B1B\u2B1C\u2B50\u2B55]|\uD83C[\uDC04\uDCCF\uDD8E\uDD91-\uDD9A\uDDE6-\uDDFF\uDE01\uDE1A\uDE2F\uDE32-\uDE36\uDE38-\uDE3A\uDE50\uDE51\uDF00-\uDF20\uDF2D-\uDF35\uDF37-\uDF7C\uDF7E-\uDF93\uDFA0-\uDFCA\uDFCF-\uDFD3\uDFE0-\uDFF0\uDFF4\uDFF8-\uDFFF]|\uD83D[\uDC00-\uDC3E\uDC40\uDC42-\uDCFC\uDCFF-\uDD3D\uDD4B-\uDD4E\uDD50-\uDD67\uDD7A\uDD95\uDD96\uDDA4\uDDFB-\uDE4F\uDE80-\uDEC5\uDECC\uDED0-\uDED2\uDEEB\uDEEC\uDEF4-\uDEF9]|\uD83E[\uDD10-\uDD3A\uDD3C-\uDD3E\uDD40-\uDD45\uDD47-\uDD70\uDD73-\uDD76\uDD7A\uDD7C-\uDDA2\uDDB0-\uDDB9\uDDC0-\uDDC2\uDDD0-\uDDFF])|(?:[#\*0-9\xA9\xAE\u203C\u2049\u2122\u2139\u2194-\u2199\u21A9\u21AA\u231A\u231B\u2328\u23CF\u23E9-\u23F3\u23F8-\u23FA\u24C2\u25AA\u25AB\u25B6\u25C0\u25FB-\u25FE\u2600-\u2604\u260E\u2611\u2614\u2615\u2618\u261D\u2620\u2622\u2623\u2626\u262A\u262E\u262F\u2638-\u263A\u2640\u2642\u2648-\u2653\u265F\u2660\u2663\u2665\u2666\u2668\u267B\u267E\u267F\u2692-\u2697\u2699\u269B\u269C\u26A0\u26A1\u26AA\u26AB\u26B0\u26B1\u26BD\u26BE\u26C4\u26C5\u26C8\u26CE\u26CF\u26D1\u26D3\u26D4\u26E9\u26EA\u26F0-\u26F5\u26F7-\u26FA\u26FD\u2702\u2705\u2708-\u270D\u270F\u2712\u2714\u2716\u271D\u2721\u2728\u2733\u2734\u2744\u2747\u274C\u274E\u2753-\u2755\u2757\u2763\u2764\u2795-\u2797\u27A1\u27B0\u27BF\u2934\u2935\u2B05-\u2B07\u2B1B\u2B1C\u2B50\u2B55\u3030\u303D\u3297\u3299]|\uD83C[\uDC04\uDCCF\uDD70\uDD71\uDD7E\uDD7F\uDD8E\uDD91-\uDD9A\uDDE6-\uDDFF\uDE01\uDE02\uDE1A\uDE2F\uDE32-\uDE3A\uDE50\uDE51\uDF00-\uDF21\uDF24-\uDF93\uDF96\uDF97\uDF99-\uDF9B\uDF9E-\uDFF0\uDFF3-\uDFF5\uDFF7-\uDFFF]|\uD83D[\uDC00-\uDCFD\uDCFF-\uDD3D\uDD49-\uDD4E\uDD50-\uDD67\uDD6F\uDD70\uDD73-\uDD7A\uDD87\uDD8A-\uDD8D\uDD90\uDD95\uDD96\uDDA4\uDDA5\uDDA8\uDDB1\uDDB2\uDDBC\uDDC2-\uDDC4\uDDD1-\uDDD3\uDDDC-\uDDDE\uDDE1\uDDE3\uDDE8\uDDEF\uDDF3\uDDFA-\uDE4F\uDE80-\uDEC5\uDECB-\uDED2\uDEE0-\uDEE5\uDEE9\uDEEB\uDEEC\uDEF0\uDEF3-\uDEF9]|\uD83E[\uDD10-\uDD3A\uDD3C-\uDD3E\uDD40-\uDD45\uDD47-\uDD70\uDD73-\uDD76\uDD7A\uDD7C-\uDDA2\uDDB0-\uDDB9\uDDC0-\uDDC2\uDDD0-\uDDFF])\uFE0F|(?:[\u261D\u26F9\u270A-\u270D]|\uD83C[\uDF85\uDFC2-\uDFC4\uDFC7\uDFCA-\uDFCC]|\uD83D[\uDC42\uDC43\uDC46-\uDC50\uDC66-\uDC69\uDC6E\uDC70-\uDC78\uDC7C\uDC81-\uDC83\uDC85-\uDC87\uDCAA\uDD74\uDD75\uDD7A\uDD90\uDD95\uDD96\uDE45-\uDE47\uDE4B-\uDE4F\uDEA3\uDEB4-\uDEB6\uDEC0\uDECC]|\uD83E[\uDD18-\uDD1C\uDD1E\uDD1F\uDD26\uDD30-\uDD39\uDD3D\uDD3E\uDDB5\uDDB6\uDDB8\uDDB9\uDDD1-\uDDDD])/g}},6349:e=>{"use strict";var n=/[|\\{}()[\]^$+*?.]/g;e.exports=function(e){if("string"!=typeof e)throw new TypeError("Expected a string");return e.replace(n,"\\$&")}},6591:e=>{"use strict";e.exports=(e,n)=>{n=n||process.argv;const t=e.startsWith("-")?"":1===e.length?"-":"--",r=n.indexOf(t+e),i=n.indexOf("--");return-1!==r&&(-1===i||r<i)}},2738:(e,n,t)=>{"use strict";e.exports=t(5864).isCI},703:e=>{"use strict";e.exports=e=>!Number.isNaN(e)&&(e>=4352&&(e<=4447||9001===e||9002===e||11904<=e&&e<=12871&&12351!==e||12880<=e&&e<=19903||19968<=e&&e<=42182||43360<=e&&e<=43388||44032<=e&&e<=55203||63744<=e&&e<=64255||65040<=e&&e<=65049||65072<=e&&e<=65131||65281<=e&&e<=65376||65504<=e&&e<=65510||110592<=e&&e<=110593||127488<=e&&e<=127569||131072<=e&&e<=262141))},4623:e=>{var n=/^\s+|\s+$/g,t=/^[-+]0x[0-9a-f]+$/i,r=/^0b[01]+$/i,i=/^0o[0-7]+$/i,u=parseInt,o="object"==typeof global&&global&&global.Object===Object&&global,a="object"==typeof self&&self&&self.Object===Object&&self,l=o||a||Function("return this")(),s=Object.prototype.toString,f=Math.max,c=Math.min,d=function(){return l.Date.now()};function p(e,n,t){var r,i,u,o,a,l,s=0,p=!1,v=!1,_=!0;if("function"!=typeof e)throw new TypeError("Expected a function");function b(n){var t=r,u=i;return r=i=void 0,s=n,o=e.apply(u,t)}function g(e){return s=e,a=setTimeout(D,n),p?b(e):o}function y(e){var t=e-l;return void 0===l||t>=n||t<0||v&&e-s>=u}function D(){var e=d();if(y(e))return w(e);a=setTimeout(D,function(e){var t=n-(e-l);return v?c(t,u-(e-s)):t}(e))}function w(e){return a=void 0,_&&r?b(e):(r=i=void 0,o)}function E(){var e=d(),t=y(e);if(r=arguments,i=this,l=e,t){if(void 0===a)return g(l);if(v)return a=setTimeout(D,n),b(l)}return void 0===a&&(a=setTimeout(D,n)),o}return n=m(n)||0,h(t)&&(p=!!t.leading,u=(v="maxWait"in t)?f(m(t.maxWait)||0,n):u,_="trailing"in t?!!t.trailing:_),E.cancel=function(){void 0!==a&&clearTimeout(a),s=0,r=l=i=a=void 0},E.flush=function(){return void 0===a?o:w(d())},E}function h(e){var n=typeof e;return!!e&&("object"==n||"function"==n)}function m(e){if("number"==typeof e)return e;if(function(e){return"symbol"==typeof e||function(e){return!!e&&"object"==typeof e}(e)&&"[object Symbol]"==s.call(e)}(e))return NaN;if(h(e)){var o="function"==typeof e.valueOf?e.valueOf():e;e=h(o)?o+"":o}if("string"!=typeof e)return 0===e?e:+e;e=e.replace(n,"");var a=r.test(e);return a||i.test(e)?u(e.slice(2),a?2:8):t.test(e)?NaN:+e}e.exports=function(e,n,t){var r=!0,i=!0;if("function"!=typeof e)throw new TypeError("Expected a function");return h(t)&&(r="leading"in t?!!t.leading:r,i="trailing"in t?!!t.trailing:i),p(e,n,{leading:r,maxWait:n,trailing:i})}},4046:(e,n,t)=>{"use strict";const r=t(327),i=t(1305),u=t(5449),o=(e,n)=>{n=Object.assign({showCursor:!1},n);let t=0;const o=(...o)=>{n.showCursor||i.hide();let a=o.join(" ")+"\n";a=u(a,(e=>{const{columns:n}=e;return n?"win32"===process.platform?n-1:n:80})(e),{trim:!1,hard:!0,wordWrap:!1}),e.write(r.eraseLines(t)+a),t=a.split("\n").length};return o.clear=()=>{e.write(r.eraseLines(t)),t=0},o.done=()=>{t=0,n.showCursor||i.show()},o};e.exports=o(process.stdout),e.exports.default=e.exports,e.exports.stderr=o(process.stderr),e.exports.create=o},2658:e=>{"use strict";e.exports=(e,n)=>{for(const t of Object.getOwnPropertyNames(n).concat(Object.getOwnPropertySymbols(n)))Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(n,t));return e}},9381:e=>{"use strict";
/*
object-assign
(c) Sindre Sorhus
@license MIT
*/var n=Object.getOwnPropertySymbols,t=Object.prototype.hasOwnProperty,r=Object.prototype.propertyIsEnumerable;function i(e){if(null==e)throw new TypeError("Object.assign cannot be called with null or undefined");return Object(e)}e.exports=function(){try{if(!Object.assign)return!1;var e=new String("abc");if(e[5]="de","5"===Object.getOwnPropertyNames(e)[0])return!1;for(var n={},t=0;t<10;t++)n["_"+String.fromCharCode(t)]=t;if("0123456789"!==Object.getOwnPropertyNames(n).map((function(e){return n[e]})).join(""))return!1;var r={};return"abcdefghijklmnopqrst".split("").forEach((function(e){r[e]=e})),"abcdefghijklmnopqrst"===Object.keys(Object.assign({},r)).join("")}catch(e){return!1}}()?Object.assign:function(e,u){for(var o,a,l=i(e),s=1;s<arguments.length;s++){for(var f in o=Object(arguments[s]))t.call(o,f)&&(l[f]=o[f]);if(n){a=n(o);for(var c=0;c<a.length;c++)r.call(o,a[c])&&(l[a[c]]=o[a[c]])}}return l}},4767:(e,n,t)=>{"use strict";const r=t(2658);e.exports=(e,n)=>{if(!0===n)throw new TypeError("The second argument is now an options object");if("function"!=typeof e)throw new TypeError("Expected a function");let t;n=n||{};let i=!1;const u=e.displayName||e.name||"<anonymous>",o=function(){if(i){if(!0===n.throw)throw new Error(`Function \`${u}\` can only be called once`);return t}return i=!0,t=e.apply(this,arguments),e=null,t};return r(o,e),o}},6976:(e,n,t)=>{"use strict";var r=t(9090);function i(){}function u(){}u.resetWarningCache=i,e.exports=function(){function e(e,n,t,i,u,o){if(o!==r){var a=new Error("Calling PropTypes validators directly is not supported by the `prop-types` package. Use PropTypes.checkPropTypes() to call them. Read more at http://fb.me/use-check-prop-types");throw a.name="Invariant Violation",a}}function n(){return e}e.isRequired=e;var t={array:e,bool:e,func:e,number:e,object:e,string:e,symbol:e,any:e,arrayOf:n,element:e,elementType:e,instanceOf:n,node:e,objectOf:n,oneOf:n,oneOfType:n,shape:n,exact:n,checkPropTypes:u,resetWarningCache:i};return t.PropTypes=t,t}},6271:(e,n,t)=>{e.exports=t(6976)()},9090:e=>{"use strict";e.exports="SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED"},6099:(e,n,t)=>{"use strict";
/** @license React v16.13.1
 * react.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var r=t(9381),i="function"==typeof Symbol&&Symbol.for,u=i?Symbol.for("react.element"):60103,o=i?Symbol.for("react.portal"):60106,a=i?Symbol.for("react.fragment"):60107,l=i?Symbol.for("react.strict_mode"):60108,s=i?Symbol.for("react.profiler"):60114,f=i?Symbol.for("react.provider"):60109,c=i?Symbol.for("react.context"):60110,d=i?Symbol.for("react.forward_ref"):60112,p=i?Symbol.for("react.suspense"):60113,h=i?Symbol.for("react.memo"):60115,m=i?Symbol.for("react.lazy"):60116,v="function"==typeof Symbol&&Symbol.iterator;function _(e){for(var n="https://reactjs.org/docs/error-decoder.html?invariant="+e,t=1;t<arguments.length;t++)n+="&args[]="+encodeURIComponent(arguments[t]);return"Minified React error #"+e+"; visit "+n+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}var b={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},g={};function y(e,n,t){this.props=e,this.context=n,this.refs=g,this.updater=t||b}function D(){}function w(e,n,t){this.props=e,this.context=n,this.refs=g,this.updater=t||b}y.prototype.isReactComponent={},y.prototype.setState=function(e,n){if("object"!=typeof e&&"function"!=typeof e&&null!=e)throw Error(_(85));this.updater.enqueueSetState(this,e,n,"setState")},y.prototype.forceUpdate=function(e){this.updater.enqueueForceUpdate(this,e,"forceUpdate")},D.prototype=y.prototype;var E=w.prototype=new D;E.constructor=w,r(E,y.prototype),E.isPureReactComponent=!0;var T={current:null},C=Object.prototype.hasOwnProperty,k={key:!0,ref:!0,__self:!0,__source:!0};function M(e,n,t){var r,i={},o=null,a=null;if(null!=n)for(r in void 0!==n.ref&&(a=n.ref),void 0!==n.key&&(o=""+n.key),n)C.call(n,r)&&!k.hasOwnProperty(r)&&(i[r]=n[r]);var l=arguments.length-2;if(1===l)i.children=t;else if(1<l){for(var s=Array(l),f=0;f<l;f++)s[f]=arguments[f+2];i.children=s}if(e&&e.defaultProps)for(r in l=e.defaultProps)void 0===i[r]&&(i[r]=l[r]);return{$$typeof:u,type:e,key:o,ref:a,props:i,_owner:T.current}}function S(e){return"object"==typeof e&&null!==e&&e.$$typeof===u}var A=/\/+/g,x=[];function P(e,n,t,r){if(x.length){var i=x.pop();return i.result=e,i.keyPrefix=n,i.func=t,i.context=r,i.count=0,i}return{result:e,keyPrefix:n,func:t,context:r,count:0}}function R(e){e.result=null,e.keyPrefix=null,e.func=null,e.context=null,e.count=0,10>x.length&&x.push(e)}function N(e,n,t){return null==e?0:function e(n,t,r,i){var a=typeof n;"undefined"!==a&&"boolean"!==a||(n=null);var l=!1;if(null===n)l=!0;else switch(a){case"string":case"number":l=!0;break;case"object":switch(n.$$typeof){case u:case o:l=!0}}if(l)return r(i,n,""===t?"."+F(n,0):t),1;if(l=0,t=""===t?".":t+":",Array.isArray(n))for(var s=0;s<n.length;s++){var f=t+F(a=n[s],s);l+=e(a,f,r,i)}else if(null===n||"object"!=typeof n?f=null:f="function"==typeof(f=v&&n[v]||n["@@iterator"])?f:null,"function"==typeof f)for(n=f.call(n),s=0;!(a=n.next()).done;)l+=e(a=a.value,f=t+F(a,s++),r,i);else if("object"===a)throw r=""+n,Error(_(31,"[object Object]"===r?"object with keys {"+Object.keys(n).join(", ")+"}":r,""));return l}(e,"",n,t)}function F(e,n){return"object"==typeof e&&null!==e&&null!=e.key?function(e){var n={"=":"=0",":":"=2"};return"$"+(""+e).replace(/[=:]/g,(function(e){return n[e]}))}(e.key):n.toString(36)}function O(e,n){e.func.call(e.context,n,e.count++)}function L(e,n,t){var r=e.result,i=e.keyPrefix;e=e.func.call(e.context,n,e.count++),Array.isArray(e)?I(e,r,t,(function(e){return e})):null!=e&&(S(e)&&(e=function(e,n){return{$$typeof:u,type:e.type,key:n,ref:e.ref,props:e.props,_owner:e._owner}}(e,i+(!e.key||n&&n.key===e.key?"":(""+e.key).replace(A,"$&/")+"/")+t)),r.push(e))}function I(e,n,t,r,i){var u="";null!=t&&(u=(""+t).replace(A,"$&/")+"/"),N(e,L,n=P(n,u,r,i)),R(n)}var B={current:null};function U(){var e=B.current;if(null===e)throw Error(_(321));return e}var j={ReactCurrentDispatcher:B,ReactCurrentBatchConfig:{suspense:null},ReactCurrentOwner:T,IsSomeRendererActing:{current:!1},assign:r};n.Children={map:function(e,n,t){if(null==e)return e;var r=[];return I(e,r,null,n,t),r},forEach:function(e,n,t){if(null==e)return e;N(e,O,n=P(null,null,n,t)),R(n)},count:function(e){return N(e,(function(){return null}),null)},toArray:function(e){var n=[];return I(e,n,null,(function(e){return e})),n},only:function(e){if(!S(e))throw Error(_(143));return e}},n.Component=y,n.Fragment=a,n.Profiler=s,n.PureComponent=w,n.StrictMode=l,n.Suspense=p,n.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED=j,n.cloneElement=function(e,n,t){if(null==e)throw Error(_(267,e));var i=r({},e.props),o=e.key,a=e.ref,l=e._owner;if(null!=n){if(void 0!==n.ref&&(a=n.ref,l=T.current),void 0!==n.key&&(o=""+n.key),e.type&&e.type.defaultProps)var s=e.type.defaultProps;for(f in n)C.call(n,f)&&!k.hasOwnProperty(f)&&(i[f]=void 0===n[f]&&void 0!==s?s[f]:n[f])}var f=arguments.length-2;if(1===f)i.children=t;else if(1<f){s=Array(f);for(var c=0;c<f;c++)s[c]=arguments[c+2];i.children=s}return{$$typeof:u,type:e.type,key:o,ref:a,props:i,_owner:l}},n.createContext=function(e,n){return void 0===n&&(n=null),(e={$$typeof:c,_calculateChangedBits:n,_currentValue:e,_currentValue2:e,_threadCount:0,Provider:null,Consumer:null}).Provider={$$typeof:f,_context:e},e.Consumer=e},n.createElement=M,n.createFactory=function(e){var n=M.bind(null,e);return n.type=e,n},n.createRef=function(){return{current:null}},n.forwardRef=function(e){return{$$typeof:d,render:e}},n.isValidElement=S,n.lazy=function(e){return{$$typeof:m,_ctor:e,_status:-1,_result:null}},n.memo=function(e,n){return{$$typeof:h,type:e,compare:void 0===n?null:n}},n.useCallback=function(e,n){return U().useCallback(e,n)},n.useContext=function(e,n){return U().useContext(e,n)},n.useDebugValue=function(){},n.useEffect=function(e,n){return U().useEffect(e,n)},n.useImperativeHandle=function(e,n,t){return U().useImperativeHandle(e,n,t)},n.useLayoutEffect=function(e,n){return U().useLayoutEffect(e,n)},n.useMemo=function(e,n){return U().useMemo(e,n)},n.useReducer=function(e,n,t){return U().useReducer(e,n,t)},n.useRef=function(e){return U().useRef(e)},n.useState=function(e){return U().useState(e)},n.version="16.13.1"},7382:(e,n,t)=>{"use strict";e.exports=t(6099)},2428:(e,n,t)=>{"use strict";const r=t(4767),i=t(6458);e.exports=r(()=>{i(()=>{process.stderr.write("[?25h")},{alwaysLast:!0})})},8992:(e,n)=>{"use strict";
/** @license React v0.13.6
 * scheduler.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */Object.defineProperty(n,"__esModule",{value:!0});var t=null,r=!1,i=3,u=-1,o=-1,a=!1,l=!1;function s(){if(!a){var e=t.expirationTime;l?E():l=!0,w(d,e)}}function f(){var e=t,n=t.next;if(t===n)t=null;else{var r=t.previous;t=r.next=n,n.previous=r}e.next=e.previous=null,r=e.callback,n=e.expirationTime,e=e.priorityLevel;var u=i,a=o;i=e,o=n;try{var l=r()}finally{i=u,o=a}if("function"==typeof l)if(l={callback:l,priorityLevel:e,expirationTime:n,next:null,previous:null},null===t)t=l.next=l.previous=l;else{r=null,e=t;do{if(e.expirationTime>=n){r=e;break}e=e.next}while(e!==t);null===r?r=t:r===t&&(t=l,s()),(n=r.previous).next=r.previous=l,l.next=r,l.previous=n}}function c(){if(-1===u&&null!==t&&1===t.priorityLevel){a=!0;try{do{f()}while(null!==t&&1===t.priorityLevel)}finally{a=!1,null!==t?s():l=!1}}}function d(e){a=!0;var i=r;r=e;try{if(e)for(;null!==t;){var u=n.unstable_now();if(!(t.expirationTime<=u))break;do{f()}while(null!==t&&t.expirationTime<=u)}else if(null!==t)do{f()}while(null!==t&&!T())}finally{a=!1,r=i,null!==t?s():l=!1,c()}}var p,h,m=Date,v="function"==typeof setTimeout?setTimeout:void 0,_="function"==typeof clearTimeout?clearTimeout:void 0,b="function"==typeof requestAnimationFrame?requestAnimationFrame:void 0,g="function"==typeof cancelAnimationFrame?cancelAnimationFrame:void 0;function y(e){p=b((function(n){_(h),e(n)})),h=v((function(){g(p),e(n.unstable_now())}),100)}if("object"==typeof performance&&"function"==typeof performance.now){var D=performance;n.unstable_now=function(){return D.now()}}else n.unstable_now=function(){return m.now()};var w,E,T,C=null;if("undefined"!=typeof window?C=window:"undefined"!=typeof global&&(C=global),C&&C._schedMock){var k=C._schedMock;w=k[0],E=k[1],T=k[2],n.unstable_now=k[3]}else if("undefined"==typeof window||"function"!=typeof MessageChannel){var M=null,S=function(e){if(null!==M)try{M(e)}finally{M=null}};w=function(e){null!==M?setTimeout(w,0,e):(M=e,setTimeout(S,0,!1))},E=function(){M=null},T=function(){return!1}}else{"undefined"!=typeof console&&("function"!=typeof b&&console.error("This browser doesn't support requestAnimationFrame. Make sure that you load a polyfill in older browsers. https://fb.me/react-polyfills"),"function"!=typeof g&&console.error("This browser doesn't support cancelAnimationFrame. Make sure that you load a polyfill in older browsers. https://fb.me/react-polyfills"));var A=null,x=!1,P=-1,R=!1,N=!1,F=0,O=33,L=33;T=function(){return F<=n.unstable_now()};var I=new MessageChannel,B=I.port2;I.port1.onmessage=function(){x=!1;var e=A,t=P;A=null,P=-1;var r=n.unstable_now(),i=!1;if(0>=F-r){if(!(-1!==t&&t<=r))return R||(R=!0,y(U)),A=e,void(P=t);i=!0}if(null!==e){N=!0;try{e(i)}finally{N=!1}}};var U=function(e){if(null!==A){y(U);var n=e-F+L;n<L&&O<L?(8>n&&(n=8),L=n<O?O:n):O=n,F=e+L,x||(x=!0,B.postMessage(void 0))}else R=!1};w=function(e,n){A=e,P=n,N||0>n?B.postMessage(void 0):R||(R=!0,y(U))},E=function(){A=null,x=!1,P=-1}}n.unstable_ImmediatePriority=1,n.unstable_UserBlockingPriority=2,n.unstable_NormalPriority=3,n.unstable_IdlePriority=5,n.unstable_LowPriority=4,n.unstable_runWithPriority=function(e,t){switch(e){case 1:case 2:case 3:case 4:case 5:break;default:e=3}var r=i,o=u;i=e,u=n.unstable_now();try{return t()}finally{i=r,u=o,c()}},n.unstable_next=function(e){switch(i){case 1:case 2:case 3:var t=3;break;default:t=i}var r=i,o=u;i=t,u=n.unstable_now();try{return e()}finally{i=r,u=o,c()}},n.unstable_scheduleCallback=function(e,r){var o=-1!==u?u:n.unstable_now();if("object"==typeof r&&null!==r&&"number"==typeof r.timeout)r=o+r.timeout;else switch(i){case 1:r=o+-1;break;case 2:r=o+250;break;case 5:r=o+1073741823;break;case 4:r=o+1e4;break;default:r=o+5e3}if(e={callback:e,priorityLevel:i,expirationTime:r,next:null,previous:null},null===t)t=e.next=e.previous=e,s();else{o=null;var a=t;do{if(a.expirationTime>r){o=a;break}a=a.next}while(a!==t);null===o?o=t:o===t&&(t=e,s()),(r=o.previous).next=o.previous=e,e.next=o,e.previous=r}return e},n.unstable_cancelCallback=function(e){var n=e.next;if(null!==n){if(n===e)t=null;else{e===t&&(t=n);var r=e.previous;r.next=n,n.previous=r}e.next=e.previous=null}},n.unstable_wrapCallback=function(e){var t=i;return function(){var r=i,o=u;i=t,u=n.unstable_now();try{return e.apply(this,arguments)}finally{i=r,u=o,c()}}},n.unstable_getCurrentPriorityLevel=function(){return i},n.unstable_shouldYield=function(){return!r&&(null!==t&&t.expirationTime<o||T())},n.unstable_continueExecution=function(){null!==t&&s()},n.unstable_pauseExecution=function(){},n.unstable_getFirstCallbackNode=function(){return t}},5201:(e,n,t)=>{"use strict";e.exports=t(8992)},6458:(e,n,t)=>{var r,i=t(2357),u=t(8082),o=t(8614);function a(){f&&(f=!1,u.forEach((function(e){try{process.removeListener(e,s[e])}catch(e){}})),process.emit=h,process.reallyExit=d,r.count-=1)}function l(e,n,t){r.emitted[e]||(r.emitted[e]=!0,r.emit(e,n,t))}"function"!=typeof o&&(o=o.EventEmitter),process.__signal_exit_emitter__?r=process.__signal_exit_emitter__:((r=process.__signal_exit_emitter__=new o).count=0,r.emitted={}),r.infinite||(r.setMaxListeners(1/0),r.infinite=!0),e.exports=function(e,n){i.equal(typeof e,"function","a callback must be provided for exit handler"),!1===f&&c();var t="exit";n&&n.alwaysLast&&(t="afterexit");return r.on(t,e),function(){r.removeListener(t,e),0===r.listeners("exit").length&&0===r.listeners("afterexit").length&&a()}},e.exports.unload=a;var s={};u.forEach((function(e){s[e]=function(){process.listeners(e).length===r.count&&(a(),l("exit",null,e),l("afterexit",null,e),process.kill(process.pid,e))}})),e.exports.signals=function(){return u},e.exports.load=c;var f=!1;function c(){f||(f=!0,r.count+=1,u=u.filter((function(e){try{return process.on(e,s[e]),!0}catch(e){return!1}})),process.emit=m,process.reallyExit=p)}var d=process.reallyExit;function p(e){process.exitCode=e||0,l("exit",process.exitCode,null),l("afterexit",process.exitCode,null),d.call(process,process.exitCode)}var h=process.emit;function m(e,n){if("exit"===e){void 0!==n&&(process.exitCode=n);var t=h.apply(this,arguments);return l("exit",process.exitCode,null),l("afterexit",process.exitCode,null),t}return h.apply(this,arguments)}},8082:e=>{e.exports=["SIGABRT","SIGALRM","SIGHUP","SIGINT","SIGTERM"],"win32"!==process.platform&&e.exports.push("SIGVTALRM","SIGXCPU","SIGXFSZ","SIGUSR2","SIGTRAP","SIGSYS","SIGQUIT","SIGIOT"),"linux"===process.platform&&e.exports.push("SIGIO","SIGPOLL","SIGPWR","SIGSTKFLT","SIGUNUSED")},7498:(e,n,t)=>{"use strict";const r=t(703),i=["",""],u=/[\uD800-\uDBFF][\uDC00-\uDFFF]/,o=new Map([[0,0],[1,22],[2,22],[3,23],[4,24],[7,27],[8,28],[9,29],[30,39],[31,39],[32,39],[33,39],[34,39],[35,39],[36,39],[37,39],[90,39],[40,49],[41,49],[42,49],[43,49],[44,49],[45,49],[46,49],[47,49]]),a=e=>`${i[0]}[${e}m`;e.exports=(e,n,t)=>{const l=Array.from(e.normalize());t="number"==typeof t?t:l.length;let s,f=!1,c=0,d="";for(const p of l.entries()){const l=p[0],h=p[1];let m=!1;if(-1!==i.indexOf(h)){f=!0;const n=/\d[^m]*/.exec(e.slice(l,l+4));s=39===n?null:n}else f&&"m"===h&&(f=!1,m=!0);if(f||m||++c,!u.test(h)&&r(h.codePointAt())&&++c,c>n&&c<=t)d+=h;else if(c!==n||f||void 0===s||39===s){if(c>=t){void 0!==s&&(d+=a(o.get(parseInt(s,10))||39));break}}else d+=a(s)}return d}},2989:(e,n,t)=>{"use strict";const r=t(3455),i=t(5640);e.exports=e=>r(e).replace(i()," ").length},5478:(e,n,t)=>{"use strict";const r=t(3455),i=t(703);e.exports=e=>{if("string"!=typeof e||0===e.length)return 0;e=r(e);let n=0;for(let t=0;t<e.length;t++){const r=e.codePointAt(t);r<=31||r>=127&&r<=159||(r>=768&&r<=879||(r>65535&&t++,n+=i(r)?2:1))}return n}},5554:(e,n,t)=>{"use strict";const r=t(7402),i=t(703),u=t(2517)();e.exports=e=>{if("string"!=typeof(e=e.replace(u,"  "))||0===e.length)return 0;e=r(e);let n=0;for(let t=0;t<e.length;t++){const r=e.codePointAt(t);r<=31||r>=127&&r<=159||(r>=768&&r<=879||(r>65535&&t++,n+=i(r)?2:1))}return n}},3455:(e,n,t)=>{"use strict";const r=t(7788);e.exports=e=>"string"==typeof e?e.replace(r(),""):e},7402:(e,n,t)=>{"use strict";const r=t(5378),i=e=>"string"==typeof e?e.replace(r(),""):e;e.exports=i,e.exports.default=i},5180:(e,n,t)=>{"use strict";const r=t(2087),i=t(6591),u=process.env;let o;function a(e){return function(e){return 0!==e&&{level:e,hasBasic:!0,has256:e>=2,has16m:e>=3}}(function(e){if(!1===o)return 0;if(i("color=16m")||i("color=full")||i("color=truecolor"))return 3;if(i("color=256"))return 2;if(e&&!e.isTTY&&!0!==o)return 0;const n=o?1:0;if("win32"===process.platform){const e=r.release().split(".");return Number(process.versions.node.split(".")[0])>=8&&Number(e[0])>=10&&Number(e[2])>=10586?Number(e[2])>=14931?3:2:1}if("CI"in u)return["TRAVIS","CIRCLECI","APPVEYOR","GITLAB_CI"].some(e=>e in u)||"codeship"===u.CI_NAME?1:n;if("TEAMCITY_VERSION"in u)return/^(9\.(0*[1-9]\d*)\.|\d{2,}\.)/.test(u.TEAMCITY_VERSION)?1:0;if("truecolor"===u.COLORTERM)return 3;if("TERM_PROGRAM"in u){const e=parseInt((u.TERM_PROGRAM_VERSION||"").split(".")[0],10);switch(u.TERM_PROGRAM){case"iTerm.app":return e>=3?3:2;case"Apple_Terminal":return 2}}return/-256(color)?$/i.test(u.TERM)?2:/^screen|^xterm|^vt100|^vt220|^rxvt|color|ansi|cygwin|linux/i.test(u.TERM)||"COLORTERM"in u?1:(u.TERM,n)}(e))}i("no-color")||i("no-colors")||i("color=false")?o=!1:(i("color")||i("colors")||i("color=true")||i("color=always"))&&(o=!0),"FORCE_COLOR"in u&&(o=0===u.FORCE_COLOR.length||0!==parseInt(u.FORCE_COLOR,10)),e.exports={supportsColor:a,stdout:a(process.stdout),stderr:a(process.stderr)}},128:(e,n,t)=>{"use strict";const r=t(5478);e.exports=e=>{let n=0;for(const t of e.split("\n"))n=Math.max(n,r(t));return n}},5449:(e,n,t)=>{"use strict";const r=t(5554),i=t(7402),u=t(5256),o=new Set(["",""]),a=e=>`${o.values().next().value}[${e}m`,l=(e,n,t)=>{const u=[...n];let a=!1,l=r(i(e[e.length-1]));for(const[n,i]of u.entries()){const s=r(i);if(l+s<=t?e[e.length-1]+=i:(e.push(i),l=0),o.has(i))a=!0;else if(a&&"m"===i){a=!1;continue}a||(l+=s,l===t&&n<u.length-1&&(e.push(""),l=0))}!l&&e[e.length-1].length>0&&e.length>1&&(e[e.length-2]+=e.pop())},s=e=>{const n=e.split(" ");let t=n.length;for(;t>0&&!(r(n[t-1])>0);)t--;return t===n.length?e:n.slice(0,t).join(" ")+n.slice(t).join("")},f=(e,n,t={})=>{if(!1!==t.trim&&""===e.trim())return"";let i,f="",c="";const d=(e=>e.split(" ").map(e=>r(e)))(e);let p=[""];for(const[i,u]of e.split(" ").entries()){!1!==t.trim&&(p[p.length-1]=p[p.length-1].trimLeft());let e=r(p[p.length-1]);if(0!==i&&(e>=n&&(!1===t.wordWrap||!1===t.trim)&&(p.push(""),e=0),(e>0||!1===t.trim)&&(p[p.length-1]+=" ",e++)),t.hard&&d[i]>n){const t=n-e,r=1+Math.floor((d[i]-t-1)/n);Math.floor((d[i]-1)/n)<r&&p.push(""),l(p,u,n)}else{if(e+d[i]>n&&e>0&&d[i]>0){if(!1===t.wordWrap&&e<n){l(p,u,n);continue}p.push("")}e+d[i]>n&&!1===t.wordWrap?l(p,u,n):p[p.length-1]+=u}}!1!==t.trim&&(p=p.map(s)),f=p.join("\n");for(const[e,n]of[...f].entries()){if(c+=n,o.has(n)){const n=parseFloat(/\d[^m]*/.exec(f.slice(e,e+4)));i=39===n?null:n}const t=u.codes.get(Number(i));i&&t&&("\n"===f[e+1]?c+=a(t):"\n"===n&&(c+=a(i)))}return c};e.exports=(e,n,t)=>String(e).normalize().split("\n").map(e=>f(e,n,t)).join("\n")},7356:function(module,exports){var __WEBPACK_AMD_DEFINE_ARRAY__,__WEBPACK_AMD_DEFINE_RESULT__,wrapper;wrapper=function(Module,cb){var Module;"function"==typeof Module&&(cb=Module,Module={}),Module.onRuntimeInitialized=function(e,n){return function(){e&&e.apply(this,arguments);try{Module.ccall("nbind_init")}catch(e){return void n(e)}n(null,{bind:Module._nbind_value,reflect:Module.NBind.reflect,queryType:Module.NBind.queryType,toggleLightGC:Module.toggleLightGC,lib:Module})}}(Module.onRuntimeInitialized,cb),Module||(Module=(void 0!==Module?Module:null)||{});var moduleOverrides={};for(var key in Module)Module.hasOwnProperty(key)&&(moduleOverrides[key]=Module[key]);var ENVIRONMENT_IS_WEB=!1,ENVIRONMENT_IS_WORKER=!1,ENVIRONMENT_IS_NODE=!1,ENVIRONMENT_IS_SHELL=!1,nodeFS,nodePath;if(Module.ENVIRONMENT)if("WEB"===Module.ENVIRONMENT)ENVIRONMENT_IS_WEB=!0;else if("WORKER"===Module.ENVIRONMENT)ENVIRONMENT_IS_WORKER=!0;else if("NODE"===Module.ENVIRONMENT)ENVIRONMENT_IS_NODE=!0;else{if("SHELL"!==Module.ENVIRONMENT)throw new Error("The provided Module['ENVIRONMENT'] value is not valid. It must be one of: WEB|WORKER|NODE|SHELL.");ENVIRONMENT_IS_SHELL=!0}else ENVIRONMENT_IS_WEB="object"==typeof window,ENVIRONMENT_IS_WORKER="function"==typeof importScripts,ENVIRONMENT_IS_NODE="object"==typeof process&&!ENVIRONMENT_IS_WEB&&!ENVIRONMENT_IS_WORKER,ENVIRONMENT_IS_SHELL=!ENVIRONMENT_IS_WEB&&!ENVIRONMENT_IS_NODE&&!ENVIRONMENT_IS_WORKER;if(ENVIRONMENT_IS_NODE)Module.print||(Module.print=console.log),Module.printErr||(Module.printErr=console.warn),Module.read=function(e,n){nodeFS||(nodeFS={}("")),nodePath||(nodePath={}("")),e=nodePath.normalize(e);var t=nodeFS.readFileSync(e);return n?t:t.toString()},Module.readBinary=function(e){var n=Module.read(e,!0);return n.buffer||(n=new Uint8Array(n)),assert(n.buffer),n},Module.load=function(e){globalEval(read(e))},Module.thisProgram||(process.argv.length>1?Module.thisProgram=process.argv[1].replace(/\\/g,"/"):Module.thisProgram="unknown-program"),Module.arguments=process.argv.slice(2),module.exports=Module,process.on("uncaughtException",(function(e){if(!(e instanceof ExitStatus))throw e})),Module.inspect=function(){return"[Emscripten Module object]"};else if(ENVIRONMENT_IS_SHELL)Module.print||(Module.print=print),"undefined"!=typeof printErr&&(Module.printErr=printErr),"undefined"!=typeof read?Module.read=read:Module.read=function(){throw"no read() available"},Module.readBinary=function(e){if("function"==typeof readbuffer)return new Uint8Array(readbuffer(e));var n=read(e,"binary");return assert("object"==typeof n),n},"undefined"!=typeof scriptArgs?Module.arguments=scriptArgs:void 0!==arguments&&(Module.arguments=arguments),"function"==typeof quit&&(Module.quit=function(e,n){quit(e)});else{if(!ENVIRONMENT_IS_WEB&&!ENVIRONMENT_IS_WORKER)throw"Unknown runtime environment. Where are we?";if(Module.read=function(e){var n=new XMLHttpRequest;return n.open("GET",e,!1),n.send(null),n.responseText},ENVIRONMENT_IS_WORKER&&(Module.readBinary=function(e){var n=new XMLHttpRequest;return n.open("GET",e,!1),n.responseType="arraybuffer",n.send(null),new Uint8Array(n.response)}),Module.readAsync=function(e,n,t){var r=new XMLHttpRequest;r.open("GET",e,!0),r.responseType="arraybuffer",r.onload=function(){200==r.status||0==r.status&&r.response?n(r.response):t()},r.onerror=t,r.send(null)},void 0!==arguments&&(Module.arguments=arguments),"undefined"!=typeof console)Module.print||(Module.print=function(e){console.log(e)}),Module.printErr||(Module.printErr=function(e){console.warn(e)});else{var TRY_USE_DUMP=!1;Module.print||(Module.print=TRY_USE_DUMP&&"undefined"!=typeof dump?function(e){dump(e)}:function(e){})}ENVIRONMENT_IS_WORKER&&(Module.load=importScripts),void 0===Module.setWindowTitle&&(Module.setWindowTitle=function(e){document.title=e})}function globalEval(e){eval.call(null,e)}for(var key in!Module.load&&Module.read&&(Module.load=function(e){globalEval(Module.read(e))}),Module.print||(Module.print=function(){}),Module.printErr||(Module.printErr=Module.print),Module.arguments||(Module.arguments=[]),Module.thisProgram||(Module.thisProgram="./this.program"),Module.quit||(Module.quit=function(e,n){throw n}),Module.print=Module.print,Module.printErr=Module.printErr,Module.preRun=[],Module.postRun=[],moduleOverrides)moduleOverrides.hasOwnProperty(key)&&(Module[key]=moduleOverrides[key]);moduleOverrides=void 0;var Runtime={setTempRet0:function(e){return tempRet0=e,e},getTempRet0:function(){return tempRet0},stackSave:function(){return STACKTOP},stackRestore:function(e){STACKTOP=e},getNativeTypeSize:function(e){switch(e){case"i1":case"i8":return 1;case"i16":return 2;case"i32":return 4;case"i64":return 8;case"float":return 4;case"double":return 8;default:if("*"===e[e.length-1])return Runtime.QUANTUM_SIZE;if("i"===e[0]){var n=parseInt(e.substr(1));return assert(n%8==0),n/8}return 0}},getNativeFieldSize:function(e){return Math.max(Runtime.getNativeTypeSize(e),Runtime.QUANTUM_SIZE)},STACK_ALIGN:16,prepVararg:function(e,n){return"double"===n||"i64"===n?7&e&&(assert(4==(7&e)),e+=4):assert(0==(3&e)),e},getAlignSize:function(e,n,t){return t||"i64"!=e&&"double"!=e?e?Math.min(n||(e?Runtime.getNativeFieldSize(e):0),Runtime.QUANTUM_SIZE):Math.min(n,8):8},dynCall:function(e,n,t){return t&&t.length?Module["dynCall_"+e].apply(null,[n].concat(t)):Module["dynCall_"+e].call(null,n)},functionPointers:[],addFunction:function(e){for(var n=0;n<Runtime.functionPointers.length;n++)if(!Runtime.functionPointers[n])return Runtime.functionPointers[n]=e,2*(1+n);throw"Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS."},removeFunction:function(e){Runtime.functionPointers[(e-2)/2]=null},warnOnce:function(e){Runtime.warnOnce.shown||(Runtime.warnOnce.shown={}),Runtime.warnOnce.shown[e]||(Runtime.warnOnce.shown[e]=1,Module.printErr(e))},funcWrappers:{},getFuncWrapper:function(e,n){if(e){assert(n),Runtime.funcWrappers[n]||(Runtime.funcWrappers[n]={});var t=Runtime.funcWrappers[n];return t[e]||(1===n.length?t[e]=function(){return Runtime.dynCall(n,e)}:2===n.length?t[e]=function(t){return Runtime.dynCall(n,e,[t])}:t[e]=function(){return Runtime.dynCall(n,e,Array.prototype.slice.call(arguments))}),t[e]}},getCompilerSetting:function(e){throw"You must build with -s RETAIN_COMPILER_SETTINGS=1 for Runtime.getCompilerSetting or emscripten_get_compiler_setting to work"},stackAlloc:function(e){var n=STACKTOP;return STACKTOP=15+(STACKTOP=STACKTOP+e|0)&-16,n},staticAlloc:function(e){var n=STATICTOP;return STATICTOP=15+(STATICTOP=STATICTOP+e|0)&-16,n},dynamicAlloc:function(e){var n=HEAP32[DYNAMICTOP_PTR>>2],t=-16&(n+e+15|0);return HEAP32[DYNAMICTOP_PTR>>2]=t,t>=TOTAL_MEMORY&&!enlargeMemory()?(HEAP32[DYNAMICTOP_PTR>>2]=n,0):n},alignMemory:function(e,n){return e=Math.ceil(e/(n||16))*(n||16)},makeBigInt:function(e,n,t){return t?+(e>>>0)+4294967296*+(n>>>0):+(e>>>0)+4294967296*+(0|n)},GLOBAL_BASE:8,QUANTUM_SIZE:4,__dummy__:0};Module.Runtime=Runtime;var ABORT=0,EXITSTATUS=0,cwrap,ccall;function assert(e,n){e||abort("Assertion failed: "+n)}function getCFunc(ident){var func=Module["_"+ident];if(!func)try{func=eval("_"+ident)}catch(e){}return assert(func,"Cannot call unknown function "+ident+" (perhaps LLVM optimizations or closure removed it?)"),func}function setValue(e,n,t,r){switch("*"===(t=t||"i8").charAt(t.length-1)&&(t="i32"),t){case"i1":case"i8":HEAP8[e>>0]=n;break;case"i16":HEAP16[e>>1]=n;break;case"i32":HEAP32[e>>2]=n;break;case"i64":tempI64=[n>>>0,(tempDouble=n,+Math_abs(tempDouble)>=1?tempDouble>0?(0|Math_min(+Math_floor(tempDouble/4294967296),4294967295))>>>0:~~+Math_ceil((tempDouble-+(~~tempDouble>>>0))/4294967296)>>>0:0)],HEAP32[e>>2]=tempI64[0],HEAP32[e+4>>2]=tempI64[1];break;case"float":HEAPF32[e>>2]=n;break;case"double":HEAPF64[e>>3]=n;break;default:abort("invalid type for setValue: "+t)}}function getValue(e,n,t){switch("*"===(n=n||"i8").charAt(n.length-1)&&(n="i32"),n){case"i1":case"i8":return HEAP8[e>>0];case"i16":return HEAP16[e>>1];case"i32":case"i64":return HEAP32[e>>2];case"float":return HEAPF32[e>>2];case"double":return HEAPF64[e>>3];default:abort("invalid type for setValue: "+n)}return null}!function(){var JSfuncs={stackSave:function(){Runtime.stackSave()},stackRestore:function(){Runtime.stackRestore()},arrayToC:function(e){var n=Runtime.stackAlloc(e.length);return writeArrayToMemory(e,n),n},stringToC:function(e){var n=0;if(null!=e&&0!==e){var t=1+(e.length<<2);stringToUTF8(e,n=Runtime.stackAlloc(t),t)}return n}},toC={string:JSfuncs.stringToC,array:JSfuncs.arrayToC};ccall=function(e,n,t,r,i){var u=getCFunc(e),o=[],a=0;if(r)for(var l=0;l<r.length;l++){var s=toC[t[l]];s?(0===a&&(a=Runtime.stackSave()),o[l]=s(r[l])):o[l]=r[l]}var f=u.apply(null,o);if("string"===n&&(f=Pointer_stringify(f)),0!==a){if(i&&i.async)return void EmterpreterAsync.asyncFinalizers.push((function(){Runtime.stackRestore(a)}));Runtime.stackRestore(a)}return f};var sourceRegex=/^function\s*[a-zA-Z$_0-9]*\s*\(([^)]*)\)\s*{\s*([^*]*?)[\s;]*(?:return\s*(.*?)[;\s]*)?}$/;function parseJSFunc(e){var n=e.toString().match(sourceRegex).slice(1);return{arguments:n[0],body:n[1],returnValue:n[2]}}var JSsource=null;function ensureJSsource(){if(!JSsource)for(var e in JSsource={},JSfuncs)JSfuncs.hasOwnProperty(e)&&(JSsource[e]=parseJSFunc(JSfuncs[e]))}cwrap=function cwrap(ident,returnType,argTypes){argTypes=argTypes||[];var cfunc=getCFunc(ident),numericArgs=argTypes.every((function(e){return"number"===e})),numericRet="string"!==returnType;if(numericRet&&numericArgs)return cfunc;var argNames=argTypes.map((function(e,n){return"$"+n})),funcstr="(function("+argNames.join(",")+") {",nargs=argTypes.length;if(!numericArgs){ensureJSsource(),funcstr+="var stack = "+JSsource.stackSave.body+";";for(var i=0;i<nargs;i++){var arg=argNames[i],type=argTypes[i];if("number"!==type){var convertCode=JSsource[type+"ToC"];funcstr+="var "+convertCode.arguments+" = "+arg+";",funcstr+=convertCode.body+";",funcstr+=arg+"=("+convertCode.returnValue+");"}}}var cfuncname=parseJSFunc((function(){return cfunc})).returnValue;if(funcstr+="var ret = "+cfuncname+"("+argNames.join(",")+");",!numericRet){var strgfy=parseJSFunc((function(){return Pointer_stringify})).returnValue;funcstr+="ret = "+strgfy+"(ret);"}return numericArgs||(ensureJSsource(),funcstr+=JSsource.stackRestore.body.replace("()","(stack)")+";"),funcstr+="return ret})",eval(funcstr)}}(),Module.ccall=ccall,Module.cwrap=cwrap,Module.setValue=setValue,Module.getValue=getValue;var ALLOC_NORMAL=0,ALLOC_STACK=1,ALLOC_STATIC=2,ALLOC_DYNAMIC=3,ALLOC_NONE=4;function allocate(e,n,t,r){var i,u;"number"==typeof e?(i=!0,u=e):(i=!1,u=e.length);var o,a="string"==typeof n?n:null;if(o=t==ALLOC_NONE?r:["function"==typeof _malloc?_malloc:Runtime.staticAlloc,Runtime.stackAlloc,Runtime.staticAlloc,Runtime.dynamicAlloc][void 0===t?ALLOC_STATIC:t](Math.max(u,a?1:n.length)),i){var l;for(r=o,assert(0==(3&o)),l=o+(-4&u);r<l;r+=4)HEAP32[r>>2]=0;for(l=o+u;r<l;)HEAP8[r++>>0]=0;return o}if("i8"===a)return e.subarray||e.slice?HEAPU8.set(e,o):HEAPU8.set(new Uint8Array(e),o),o;for(var s,f,c,d=0;d<u;){var p=e[d];"function"==typeof p&&(p=Runtime.getFunctionIndex(p)),0!==(s=a||n[d])?("i64"==s&&(s="i32"),setValue(o+d,p,s),c!==s&&(f=Runtime.getNativeTypeSize(s),c=s),d+=f):d++}return o}function getMemory(e){return staticSealed?runtimeInitialized?_malloc(e):Runtime.dynamicAlloc(e):Runtime.staticAlloc(e)}function Pointer_stringify(e,n){if(0===n||!e)return"";for(var t,r=0,i=0;r|=t=HEAPU8[e+i>>0],(0!=t||n)&&(i++,!n||i!=n););n||(n=i);var u="";if(r<128){for(var o;n>0;)o=String.fromCharCode.apply(String,HEAPU8.subarray(e,e+Math.min(n,1024))),u=u?u+o:o,e+=1024,n-=1024;return u}return Module.UTF8ToString(e)}function AsciiToString(e){for(var n="";;){var t=HEAP8[e++>>0];if(!t)return n;n+=String.fromCharCode(t)}}function stringToAscii(e,n){return writeAsciiToMemory(e,n,!1)}Module.ALLOC_NORMAL=ALLOC_NORMAL,Module.ALLOC_STACK=ALLOC_STACK,Module.ALLOC_STATIC=ALLOC_STATIC,Module.ALLOC_DYNAMIC=ALLOC_DYNAMIC,Module.ALLOC_NONE=ALLOC_NONE,Module.allocate=allocate,Module.getMemory=getMemory,Module.Pointer_stringify=Pointer_stringify,Module.AsciiToString=AsciiToString,Module.stringToAscii=stringToAscii;var UTF8Decoder="undefined"!=typeof TextDecoder?new TextDecoder("utf8"):void 0;function UTF8ArrayToString(e,n){for(var t=n;e[t];)++t;if(t-n>16&&e.subarray&&UTF8Decoder)return UTF8Decoder.decode(e.subarray(n,t));for(var r,i,u,o,a,l="";;){if(!(r=e[n++]))return l;if(128&r)if(i=63&e[n++],192!=(224&r))if(u=63&e[n++],224==(240&r)?r=(15&r)<<12|i<<6|u:(o=63&e[n++],240==(248&r)?r=(7&r)<<18|i<<12|u<<6|o:(a=63&e[n++],r=248==(252&r)?(3&r)<<24|i<<18|u<<12|o<<6|a:(1&r)<<30|i<<24|u<<18|o<<12|a<<6|63&e[n++])),r<65536)l+=String.fromCharCode(r);else{var s=r-65536;l+=String.fromCharCode(55296|s>>10,56320|1023&s)}else l+=String.fromCharCode((31&r)<<6|i);else l+=String.fromCharCode(r)}}function UTF8ToString(e){return UTF8ArrayToString(HEAPU8,e)}function stringToUTF8Array(e,n,t,r){if(!(r>0))return 0;for(var i=t,u=t+r-1,o=0;o<e.length;++o){var a=e.charCodeAt(o);if(a>=55296&&a<=57343&&(a=65536+((1023&a)<<10)|1023&e.charCodeAt(++o)),a<=127){if(t>=u)break;n[t++]=a}else if(a<=2047){if(t+1>=u)break;n[t++]=192|a>>6,n[t++]=128|63&a}else if(a<=65535){if(t+2>=u)break;n[t++]=224|a>>12,n[t++]=128|a>>6&63,n[t++]=128|63&a}else if(a<=2097151){if(t+3>=u)break;n[t++]=240|a>>18,n[t++]=128|a>>12&63,n[t++]=128|a>>6&63,n[t++]=128|63&a}else if(a<=67108863){if(t+4>=u)break;n[t++]=248|a>>24,n[t++]=128|a>>18&63,n[t++]=128|a>>12&63,n[t++]=128|a>>6&63,n[t++]=128|63&a}else{if(t+5>=u)break;n[t++]=252|a>>30,n[t++]=128|a>>24&63,n[t++]=128|a>>18&63,n[t++]=128|a>>12&63,n[t++]=128|a>>6&63,n[t++]=128|63&a}}return n[t]=0,t-i}function stringToUTF8(e,n,t){return stringToUTF8Array(e,HEAPU8,n,t)}function lengthBytesUTF8(e){for(var n=0,t=0;t<e.length;++t){var r=e.charCodeAt(t);r>=55296&&r<=57343&&(r=65536+((1023&r)<<10)|1023&e.charCodeAt(++t)),r<=127?++n:n+=r<=2047?2:r<=65535?3:r<=2097151?4:r<=67108863?5:6}return n}Module.UTF8ArrayToString=UTF8ArrayToString,Module.UTF8ToString=UTF8ToString,Module.stringToUTF8Array=stringToUTF8Array,Module.stringToUTF8=stringToUTF8,Module.lengthBytesUTF8=lengthBytesUTF8;var UTF16Decoder="undefined"!=typeof TextDecoder?new TextDecoder("utf-16le"):void 0,HEAP,buffer,HEAP8,HEAPU8,HEAP16,HEAPU16,HEAP32,HEAPU32,HEAPF32,HEAPF64,STATIC_BASE,STATICTOP,staticSealed,STACK_BASE,STACKTOP,STACK_MAX,DYNAMIC_BASE,DYNAMICTOP_PTR;function demangle(e){var n=Module.___cxa_demangle||Module.__cxa_demangle;if(n){try{var t=e.substr(1),r=lengthBytesUTF8(t)+1,i=_malloc(r);stringToUTF8(t,i,r);var u=_malloc(4),o=n(i,0,0,u);if(0===getValue(u,"i32")&&o)return Pointer_stringify(o)}catch(e){}finally{i&&_free(i),u&&_free(u),o&&_free(o)}return e}return Runtime.warnOnce("warning: build with  -s DEMANGLE_SUPPORT=1  to link in libcxxabi demangling"),e}function demangleAll(e){return e.replace(/__Z[\w\d_]+/g,(function(e){var n=demangle(e);return e===n?e:e+" ["+n+"]"}))}function jsStackTrace(){var e=new Error;if(!e.stack){try{throw new Error(0)}catch(n){e=n}if(!e.stack)return"(no stack trace available)"}return e.stack.toString()}function stackTrace(){var e=jsStackTrace();return Module.extraStackTrace&&(e+="\n"+Module.extraStackTrace()),demangleAll(e)}function updateGlobalBufferViews(){Module.HEAP8=HEAP8=new Int8Array(buffer),Module.HEAP16=HEAP16=new Int16Array(buffer),Module.HEAP32=HEAP32=new Int32Array(buffer),Module.HEAPU8=HEAPU8=new Uint8Array(buffer),Module.HEAPU16=HEAPU16=new Uint16Array(buffer),Module.HEAPU32=HEAPU32=new Uint32Array(buffer),Module.HEAPF32=HEAPF32=new Float32Array(buffer),Module.HEAPF64=HEAPF64=new Float64Array(buffer)}function abortOnCannotGrowMemory(){abort("Cannot enlarge memory arrays. Either (1) compile with  -s TOTAL_MEMORY=X  with X higher than the current value "+TOTAL_MEMORY+", (2) compile with  -s ALLOW_MEMORY_GROWTH=1  which allows increasing the size at runtime but prevents some optimizations, (3) set Module.TOTAL_MEMORY to a higher value before the program runs, or (4) if you want malloc to return NULL (0) instead of this abort, compile with  -s ABORTING_MALLOC=0 ")}function enlargeMemory(){abortOnCannotGrowMemory()}Module.stackTrace=stackTrace,STATIC_BASE=STATICTOP=STACK_BASE=STACKTOP=STACK_MAX=DYNAMIC_BASE=DYNAMICTOP_PTR=0,staticSealed=!1;var TOTAL_STACK=Module.TOTAL_STACK||5242880,TOTAL_MEMORY=Module.TOTAL_MEMORY||134217728;function getTotalMemory(){return TOTAL_MEMORY}if(TOTAL_MEMORY<TOTAL_STACK&&Module.printErr("TOTAL_MEMORY should be larger than TOTAL_STACK, was "+TOTAL_MEMORY+"! (TOTAL_STACK="+TOTAL_STACK+")"),buffer=Module.buffer?Module.buffer:new ArrayBuffer(TOTAL_MEMORY),updateGlobalBufferViews(),HEAP32[0]=1668509029,HEAP16[1]=25459,115!==HEAPU8[2]||99!==HEAPU8[3])throw"Runtime error: expected the system to be little-endian!";function callRuntimeCallbacks(e){for(;e.length>0;){var n=e.shift();if("function"!=typeof n){var t=n.func;"number"==typeof t?void 0===n.arg?Module.dynCall_v(t):Module.dynCall_vi(t,n.arg):t(void 0===n.arg?null:n.arg)}else n()}}Module.HEAP=HEAP,Module.buffer=buffer,Module.HEAP8=HEAP8,Module.HEAP16=HEAP16,Module.HEAP32=HEAP32,Module.HEAPU8=HEAPU8,Module.HEAPU16=HEAPU16,Module.HEAPU32=HEAPU32,Module.HEAPF32=HEAPF32,Module.HEAPF64=HEAPF64;var __ATPRERUN__=[],__ATINIT__=[],__ATMAIN__=[],__ATEXIT__=[],__ATPOSTRUN__=[],runtimeInitialized=!1,runtimeExited=!1;function preRun(){if(Module.preRun)for("function"==typeof Module.preRun&&(Module.preRun=[Module.preRun]);Module.preRun.length;)addOnPreRun(Module.preRun.shift());callRuntimeCallbacks(__ATPRERUN__)}function ensureInitRuntime(){runtimeInitialized||(runtimeInitialized=!0,callRuntimeCallbacks(__ATINIT__))}function preMain(){callRuntimeCallbacks(__ATMAIN__)}function exitRuntime(){callRuntimeCallbacks(__ATEXIT__),runtimeExited=!0}function postRun(){if(Module.postRun)for("function"==typeof Module.postRun&&(Module.postRun=[Module.postRun]);Module.postRun.length;)addOnPostRun(Module.postRun.shift());callRuntimeCallbacks(__ATPOSTRUN__)}function addOnPreRun(e){__ATPRERUN__.unshift(e)}function addOnInit(e){__ATINIT__.unshift(e)}function addOnPreMain(e){__ATMAIN__.unshift(e)}function addOnExit(e){__ATEXIT__.unshift(e)}function addOnPostRun(e){__ATPOSTRUN__.unshift(e)}function intArrayFromString(e,n,t){var r=t>0?t:lengthBytesUTF8(e)+1,i=new Array(r),u=stringToUTF8Array(e,i,0,i.length);return n&&(i.length=u),i}function intArrayToString(e){for(var n=[],t=0;t<e.length;t++){var r=e[t];r>255&&(r&=255),n.push(String.fromCharCode(r))}return n.join("")}function writeStringToMemory(e,n,t){var r,i;Runtime.warnOnce("writeStringToMemory is deprecated and should not be called! Use stringToUTF8() instead!"),t&&(i=n+lengthBytesUTF8(e),r=HEAP8[i]),stringToUTF8(e,n,1/0),t&&(HEAP8[i]=r)}function writeArrayToMemory(e,n){HEAP8.set(e,n)}function writeAsciiToMemory(e,n,t){for(var r=0;r<e.length;++r)HEAP8[n++>>0]=e.charCodeAt(r);t||(HEAP8[n>>0]=0)}if(Module.addOnPreRun=addOnPreRun,Module.addOnInit=addOnInit,Module.addOnPreMain=addOnPreMain,Module.addOnExit=addOnExit,Module.addOnPostRun=addOnPostRun,Module.intArrayFromString=intArrayFromString,Module.intArrayToString=intArrayToString,Module.writeStringToMemory=writeStringToMemory,Module.writeArrayToMemory=writeArrayToMemory,Module.writeAsciiToMemory=writeAsciiToMemory,Math.imul&&-5===Math.imul(4294967295,5)||(Math.imul=function(e,n){var t=65535&e,r=65535&n;return t*r+((e>>>16)*r+t*(n>>>16)<<16)|0}),Math.imul=Math.imul,!Math.fround){var froundBuffer=new Float32Array(1);Math.fround=function(e){return froundBuffer[0]=e,froundBuffer[0]}}Math.fround=Math.fround,Math.clz32||(Math.clz32=function(e){e>>>=0;for(var n=0;n<32;n++)if(e&1<<31-n)return n;return 32}),Math.clz32=Math.clz32,Math.trunc||(Math.trunc=function(e){return e<0?Math.ceil(e):Math.floor(e)}),Math.trunc=Math.trunc;var Math_abs=Math.abs,Math_cos=Math.cos,Math_sin=Math.sin,Math_tan=Math.tan,Math_acos=Math.acos,Math_asin=Math.asin,Math_atan=Math.atan,Math_atan2=Math.atan2,Math_exp=Math.exp,Math_log=Math.log,Math_sqrt=Math.sqrt,Math_ceil=Math.ceil,Math_floor=Math.floor,Math_pow=Math.pow,Math_imul=Math.imul,Math_fround=Math.fround,Math_round=Math.round,Math_min=Math.min,Math_clz32=Math.clz32,Math_trunc=Math.trunc,runDependencies=0,runDependencyWatcher=null,dependenciesFulfilled=null;function getUniqueRunDependency(e){return e}function addRunDependency(e){runDependencies++,Module.monitorRunDependencies&&Module.monitorRunDependencies(runDependencies)}function removeRunDependency(e){if(runDependencies--,Module.monitorRunDependencies&&Module.monitorRunDependencies(runDependencies),0==runDependencies&&(null!==runDependencyWatcher&&(clearInterval(runDependencyWatcher),runDependencyWatcher=null),dependenciesFulfilled)){var n=dependenciesFulfilled;dependenciesFulfilled=null,n()}}Module.addRunDependency=addRunDependency,Module.removeRunDependency=removeRunDependency,Module.preloadedImages={},Module.preloadedAudios={};var ASM_CONSTS=[function(e,n,t,r,i,u,o,a){return _nbind.callbackSignatureList[e].apply(this,arguments)}];function _emscripten_asm_const_iiiiiiii(e,n,t,r,i,u,o,a){return ASM_CONSTS[e](n,t,r,i,u,o,a)}function _emscripten_asm_const_iiiii(e,n,t,r,i){return ASM_CONSTS[e](n,t,r,i)}function _emscripten_asm_const_iiidddddd(e,n,t,r,i,u,o,a,l){return ASM_CONSTS[e](n,t,r,i,u,o,a,l)}function _emscripten_asm_const_iiididi(e,n,t,r,i,u,o){return ASM_CONSTS[e](n,t,r,i,u,o)}function _emscripten_asm_const_iiii(e,n,t,r){return ASM_CONSTS[e](n,t,r)}function _emscripten_asm_const_iiiid(e,n,t,r,i){return ASM_CONSTS[e](n,t,r,i)}function _emscripten_asm_const_iiiiii(e,n,t,r,i,u){return ASM_CONSTS[e](n,t,r,i,u)}STATIC_BASE=Runtime.GLOBAL_BASE,STATICTOP=STATIC_BASE+12800,__ATINIT__.push({func:function(){__GLOBAL__sub_I_Yoga_cpp()}},{func:function(){__GLOBAL__sub_I_nbind_cc()}},{func:function(){__GLOBAL__sub_I_common_cc()}},{func:function(){__GLOBAL__sub_I_Binding_cc()}}),allocate([0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,127,0,0,192,127,0,0,192,127,0,0,192,127,3,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,3,0,0,0,0,0,192,127,3,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,192,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,127,0,0,192,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,127,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,127,0,0,192,127,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,0,0,128,191,0,0,128,191,0,0,192,127,0,0,0,0,0,0,0,0,0,0,128,63,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,190,12,0,0,200,12,0,0,208,12,0,0,216,12,0,0,230,12,0,0,242,12,0,0,1,0,0,0,3,0,0,0,0,0,0,0,2,0,0,0,0,0,192,127,3,0,0,0,180,45,0,0,181,45,0,0,182,45,0,0,181,45,0,0,182,45,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,1,0,0,0,4,0,0,0,183,45,0,0,181,45,0,0,181,45,0,0,181,45,0,0,181,45,0,0,181,45,0,0,181,45,0,0,184,45,0,0,185,45,0,0,181,45,0,0,181,45,0,0,182,45,0,0,186,45,0,0,185,45,0,0,148,4,0,0,3,0,0,0,187,45,0,0,164,4,0,0,188,45,0,0,2,0,0,0,189,45,0,0,164,4,0,0,188,45,0,0,185,45,0,0,164,4,0,0,185,45,0,0,164,4,0,0,188,45,0,0,181,45,0,0,182,45,0,0,181,45,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,6,0,0,0,1,0,0,0,7,0,0,0,183,45,0,0,182,45,0,0,181,45,0,0,190,45,0,0,190,45,0,0,182,45,0,0,182,45,0,0,185,45,0,0,181,45,0,0,185,45,0,0,182,45,0,0,181,45,0,0,185,45,0,0,182,45,0,0,185,45,0,0,48,5,0,0,3,0,0,0,56,5,0,0,1,0,0,0,189,45,0,0,185,45,0,0,164,4,0,0,76,5,0,0,2,0,0,0,191,45,0,0,186,45,0,0,182,45,0,0,185,45,0,0,192,45,0,0,185,45,0,0,182,45,0,0,186,45,0,0,185,45,0,0,76,5,0,0,76,5,0,0,136,5,0,0,182,45,0,0,181,45,0,0,2,0,0,0,190,45,0,0,136,5,0,0,56,19,0,0,156,5,0,0,2,0,0,0,184,45,0,0,0,0,0,0,0,0,0,0,1,0,0,0,8,0,0,0,9,0,0,0,1,0,0,0,10,0,0,0,204,5,0,0,181,45,0,0,181,45,0,0,2,0,0,0,180,45,0,0,204,5,0,0,2,0,0,0,195,45,0,0,236,5,0,0,97,19,0,0,198,45,0,0,211,45,0,0,212,45,0,0,213,45,0,0,214,45,0,0,215,45,0,0,188,45,0,0,182,45,0,0,216,45,0,0,217,45,0,0,218,45,0,0,219,45,0,0,192,45,0,0,181,45,0,0,0,0,0,0,185,45,0,0,110,19,0,0,186,45,0,0,115,19,0,0,221,45,0,0,120,19,0,0,148,4,0,0,132,19,0,0,96,6,0,0,145,19,0,0,222,45,0,0,164,19,0,0,223,45,0,0,173,19,0,0,0,0,0,0,3,0,0,0,104,6,0,0,1,0,0,0,187,45,0,0,0,0,0,0,0,0,0,0,1,0,0,0,11,0,0,0,12,0,0,0,1,0,0,0,13,0,0,0,185,45,0,0,224,45,0,0,164,6,0,0,188,45,0,0,172,6,0,0,180,6,0,0,2,0,0,0,188,6,0,0,7,0,0,0,224,45,0,0,7,0,0,0,164,6,0,0,1,0,0,0,213,45,0,0,185,45,0,0,224,45,0,0,172,6,0,0,185,45,0,0,224,45,0,0,164,6,0,0,185,45,0,0,224,45,0,0,211,45,0,0,211,45,0,0,222,45,0,0,211,45,0,0,224,45,0,0,222,45,0,0,211,45,0,0,224,45,0,0,172,6,0,0,222,45,0,0,211,45,0,0,224,45,0,0,188,45,0,0,222,45,0,0,211,45,0,0,40,7,0,0,188,45,0,0,2,0,0,0,224,45,0,0,185,45,0,0,188,45,0,0,188,45,0,0,188,45,0,0,188,45,0,0,222,45,0,0,224,45,0,0,148,4,0,0,185,45,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,148,4,0,0,185,45,0,0,164,6,0,0,148,4,0,0,0,0,0,0,0,0,0,0,1,0,0,0,14,0,0,0,15,0,0,0,1,0,0,0,16,0,0,0,148,7,0,0,2,0,0,0,225,45,0,0,183,45,0,0,188,45,0,0,168,7,0,0,5,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,234,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,9,0,0,5,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,2,0,0,0,242,45,0,0,0,4,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,110,111,100,101,0,67,97,110,110,111,116,32,114,101,115,101,116,32,97,32,110,111,100,101,32,119,104,105,99,104,32,115,116,105,108,108,32,104,97,115,32,99,104,105,108,100,114,101,110,32,97,116,116,97,99,104,101,100,0,67,97,110,110,111,116,32,114,101,115,101,116,32,97,32,110,111,100,101,32,115,116,105,108,108,32,97,116,116,97,99,104,101,100,32,116,111,32,97,32,112,97,114,101,110,116,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,99,111,110,102,105,103,0,67,97,110,110,111,116,32,115,101,116,32,109,101,97,115,117,114,101,32,102,117,110,99,116,105,111,110,58,32,78,111,100,101,115,32,119,105,116,104,32,109,101,97,115,117,114,101,32,102,117,110,99,116,105,111,110,115,32,99,97,110,110,111,116,32,104,97,118,101,32,99,104,105,108,100,114,101,110,46,0,67,104,105,108,100,32,97,108,114,101,97,100,121,32,104,97,115,32,97,32,112,97,114,101,110,116,44,32,105,116,32,109,117,115,116,32,98,101,32,114,101,109,111,118,101,100,32,102,105,114,115,116,46,0,67,97,110,110,111,116,32,97,100,100,32,99,104,105,108,100,58,32,78,111,100,101,115,32,119,105,116,104,32,109,101,97,115,117,114,101,32,102,117,110,99,116,105,111,110,115,32,99,97,110,110,111,116,32,104,97,118,101,32,99,104,105,108,100,114,101,110,46,0,79,110,108,121,32,108,101,97,102,32,110,111,100,101,115,32,119,105,116,104,32,99,117,115,116,111,109,32,109,101,97,115,117,114,101,32,102,117,110,99,116,105,111,110,115,115,104,111,117,108,100,32,109,97,110,117,97,108,108,121,32,109,97,114,107,32,116,104,101,109,115,101,108,118,101,115,32,97,115,32,100,105,114,116,121,0,67,97,110,110,111,116,32,103,101,116,32,108,97,121,111,117,116,32,112,114,111,112,101,114,116,105,101,115,32,111,102,32,109,117,108,116,105,45,101,100,103,101,32,115,104,111,114,116,104,97,110,100,115,0,37,115,37,100,46,123,91,115,107,105,112,112,101,100,93,32,0,119,109,58,32,37,115,44,32,104,109,58,32,37,115,44,32,97,119,58,32,37,102,32,97,104,58,32,37,102,32,61,62,32,100,58,32,40,37,102,44,32,37,102,41,32,37,115,10,0,37,115,37,100,46,123,37,115,0,42,0,119,109,58,32,37,115,44,32,104,109,58,32,37,115,44,32,97,119,58,32,37,102,32,97,104,58,32,37,102,32,37,115,10,0,37,115,37,100,46,125,37,115,0,119,109,58,32,37,115,44,32,104,109,58,32,37,115,44,32,100,58,32,40,37,102,44,32,37,102,41,32,37,115,10,0,79,117,116,32,111,102,32,99,97,99,104,101,32,101,110,116,114,105,101,115,33,10,0,83,99,97,108,101,32,102,97,99,116,111,114,32,115,104,111,117,108,100,32,110,111,116,32,98,101,32,108,101,115,115,32,116,104,97,110,32,122,101,114,111,0,105,110,105,116,105,97,108,0,37,115,10,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,85,78,68,69,70,73,78,69,68,0,69,88,65,67,84,76,89,0,65,84,95,77,79,83,84,0,76,65,89,95,85,78,68,69,70,73,78,69,68,0,76,65,89,95,69,88,65,67,84,76,89,0,76,65,89,95,65,84,95,77,79,83,84,0,97,118,97,105,108,97,98,108,101,87,105,100,116,104,32,105,115,32,105,110,100,101,102,105,110,105,116,101,32,115,111,32,119,105,100,116,104,77,101,97,115,117,114,101,77,111,100,101,32,109,117,115,116,32,98,101,32,89,71,77,101,97,115,117,114,101,77,111,100,101,85,110,100,101,102,105,110,101,100,0,97,118,97,105,108,97,98,108,101,72,101,105,103,104,116,32,105,115,32,105,110,100,101,102,105,110,105,116,101,32,115,111,32,104,101,105,103,104,116,77,101,97,115,117,114,101,77,111,100,101,32,109,117,115,116,32,98,101,32,89,71,77,101,97,115,117,114,101,77,111,100,101,85,110,100,101,102,105,110,101,100,0,102,108,101,120,0,115,116,114,101,116,99,104,0,109,117,108,116,105,108,105,110,101,45,115,116,114,101,116,99,104,0,69,120,112,101,99,116,101,100,32,110,111,100,101,32,116,111,32,104,97,118,101,32,99,117,115,116,111,109,32,109,101,97,115,117,114,101,32,102,117,110,99,116,105,111,110,0,109,101,97,115,117,114,101,0,69,120,112,101,99,116,32,99,117,115,116,111,109,32,98,97,115,101,108,105,110,101,32,102,117,110,99,116,105,111,110,32,116,111,32,110,111,116,32,114,101,116,117,114,110,32,78,97,78,0,97,98,115,45,109,101,97,115,117,114,101,0,97,98,115,45,108,97,121,111,117,116,0,78,111,100,101,0,99,114,101,97,116,101,68,101,102,97,117,108,116,0,99,114,101,97,116,101,87,105,116,104,67,111,110,102,105,103,0,100,101,115,116,114,111,121,0,114,101,115,101,116,0,99,111,112,121,83,116,121,108,101,0,115,101,116,80,111,115,105,116,105,111,110,84,121,112,101,0,115,101,116,80,111,115,105,116,105,111,110,0,115,101,116,80,111,115,105,116,105,111,110,80,101,114,99,101,110,116,0,115,101,116,65,108,105,103,110,67,111,110,116,101,110,116,0,115,101,116,65,108,105,103,110,73,116,101,109,115,0,115,101,116,65,108,105,103,110,83,101,108,102,0,115,101,116,70,108,101,120,68,105,114,101,99,116,105,111,110,0,115,101,116,70,108,101,120,87,114,97,112,0,115,101,116,74,117,115,116,105,102,121,67,111,110,116,101,110,116,0,115,101,116,77,97,114,103,105,110,0,115,101,116,77,97,114,103,105,110,80,101,114,99,101,110,116,0,115,101,116,77,97,114,103,105,110,65,117,116,111,0,115,101,116,79,118,101,114,102,108,111,119,0,115,101,116,68,105,115,112,108,97,121,0,115,101,116,70,108,101,120,0,115,101,116,70,108,101,120,66,97,115,105,115,0,115,101,116,70,108,101,120,66,97,115,105,115,80,101,114,99,101,110,116,0,115,101,116,70,108,101,120,71,114,111,119,0,115,101,116,70,108,101,120,83,104,114,105,110,107,0,115,101,116,87,105,100,116,104,0,115,101,116,87,105,100,116,104,80,101,114,99,101,110,116,0,115,101,116,87,105,100,116,104,65,117,116,111,0,115,101,116,72,101,105,103,104,116,0,115,101,116,72,101,105,103,104,116,80,101,114,99,101,110,116,0,115,101,116,72,101,105,103,104,116,65,117,116,111,0,115,101,116,77,105,110,87,105,100,116,104,0,115,101,116,77,105,110,87,105,100,116,104,80,101,114,99,101,110,116,0,115,101,116,77,105,110,72,101,105,103,104,116,0,115,101,116,77,105,110,72,101,105,103,104,116,80,101,114,99,101,110,116,0,115,101,116,77,97,120,87,105,100,116,104,0,115,101,116,77,97,120,87,105,100,116,104,80,101,114,99,101,110,116,0,115,101,116,77,97,120,72,101,105,103,104,116,0,115,101,116,77,97,120,72,101,105,103,104,116,80,101,114,99,101,110,116,0,115,101,116,65,115,112,101,99,116,82,97,116,105,111,0,115,101,116,66,111,114,100,101,114,0,115,101,116,80,97,100,100,105,110,103,0,115,101,116,80,97,100,100,105,110,103,80,101,114,99,101,110,116,0,103,101,116,80,111,115,105,116,105,111,110,84,121,112,101,0,103,101,116,80,111,115,105,116,105,111,110,0,103,101,116,65,108,105,103,110,67,111,110,116,101,110,116,0,103,101,116,65,108,105,103,110,73,116,101,109,115,0,103,101,116,65,108,105,103,110,83,101,108,102,0,103,101,116,70,108,101,120,68,105,114,101,99,116,105,111,110,0,103,101,116,70,108,101,120,87,114,97,112,0,103,101,116,74,117,115,116,105,102,121,67,111,110,116,101,110,116,0,103,101,116,77,97,114,103,105,110,0,103,101,116,70,108,101,120,66,97,115,105,115,0,103,101,116,70,108,101,120,71,114,111,119,0,103,101,116,70,108,101,120,83,104,114,105,110,107,0,103,101,116,87,105,100,116,104,0,103,101,116,72,101,105,103,104,116,0,103,101,116,77,105,110,87,105,100,116,104,0,103,101,116,77,105,110,72,101,105,103,104,116,0,103,101,116,77,97,120,87,105,100,116,104,0,103,101,116,77,97,120,72,101,105,103,104,116,0,103,101,116,65,115,112,101,99,116,82,97,116,105,111,0,103,101,116,66,111,114,100,101,114,0,103,101,116,79,118,101,114,102,108,111,119,0,103,101,116,68,105,115,112,108,97,121,0,103,101,116,80,97,100,100,105,110,103,0,105,110,115,101,114,116,67,104,105,108,100,0,114,101,109,111,118,101,67,104,105,108,100,0,103,101,116,67,104,105,108,100,67,111,117,110,116,0,103,101,116,80,97,114,101,110,116,0,103,101,116,67,104,105,108,100,0,115,101,116,77,101,97,115,117,114,101,70,117,110,99,0,117,110,115,101,116,77,101,97,115,117,114,101,70,117,110,99,0,109,97,114,107,68,105,114,116,121,0,105,115,68,105,114,116,121,0,99,97,108,99,117,108,97,116,101,76,97,121,111,117,116,0,103,101,116,67,111,109,112,117,116,101,100,76,101,102,116,0,103,101,116,67,111,109,112,117,116,101,100,82,105,103,104,116,0,103,101,116,67,111,109,112,117,116,101,100,84,111,112,0,103,101,116,67,111,109,112,117,116,101,100,66,111,116,116,111,109,0,103,101,116,67,111,109,112,117,116,101,100,87,105,100,116,104,0,103,101,116,67,111,109,112,117,116,101,100,72,101,105,103,104,116,0,103,101,116,67,111,109,112,117,116,101,100,76,97,121,111,117,116,0,103,101,116,67,111,109,112,117,116,101,100,77,97,114,103,105,110,0,103,101,116,67,111,109,112,117,116,101,100,66,111,114,100,101,114,0,103,101,116,67,111,109,112,117,116,101,100,80,97,100,100,105,110,103,0,67,111,110,102,105,103,0,99,114,101,97,116,101,0,115,101,116,69,120,112,101,114,105,109,101,110,116,97,108,70,101,97,116,117,114,101,69,110,97,98,108,101,100,0,115,101,116,80,111,105,110,116,83,99,97,108,101,70,97,99,116,111,114,0,105,115,69,120,112,101,114,105,109,101,110,116,97,108,70,101,97,116,117,114,101,69,110,97,98,108,101,100,0,86,97,108,117,101,0,76,97,121,111,117,116,0,83,105,122,101,0,103,101,116,73,110,115,116,97,110,99,101,67,111,117,110,116,0,73,110,116,54,52,0,1,1,1,2,2,4,4,4,4,8,8,4,8,118,111,105,100,0,98,111,111,108,0,115,116,100,58,58,115,116,114,105,110,103,0,99,98,70,117,110,99,116,105,111,110,32,38,0,99,111,110,115,116,32,99,98,70,117,110,99,116,105,111,110,32,38,0,69,120,116,101,114,110,97,108,0,66,117,102,102,101,114,0,78,66,105,110,100,73,68,0,78,66,105,110,100,0,98,105,110,100,95,118,97,108,117,101,0,114,101,102,108,101,99,116,0,113,117,101,114,121,84,121,112,101,0,108,97,108,108,111,99,0,108,114,101,115,101,116,0,123,114,101,116,117,114,110,40,95,110,98,105,110,100,46,99,97,108,108,98,97,99,107,83,105,103,110,97,116,117,114,101,76,105,115,116,91,36,48,93,46,97,112,112,108,121,40,116,104,105,115,44,97,114,103,117,109,101,110,116,115,41,41,59,125,0,95,110,98,105,110,100,95,110,101,119,0,17,0,10,0,17,17,17,0,0,0,0,5,0,0,0,0,0,0,9,0,0,0,0,11,0,0,0,0,0,0,0,0,17,0,15,10,17,17,17,3,10,7,0,1,19,9,11,11,0,0,9,6,11,0,0,11,0,6,17,0,0,0,17,17,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,17,0,10,10,17,17,17,0,10,0,0,2,0,9,11,0,0,0,9,0,11,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,12,0,0,0,0,9,12,0,0,0,0,0,12,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,13,0,0,0,4,13,0,0,0,0,9,14,0,0,0,0,0,14,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,15,0,0,0,0,9,16,0,0,0,0,0,16,0,0,16,0,0,18,0,0,0,18,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,18,18,18,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,10,0,0,0,0,9,11,0,0,0,0,0,11,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,12,0,0,0,0,9,12,0,0,0,0,0,12,0,0,12,0,0,45,43,32,32,32,48,88,48,120,0,40,110,117,108,108,41,0,45,48,88,43,48,88,32,48,88,45,48,120,43,48,120,32,48,120,0,105,110,102,0,73,78,70,0,110,97,110,0,78,65,78,0,48,49,50,51,52,53,54,55,56,57,65,66,67,68,69,70,46,0,84,33,34,25,13,1,2,3,17,75,28,12,16,4,11,29,18,30,39,104,110,111,112,113,98,32,5,6,15,19,20,21,26,8,22,7,40,36,23,24,9,10,14,27,31,37,35,131,130,125,38,42,43,60,61,62,63,67,71,74,77,88,89,90,91,92,93,94,95,96,97,99,100,101,102,103,105,106,107,108,114,115,116,121,122,123,124,0,73,108,108,101,103,97,108,32,98,121,116,101,32,115,101,113,117,101,110,99,101,0,68,111,109,97,105,110,32,101,114,114,111,114,0,82,101,115,117,108,116,32,110,111,116,32,114,101,112,114,101,115,101,110,116,97,98,108,101,0,78,111,116,32,97,32,116,116,121,0,80,101,114,109,105,115,115,105,111,110,32,100,101,110,105,101,100,0,79,112,101,114,97,116,105,111,110,32,110,111,116,32,112,101,114,109,105,116,116,101,100,0,78,111,32,115,117,99,104,32,102,105,108,101,32,111,114,32,100,105,114,101,99,116,111,114,121,0,78,111,32,115,117,99,104,32,112,114,111,99,101,115,115,0,70,105,108,101,32,101,120,105,115,116,115,0,86,97,108,117,101,32,116,111,111,32,108,97,114,103,101,32,102,111,114,32,100,97,116,97,32,116,121,112,101,0,78,111,32,115,112,97,99,101,32,108,101,102,116,32,111,110,32,100,101,118,105,99,101,0,79,117,116,32,111,102,32,109,101,109,111,114,121,0,82,101,115,111,117,114,99,101,32,98,117,115,121,0,73,110,116,101,114,114,117,112,116,101,100,32,115,121,115,116,101,109,32,99,97,108,108,0,82,101,115,111,117,114,99,101,32,116,101,109,112,111,114,97,114,105,108,121,32,117,110,97,118,97,105,108,97,98,108,101,0,73,110,118,97,108,105,100,32,115,101,101,107,0,67,114,111,115,115,45,100,101,118,105,99,101,32,108,105,110,107,0,82,101,97,100,45,111,110,108,121,32,102,105,108,101,32,115,121,115,116,101,109,0,68,105,114,101,99,116,111,114,121,32,110,111,116,32,101,109,112,116,121,0,67,111,110,110,101,99,116,105,111,110,32,114,101,115,101,116,32,98,121,32,112,101,101,114,0,79,112,101,114,97,116,105,111,110,32,116,105,109,101,100,32,111,117,116,0,67,111,110,110,101,99,116,105,111,110,32,114,101,102,117,115,101,100,0,72,111,115,116,32,105,115,32,100,111,119,110,0,72,111,115,116,32,105,115,32,117,110,114,101,97,99,104,97,98,108,101,0,65,100,100,114,101,115,115,32,105,110,32,117,115,101,0,66,114,111,107,101,110,32,112,105,112,101,0,73,47,79,32,101,114,114,111,114,0,78,111,32,115,117,99,104,32,100,101,118,105,99,101,32,111,114,32,97,100,100,114,101,115,115,0,66,108,111,99,107,32,100,101,118,105,99,101,32,114,101,113,117,105,114,101,100,0,78,111,32,115,117,99,104,32,100,101,118,105,99,101,0,78,111,116,32,97,32,100,105,114,101,99,116,111,114,121,0,73,115,32,97,32,100,105,114,101,99,116,111,114,121,0,84,101,120,116,32,102,105,108,101,32,98,117,115,121,0,69,120,101,99,32,102,111,114,109,97,116,32,101,114,114,111,114,0,73,110,118,97,108,105,100,32,97,114,103,117,109,101,110,116,0,65,114,103,117,109,101,110,116,32,108,105,115,116,32,116,111,111,32,108,111,110,103,0,83,121,109,98,111,108,105,99,32,108,105,110,107,32,108,111,111,112,0,70,105,108,101,110,97,109,101,32,116,111,111,32,108,111,110,103,0,84,111,111,32,109,97,110,121,32,111,112,101,110,32,102,105,108,101,115,32,105,110,32,115,121,115,116,101,109,0,78,111,32,102,105,108,101,32,100,101,115,99,114,105,112,116,111,114,115,32,97,118,97,105,108,97,98,108,101,0,66,97,100,32,102,105,108,101,32,100,101,115,99,114,105,112,116,111,114,0,78,111,32,99,104,105,108,100,32,112,114,111,99,101,115,115,0,66,97,100,32,97,100,100,114,101,115,115,0,70,105,108,101,32,116,111,111,32,108,97,114,103,101,0,84,111,111,32,109,97,110,121,32,108,105,110,107,115,0,78,111,32,108,111,99,107,115,32,97,118,97,105,108,97,98,108,101,0,82,101,115,111,117,114,99,101,32,100,101,97,100,108,111,99,107,32,119,111,117,108,100,32,111,99,99,117,114,0,83,116,97,116,101,32,110,111,116,32,114,101,99,111,118,101,114,97,98,108,101,0,80,114,101,118,105,111,117,115,32,111,119,110,101,114,32,100,105,101,100,0,79,112,101,114,97,116,105,111,110,32,99,97,110,99,101,108,101,100,0,70,117,110,99,116,105,111,110,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,0,78,111,32,109,101,115,115,97,103,101,32,111,102,32,100,101,115,105,114,101,100,32,116,121,112,101,0,73,100,101,110,116,105,102,105,101,114,32,114,101,109,111,118,101,100,0,68,101,118,105,99,101,32,110,111,116,32,97,32,115,116,114,101,97,109,0,78,111,32,100,97,116,97,32,97,118,97,105,108,97,98,108,101,0,68,101,118,105,99,101,32,116,105,109,101,111,117,116,0,79,117,116,32,111,102,32,115,116,114,101,97,109,115,32,114,101,115,111,117,114,99,101,115,0,76,105,110,107,32,104,97,115,32,98,101,101,110,32,115,101,118,101,114,101,100,0,80,114,111,116,111,99,111,108,32,101,114,114,111,114,0,66,97,100,32,109,101,115,115,97,103,101,0,70,105,108,101,32,100,101,115,99,114,105,112,116,111,114,32,105,110,32,98,97,100,32,115,116,97,116,101,0,78,111,116,32,97,32,115,111,99,107,101,116,0,68,101,115,116,105,110,97,116,105,111,110,32,97,100,100,114,101,115,115,32,114,101,113,117,105,114,101,100,0,77,101,115,115,97,103,101,32,116,111,111,32,108,97,114,103,101,0,80,114,111,116,111,99,111,108,32,119,114,111,110,103,32,116,121,112,101,32,102,111,114,32,115,111,99,107,101,116,0,80,114,111,116,111,99,111,108,32,110,111,116,32,97,118,97,105,108,97,98,108,101,0,80,114,111,116,111,99,111,108,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,83,111,99,107,101,116,32,116,121,112,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,78,111,116,32,115,117,112,112,111,114,116,101,100,0,80,114,111,116,111,99,111,108,32,102,97,109,105,108,121,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,65,100,100,114,101,115,115,32,102,97,109,105,108,121,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,112,114,111,116,111,99,111,108,0,65,100,100,114,101,115,115,32,110,111,116,32,97,118,97,105,108,97,98,108,101,0,78,101,116,119,111,114,107,32,105,115,32,100,111,119,110,0,78,101,116,119,111,114,107,32,117,110,114,101,97,99,104,97,98,108,101,0,67,111,110,110,101,99,116,105,111,110,32,114,101,115,101,116,32,98,121,32,110,101,116,119,111,114,107,0,67,111,110,110,101,99,116,105,111,110,32,97,98,111,114,116,101,100,0,78,111,32,98,117,102,102,101,114,32,115,112,97,99,101,32,97,118,97,105,108,97,98,108,101,0,83,111,99,107,101,116,32,105,115,32,99,111,110,110,101,99,116,101,100,0,83,111,99,107,101,116,32,110,111,116,32,99,111,110,110,101,99,116,101,100,0,67,97,110,110,111,116,32,115,101,110,100,32,97,102,116,101,114,32,115,111,99,107,101,116,32,115,104,117,116,100,111,119,110,0,79,112,101,114,97,116,105,111,110,32,97,108,114,101,97,100,121,32,105,110,32,112,114,111,103,114,101,115,115,0,79,112,101,114,97,116,105,111,110,32,105,110,32,112,114,111,103,114,101,115,115,0,83,116,97,108,101,32,102,105,108,101,32,104,97,110,100,108,101,0,82,101,109,111,116,101,32,73,47,79,32,101,114,114,111,114,0,81,117,111,116,97,32,101,120,99,101,101,100,101,100,0,78,111,32,109,101,100,105,117,109,32,102,111,117,110,100,0,87,114,111,110,103,32,109,101,100,105,117,109,32,116,121,112,101,0,78,111,32,101,114,114,111,114,32,105,110,102,111,114,109,97,116,105,111,110,0,0],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE);var tempDoublePtr=STATICTOP;function _atexit(e,n){__ATEXIT__.unshift({func:e,arg:n})}function ___cxa_atexit(){return _atexit.apply(null,arguments)}function _abort(){Module.abort()}function __ZN8facebook4yoga14YGNodeToStringEPNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEP6YGNode14YGPrintOptionsj(){Module.printErr("missing function: _ZN8facebook4yoga14YGNodeToStringEPNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEP6YGNode14YGPrintOptionsj"),abort(-1)}function __decorate(e,n,t,r){var i,u=arguments.length,o=u<3?n:null===r?r=Object.getOwnPropertyDescriptor(n,t):r;if("object"==typeof Reflect&&"function"==typeof Reflect.decorate)o=Reflect.decorate(e,n,t,r);else for(var a=e.length-1;a>=0;a--)(i=e[a])&&(o=(u<3?i(o):u>3?i(n,t,o):i(n,t))||o);return u>3&&o&&Object.defineProperty(n,t,o),o}function _defineHidden(e){return function(n,t){Object.defineProperty(n,t,{configurable:!1,enumerable:!1,value:e,writable:!0})}}STATICTOP+=16;var _nbind={};function __nbind_free_external(e){_nbind.externalList[e].dereference(e)}function __nbind_reference_external(e){_nbind.externalList[e].reference()}function _llvm_stackrestore(e){var n=_llvm_stacksave,t=n.LLVM_SAVEDSTACKS[e];n.LLVM_SAVEDSTACKS.splice(e,1),Runtime.stackRestore(t)}function __nbind_register_pool(e,n,t,r){_nbind.Pool.pageSize=e,_nbind.Pool.usedPtr=n/4,_nbind.Pool.rootPtr=t,_nbind.Pool.pagePtr=r/4,HEAP32[n/4]=16909060,1==HEAP8[n]&&(_nbind.bigEndian=!0),HEAP32[n/4]=0,_nbind.makeTypeKindTbl=((i={})[1024]=_nbind.PrimitiveType,i[64]=_nbind.Int64Type,i[2048]=_nbind.BindClass,i[3072]=_nbind.BindClassPtr,i[4096]=_nbind.SharedClassPtr,i[5120]=_nbind.ArrayType,i[6144]=_nbind.ArrayType,i[7168]=_nbind.CStringType,i[9216]=_nbind.CallbackType,i[10240]=_nbind.BindType,i),_nbind.makeTypeNameTbl={Buffer:_nbind.BufferType,External:_nbind.ExternalType,Int64:_nbind.Int64Type,_nbind_new:_nbind.CreateValueType,bool:_nbind.BooleanType,"cbFunction &":_nbind.CallbackType,"const cbFunction &":_nbind.CallbackType,"const std::string &":_nbind.StringType,"std::string":_nbind.StringType},Module.toggleLightGC=_nbind.toggleLightGC,_nbind.callUpcast=Module.dynCall_ii;var i,u=_nbind.makeType(_nbind.constructType,{flags:2048,id:0,name:""});u.proto=Module,_nbind.BindClass.list.push(u)}function _emscripten_set_main_loop_timing(e,n){if(Browser.mainLoop.timingMode=e,Browser.mainLoop.timingValue=n,!Browser.mainLoop.func)return 1;if(0==e)Browser.mainLoop.scheduler=function(){var e=0|Math.max(0,Browser.mainLoop.tickStartTime+n-_emscripten_get_now());setTimeout(Browser.mainLoop.runner,e)},Browser.mainLoop.method="timeout";else if(1==e)Browser.mainLoop.scheduler=function(){Browser.requestAnimationFrame(Browser.mainLoop.runner)},Browser.mainLoop.method="rAF";else if(2==e){if(!window.setImmediate){var t=[];window.addEventListener("message",(function(e){e.source===window&&"setimmediate"===e.data&&(e.stopPropagation(),t.shift()())}),!0),window.setImmediate=function(e){t.push(e),ENVIRONMENT_IS_WORKER?(void 0===Module.setImmediates&&(Module.setImmediates=[]),Module.setImmediates.push(e),window.postMessage({target:"setimmediate"})):window.postMessage("setimmediate","*")}}Browser.mainLoop.scheduler=function(){window.setImmediate(Browser.mainLoop.runner)},Browser.mainLoop.method="immediate"}return 0}function _emscripten_get_now(){abort()}function _emscripten_set_main_loop(e,n,t,r,i){var u;Module.noExitRuntime=!0,assert(!Browser.mainLoop.func,"emscripten_set_main_loop: there can only be one main loop function at once: call emscripten_cancel_main_loop to cancel the previous one before setting a new one with different parameters."),Browser.mainLoop.func=e,Browser.mainLoop.arg=r,u=void 0!==r?function(){Module.dynCall_vi(e,r)}:function(){Module.dynCall_v(e)};var o=Browser.mainLoop.currentlyRunningMainloop;if(Browser.mainLoop.runner=function(){if(!ABORT)if(Browser.mainLoop.queue.length>0){var e=Date.now(),n=Browser.mainLoop.queue.shift();if(n.func(n.arg),Browser.mainLoop.remainingBlockers){var t=Browser.mainLoop.remainingBlockers,r=t%1==0?t-1:Math.floor(t);n.counted?Browser.mainLoop.remainingBlockers=r:(r+=.5,Browser.mainLoop.remainingBlockers=(8*t+r)/9)}if(console.log('main loop blocker "'+n.name+'" took '+(Date.now()-e)+" ms"),Browser.mainLoop.updateStatus(),o<Browser.mainLoop.currentlyRunningMainloop)return;setTimeout(Browser.mainLoop.runner,0)}else o<Browser.mainLoop.currentlyRunningMainloop||(Browser.mainLoop.currentFrameNumber=Browser.mainLoop.currentFrameNumber+1|0,1==Browser.mainLoop.timingMode&&Browser.mainLoop.timingValue>1&&Browser.mainLoop.currentFrameNumber%Browser.mainLoop.timingValue!=0?Browser.mainLoop.scheduler():(0==Browser.mainLoop.timingMode&&(Browser.mainLoop.tickStartTime=_emscripten_get_now()),"timeout"===Browser.mainLoop.method&&Module.ctx&&(Module.printErr("Looks like you are rendering without using requestAnimationFrame for the main loop. You should use 0 for the frame rate in emscripten_set_main_loop in order to use requestAnimationFrame, as that can greatly improve your frame rates!"),Browser.mainLoop.method=""),Browser.mainLoop.runIter(u),o<Browser.mainLoop.currentlyRunningMainloop||("object"==typeof SDL&&SDL.audio&&SDL.audio.queueNewAudioData&&SDL.audio.queueNewAudioData(),Browser.mainLoop.scheduler())))},i||(n&&n>0?_emscripten_set_main_loop_timing(0,1e3/n):_emscripten_set_main_loop_timing(1,1),Browser.mainLoop.scheduler()),t)throw"SimulateInfiniteLoop"}var Browser={mainLoop:{scheduler:null,method:"",currentlyRunningMainloop:0,func:null,arg:0,timingMode:0,timingValue:0,currentFrameNumber:0,queue:[],pause:function(){Browser.mainLoop.scheduler=null,Browser.mainLoop.currentlyRunningMainloop++},resume:function(){Browser.mainLoop.currentlyRunningMainloop++;var e=Browser.mainLoop.timingMode,n=Browser.mainLoop.timingValue,t=Browser.mainLoop.func;Browser.mainLoop.func=null,_emscripten_set_main_loop(t,0,!1,Browser.mainLoop.arg,!0),_emscripten_set_main_loop_timing(e,n),Browser.mainLoop.scheduler()},updateStatus:function(){if(Module.setStatus){var e=Module.statusMessage||"Please wait...",n=Browser.mainLoop.remainingBlockers,t=Browser.mainLoop.expectedBlockers;n?n<t?Module.setStatus(e+" ("+(t-n)+"/"+t+")"):Module.setStatus(e):Module.setStatus("")}},runIter:function(e){if(!ABORT){if(Module.preMainLoop&&!1===Module.preMainLoop())return;try{e()}catch(e){if(e instanceof ExitStatus)return;throw e&&"object"==typeof e&&e.stack&&Module.printErr("exception thrown: "+[e,e.stack]),e}Module.postMainLoop&&Module.postMainLoop()}}},isFullscreen:!1,pointerLock:!1,moduleContextCreatedCallbacks:[],workers:[],init:function(){if(Module.preloadPlugins||(Module.preloadPlugins=[]),!Browser.initted){Browser.initted=!0;try{new Blob,Browser.hasBlobConstructor=!0}catch(e){Browser.hasBlobConstructor=!1,console.log("warning: no blob constructor, cannot create blobs with mimetypes")}Browser.BlobBuilder="undefined"!=typeof MozBlobBuilder?MozBlobBuilder:"undefined"!=typeof WebKitBlobBuilder?WebKitBlobBuilder:Browser.hasBlobConstructor?null:console.log("warning: no BlobBuilder"),Browser.URLObject="undefined"!=typeof window?window.URL?window.URL:window.webkitURL:void 0,Module.noImageDecoding||void 0!==Browser.URLObject||(console.log("warning: Browser does not support creating object URLs. Built-in browser image decoding will not be available."),Module.noImageDecoding=!0);var e={canHandle:function(e){return!Module.noImageDecoding&&/\.(jpg|jpeg|png|bmp)$/i.test(e)},handle:function(e,n,t,r){var i=null;if(Browser.hasBlobConstructor)try{(i=new Blob([e],{type:Browser.getMimetype(n)})).size!==e.length&&(i=new Blob([new Uint8Array(e).buffer],{type:Browser.getMimetype(n)}))}catch(e){Runtime.warnOnce("Blob constructor present but fails: "+e+"; falling back to blob builder")}if(!i){var u=new Browser.BlobBuilder;u.append(new Uint8Array(e).buffer),i=u.getBlob()}var o=Browser.URLObject.createObjectURL(i),a=new Image;a.onload=function(){assert(a.complete,"Image "+n+" could not be decoded");var r=document.createElement("canvas");r.width=a.width,r.height=a.height,r.getContext("2d").drawImage(a,0,0),Module.preloadedImages[n]=r,Browser.URLObject.revokeObjectURL(o),t&&t(e)},a.onerror=function(e){console.log("Image "+o+" could not be decoded"),r&&r()},a.src=o}};Module.preloadPlugins.push(e);var n={canHandle:function(e){return!Module.noAudioDecoding&&e.substr(-4)in{".ogg":1,".wav":1,".mp3":1}},handle:function(e,n,t,r){var i=!1;function u(r){i||(i=!0,Module.preloadedAudios[n]=r,t&&t(e))}function o(){i||(i=!0,Module.preloadedAudios[n]=new Audio,r&&r())}if(!Browser.hasBlobConstructor)return o();try{var a=new Blob([e],{type:Browser.getMimetype(n)})}catch(e){return o()}var l=Browser.URLObject.createObjectURL(a),s=new Audio;s.addEventListener("canplaythrough",(function(){u(s)}),!1),s.onerror=function(t){i||(console.log("warning: browser could not fully decode audio "+n+", trying slower base64 approach"),s.src="data:audio/x-"+n.substr(-3)+";base64,"+function(e){for(var n="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",t="",r=0,i=0,u=0;u<e.length;u++)for(r=r<<8|e[u],i+=8;i>=6;){var o=r>>i-6&63;i-=6,t+=n[o]}return 2==i?(t+=n[(3&r)<<4],t+="=="):4==i&&(t+=n[(15&r)<<2],t+="="),t}(e),u(s))},s.src=l,Browser.safeSetTimeout((function(){u(s)}),1e4)}};Module.preloadPlugins.push(n);var t=Module.canvas;t&&(t.requestPointerLock=t.requestPointerLock||t.mozRequestPointerLock||t.webkitRequestPointerLock||t.msRequestPointerLock||function(){},t.exitPointerLock=document.exitPointerLock||document.mozExitPointerLock||document.webkitExitPointerLock||document.msExitPointerLock||function(){},t.exitPointerLock=t.exitPointerLock.bind(document),document.addEventListener("pointerlockchange",r,!1),document.addEventListener("mozpointerlockchange",r,!1),document.addEventListener("webkitpointerlockchange",r,!1),document.addEventListener("mspointerlockchange",r,!1),Module.elementPointerLock&&t.addEventListener("click",(function(e){!Browser.pointerLock&&Module.canvas.requestPointerLock&&(Module.canvas.requestPointerLock(),e.preventDefault())}),!1))}function r(){Browser.pointerLock=document.pointerLockElement===Module.canvas||document.mozPointerLockElement===Module.canvas||document.webkitPointerLockElement===Module.canvas||document.msPointerLockElement===Module.canvas}},createContext:function(e,n,t,r){if(n&&Module.ctx&&e==Module.canvas)return Module.ctx;var i,u;if(n){var o={antialias:!1,alpha:!1};if(r)for(var a in r)o[a]=r[a];(u=GL.createContext(e,o))&&(i=GL.getContext(u).GLctx)}else i=e.getContext("2d");return i?(t&&(n||assert("undefined"==typeof GLctx,"cannot set in module if GLctx is used, but we are a non-GL context that would replace it"),Module.ctx=i,n&&GL.makeContextCurrent(u),Module.useWebGL=n,Browser.moduleContextCreatedCallbacks.forEach((function(e){e()})),Browser.init()),i):null},destroyContext:function(e,n,t){},fullscreenHandlersInstalled:!1,lockPointer:void 0,resizeCanvas:void 0,requestFullscreen:function(e,n,t){Browser.lockPointer=e,Browser.resizeCanvas=n,Browser.vrDevice=t,void 0===Browser.lockPointer&&(Browser.lockPointer=!0),void 0===Browser.resizeCanvas&&(Browser.resizeCanvas=!1),void 0===Browser.vrDevice&&(Browser.vrDevice=null);var r=Module.canvas;function i(){Browser.isFullscreen=!1;var e=r.parentNode;(document.fullscreenElement||document.mozFullScreenElement||document.msFullscreenElement||document.webkitFullscreenElement||document.webkitCurrentFullScreenElement)===e?(r.exitFullscreen=document.exitFullscreen||document.cancelFullScreen||document.mozCancelFullScreen||document.msExitFullscreen||document.webkitCancelFullScreen||function(){},r.exitFullscreen=r.exitFullscreen.bind(document),Browser.lockPointer&&r.requestPointerLock(),Browser.isFullscreen=!0,Browser.resizeCanvas&&Browser.setFullscreenCanvasSize()):(e.parentNode.insertBefore(r,e),e.parentNode.removeChild(e),Browser.resizeCanvas&&Browser.setWindowedCanvasSize()),Module.onFullScreen&&Module.onFullScreen(Browser.isFullscreen),Module.onFullscreen&&Module.onFullscreen(Browser.isFullscreen),Browser.updateCanvasDimensions(r)}Browser.fullscreenHandlersInstalled||(Browser.fullscreenHandlersInstalled=!0,document.addEventListener("fullscreenchange",i,!1),document.addEventListener("mozfullscreenchange",i,!1),document.addEventListener("webkitfullscreenchange",i,!1),document.addEventListener("MSFullscreenChange",i,!1));var u=document.createElement("div");r.parentNode.insertBefore(u,r),u.appendChild(r),u.requestFullscreen=u.requestFullscreen||u.mozRequestFullScreen||u.msRequestFullscreen||(u.webkitRequestFullscreen?function(){u.webkitRequestFullscreen(Element.ALLOW_KEYBOARD_INPUT)}:null)||(u.webkitRequestFullScreen?function(){u.webkitRequestFullScreen(Element.ALLOW_KEYBOARD_INPUT)}:null),t?u.requestFullscreen({vrDisplay:t}):u.requestFullscreen()},requestFullScreen:function(e,n,t){return Module.printErr("Browser.requestFullScreen() is deprecated. Please call Browser.requestFullscreen instead."),Browser.requestFullScreen=function(e,n,t){return Browser.requestFullscreen(e,n,t)},Browser.requestFullscreen(e,n,t)},nextRAF:0,fakeRequestAnimationFrame:function(e){var n=Date.now();if(0===Browser.nextRAF)Browser.nextRAF=n+1e3/60;else for(;n+2>=Browser.nextRAF;)Browser.nextRAF+=1e3/60;var t=Math.max(Browser.nextRAF-n,0);setTimeout(e,t)},requestAnimationFrame:function(e){"undefined"==typeof window?Browser.fakeRequestAnimationFrame(e):(window.requestAnimationFrame||(window.requestAnimationFrame=window.requestAnimationFrame||window.mozRequestAnimationFrame||window.webkitRequestAnimationFrame||window.msRequestAnimationFrame||window.oRequestAnimationFrame||Browser.fakeRequestAnimationFrame),window.requestAnimationFrame(e))},safeCallback:function(e){return function(){if(!ABORT)return e.apply(null,arguments)}},allowAsyncCallbacks:!0,queuedAsyncCallbacks:[],pauseAsyncCallbacks:function(){Browser.allowAsyncCallbacks=!1},resumeAsyncCallbacks:function(){if(Browser.allowAsyncCallbacks=!0,Browser.queuedAsyncCallbacks.length>0){var e=Browser.queuedAsyncCallbacks;Browser.queuedAsyncCallbacks=[],e.forEach((function(e){e()}))}},safeRequestAnimationFrame:function(e){return Browser.requestAnimationFrame((function(){ABORT||(Browser.allowAsyncCallbacks?e():Browser.queuedAsyncCallbacks.push(e))}))},safeSetTimeout:function(e,n){return Module.noExitRuntime=!0,setTimeout((function(){ABORT||(Browser.allowAsyncCallbacks?e():Browser.queuedAsyncCallbacks.push(e))}),n)},safeSetInterval:function(e,n){return Module.noExitRuntime=!0,setInterval((function(){ABORT||Browser.allowAsyncCallbacks&&e()}),n)},getMimetype:function(e){return{jpg:"image/jpeg",jpeg:"image/jpeg",png:"image/png",bmp:"image/bmp",ogg:"audio/ogg",wav:"audio/wav",mp3:"audio/mpeg"}[e.substr(e.lastIndexOf(".")+1)]},getUserMedia:function(e){window.getUserMedia||(window.getUserMedia=navigator.getUserMedia||navigator.mozGetUserMedia),window.getUserMedia(e)},getMovementX:function(e){return e.movementX||e.mozMovementX||e.webkitMovementX||0},getMovementY:function(e){return e.movementY||e.mozMovementY||e.webkitMovementY||0},getMouseWheelDelta:function(e){var n=0;switch(e.type){case"DOMMouseScroll":n=e.detail;break;case"mousewheel":n=e.wheelDelta;break;case"wheel":n=e.deltaY;break;default:throw"unrecognized mouse wheel event: "+e.type}return n},mouseX:0,mouseY:0,mouseMovementX:0,mouseMovementY:0,touches:{},lastTouches:{},calculateMouseEvent:function(e){if(Browser.pointerLock)"mousemove"!=e.type&&"mozMovementX"in e?Browser.mouseMovementX=Browser.mouseMovementY=0:(Browser.mouseMovementX=Browser.getMovementX(e),Browser.mouseMovementY=Browser.getMovementY(e)),"undefined"!=typeof SDL?(Browser.mouseX=SDL.mouseX+Browser.mouseMovementX,Browser.mouseY=SDL.mouseY+Browser.mouseMovementY):(Browser.mouseX+=Browser.mouseMovementX,Browser.mouseY+=Browser.mouseMovementY);else{var n=Module.canvas.getBoundingClientRect(),t=Module.canvas.width,r=Module.canvas.height,i=void 0!==window.scrollX?window.scrollX:window.pageXOffset,u=void 0!==window.scrollY?window.scrollY:window.pageYOffset;if("touchstart"===e.type||"touchend"===e.type||"touchmove"===e.type){var o=e.touch;if(void 0===o)return;var a=o.pageX-(i+n.left),l=o.pageY-(u+n.top),s={x:a*=t/n.width,y:l*=r/n.height};if("touchstart"===e.type)Browser.lastTouches[o.identifier]=s,Browser.touches[o.identifier]=s;else if("touchend"===e.type||"touchmove"===e.type){var f=Browser.touches[o.identifier];f||(f=s),Browser.lastTouches[o.identifier]=f,Browser.touches[o.identifier]=s}return}var c=e.pageX-(i+n.left),d=e.pageY-(u+n.top);c*=t/n.width,d*=r/n.height,Browser.mouseMovementX=c-Browser.mouseX,Browser.mouseMovementY=d-Browser.mouseY,Browser.mouseX=c,Browser.mouseY=d}},asyncLoad:function(e,n,t,r){var i=r?"":getUniqueRunDependency("al "+e);Module.readAsync(e,(function(t){assert(t,'Loading data file "'+e+'" failed (no arrayBuffer).'),n(new Uint8Array(t)),i&&removeRunDependency(i)}),(function(n){if(!t)throw'Loading data file "'+e+'" failed.';t()})),i&&addRunDependency(i)},resizeListeners:[],updateResizeListeners:function(){var e=Module.canvas;Browser.resizeListeners.forEach((function(n){n(e.width,e.height)}))},setCanvasSize:function(e,n,t){var r=Module.canvas;Browser.updateCanvasDimensions(r,e,n),t||Browser.updateResizeListeners()},windowedWidth:0,windowedHeight:0,setFullscreenCanvasSize:function(){if("undefined"!=typeof SDL){var e=HEAPU32[SDL.screen+0*Runtime.QUANTUM_SIZE>>2];e|=8388608,HEAP32[SDL.screen+0*Runtime.QUANTUM_SIZE>>2]=e}Browser.updateResizeListeners()},setWindowedCanvasSize:function(){if("undefined"!=typeof SDL){var e=HEAPU32[SDL.screen+0*Runtime.QUANTUM_SIZE>>2];e&=-8388609,HEAP32[SDL.screen+0*Runtime.QUANTUM_SIZE>>2]=e}Browser.updateResizeListeners()},updateCanvasDimensions:function(e,n,t){n&&t?(e.widthNative=n,e.heightNative=t):(n=e.widthNative,t=e.heightNative);var r=n,i=t;if(Module.forcedAspectRatio&&Module.forcedAspectRatio>0&&(r/i<Module.forcedAspectRatio?r=Math.round(i*Module.forcedAspectRatio):i=Math.round(r/Module.forcedAspectRatio)),(document.fullscreenElement||document.mozFullScreenElement||document.msFullscreenElement||document.webkitFullscreenElement||document.webkitCurrentFullScreenElement)===e.parentNode&&"undefined"!=typeof screen){var u=Math.min(screen.width/r,screen.height/i);r=Math.round(r*u),i=Math.round(i*u)}Browser.resizeCanvas?(e.width!=r&&(e.width=r),e.height!=i&&(e.height=i),void 0!==e.style&&(e.style.removeProperty("width"),e.style.removeProperty("height"))):(e.width!=n&&(e.width=n),e.height!=t&&(e.height=t),void 0!==e.style&&(r!=n||i!=t?(e.style.setProperty("width",r+"px","important"),e.style.setProperty("height",i+"px","important")):(e.style.removeProperty("width"),e.style.removeProperty("height"))))},wgetRequests:{},nextWgetRequestHandle:0,getNextWgetRequestHandle:function(){var e=Browser.nextWgetRequestHandle;return Browser.nextWgetRequestHandle++,e}},SYSCALLS={varargs:0,get:function(e){return SYSCALLS.varargs+=4,HEAP32[SYSCALLS.varargs-4>>2]},getStr:function(){return Pointer_stringify(SYSCALLS.get())},get64:function(){var e=SYSCALLS.get(),n=SYSCALLS.get();return assert(e>=0?0===n:-1===n),e},getZero:function(){assert(0===SYSCALLS.get())}};function ___syscall6(e,n){SYSCALLS.varargs=n;try{var t=SYSCALLS.getStreamFromFD();return FS.close(t),0}catch(e){return"undefined"!=typeof FS&&e instanceof FS.ErrnoError||abort(e),-e.errno}}function ___syscall54(e,n){SYSCALLS.varargs=n;try{return 0}catch(e){return"undefined"!=typeof FS&&e instanceof FS.ErrnoError||abort(e),-e.errno}}function _typeModule(e){var n=[[0,1,"X"],[1,1,"const X"],[128,1,"X *"],[256,1,"X &"],[384,1,"X &&"],[512,1,"std::shared_ptr<X>"],[640,1,"std::unique_ptr<X>"],[5120,1,"std::vector<X>"],[6144,2,"std::array<X, Y>"],[9216,-1,"std::function<X (Y)>"]];function t(e,n,t,r,i,u){if(1==n){var o=896&r;128!=o&&256!=o&&384!=o||(e="X const")}return(u?t.replace("X",e).replace("Y",i):e.replace("X",t).replace("Y",i)).replace(/([*&]) (?=[*&])/g,"$1")}function r(e,n){var t=n.flags,r=896&t,i=15360&t;return n.name||1024!=i||(1==n.ptrSize?n.name=(16&t?"":(8&t?"un":"")+"signed ")+"char":n.name=(8&t?"u":"")+(32&t?"float":"int")+8*n.ptrSize+"_t"),8!=n.ptrSize||32&t||(i=64),2048==i&&(512==r||640==r?i=4096:r&&(i=3072)),e(i,n)}var i={Type:function(){function e(e){this.id=e.id,this.name=e.name,this.flags=e.flags,this.spec=e}return e.prototype.toString=function(){return this.name},e}(),getComplexType:function e(i,u,o,a,l,s,f,c){void 0===s&&(s="X"),void 0===c&&(c=1);var d=o(i);if(d)return d;var p,h=a(i),m=h.placeholderFlag,v=n[m];f&&v&&(s=t(f[2],f[0],s,v[0],"?",!0)),0==m&&(p="Unbound"),m>=10&&(p="Corrupt"),c>20&&(p="Deeply nested"),p&&function(e,n,t,r,i){throw new Error(e+" type "+t.replace("X",n+"?")+(r?" with flag "+r:"")+" in "+i)}(p,i,s,m,l||"?");var _,b=e(h.paramList[0],u,o,a,l,s,v,c+1),g={flags:v[0],id:i,name:"",paramList:[b]},y=[],D="?";switch(h.placeholderFlag){case 1:_=b.spec;break;case 2:if(1024==(15360&b.flags)&&1==b.spec.ptrSize){g.flags=7168;break}case 3:case 6:case 5:_=b.spec,b.flags;break;case 8:D=""+h.paramList[1],g.paramList.push(h.paramList[1]);break;case 9:for(var w=0,E=h.paramList[1];w<E.length;w++){var T=e(E[w],u,o,a,l,s,v,c+1);y.push(T.name),g.paramList.push(T)}D=y.join(", ")}if(g.name=t(v[2],v[0],b.name,b.flags,D),_){for(var C=0,k=Object.keys(_);C<k.length;C++){var M=k[C];g[M]=g[M]||_[M]}g.flags|=_.flags}return r(u,g)},makeType:r,structureList:n};return e.output=i,e.output||i}function __nbind_register_type(e,n){var t={flags:10240,id:e,name:_nbind.readAsciiString(n)};_nbind.makeType(_nbind.constructType,t)}function __nbind_register_callback_signature(e,n){var t=_nbind.readTypeIdList(e,n),r=_nbind.callbackSignatureList.length;return _nbind.callbackSignatureList[r]=_nbind.makeJSCaller(t),r}function __extends(e,n){for(var t in n)n.hasOwnProperty(t)&&(e[t]=n[t]);function r(){this.constructor=e}r.prototype=n.prototype,e.prototype=new r}function __nbind_register_class(e,n,t,r,i,u,o){var a=_nbind.readAsciiString(o),l=_nbind.readPolicyList(n),s=HEAPU32.subarray(e/4,e/4+2),f={flags:2048|(l.Value?2:0),id:s[0],name:a},c=_nbind.makeType(_nbind.constructType,f);c.ptrType=_nbind.getComplexType(s[1],_nbind.constructType,_nbind.getType,_nbind.queryType),c.destroy=_nbind.makeMethodCaller(c.ptrType,{boundID:f.id,flags:0,name:"destroy",num:0,ptr:u,title:c.name+".free",typeList:["void","uint32_t","uint32_t"]}),i&&(c.superIdList=Array.prototype.slice.call(HEAPU32.subarray(t/4,t/4+i)),c.upcastList=Array.prototype.slice.call(HEAPU32.subarray(r/4,r/4+i))),Module[c.name]=c.makeBound(l),_nbind.BindClass.list.push(c)}function _removeAccessorPrefix(e){return e.replace(/^[Gg]et_?([A-Z]?([A-Z]?))/,(function(e,n,t){return t?n:n.toLowerCase()}))}function __nbind_register_function(e,n,t,r,i,u,o,a,l,s){var f,c=_nbind.getType(e),d=_nbind.readPolicyList(n),p=_nbind.readTypeIdList(t,r);if(5==o)f=[{direct:i,name:"__nbindConstructor",ptr:0,title:c.name+" constructor",typeList:["uint32_t"].concat(p.slice(1))},{direct:u,name:"__nbindValueConstructor",ptr:0,title:c.name+" value constructor",typeList:["void","uint32_t"].concat(p.slice(1))}];else{var h=_nbind.readAsciiString(a),m=(c.name&&c.name+".")+h;3!=o&&4!=o||(h=_removeAccessorPrefix(h)),f=[{boundID:e,direct:u,name:h,ptr:i,title:m,typeList:p}]}for(var v=0,_=f;v<_.length;v++){var b=_[v];b.signatureType=o,b.policyTbl=d,b.num=l,b.flags=s,c.addMethod(b)}}function _nbind_value(e,n){_nbind.typeNameTbl[e]||_nbind.throwError("Unknown value type "+e),Module.NBind.bind_value(e,n),_defineHidden(_nbind.typeNameTbl[e].proto.prototype.__nbindValueConstructor)(n.prototype,"__nbindValueConstructor")}function __nbind_get_value_object(e,n){var t=_nbind.popValue(e);if(!t.fromJS)throw new Error("Object "+t+" has no fromJS function");t.fromJS((function(){t.__nbindValueConstructor.apply(this,Array.prototype.concat.apply([n],arguments))}))}function _emscripten_memcpy_big(e,n,t){return HEAPU8.set(HEAPU8.subarray(n,n+t),e),e}function __nbind_register_primitive(e,n,t){var r={flags:1024|t,id:e,ptrSize:n};_nbind.makeType(_nbind.constructType,r)}Module._nbind_value=_nbind_value;var cttz_i8=allocate([8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0],"i8",ALLOC_STATIC);function ___setErrNo(e){return Module.___errno_location&&(HEAP32[Module.___errno_location()>>2]=e),e}function _llvm_stacksave(){var e=_llvm_stacksave;return e.LLVM_SAVEDSTACKS||(e.LLVM_SAVEDSTACKS=[]),e.LLVM_SAVEDSTACKS.push(Runtime.stackSave()),e.LLVM_SAVEDSTACKS.length-1}function ___syscall140(e,n){SYSCALLS.varargs=n;try{var t=SYSCALLS.getStreamFromFD(),r=(SYSCALLS.get(),SYSCALLS.get()),i=SYSCALLS.get(),u=SYSCALLS.get(),o=r;return FS.llseek(t,o,u),HEAP32[i>>2]=t.position,t.getdents&&0===o&&0===u&&(t.getdents=null),0}catch(e){return"undefined"!=typeof FS&&e instanceof FS.ErrnoError||abort(e),-e.errno}}function ___syscall146(e,n){SYSCALLS.varargs=n;try{var t=SYSCALLS.get(),r=SYSCALLS.get(),i=SYSCALLS.get(),u=0;___syscall146.buffer||(___syscall146.buffers=[null,[],[]],___syscall146.printChar=function(e,n){var t=___syscall146.buffers[e];assert(t),0===n||10===n?((1===e?Module.print:Module.printErr)(UTF8ArrayToString(t,0)),t.length=0):t.push(n)});for(var o=0;o<i;o++){for(var a=HEAP32[r+8*o>>2],l=HEAP32[r+(8*o+4)>>2],s=0;s<l;s++)___syscall146.printChar(t,HEAPU8[a+s]);u+=l}return u}catch(e){return"undefined"!=typeof FS&&e instanceof FS.ErrnoError||abort(e),-e.errno}}function __nbind_finish(){for(var e=0,n=_nbind.BindClass.list;e<n.length;e++)n[e].finish()}var ___dso_handle=STATICTOP;function invoke_viiiii(e,n,t,r,i,u){try{Module.dynCall_viiiii(e,n,t,r,i,u)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_vif(e,n,t){try{Module.dynCall_vif(e,n,t)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_vid(e,n,t){try{Module.dynCall_vid(e,n,t)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_fiff(e,n,t,r){try{return Module.dynCall_fiff(e,n,t,r)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_vi(e,n){try{Module.dynCall_vi(e,n)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_vii(e,n,t){try{Module.dynCall_vii(e,n,t)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_ii(e,n){try{return Module.dynCall_ii(e,n)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_viddi(e,n,t,r,i){try{Module.dynCall_viddi(e,n,t,r,i)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_vidd(e,n,t,r){try{Module.dynCall_vidd(e,n,t,r)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_iiii(e,n,t,r){try{return Module.dynCall_iiii(e,n,t,r)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_diii(e,n,t,r){try{return Module.dynCall_diii(e,n,t,r)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_di(e,n){try{return Module.dynCall_di(e,n)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_iid(e,n,t){try{return Module.dynCall_iid(e,n,t)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_iii(e,n,t){try{return Module.dynCall_iii(e,n,t)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_viiddi(e,n,t,r,i,u){try{Module.dynCall_viiddi(e,n,t,r,i,u)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_viiiiii(e,n,t,r,i,u,o){try{Module.dynCall_viiiiii(e,n,t,r,i,u,o)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_dii(e,n,t){try{return Module.dynCall_dii(e,n,t)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_i(e){try{return Module.dynCall_i(e)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_iiiiii(e,n,t,r,i,u){try{return Module.dynCall_iiiiii(e,n,t,r,i,u)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_viiid(e,n,t,r,i){try{Module.dynCall_viiid(e,n,t,r,i)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_viififi(e,n,t,r,i,u,o){try{Module.dynCall_viififi(e,n,t,r,i,u,o)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_viii(e,n,t,r){try{Module.dynCall_viii(e,n,t,r)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_v(e){try{Module.dynCall_v(e)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_viid(e,n,t,r){try{Module.dynCall_viid(e,n,t,r)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_idd(e,n,t){try{return Module.dynCall_idd(e,n,t)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}function invoke_viiii(e,n,t,r,i){try{Module.dynCall_viiii(e,n,t,r,i)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;Module.setThrew(1,0)}}STATICTOP+=16,function(_nbind){var typeIdTbl={};_nbind.typeNameTbl={};var Pool=function(){function e(){}return e.lalloc=function(n){n=n+7&-8;var t=HEAPU32[e.usedPtr];return n>e.pageSize/2||n>e.pageSize-t?_nbind.typeNameTbl.NBind.proto.lalloc(n):(HEAPU32[e.usedPtr]=t+n,e.rootPtr+t)},e.lreset=function(n,t){HEAPU32[e.pagePtr]?_nbind.typeNameTbl.NBind.proto.lreset(n,t):HEAPU32[e.usedPtr]=n},e}();function constructType(e,n){var t=new(10240==e?_nbind.makeTypeNameTbl[n.name]||_nbind.BindType:_nbind.makeTypeKindTbl[e])(n);return typeIdTbl[n.id]=t,_nbind.typeNameTbl[n.name]=t,t}function getType(e){return typeIdTbl[e]}function queryType(e){var n=HEAPU8[e],t=_nbind.structureList[n][1];e/=4,t<0&&(++e,t=HEAPU32[e]+1);var r=Array.prototype.slice.call(HEAPU32.subarray(e+1,e+1+t));return 9==n&&(r=[r[0],r.slice(1)]),{paramList:r,placeholderFlag:n}}function getTypes(e,n){return e.map((function(e){return"number"==typeof e?_nbind.getComplexType(e,constructType,getType,queryType,n):_nbind.typeNameTbl[e]}))}function readTypeIdList(e,n){return Array.prototype.slice.call(HEAPU32,e/4,e/4+n)}function readAsciiString(e){for(var n=e;HEAPU8[n++];);return String.fromCharCode.apply("",HEAPU8.subarray(e,n-1))}function readPolicyList(e){var n={};if(e)for(;;){var t=HEAPU32[e/4];if(!t)break;n[readAsciiString(t)]=!0,e+=4}return n}function getDynCall(e,n){var t={float32_t:"d",float64_t:"d",int64_t:"d",uint64_t:"d",void:"v"},r=e.map((function(e){return t[e.name]||"i"})).join(""),i=Module["dynCall_"+r];if(!i)throw new Error("dynCall_"+r+" not found for "+n+"("+e.map((function(e){return e.name})).join(", ")+")");return i}function addMethod(e,n,t,r){var i=e[n];e.hasOwnProperty(n)&&i?((i.arity||0===i.arity)&&(i=_nbind.makeOverloader(i,i.arity),e[n]=i),i.addMethod(t,r)):(t.arity=r,e[n]=t)}function throwError(e){throw new Error(e)}_nbind.Pool=Pool,_nbind.constructType=constructType,_nbind.getType=getType,_nbind.queryType=queryType,_nbind.getTypes=getTypes,_nbind.readTypeIdList=readTypeIdList,_nbind.readAsciiString=readAsciiString,_nbind.readPolicyList=readPolicyList,_nbind.getDynCall=getDynCall,_nbind.addMethod=addMethod,_nbind.throwError=throwError,_nbind.bigEndian=!1,_a=_typeModule(_typeModule),_nbind.Type=_a.Type,_nbind.makeType=_a.makeType,_nbind.getComplexType=_a.getComplexType,_nbind.structureList=_a.structureList;var BindType=function(e){function n(){var n=null!==e&&e.apply(this,arguments)||this;return n.heap=HEAPU32,n.ptrSize=4,n}return __extends(n,e),n.prototype.needsWireRead=function(e){return!!this.wireRead||!!this.makeWireRead},n.prototype.needsWireWrite=function(e){return!!this.wireWrite||!!this.makeWireWrite},n}(_nbind.Type);_nbind.BindType=BindType;var PrimitiveType=function(e){function n(n){var t=e.call(this,n)||this,r=32&n.flags?{32:HEAPF32,64:HEAPF64}:8&n.flags?{8:HEAPU8,16:HEAPU16,32:HEAPU32}:{8:HEAP8,16:HEAP16,32:HEAP32};return t.heap=r[8*n.ptrSize],t.ptrSize=n.ptrSize,t}return __extends(n,e),n.prototype.needsWireWrite=function(e){return!!e&&!!e.Strict},n.prototype.makeWireWrite=function(e,n){return n&&n.Strict&&function(e){if("number"==typeof e)return e;throw new Error("Type mismatch")}},n}(BindType);function pushCString(e,n){if(null==e){if(n&&n.Nullable)return 0;throw new Error("Type mismatch")}if(n&&n.Strict){if("string"!=typeof e)throw new Error("Type mismatch")}else e=e.toString();var t=Module.lengthBytesUTF8(e)+1,r=_nbind.Pool.lalloc(t);return Module.stringToUTF8Array(e,HEAPU8,r,t),r}function popCString(e){return 0===e?null:Module.Pointer_stringify(e)}_nbind.PrimitiveType=PrimitiveType,_nbind.pushCString=pushCString,_nbind.popCString=popCString;var CStringType=function(e){function n(){var n=null!==e&&e.apply(this,arguments)||this;return n.wireRead=popCString,n.wireWrite=pushCString,n.readResources=[_nbind.resources.pool],n.writeResources=[_nbind.resources.pool],n}return __extends(n,e),n.prototype.makeWireWrite=function(e,n){return function(e){return pushCString(e,n)}},n}(BindType);_nbind.CStringType=CStringType;var BooleanType=function(e){function n(){var n=null!==e&&e.apply(this,arguments)||this;return n.wireRead=function(e){return!!e},n}return __extends(n,e),n.prototype.needsWireWrite=function(e){return!!e&&!!e.Strict},n.prototype.makeWireRead=function(e){return"!!("+e+")"},n.prototype.makeWireWrite=function(e,n){return n&&n.Strict&&function(e){if("boolean"==typeof e)return e;throw new Error("Type mismatch")}||e},n}(BindType);_nbind.BooleanType=BooleanType;var Wrapper=function(){function e(){}return e.prototype.persist=function(){this.__nbindState|=1},e}();function makeBound(e,n){var t=function(e){function t(n,r,i,u){var o=e.call(this)||this;if(!(o instanceof t))return new(Function.prototype.bind.apply(t,Array.prototype.concat.apply([null],arguments)));var a=r,l=i,s=u;if(n!==_nbind.ptrMarker){var f=o.__nbindConstructor.apply(o,arguments);a=4608,s=HEAPU32[f/4],l=HEAPU32[f/4+1]}var c={configurable:!0,enumerable:!1,value:null,writable:!1},d={__nbindFlags:a,__nbindPtr:l};s&&(d.__nbindShared=s,_nbind.mark(o));for(var p=0,h=Object.keys(d);p<h.length;p++){var m=h[p];c.value=d[m],Object.defineProperty(o,m,c)}return _defineHidden(0)(o,"__nbindState"),o}return __extends(t,e),t.prototype.free=function(){n.destroy.call(this,this.__nbindShared,this.__nbindFlags),this.__nbindState|=2,disableMember(this,"__nbindShared"),disableMember(this,"__nbindPtr")},t}(Wrapper);return __decorate([_defineHidden()],t.prototype,"__nbindConstructor",void 0),__decorate([_defineHidden()],t.prototype,"__nbindValueConstructor",void 0),__decorate([_defineHidden(e)],t.prototype,"__nbindPolicies",void 0),t}function disableMember(e,n){function t(){throw new Error("Accessing deleted object")}Object.defineProperty(e,n,{configurable:!1,enumerable:!1,get:t,set:t})}_nbind.Wrapper=Wrapper,_nbind.makeBound=makeBound,_nbind.ptrMarker={};var BindClass=function(e){function n(n){var t=e.call(this,n)||this;return t.wireRead=function(e){return _nbind.popValue(e,t.ptrType)},t.wireWrite=function(e){return pushPointer(e,t.ptrType,!0)},t.pendingSuperCount=0,t.ready=!1,t.methodTbl={},n.paramList?(t.classType=n.paramList[0].classType,t.proto=t.classType.proto):t.classType=t,t}return __extends(n,e),n.prototype.makeBound=function(e){var n=_nbind.makeBound(e,this);return this.proto=n,this.ptrType.proto=n,n},n.prototype.addMethod=function(e){var n=this.methodTbl[e.name]||[];n.push(e),this.methodTbl[e.name]=n},n.prototype.registerMethods=function(e,n){for(var t,r=0,i=Object.keys(e.methodTbl);r<i.length;r++)for(var u=i[r],o=0,a=e.methodTbl[u];o<a.length;o++){var l=a[o],s=void 0,f=void 0;if(s=this.proto.prototype,!n||1==l.signatureType)switch(l.signatureType){case 1:s=this.proto;case 5:f=_nbind.makeCaller(l),_nbind.addMethod(s,l.name,f,l.typeList.length-1);break;case 4:t=_nbind.makeMethodCaller(e.ptrType,l);break;case 3:Object.defineProperty(s,l.name,{configurable:!0,enumerable:!1,get:_nbind.makeMethodCaller(e.ptrType,l),set:t});break;case 2:f=_nbind.makeMethodCaller(e.ptrType,l),_nbind.addMethod(s,l.name,f,l.typeList.length-1)}}},n.prototype.registerSuperMethods=function(e,n,t){if(!t[e.name]){t[e.name]=!0;for(var r,i=0,u=0,o=e.superIdList||[];u<o.length;u++){var a=o[u],l=_nbind.getType(a);r=i++<n||n<0?-1:0,this.registerSuperMethods(l,r,t)}this.registerMethods(e,n<0)}},n.prototype.finish=function(){if(this.ready)return this;this.ready=!0,this.superList=(this.superIdList||[]).map((function(e){return _nbind.getType(e).finish()}));var e=this.proto;if(this.superList.length){var n=function(){this.constructor=e};n.prototype=this.superList[0].proto.prototype,e.prototype=new n}return e!=Module&&(e.prototype.__nbindType=this),this.registerSuperMethods(this,1,{}),this},n.prototype.upcastStep=function(e,n){if(e==this)return n;for(var t=0;t<this.superList.length;++t){var r=this.superList[t].upcastStep(e,_nbind.callUpcast(this.upcastList[t],n));if(r)return r}return 0},n}(_nbind.BindType);function popPointer(e,n){return e?new n.proto(_nbind.ptrMarker,n.flags,e):null}function pushPointer(e,n,t){if(!(e instanceof _nbind.Wrapper)){if(t)return _nbind.pushValue(e);throw new Error("Type mismatch")}var r=e.__nbindPtr,i=e.__nbindType.classType,u=n.classType;if(e instanceof n.proto)for(;i!=u;)r=_nbind.callUpcast(i.upcastList[0],r),i=i.superList[0];else if(!(r=i.upcastStep(u,r)))throw new Error("Type mismatch");return r}function pushMutablePointer(e,n){var t=pushPointer(e,n);if(1&e.__nbindFlags)throw new Error("Passing a const value as a non-const argument");return t}BindClass.list=[],_nbind.BindClass=BindClass,_nbind.popPointer=popPointer,_nbind.pushPointer=pushPointer;var BindClassPtr=function(e){function n(n){var t=e.call(this,n)||this;t.classType=n.paramList[0].classType,t.proto=t.classType.proto;var r=1&n.flags,i=256==(896&t.flags)&&2&n.flags,u=r?pushPointer:pushMutablePointer,o=i?_nbind.popValue:popPointer;return t.makeWireWrite=function(e,n){return n.Nullable?function(e){return e?u(e,t):0}:function(e){return u(e,t)}},t.wireRead=function(e){return o(e,t)},t.wireWrite=function(e){return u(e,t)},t}return __extends(n,e),n}(_nbind.BindType);function popShared(e,n){var t=HEAPU32[e/4],r=HEAPU32[e/4+1];return r?new n.proto(_nbind.ptrMarker,n.flags,r,t):null}function pushShared(e,n){if(!(e instanceof n.proto))throw new Error("Type mismatch");return e.__nbindShared}function pushMutableShared(e,n){if(!(e instanceof n.proto))throw new Error("Type mismatch");if(1&e.__nbindFlags)throw new Error("Passing a const value as a non-const argument");return e.__nbindShared}_nbind.BindClassPtr=BindClassPtr,_nbind.popShared=popShared;var SharedClassPtr=function(e){function n(n){var t=e.call(this,n)||this;t.readResources=[_nbind.resources.pool],t.classType=n.paramList[0].classType,t.proto=t.classType.proto;var r=1&n.flags?pushShared:pushMutableShared;return t.wireRead=function(e){return popShared(e,t)},t.wireWrite=function(e){return r(e,t)},t}return __extends(n,e),n}(_nbind.BindType);_nbind.SharedClassPtr=SharedClassPtr,_nbind.externalList=[0];var firstFreeExternal=0,External=function(){function e(e){this.refCount=1,this.data=e}return e.prototype.register=function(){var e=firstFreeExternal;return e?firstFreeExternal=_nbind.externalList[e]:e=_nbind.externalList.length,_nbind.externalList[e]=this,e},e.prototype.reference=function(){++this.refCount},e.prototype.dereference=function(e){0==--this.refCount&&(this.free&&this.free(),_nbind.externalList[e]=firstFreeExternal,firstFreeExternal=e)},e}();function popExternal(e){var n=_nbind.externalList[e];return n.dereference(e),n.data}function pushExternal(e){var n=new External(e);return n.reference(),n.register()}_nbind.External=External;var ExternalType=function(e){function n(){var n=null!==e&&e.apply(this,arguments)||this;return n.wireRead=popExternal,n.wireWrite=pushExternal,n}return __extends(n,e),n}(_nbind.BindType);_nbind.ExternalType=ExternalType,_nbind.callbackSignatureList=[];var CallbackType=function(e){function n(){var n=null!==e&&e.apply(this,arguments)||this;return n.wireWrite=function(e){return"function"!=typeof e&&_nbind.throwError("Type mismatch"),new _nbind.External(e).register()},n}return __extends(n,e),n}(_nbind.BindType);_nbind.CallbackType=CallbackType,_nbind.valueList=[0];var firstFreeValue=0;function pushValue(e){var n=firstFreeValue;return n?firstFreeValue=_nbind.valueList[n]:n=_nbind.valueList.length,_nbind.valueList[n]=e,2*n+1}function popValue(e,n){if(e||_nbind.throwError("Value type JavaScript class is missing or not registered"),1&e){e>>=1;var t=_nbind.valueList[e];return _nbind.valueList[e]=firstFreeValue,firstFreeValue=e,t}if(n)return _nbind.popShared(e,n);throw new Error("Invalid value slot "+e)}_nbind.pushValue=pushValue,_nbind.popValue=popValue;var valueBase=0x10000000000000000;function push64(e){return"number"==typeof e?e:4096*pushValue(e)+valueBase}function pop64(e){return e<valueBase?e:popValue((e-valueBase)/4096)}var CreateValueType=function(e){function n(){return null!==e&&e.apply(this,arguments)||this}return __extends(n,e),n.prototype.makeWireWrite=function(e){return"(_nbind.pushValue(new "+e+"))"},n}(_nbind.BindType);_nbind.CreateValueType=CreateValueType;var Int64Type=function(e){function n(){var n=null!==e&&e.apply(this,arguments)||this;return n.wireWrite=push64,n.wireRead=pop64,n}return __extends(n,e),n}(_nbind.BindType);function pushArray(e,n){if(!e)return 0;var t=e.length;if((n.size||0===n.size)&&t<n.size)throw new Error("Type mismatch");var r=n.memberType.ptrSize,i=_nbind.Pool.lalloc(4+t*r);HEAPU32[i/4]=t;var u=n.memberType.heap,o=(i+4)/r,a=n.memberType.wireWrite,l=0;if(a)for(;l<t;)u[o++]=a(e[l++]);else for(;l<t;)u[o++]=e[l++];return i}function popArray(e,n){if(0===e)return null;var t=HEAPU32[e/4],r=new Array(t),i=n.memberType.heap;e=(e+4)/n.memberType.ptrSize;var u=n.memberType.wireRead,o=0;if(u)for(;o<t;)r[o++]=u(i[e++]);else for(;o<t;)r[o++]=i[e++];return r}_nbind.Int64Type=Int64Type,_nbind.pushArray=pushArray,_nbind.popArray=popArray;var ArrayType=function(e){function n(n){var t=e.call(this,n)||this;return t.wireRead=function(e){return popArray(e,t)},t.wireWrite=function(e){return pushArray(e,t)},t.readResources=[_nbind.resources.pool],t.writeResources=[_nbind.resources.pool],t.memberType=n.paramList[0],n.paramList[1]&&(t.size=n.paramList[1]),t}return __extends(n,e),n}(_nbind.BindType);function pushString(e,n){if(null==e){if(!n||!n.Nullable)throw new Error("Type mismatch");e=""}if(n&&n.Strict){if("string"!=typeof e)throw new Error("Type mismatch")}else e=e.toString();var t=Module.lengthBytesUTF8(e),r=_nbind.Pool.lalloc(4+t+1);return HEAPU32[r/4]=t,Module.stringToUTF8Array(e,HEAPU8,r+4,t+1),r}function popString(e){if(0===e)return null;var n=HEAPU32[e/4];return Module.Pointer_stringify(e+4,n)}_nbind.ArrayType=ArrayType,_nbind.pushString=pushString,_nbind.popString=popString;var StringType=function(e){function n(){var n=null!==e&&e.apply(this,arguments)||this;return n.wireRead=popString,n.wireWrite=pushString,n.readResources=[_nbind.resources.pool],n.writeResources=[_nbind.resources.pool],n}return __extends(n,e),n.prototype.makeWireWrite=function(e,n){return function(e){return pushString(e,n)}},n}(_nbind.BindType);function makeArgList(e){return Array.apply(null,Array(e)).map((function(e,n){return"a"+(n+1)}))}function anyNeedsWireWrite(e,n){return e.reduce((function(e,t){return e||t.needsWireWrite(n)}),!1)}function anyNeedsWireRead(e,n){return e.reduce((function(e,t){return e||!!t.needsWireRead(n)}),!1)}function makeWireRead(e,n,t,r){var i=e.length;return t.makeWireRead?t.makeWireRead(r,e,i):t.wireRead?(e[i]=t.wireRead,"(convertParamList["+i+"]("+r+"))"):r}function makeWireWrite(e,n,t,r){var i,u=e.length;return(i=t.makeWireWrite?t.makeWireWrite(r,n,e,u):t.wireWrite)?"string"==typeof i?i:(e[u]=i,"(convertParamList["+u+"]("+r+"))"):r}function buildCallerFunction(dynCall,ptrType,ptr,num,policyTbl,needsWireWrite,prefix,returnType,argTypeList,mask,err){var argList=makeArgList(argTypeList.length),convertParamList=[],callExpression=makeWireRead(convertParamList,policyTbl,returnType,"dynCall("+[prefix].concat(argList.map((function(e,n){return makeWireWrite(convertParamList,policyTbl,argTypeList[n],e)}))).join(",")+")"),resourceSet=_nbind.listResources([returnType],argTypeList),sourceCode="function("+argList.join(",")+"){"+(mask?"this.__nbindFlags&mask&&err();":"")+resourceSet.makeOpen()+"var r="+callExpression+";"+resourceSet.makeClose()+"return r;}";return eval("("+sourceCode+")")}function buildJSCallerFunction(returnType,argTypeList){var argList=makeArgList(argTypeList.length),convertParamList=[],callExpression=makeWireWrite(convertParamList,null,returnType,"_nbind.externalList[num].data("+argList.map((function(e,n){return makeWireRead(convertParamList,null,argTypeList[n],e)})).join(",")+")"),resourceSet=_nbind.listResources(argTypeList,[returnType]);resourceSet.remove(_nbind.resources.pool);var sourceCode="function("+["dummy","num"].concat(argList).join(",")+"){"+resourceSet.makeOpen()+"var r="+callExpression+";"+resourceSet.makeClose()+"return r;}";return eval("("+sourceCode+")")}function makeJSCaller(e){var n=e.length-1,t=_nbind.getTypes(e,"callback"),r=t[0],i=t.slice(1),u=anyNeedsWireRead(i,null);if(!r.needsWireWrite(null)&&!u)switch(n){case 0:return function(e,n){return _nbind.externalList[n].data()};case 1:return function(e,n,t){return _nbind.externalList[n].data(t)};case 2:return function(e,n,t,r){return _nbind.externalList[n].data(t,r)};case 3:return function(e,n,t,r,i){return _nbind.externalList[n].data(t,r,i)}}return buildJSCallerFunction(r,i)}function makeMethodCaller(e,n){var t=n.typeList.length-1,r=n.typeList.slice(0);r.splice(1,0,"uint32_t",n.boundID);var i=_nbind.getTypes(r,n.title),u=i[0],o=i.slice(3),a=u.needsWireRead(n.policyTbl),l=anyNeedsWireWrite(o,n.policyTbl),s=n.ptr,f=n.num,c=_nbind.getDynCall(i,n.title),d=1&~n.flags;function p(){throw new Error("Calling a non-const method on a const object")}if(!a&&!l)switch(t){case 0:return function(){return this.__nbindFlags&d?p():c(s,f,_nbind.pushPointer(this,e))};case 1:return function(n){return this.__nbindFlags&d?p():c(s,f,_nbind.pushPointer(this,e),n)};case 2:return function(n,t){return this.__nbindFlags&d?p():c(s,f,_nbind.pushPointer(this,e),n,t)};case 3:return function(n,t,r){return this.__nbindFlags&d?p():c(s,f,_nbind.pushPointer(this,e),n,t,r)}}return buildCallerFunction(c,e,s,f,n.policyTbl,l,"ptr,num,pushPointer(this,ptrType)",u,o,d,p)}function makeCaller(e){var n,t=e.typeList.length-1,r=_nbind.getTypes(e.typeList,e.title),i=r[0],u=r.slice(1),o=i.needsWireRead(e.policyTbl),a=anyNeedsWireWrite(u,e.policyTbl),l=e.direct,s=e.ptr;if(e.direct&&!o&&!a){var f=_nbind.getDynCall(r,e.title);switch(t){case 0:return function(){return f(l)};case 1:return function(e){return f(l,e)};case 2:return function(e,n){return f(l,e,n)};case 3:return function(e,n,t){return f(l,e,n,t)}}s=0}if(s){var c=e.typeList.slice(0);c.splice(1,0,"uint32_t"),r=_nbind.getTypes(c,e.title),n="ptr,num"}else s=l,n="ptr";return buildCallerFunction(_nbind.getDynCall(r,e.title),null,s,e.num,e.policyTbl,a,n,i,u)}function makeOverloader(e,n){var t=[];function r(){return t[arguments.length].apply(this,arguments)}return r.addMethod=function(e,n){t[n]=e},r.addMethod(e,n),r}_nbind.StringType=StringType,_nbind.buildJSCallerFunction=buildJSCallerFunction,_nbind.makeJSCaller=makeJSCaller,_nbind.makeMethodCaller=makeMethodCaller,_nbind.makeCaller=makeCaller,_nbind.makeOverloader=makeOverloader;var Resource=function(){function e(e,n){var t=this;this.makeOpen=function(){return Object.keys(t.openTbl).join("")},this.makeClose=function(){return Object.keys(t.closeTbl).join("")},this.openTbl={},this.closeTbl={},e&&(this.openTbl[e]=!0),n&&(this.closeTbl[n]=!0)}return e.prototype.add=function(e){for(var n=0,t=Object.keys(e.openTbl);n<t.length;n++){var r=t[n];this.openTbl[r]=!0}for(var i=0,u=Object.keys(e.closeTbl);i<u.length;i++)r=u[i],this.closeTbl[r]=!0},e.prototype.remove=function(e){for(var n=0,t=Object.keys(e.openTbl);n<t.length;n++){var r=t[n];delete this.openTbl[r]}for(var i=0,u=Object.keys(e.closeTbl);i<u.length;i++)r=u[i],delete this.closeTbl[r]},e}();function listResources(e,n){for(var t=new Resource,r=0,i=e;r<i.length;r++)for(var u=0,o=i[r].readResources||[];u<o.length;u++){var a=o[u];t.add(a)}for(var l=0,s=n;l<s.length;l++)for(var f=0,c=s[l].writeResources||[];f<c.length;f++)a=c[f],t.add(a);return t}_nbind.Resource=Resource,_nbind.listResources=listResources,_nbind.resources={pool:new Resource("var used=HEAPU32[_nbind.Pool.usedPtr],page=HEAPU32[_nbind.Pool.pagePtr];","_nbind.Pool.lreset(used,page);")};var ExternalBuffer=function(e){function n(n,t){var r=e.call(this,n)||this;return r.ptr=t,r}return __extends(n,e),n.prototype.free=function(){_free(this.ptr)},n}(_nbind.External);function getBuffer(e){return e instanceof ArrayBuffer?new Uint8Array(e):e instanceof DataView?new Uint8Array(e.buffer,e.byteOffset,e.byteLength):e}function pushBuffer(e,n){if(null==e&&n&&n.Nullable&&(e=[]),"object"!=typeof e)throw new Error("Type mismatch");var t=e,r=t.byteLength||t.length;if(!r&&0!==r&&0!==t.byteLength)throw new Error("Type mismatch");var i=_nbind.Pool.lalloc(8),u=_malloc(r),o=i/4;return HEAPU32[o++]=r,HEAPU32[o++]=u,HEAPU32[o++]=new ExternalBuffer(e,u).register(),HEAPU8.set(getBuffer(e),u),i}var BufferType=function(e){function n(){var n=null!==e&&e.apply(this,arguments)||this;return n.wireWrite=pushBuffer,n.readResources=[_nbind.resources.pool],n.writeResources=[_nbind.resources.pool],n}return __extends(n,e),n.prototype.makeWireWrite=function(e,n){return function(e){return pushBuffer(e,n)}},n}(_nbind.BindType);function commitBuffer(e,n,t){var r=_nbind.externalList[e].data,i=Buffer;if("function"!=typeof Buffer&&(i=function(){}),r instanceof Array);else{var u=HEAPU8.subarray(n,n+t);r instanceof i?("function"==typeof Buffer.from&&Buffer.from.length>=3?Buffer.from(u):new Buffer(u)).copy(r):getBuffer(r).set(u)}}_nbind.BufferType=BufferType,_nbind.commitBuffer=commitBuffer;var dirtyList=[],gcTimer=0;function sweep(){for(var e=0,n=dirtyList;e<n.length;e++){var t=n[e];3&t.__nbindState||t.free()}dirtyList=[],gcTimer=0}function toggleLightGC(e){_nbind.mark=e?function(e){dirtyList.push(e),gcTimer||(gcTimer=setTimeout(sweep,0))}:function(e){}}_nbind.mark=function(e){},_nbind.toggleLightGC=toggleLightGC}(_nbind),Module.requestFullScreen=function(e,n,t){Module.printErr("Module.requestFullScreen is deprecated. Please call Module.requestFullscreen instead."),Module.requestFullScreen=Module.requestFullscreen,Browser.requestFullScreen(e,n,t)},Module.requestFullscreen=function(e,n,t){Browser.requestFullscreen(e,n,t)},Module.requestAnimationFrame=function(e){Browser.requestAnimationFrame(e)},Module.setCanvasSize=function(e,n,t){Browser.setCanvasSize(e,n,t)},Module.pauseMainLoop=function(){Browser.mainLoop.pause()},Module.resumeMainLoop=function(){Browser.mainLoop.resume()},Module.getUserMedia=function(){Browser.getUserMedia()},Module.createContext=function(e,n,t,r){return Browser.createContext(e,n,t,r)},_emscripten_get_now=ENVIRONMENT_IS_NODE?function(){var e=process.hrtime();return 1e3*e[0]+e[1]/1e6}:"undefined"!=typeof dateNow?dateNow:"object"==typeof self&&self.performance&&"function"==typeof self.performance.now?function(){return self.performance.now()}:"object"==typeof performance&&"function"==typeof performance.now?function(){return performance.now()}:Date.now,__ATEXIT__.push((function(){var e=Module._fflush;e&&e(0);var n=___syscall146.printChar;if(n){var t=___syscall146.buffers;t[1].length&&n(1,10),t[2].length&&n(2,10)}})),DYNAMICTOP_PTR=allocate(1,"i32",ALLOC_STATIC),STACK_BASE=STACKTOP=Runtime.alignMemory(STATICTOP),STACK_MAX=STACK_BASE+TOTAL_STACK,DYNAMIC_BASE=Runtime.alignMemory(STACK_MAX),HEAP32[DYNAMICTOP_PTR>>2]=DYNAMIC_BASE,staticSealed=!0,Module.asmGlobalArg={Math,Int8Array,Int16Array,Int32Array,Uint8Array,Uint16Array,Uint32Array,Float32Array,Float64Array,NaN:NaN,Infinity:1/0},Module.asmLibraryArg={abort,assert,enlargeMemory,getTotalMemory,abortOnCannotGrowMemory,invoke_viiiii,invoke_vif,invoke_vid,invoke_fiff,invoke_vi,invoke_vii,invoke_ii,invoke_viddi,invoke_vidd,invoke_iiii,invoke_diii,invoke_di,invoke_iid,invoke_iii,invoke_viiddi,invoke_viiiiii,invoke_dii,invoke_i,invoke_iiiiii,invoke_viiid,invoke_viififi,invoke_viii,invoke_v,invoke_viid,invoke_idd,invoke_viiii,_emscripten_asm_const_iiiii,_emscripten_asm_const_iiidddddd,_emscripten_asm_const_iiiid,__nbind_reference_external,_emscripten_asm_const_iiiiiiii,_removeAccessorPrefix,_typeModule,__nbind_register_pool,__decorate,_llvm_stackrestore,___cxa_atexit,__extends,__nbind_get_value_object,__ZN8facebook4yoga14YGNodeToStringEPNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEP6YGNode14YGPrintOptionsj,_emscripten_set_main_loop_timing,__nbind_register_primitive,__nbind_register_type,_emscripten_memcpy_big,__nbind_register_function,___setErrNo,__nbind_register_class,__nbind_finish,_abort,_nbind_value,_llvm_stacksave,___syscall54,_defineHidden,_emscripten_set_main_loop,_emscripten_get_now,__nbind_register_callback_signature,_emscripten_asm_const_iiiiii,__nbind_free_external,_emscripten_asm_const_iiii,_emscripten_asm_const_iiididi,___syscall6,_atexit,___syscall140,___syscall146,DYNAMICTOP_PTR,tempDoublePtr,ABORT,STACKTOP,STACK_MAX,cttz_i8,___dso_handle};var asm=function(e,n,t){"use asm";var r=new e.Int8Array(t);var i=new e.Int16Array(t);var u=new e.Int32Array(t);var o=new e.Uint8Array(t);var a=new e.Uint16Array(t);var l=new e.Uint32Array(t);var s=new e.Float32Array(t);var f=new e.Float64Array(t);var c=n.DYNAMICTOP_PTR|0;var d=n.tempDoublePtr|0;var p=n.ABORT|0;var h=n.STACKTOP|0;var m=n.STACK_MAX|0;var v=n.cttz_i8|0;var _=n.___dso_handle|0;var b=0;var g=0;var y=0;var D=0;var w=e.NaN,E=e.Infinity;var T=0,C=0,k=0,M=0,S=0.0;var A=0;var x=e.Math.floor;var P=e.Math.abs;var R=e.Math.sqrt;var N=e.Math.pow;var F=e.Math.cos;var O=e.Math.sin;var L=e.Math.tan;var I=e.Math.acos;var B=e.Math.asin;var U=e.Math.atan;var j=e.Math.atan2;var W=e.Math.exp;var z=e.Math.log;var H=e.Math.ceil;var G=e.Math.imul;var Y=e.Math.min;var q=e.Math.max;var V=e.Math.clz32;var $=e.Math.fround;var X=n.abort;var K=n.assert;var J=n.enlargeMemory;var Q=n.getTotalMemory;var Z=n.abortOnCannotGrowMemory;var ee=n.invoke_viiiii;var ne=n.invoke_vif;var te=n.invoke_vid;var re=n.invoke_fiff;var ie=n.invoke_vi;var ue=n.invoke_vii;var oe=n.invoke_ii;var ae=n.invoke_viddi;var le=n.invoke_vidd;var se=n.invoke_iiii;var fe=n.invoke_diii;var ce=n.invoke_di;var de=n.invoke_iid;var pe=n.invoke_iii;var he=n.invoke_viiddi;var me=n.invoke_viiiiii;var ve=n.invoke_dii;var _e=n.invoke_i;var be=n.invoke_iiiiii;var ge=n.invoke_viiid;var ye=n.invoke_viififi;var De=n.invoke_viii;var we=n.invoke_v;var Ee=n.invoke_viid;var Te=n.invoke_idd;var Ce=n.invoke_viiii;var ke=n._emscripten_asm_const_iiiii;var Me=n._emscripten_asm_const_iiidddddd;var Se=n._emscripten_asm_const_iiiid;var Ae=n.__nbind_reference_external;var xe=n._emscripten_asm_const_iiiiiiii;var Pe=n._removeAccessorPrefix;var Re=n._typeModule;var Ne=n.__nbind_register_pool;var Fe=n.__decorate;var Oe=n._llvm_stackrestore;var Le=n.___cxa_atexit;var Ie=n.__extends;var Be=n.__nbind_get_value_object;var Ue=n.__ZN8facebook4yoga14YGNodeToStringEPNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEP6YGNode14YGPrintOptionsj;var je=n._emscripten_set_main_loop_timing;var We=n.__nbind_register_primitive;var ze=n.__nbind_register_type;var He=n._emscripten_memcpy_big;var Ge=n.__nbind_register_function;var Ye=n.___setErrNo;var qe=n.__nbind_register_class;var Ve=n.__nbind_finish;var $e=n._abort;var Xe=n._nbind_value;var Ke=n._llvm_stacksave;var Je=n.___syscall54;var Qe=n._defineHidden;var Ze=n._emscripten_set_main_loop;var en=n._emscripten_get_now;var nn=n.__nbind_register_callback_signature;var tn=n._emscripten_asm_const_iiiiii;var rn=n.__nbind_free_external;var un=n._emscripten_asm_const_iiii;var on=n._emscripten_asm_const_iiididi;var an=n.___syscall6;var ln=n._atexit;var sn=n.___syscall140;var fn=n.___syscall146;var cn=$(0);const dn=$(0);function pn(e){e=e|0;var n=0;n=h;h=h+e|0;h=h+15&-16;return n|0}function hn(){return h|0}function mn(e){e=e|0;h=e}function vn(e,n){e=e|0;n=n|0;h=e;m=n}function _n(e,n){e=e|0;n=n|0;if(!b){b=e;g=n}}function bn(e){e=e|0;A=e}function gn(){return A|0}function yn(){var e=0,n=0;iS(8104,8,400)|0;iS(8504,408,540)|0;e=9044;n=e+44|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));r[9088]=0;r[9089]=1;u[2273]=0;u[2274]=948;u[2275]=948;Le(17,8104,_|0)|0;return}function Dn(e){e=e|0;qn(e+948|0);return}function wn(e){e=$(e);return((Ri(e)|0)&2147483647)>>>0>2139095040|0}function En(e,n,t){e=e|0;n=n|0;t=t|0;e:do{if(!(u[e+(n<<3)+4>>2]|0)){if((n|2|0)==3?u[e+60>>2]|0:0){e=e+56|0;break}switch(n|0){case 0:case 2:case 4:case 5:{if(u[e+52>>2]|0){e=e+48|0;break e}break}default:{}}if(!(u[e+68>>2]|0)){e=(n|1|0)==5?948:t;break}else{e=e+64|0;break}}else e=e+(n<<3)|0}while(0);return e|0}function Tn(e){e=e|0;var n=0;n=Yk(1e3)|0;Cn(e,(n|0)!=0,2456);u[2276]=(u[2276]|0)+1;iS(n|0,8104,1e3)|0;if(r[e+2>>0]|0){u[n+4>>2]=2;u[n+12>>2]=4}u[n+976>>2]=e;return n|0}function Cn(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0;i=h;h=h+16|0;r=i;if(!n){u[r>>2]=t;Ir(e,5,3197,r)}h=i;return}function kn(){return Tn(956)|0}function Mn(e){e=e|0;var n=0;n=VM(1e3)|0;Sn(n,e);Cn(u[e+976>>2]|0,1,2456);u[2276]=(u[2276]|0)+1;u[n+944>>2]=0;return n|0}function Sn(e,n){e=e|0;n=n|0;var t=0;iS(e|0,n|0,948)|0;jr(e+948|0,n+948|0);t=e+960|0;e=n+960|0;n=t+40|0;do{u[t>>2]=u[e>>2];t=t+4|0;e=e+4|0}while((t|0)<(n|0));return}function An(e){e=e|0;var n=0,t=0,r=0,i=0;n=e+944|0;t=u[n>>2]|0;if(t|0){xn(t+948|0,e)|0;u[n>>2]=0}t=Pn(e)|0;if(t|0){n=0;do{u[(Rn(e,n)|0)+944>>2]=0;n=n+1|0}while((n|0)!=(t|0))}t=e+948|0;r=u[t>>2]|0;i=e+952|0;n=u[i>>2]|0;if((n|0)!=(r|0))u[i>>2]=n+(~((n+-4-r|0)>>>2)<<2);Nn(t);qk(e);u[2276]=(u[2276]|0)+-1;return}function xn(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0;r=u[e>>2]|0;l=e+4|0;t=u[l>>2]|0;o=t;e:do{if((r|0)==(t|0)){i=r;a=4}else{e=r;while(1){if((u[e>>2]|0)==(n|0)){i=e;a=4;break e}e=e+4|0;if((e|0)==(t|0)){e=0;break}}}}while(0);if((a|0)==4)if((i|0)!=(t|0)){r=i+4|0;e=o-r|0;n=e>>2;if(n){sS(i|0,r|0,e|0)|0;t=u[l>>2]|0}e=i+(n<<2)|0;if((t|0)==(e|0))e=1;else{u[l>>2]=t+(~((t+-4-e|0)>>>2)<<2);e=1}}else e=0;return e|0}function Pn(e){e=e|0;return(u[e+952>>2]|0)-(u[e+948>>2]|0)>>2|0}function Rn(e,n){e=e|0;n=n|0;var t=0;t=u[e+948>>2]|0;if((u[e+952>>2]|0)-t>>2>>>0>n>>>0)e=u[t+(n<<2)>>2]|0;else e=0;return e|0}function Nn(e){e=e|0;var n=0,t=0,r=0,i=0;r=h;h=h+32|0;n=r;i=u[e>>2]|0;t=(u[e+4>>2]|0)-i|0;if(((u[e+8>>2]|0)-i|0)>>>0>t>>>0){i=t>>2;Ni(n,i,i,e+8|0);Fi(e,n);Oi(n)}h=r;return}function Fn(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0;f=Pn(e)|0;do{if(f|0){if((u[(Rn(e,0)|0)+944>>2]|0)==(e|0)){if(!(xn(e+948|0,n)|0))break;iS(n+400|0,8504,540)|0;u[n+944>>2]=0;Yn(e);break}a=u[(u[e+976>>2]|0)+12>>2]|0;l=e+948|0;s=(a|0)==0;t=0;o=0;do{r=u[(u[l>>2]|0)+(o<<2)>>2]|0;if((r|0)==(n|0))Yn(e);else{i=Mn(r)|0;u[(u[l>>2]|0)+(t<<2)>>2]=i;u[i+944>>2]=e;if(!s)OA[a&15](r,i,e,t);t=t+1|0}o=o+1|0}while((o|0)!=(f|0));if(t>>>0<f>>>0){s=e+948|0;l=e+952|0;a=t;t=u[l>>2]|0;do{o=(u[s>>2]|0)+(a<<2)|0;r=o+4|0;i=t-r|0;n=i>>2;if(!n)i=t;else{sS(o|0,r|0,i|0)|0;t=u[l>>2]|0;i=t}r=o+(n<<2)|0;if((i|0)!=(r|0)){t=i+(~((i+-4-r|0)>>>2)<<2)|0;u[l>>2]=t}a=a+1|0}while((a|0)!=(f|0))}}}while(0);return}function On(e){e=e|0;var n=0,t=0,i=0,o=0;Ln(e,(Pn(e)|0)==0,2491);Ln(e,(u[e+944>>2]|0)==0,2545);n=e+948|0;t=u[n>>2]|0;i=e+952|0;o=u[i>>2]|0;if((o|0)!=(t|0))u[i>>2]=o+(~((o+-4-t|0)>>>2)<<2);Nn(n);n=e+976|0;t=u[n>>2]|0;iS(e|0,8104,1e3)|0;if(r[t+2>>0]|0){u[e+4>>2]=2;u[e+12>>2]=4}u[n>>2]=t;return}function Ln(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0;i=h;h=h+16|0;r=i;if(!n){u[r>>2]=t;Cr(e,5,3197,r)}h=i;return}function In(){return u[2276]|0}function Bn(){var e=0;e=Yk(20)|0;Un((e|0)!=0,2592);u[2277]=(u[2277]|0)+1;u[e>>2]=u[239];u[e+4>>2]=u[240];u[e+8>>2]=u[241];u[e+12>>2]=u[242];u[e+16>>2]=u[243];return e|0}function Un(e,n){e=e|0;n=n|0;var t=0,r=0;r=h;h=h+16|0;t=r;if(!e){u[t>>2]=n;Cr(0,5,3197,t)}h=r;return}function jn(e){e=e|0;qk(e);u[2277]=(u[2277]|0)+-1;return}function Wn(e,n){e=e|0;n=n|0;var t=0;if(!n){t=0;n=0}else{Ln(e,(Pn(e)|0)==0,2629);t=1}u[e+964>>2]=n;u[e+988>>2]=t;return}function zn(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;o=r+8|0;i=r+4|0;a=r;u[i>>2]=n;Ln(e,(u[n+944>>2]|0)==0,2709);Ln(e,(u[e+964>>2]|0)==0,2763);Hn(e);n=e+948|0;u[a>>2]=(u[n>>2]|0)+(t<<2);u[o>>2]=u[a>>2];Gn(n,o,i)|0;u[(u[i>>2]|0)+944>>2]=e;Yn(e);h=r;return}function Hn(e){e=e|0;var n=0,t=0,r=0,i=0,o=0,a=0,l=0;t=Pn(e)|0;if(t|0?(u[(Rn(e,0)|0)+944>>2]|0)!=(e|0):0){r=u[(u[e+976>>2]|0)+12>>2]|0;i=e+948|0;o=(r|0)==0;n=0;do{a=u[(u[i>>2]|0)+(n<<2)>>2]|0;l=Mn(a)|0;u[(u[i>>2]|0)+(n<<2)>>2]=l;u[l+944>>2]=e;if(!o)OA[r&15](a,l,e,n);n=n+1|0}while((n|0)!=(t|0))}return}function Gn(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0,m=0,v=0,_=0,b=0,g=0;b=h;h=h+64|0;d=b+52|0;l=b+48|0;p=b+28|0;m=b+24|0;v=b+20|0;_=b;r=u[e>>2]|0;o=r;n=r+((u[n>>2]|0)-o>>2<<2)|0;r=e+4|0;i=u[r>>2]|0;a=e+8|0;do{if(i>>>0<(u[a>>2]|0)>>>0){if((n|0)==(i|0)){u[n>>2]=u[t>>2];u[r>>2]=(u[r>>2]|0)+4;break}Li(e,n,i,n+4|0);if(n>>>0<=t>>>0)t=(u[r>>2]|0)>>>0>t>>>0?t+4|0:t;u[n>>2]=u[t>>2]}else{r=(i-o>>2)+1|0;i=Hr(e)|0;if(i>>>0<r>>>0)jM(e);c=u[e>>2]|0;f=(u[a>>2]|0)-c|0;o=f>>1;Ni(_,f>>2>>>0<i>>>1>>>0?o>>>0<r>>>0?r:o:i,n-c>>2,e+8|0);c=_+8|0;r=u[c>>2]|0;o=_+12|0;f=u[o>>2]|0;a=f;s=r;do{if((r|0)==(f|0)){f=_+4|0;r=u[f>>2]|0;g=u[_>>2]|0;i=g;if(r>>>0<=g>>>0){r=a-i>>1;r=(r|0)==0?1:r;Ni(p,r,r>>>2,u[_+16>>2]|0);u[m>>2]=u[f>>2];u[v>>2]=u[c>>2];u[l>>2]=u[m>>2];u[d>>2]=u[v>>2];Bi(p,l,d);r=u[_>>2]|0;u[_>>2]=u[p>>2];u[p>>2]=r;r=p+4|0;g=u[f>>2]|0;u[f>>2]=u[r>>2];u[r>>2]=g;r=p+8|0;g=u[c>>2]|0;u[c>>2]=u[r>>2];u[r>>2]=g;r=p+12|0;g=u[o>>2]|0;u[o>>2]=u[r>>2];u[r>>2]=g;Oi(p);r=u[c>>2]|0;break}o=r;a=((o-i>>2)+1|0)/-2|0;l=r+(a<<2)|0;i=s-o|0;o=i>>2;if(o){sS(l|0,r|0,i|0)|0;r=u[f>>2]|0}g=l+(o<<2)|0;u[c>>2]=g;u[f>>2]=r+(a<<2);r=g}}while(0);u[r>>2]=u[t>>2];u[c>>2]=(u[c>>2]|0)+4;n=Ii(e,_,n)|0;Oi(_)}}while(0);h=b;return n|0}function Yn(e){e=e|0;var n=0;do{n=e+984|0;if(r[n>>0]|0)break;r[n>>0]=1;s[e+504>>2]=$(w);e=u[e+944>>2]|0}while((e|0)!=0);return}function qn(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~((n+-4-r|0)>>>2)<<2);XM(t)}return}function Vn(e){e=e|0;return u[e+944>>2]|0}function $n(e){e=e|0;Ln(e,(u[e+964>>2]|0)!=0,2832);Yn(e);return}function Xn(e){e=e|0;return(r[e+984>>0]|0)!=0|0}function Kn(e,n){e=e|0;n=n|0;if(iM(e,n,400)|0){iS(e|0,n|0,400)|0;Yn(e)}return}function Jn(e){e=e|0;var n=dn;n=$(s[e+44>>2]);e=wn(n)|0;return $(e?$(0.0):n)}function Qn(e){e=e|0;var n=dn;n=$(s[e+48>>2]);if(wn(n)|0)n=r[(u[e+976>>2]|0)+2>>0]|0?$(1.0):$(0.0);return $(n)}function Zn(e,n){e=e|0;n=n|0;u[e+980>>2]=n;return}function et(e){e=e|0;return u[e+980>>2]|0}function nt(e,n){e=e|0;n=n|0;var t=0;t=e+4|0;if((u[t>>2]|0)!=(n|0)){u[t>>2]=n;Yn(e)}return}function tt(e){e=e|0;return u[e+4>>2]|0}function rt(e,n){e=e|0;n=n|0;var t=0;t=e+8|0;if((u[t>>2]|0)!=(n|0)){u[t>>2]=n;Yn(e)}return}function it(e){e=e|0;return u[e+8>>2]|0}function ut(e,n){e=e|0;n=n|0;var t=0;t=e+12|0;if((u[t>>2]|0)!=(n|0)){u[t>>2]=n;Yn(e)}return}function ot(e){e=e|0;return u[e+12>>2]|0}function at(e,n){e=e|0;n=n|0;var t=0;t=e+16|0;if((u[t>>2]|0)!=(n|0)){u[t>>2]=n;Yn(e)}return}function lt(e){e=e|0;return u[e+16>>2]|0}function st(e,n){e=e|0;n=n|0;var t=0;t=e+20|0;if((u[t>>2]|0)!=(n|0)){u[t>>2]=n;Yn(e)}return}function ft(e){e=e|0;return u[e+20>>2]|0}function ct(e,n){e=e|0;n=n|0;var t=0;t=e+24|0;if((u[t>>2]|0)!=(n|0)){u[t>>2]=n;Yn(e)}return}function dt(e){e=e|0;return u[e+24>>2]|0}function pt(e,n){e=e|0;n=n|0;var t=0;t=e+28|0;if((u[t>>2]|0)!=(n|0)){u[t>>2]=n;Yn(e)}return}function ht(e){e=e|0;return u[e+28>>2]|0}function mt(e,n){e=e|0;n=n|0;var t=0;t=e+32|0;if((u[t>>2]|0)!=(n|0)){u[t>>2]=n;Yn(e)}return}function vt(e){e=e|0;return u[e+32>>2]|0}function _t(e,n){e=e|0;n=n|0;var t=0;t=e+36|0;if((u[t>>2]|0)!=(n|0)){u[t>>2]=n;Yn(e)}return}function bt(e){e=e|0;return u[e+36>>2]|0}function gt(e,n){e=e|0;n=$(n);var t=0;t=e+40|0;if($(s[t>>2])!=n){s[t>>2]=n;Yn(e)}return}function yt(e,n){e=e|0;n=$(n);var t=0;t=e+44|0;if($(s[t>>2])!=n){s[t>>2]=n;Yn(e)}return}function Dt(e,n){e=e|0;n=$(n);var t=0;t=e+48|0;if($(s[t>>2])!=n){s[t>>2]=n;Yn(e)}return}function wt(e,n){e=e|0;n=$(n);var t=0,r=0,i=0,o=0;o=wn(n)|0;t=(o^1)&1;r=e+52|0;i=e+56|0;if(!(o|$(s[r>>2])==n?(u[i>>2]|0)==(t|0):0)){s[r>>2]=n;u[i>>2]=t;Yn(e)}return}function Et(e,n){e=e|0;n=$(n);var t=0,r=0;r=e+52|0;t=e+56|0;if(!(!($(s[r>>2])!=n)?(u[t>>2]|0)==2:0)){s[r>>2]=n;r=wn(n)|0;u[t>>2]=r?3:2;Yn(e)}return}function Tt(e,n){e=e|0;n=n|0;var t=0,r=0;r=n+52|0;t=u[r+4>>2]|0;n=e;u[n>>2]=u[r>>2];u[n+4>>2]=t;return}function Ct(e,n,t){e=e|0;n=n|0;t=$(t);var r=0,i=0,o=0;o=wn(t)|0;r=(o^1)&1;i=e+132+(n<<3)|0;n=e+132+(n<<3)+4|0;if(!(o|$(s[i>>2])==t?(u[n>>2]|0)==(r|0):0)){s[i>>2]=t;u[n>>2]=r;Yn(e)}return}function kt(e,n,t){e=e|0;n=n|0;t=$(t);var r=0,i=0,o=0;o=wn(t)|0;r=o?0:2;i=e+132+(n<<3)|0;n=e+132+(n<<3)+4|0;if(!(o|$(s[i>>2])==t?(u[n>>2]|0)==(r|0):0)){s[i>>2]=t;u[n>>2]=r;Yn(e)}return}function Mt(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=n+132+(t<<3)|0;n=u[r+4>>2]|0;t=e;u[t>>2]=u[r>>2];u[t+4>>2]=n;return}function St(e,n,t){e=e|0;n=n|0;t=$(t);var r=0,i=0,o=0;o=wn(t)|0;r=(o^1)&1;i=e+60+(n<<3)|0;n=e+60+(n<<3)+4|0;if(!(o|$(s[i>>2])==t?(u[n>>2]|0)==(r|0):0)){s[i>>2]=t;u[n>>2]=r;Yn(e)}return}function At(e,n,t){e=e|0;n=n|0;t=$(t);var r=0,i=0,o=0;o=wn(t)|0;r=o?0:2;i=e+60+(n<<3)|0;n=e+60+(n<<3)+4|0;if(!(o|$(s[i>>2])==t?(u[n>>2]|0)==(r|0):0)){s[i>>2]=t;u[n>>2]=r;Yn(e)}return}function xt(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=n+60+(t<<3)|0;n=u[r+4>>2]|0;t=e;u[t>>2]=u[r>>2];u[t+4>>2]=n;return}function Pt(e,n){e=e|0;n=n|0;var t=0;t=e+60+(n<<3)+4|0;if((u[t>>2]|0)!=3){s[e+60+(n<<3)>>2]=$(w);u[t>>2]=3;Yn(e)}return}function Rt(e,n,t){e=e|0;n=n|0;t=$(t);var r=0,i=0,o=0;o=wn(t)|0;r=(o^1)&1;i=e+204+(n<<3)|0;n=e+204+(n<<3)+4|0;if(!(o|$(s[i>>2])==t?(u[n>>2]|0)==(r|0):0)){s[i>>2]=t;u[n>>2]=r;Yn(e)}return}function Nt(e,n,t){e=e|0;n=n|0;t=$(t);var r=0,i=0,o=0;o=wn(t)|0;r=o?0:2;i=e+204+(n<<3)|0;n=e+204+(n<<3)+4|0;if(!(o|$(s[i>>2])==t?(u[n>>2]|0)==(r|0):0)){s[i>>2]=t;u[n>>2]=r;Yn(e)}return}function Ft(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=n+204+(t<<3)|0;n=u[r+4>>2]|0;t=e;u[t>>2]=u[r>>2];u[t+4>>2]=n;return}function Ot(e,n,t){e=e|0;n=n|0;t=$(t);var r=0,i=0,o=0;o=wn(t)|0;r=(o^1)&1;i=e+276+(n<<3)|0;n=e+276+(n<<3)+4|0;if(!(o|$(s[i>>2])==t?(u[n>>2]|0)==(r|0):0)){s[i>>2]=t;u[n>>2]=r;Yn(e)}return}function Lt(e,n){e=e|0;n=n|0;return $(s[e+276+(n<<3)>>2])}function It(e,n){e=e|0;n=$(n);var t=0,r=0,i=0,o=0;o=wn(n)|0;t=(o^1)&1;r=e+348|0;i=e+352|0;if(!(o|$(s[r>>2])==n?(u[i>>2]|0)==(t|0):0)){s[r>>2]=n;u[i>>2]=t;Yn(e)}return}function Bt(e,n){e=e|0;n=$(n);var t=0,r=0;r=e+348|0;t=e+352|0;if(!(!($(s[r>>2])!=n)?(u[t>>2]|0)==2:0)){s[r>>2]=n;r=wn(n)|0;u[t>>2]=r?3:2;Yn(e)}return}function Ut(e){e=e|0;var n=0;n=e+352|0;if((u[n>>2]|0)!=3){s[e+348>>2]=$(w);u[n>>2]=3;Yn(e)}return}function jt(e,n){e=e|0;n=n|0;var t=0,r=0;r=n+348|0;t=u[r+4>>2]|0;n=e;u[n>>2]=u[r>>2];u[n+4>>2]=t;return}function Wt(e,n){e=e|0;n=$(n);var t=0,r=0,i=0,o=0;o=wn(n)|0;t=(o^1)&1;r=e+356|0;i=e+360|0;if(!(o|$(s[r>>2])==n?(u[i>>2]|0)==(t|0):0)){s[r>>2]=n;u[i>>2]=t;Yn(e)}return}function zt(e,n){e=e|0;n=$(n);var t=0,r=0;r=e+356|0;t=e+360|0;if(!(!($(s[r>>2])!=n)?(u[t>>2]|0)==2:0)){s[r>>2]=n;r=wn(n)|0;u[t>>2]=r?3:2;Yn(e)}return}function Ht(e){e=e|0;var n=0;n=e+360|0;if((u[n>>2]|0)!=3){s[e+356>>2]=$(w);u[n>>2]=3;Yn(e)}return}function Gt(e,n){e=e|0;n=n|0;var t=0,r=0;r=n+356|0;t=u[r+4>>2]|0;n=e;u[n>>2]=u[r>>2];u[n+4>>2]=t;return}function Yt(e,n){e=e|0;n=$(n);var t=0,r=0,i=0,o=0;o=wn(n)|0;t=(o^1)&1;r=e+364|0;i=e+368|0;if(!(o|$(s[r>>2])==n?(u[i>>2]|0)==(t|0):0)){s[r>>2]=n;u[i>>2]=t;Yn(e)}return}function qt(e,n){e=e|0;n=$(n);var t=0,r=0,i=0,o=0;o=wn(n)|0;t=o?0:2;r=e+364|0;i=e+368|0;if(!(o|$(s[r>>2])==n?(u[i>>2]|0)==(t|0):0)){s[r>>2]=n;u[i>>2]=t;Yn(e)}return}function Vt(e,n){e=e|0;n=n|0;var t=0,r=0;r=n+364|0;t=u[r+4>>2]|0;n=e;u[n>>2]=u[r>>2];u[n+4>>2]=t;return}function $t(e,n){e=e|0;n=$(n);var t=0,r=0,i=0,o=0;o=wn(n)|0;t=(o^1)&1;r=e+372|0;i=e+376|0;if(!(o|$(s[r>>2])==n?(u[i>>2]|0)==(t|0):0)){s[r>>2]=n;u[i>>2]=t;Yn(e)}return}function Xt(e,n){e=e|0;n=$(n);var t=0,r=0,i=0,o=0;o=wn(n)|0;t=o?0:2;r=e+372|0;i=e+376|0;if(!(o|$(s[r>>2])==n?(u[i>>2]|0)==(t|0):0)){s[r>>2]=n;u[i>>2]=t;Yn(e)}return}function Kt(e,n){e=e|0;n=n|0;var t=0,r=0;r=n+372|0;t=u[r+4>>2]|0;n=e;u[n>>2]=u[r>>2];u[n+4>>2]=t;return}function Jt(e,n){e=e|0;n=$(n);var t=0,r=0,i=0,o=0;o=wn(n)|0;t=(o^1)&1;r=e+380|0;i=e+384|0;if(!(o|$(s[r>>2])==n?(u[i>>2]|0)==(t|0):0)){s[r>>2]=n;u[i>>2]=t;Yn(e)}return}function Qt(e,n){e=e|0;n=$(n);var t=0,r=0,i=0,o=0;o=wn(n)|0;t=o?0:2;r=e+380|0;i=e+384|0;if(!(o|$(s[r>>2])==n?(u[i>>2]|0)==(t|0):0)){s[r>>2]=n;u[i>>2]=t;Yn(e)}return}function Zt(e,n){e=e|0;n=n|0;var t=0,r=0;r=n+380|0;t=u[r+4>>2]|0;n=e;u[n>>2]=u[r>>2];u[n+4>>2]=t;return}function er(e,n){e=e|0;n=$(n);var t=0,r=0,i=0,o=0;o=wn(n)|0;t=(o^1)&1;r=e+388|0;i=e+392|0;if(!(o|$(s[r>>2])==n?(u[i>>2]|0)==(t|0):0)){s[r>>2]=n;u[i>>2]=t;Yn(e)}return}function nr(e,n){e=e|0;n=$(n);var t=0,r=0,i=0,o=0;o=wn(n)|0;t=o?0:2;r=e+388|0;i=e+392|0;if(!(o|$(s[r>>2])==n?(u[i>>2]|0)==(t|0):0)){s[r>>2]=n;u[i>>2]=t;Yn(e)}return}function tr(e,n){e=e|0;n=n|0;var t=0,r=0;r=n+388|0;t=u[r+4>>2]|0;n=e;u[n>>2]=u[r>>2];u[n+4>>2]=t;return}function rr(e,n){e=e|0;n=$(n);var t=0;t=e+396|0;if($(s[t>>2])!=n){s[t>>2]=n;Yn(e)}return}function ir(e){e=e|0;return $(s[e+396>>2])}function ur(e){e=e|0;return $(s[e+400>>2])}function or(e){e=e|0;return $(s[e+404>>2])}function ar(e){e=e|0;return $(s[e+408>>2])}function lr(e){e=e|0;return $(s[e+412>>2])}function sr(e){e=e|0;return $(s[e+416>>2])}function fr(e){e=e|0;return $(s[e+420>>2])}function cr(e,n){e=e|0;n=n|0;Ln(e,(n|0)<6,2918);switch(n|0){case 0:{n=(u[e+496>>2]|0)==2?5:4;break}case 2:{n=(u[e+496>>2]|0)==2?4:5;break}default:{}}return $(s[e+424+(n<<2)>>2])}function dr(e,n){e=e|0;n=n|0;Ln(e,(n|0)<6,2918);switch(n|0){case 0:{n=(u[e+496>>2]|0)==2?5:4;break}case 2:{n=(u[e+496>>2]|0)==2?4:5;break}default:{}}return $(s[e+448+(n<<2)>>2])}function pr(e,n){e=e|0;n=n|0;Ln(e,(n|0)<6,2918);switch(n|0){case 0:{n=(u[e+496>>2]|0)==2?5:4;break}case 2:{n=(u[e+496>>2]|0)==2?4:5;break}default:{}}return $(s[e+472+(n<<2)>>2])}function hr(e,n){e=e|0;n=n|0;var t=0,r=dn;t=u[e+4>>2]|0;if((t|0)==(u[n+4>>2]|0)){if(!t)e=1;else{r=$(s[e>>2]);e=$(P($(r-$(s[n>>2]))))<$(.0000999999974)}}else e=0;return e|0}function mr(e,n){e=$(e);n=$(n);var t=0;if(wn(e)|0)t=wn(n)|0;else t=$(P($(e-n)))<$(.0000999999974);return t|0}function vr(e,n){e=e|0;n=n|0;_r(e,n);return}function _r(e,n){e=e|0;n=n|0;var t=0,i=0;t=h;h=h+16|0;i=t+4|0;u[i>>2]=0;u[i+4>>2]=0;u[i+8>>2]=0;Ue(i|0,e|0,n|0,0);Cr(e,3,(r[i+11>>0]|0)<0?u[i>>2]|0:i,t);KM(i);h=t;return}function br(e,n,t,r){e=$(e);n=$(n);t=t|0;r=r|0;var i=dn;e=$(e*n);i=$(IM(e,$(1.0)));do{if(!(mr(i,$(0.0))|0)){e=$(e-i);if(mr(i,$(1.0))|0){e=$(e+$(1.0));break}if(t){e=$(e+$(1.0));break}if(!r){if(i>$(.5))i=$(1.0);else{r=mr(i,$(.5))|0;i=r?$(1.0):$(0.0)}e=$(e+i)}}else e=$(e-i)}while(0);return $(e/n)}function gr(e,n,t,r,i,u,o,a,l,f,c,d,p){e=e|0;n=$(n);t=t|0;r=$(r);i=i|0;u=$(u);o=o|0;a=$(a);l=$(l);f=$(f);c=$(c);d=$(d);p=p|0;var h=0,m=dn,v=dn,_=dn,b=dn,g=dn,y=dn;if(l<$(0.0)|f<$(0.0))p=0;else{if((p|0)!=0?(m=$(s[p+4>>2]),m!=$(0.0)):0){_=$(br(n,m,0,0));b=$(br(r,m,0,0));v=$(br(u,m,0,0));m=$(br(a,m,0,0))}else{v=u;_=n;m=a;b=r}if((i|0)==(e|0))h=mr(v,_)|0;else h=0;if((o|0)==(t|0))p=mr(m,b)|0;else p=0;if((!h?(g=$(n-c),!(yr(e,g,l)|0)):0)?!(Dr(e,g,i,l)|0):0)h=wr(e,g,i,u,l)|0;else h=1;if((!p?(y=$(r-d),!(yr(t,y,f)|0)):0)?!(Dr(t,y,o,f)|0):0)p=wr(t,y,o,a,f)|0;else p=1;p=h&p}return p|0}function yr(e,n,t){e=e|0;n=$(n);t=$(t);if((e|0)==1)e=mr(n,t)|0;else e=0;return e|0}function Dr(e,n,t,r){e=e|0;n=$(n);t=t|0;r=$(r);if((e|0)==2&(t|0)==0){if(!(n>=r))e=mr(n,r)|0;else e=1}else e=0;return e|0}function wr(e,n,t,r,i){e=e|0;n=$(n);t=t|0;r=$(r);i=$(i);if((e|0)==2&(t|0)==2&r>n){if(!(i<=n))e=mr(n,i)|0;else e=1}else e=0;return e|0}function Er(e,n,t,i,o,a,l,c,d,p,m){e=e|0;n=$(n);t=$(t);i=i|0;o=o|0;a=a|0;l=$(l);c=$(c);d=d|0;p=p|0;m=m|0;var v=0,_=0,b=0,g=0,y=dn,D=dn,w=0,E=0,T=0,C=0,k=0,M=0,S=0,A=0,x=0,P=0,R=0,N=dn,F=dn,O=dn,L=0.0,I=0.0;R=h;h=h+160|0;A=R+152|0;S=R+120|0;M=R+104|0;T=R+72|0;g=R+56|0;k=R+8|0;E=R;C=(u[2279]|0)+1|0;u[2279]=C;x=e+984|0;if((r[x>>0]|0)!=0?(u[e+512>>2]|0)!=(u[2278]|0):0)w=4;else if((u[e+516>>2]|0)==(i|0))P=0;else w=4;if((w|0)==4){u[e+520>>2]=0;u[e+924>>2]=-1;u[e+928>>2]=-1;s[e+932>>2]=$(-1.0);s[e+936>>2]=$(-1.0);P=1}e:do{if(!(u[e+964>>2]|0)){if(d){v=e+916|0;if(!(mr($(s[v>>2]),n)|0)){w=21;break}if(!(mr($(s[e+920>>2]),t)|0)){w=21;break}if((u[e+924>>2]|0)!=(o|0)){w=21;break}v=(u[e+928>>2]|0)==(a|0)?v:0;w=22;break}b=u[e+520>>2]|0;if(!b)w=21;else{_=0;while(1){v=e+524+(_*24|0)|0;if(((mr($(s[v>>2]),n)|0?mr($(s[e+524+(_*24|0)+4>>2]),t)|0:0)?(u[e+524+(_*24|0)+8>>2]|0)==(o|0):0)?(u[e+524+(_*24|0)+12>>2]|0)==(a|0):0){w=22;break e}_=_+1|0;if(_>>>0>=b>>>0){w=21;break}}}}else{y=$(Tr(e,2,l));D=$(Tr(e,0,l));v=e+916|0;O=$(s[v>>2]);F=$(s[e+920>>2]);N=$(s[e+932>>2]);if(!(gr(o,n,a,t,u[e+924>>2]|0,O,u[e+928>>2]|0,F,N,$(s[e+936>>2]),y,D,m)|0)){b=u[e+520>>2]|0;if(!b)w=21;else{_=0;while(1){v=e+524+(_*24|0)|0;N=$(s[v>>2]);F=$(s[e+524+(_*24|0)+4>>2]);O=$(s[e+524+(_*24|0)+16>>2]);if(gr(o,n,a,t,u[e+524+(_*24|0)+8>>2]|0,N,u[e+524+(_*24|0)+12>>2]|0,F,O,$(s[e+524+(_*24|0)+20>>2]),y,D,m)|0){w=22;break e}_=_+1|0;if(_>>>0>=b>>>0){w=21;break}}}}else w=22}}while(0);do{if((w|0)==21){if(!(r[11697]|0)){v=0;w=31}else{v=0;w=28}}else if((w|0)==22){_=(r[11697]|0)!=0;if(!((v|0)!=0&(P^1)))if(_){w=28;break}else{w=31;break}g=v+16|0;u[e+908>>2]=u[g>>2];b=v+20|0;u[e+912>>2]=u[b>>2];if(!((r[11698]|0)==0|_^1)){u[E>>2]=kr(C)|0;u[E+4>>2]=C;Cr(e,4,2972,E);_=u[e+972>>2]|0;if(_|0)hA[_&127](e);o=Mr(o,d)|0;a=Mr(a,d)|0;I=+$(s[g>>2]);L=+$(s[b>>2]);u[k>>2]=o;u[k+4>>2]=a;f[k+8>>3]=+n;f[k+16>>3]=+t;f[k+24>>3]=I;f[k+32>>3]=L;u[k+40>>2]=p;Cr(e,4,2989,k)}}}while(0);if((w|0)==28){_=kr(C)|0;u[g>>2]=_;u[g+4>>2]=C;u[g+8>>2]=P?3047:11699;Cr(e,4,3038,g);_=u[e+972>>2]|0;if(_|0)hA[_&127](e);k=Mr(o,d)|0;w=Mr(a,d)|0;u[T>>2]=k;u[T+4>>2]=w;f[T+8>>3]=+n;f[T+16>>3]=+t;u[T+24>>2]=p;Cr(e,4,3049,T);w=31}if((w|0)==31){Sr(e,n,t,i,o,a,l,c,d,m);if(r[11697]|0){_=u[2279]|0;k=kr(_)|0;u[M>>2]=k;u[M+4>>2]=_;u[M+8>>2]=P?3047:11699;Cr(e,4,3083,M);_=u[e+972>>2]|0;if(_|0)hA[_&127](e);k=Mr(o,d)|0;M=Mr(a,d)|0;L=+$(s[e+908>>2]);I=+$(s[e+912>>2]);u[S>>2]=k;u[S+4>>2]=M;f[S+8>>3]=L;f[S+16>>3]=I;u[S+24>>2]=p;Cr(e,4,3092,S)}u[e+516>>2]=i;if(!v){_=e+520|0;v=u[_>>2]|0;if((v|0)==16){if(r[11697]|0)Cr(e,4,3124,A);u[_>>2]=0;v=0}if(d)v=e+916|0;else{u[_>>2]=v+1;v=e+524+(v*24|0)|0}s[v>>2]=n;s[v+4>>2]=t;u[v+8>>2]=o;u[v+12>>2]=a;u[v+16>>2]=u[e+908>>2];u[v+20>>2]=u[e+912>>2];v=0}}if(d){u[e+416>>2]=u[e+908>>2];u[e+420>>2]=u[e+912>>2];r[e+985>>0]=1;r[x>>0]=0}u[2279]=(u[2279]|0)+-1;u[e+512>>2]=u[2278];h=R;return P|(v|0)==0|0}function Tr(e,n,t){e=e|0;n=n|0;t=$(t);var r=dn;r=$(Gr(e,n,t));return $(r+$(Yr(e,n,t)))}function Cr(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0;o=h;h=h+16|0;i=o;u[i>>2]=r;if(!e)r=0;else r=u[e+976>>2]|0;Br(r,e,n,t,i);h=o;return}function kr(e){e=e|0;return(e>>>0>60?3201:3201+(60-e)|0)|0}function Mr(e,n){e=e|0;n=n|0;var t=0,r=0,i=0;i=h;h=h+32|0;t=i+12|0;r=i;u[t>>2]=u[254];u[t+4>>2]=u[255];u[t+8>>2]=u[256];u[r>>2]=u[257];u[r+4>>2]=u[258];u[r+8>>2]=u[259];if((e|0)>2)e=11699;else e=u[(n?r:t)+(e<<2)>>2]|0;h=i;return e|0}function Sr(e,n,t,i,a,l,f,c,p,m){e=e|0;n=$(n);t=$(t);i=i|0;a=a|0;l=l|0;f=$(f);c=$(c);p=p|0;m=m|0;var v=0,_=0,b=0,g=0,y=dn,D=dn,w=dn,E=dn,T=dn,C=dn,k=dn,M=0,S=0,A=0,x=dn,P=dn,R=0,N=dn,F=0,O=0,L=0,I=0,B=0,U=0,j=0,W=0,z=0,H=0,G=0,Y=0,q=0,V=0,X=0,K=0,J=0,Q=0,Z=dn,ee=dn,ne=dn,te=dn,re=dn,ie=0,ue=0,oe=0,ae=0,le=0,se=dn,fe=dn,ce=dn,de=dn,pe=dn,he=dn,me=0,ve=dn,_e=dn,be=dn,ge=dn,ye=dn,De=dn,we=0,Ee=0,Te=dn,Ce=dn,ke=0,Me=0,Se=0,Ae=0,xe=dn,Pe=0,Re=0,Ne=0,Fe=0,Oe=0,Le=0,Ie=0,Be=dn,Ue=0,je=0;Ie=h;h=h+16|0;ie=Ie+12|0;ue=Ie+8|0;oe=Ie+4|0;ae=Ie;Ln(e,(a|0)==0|(wn(n)|0)^1,3326);Ln(e,(l|0)==0|(wn(t)|0)^1,3406);Re=$r(e,i)|0;u[e+496>>2]=Re;Oe=Xr(2,Re)|0;Le=Xr(0,Re)|0;s[e+440>>2]=$(Gr(e,Oe,f));s[e+444>>2]=$(Yr(e,Oe,f));s[e+428>>2]=$(Gr(e,Le,f));s[e+436>>2]=$(Yr(e,Le,f));s[e+464>>2]=$(Kr(e,Oe));s[e+468>>2]=$(Jr(e,Oe));s[e+452>>2]=$(Kr(e,Le));s[e+460>>2]=$(Jr(e,Le));s[e+488>>2]=$(Qr(e,Oe,f));s[e+492>>2]=$(Zr(e,Oe,f));s[e+476>>2]=$(Qr(e,Le,f));s[e+484>>2]=$(Zr(e,Le,f));do{if(!(u[e+964>>2]|0)){Ne=e+948|0;Fe=(u[e+952>>2]|0)-(u[Ne>>2]|0)>>2;if(!Fe){ni(e,n,t,a,l,f,c);break}if(!p?ti(e,n,t,a,l,f,c)|0:0)break;Hn(e);K=e+508|0;r[K>>0]=0;Oe=Xr(u[e+4>>2]|0,Re)|0;Le=ri(Oe,Re)|0;Pe=qr(Oe)|0;J=u[e+8>>2]|0;Me=e+28|0;Q=(u[Me>>2]|0)!=0;ye=Pe?f:c;Te=Pe?c:f;Z=$(ii(e,Oe,f));ee=$(ui(e,Oe,f));y=$(ii(e,Le,f));De=$(oi(e,Oe,f));Ce=$(oi(e,Le,f));A=Pe?a:l;ke=Pe?l:a;xe=Pe?De:Ce;T=Pe?Ce:De;ge=$(Tr(e,2,f));E=$(Tr(e,0,f));D=$($(Nr(e+364|0,f))-xe);w=$($(Nr(e+380|0,f))-xe);C=$($(Nr(e+372|0,c))-T);k=$($(Nr(e+388|0,c))-T);ne=Pe?D:C;te=Pe?w:k;ge=$(n-ge);n=$(ge-xe);if(wn(n)|0)xe=n;else xe=$(NM($(OM(n,w)),D));_e=$(t-E);n=$(_e-T);if(wn(n)|0)be=n;else be=$(NM($(OM(n,k)),C));D=Pe?xe:be;ve=Pe?be:xe;e:do{if((A|0)==1){i=0;_=0;while(1){v=Rn(e,_)|0;if(!i){if($(li(v))>$(0.0)?$(si(v))>$(0.0):0)i=v;else i=0}else if(ai(v)|0){g=0;break e}_=_+1|0;if(_>>>0>=Fe>>>0){g=i;break}}}else g=0}while(0);M=g+500|0;S=g+504|0;i=0;v=0;n=$(0.0);b=0;do{_=u[(u[Ne>>2]|0)+(b<<2)>>2]|0;if((u[_+36>>2]|0)==1){fi(_);r[_+985>>0]=1;r[_+984>>0]=0}else{Pr(_);if(p)Fr(_,$r(_,Re)|0,D,ve,xe);do{if((u[_+24>>2]|0)!=1){if((_|0)==(g|0)){u[M>>2]=u[2278];s[S>>2]=$(0.0);break}else{ci(e,_,xe,a,be,xe,be,l,Re,m);break}}else{if(v|0)u[v+960>>2]=_;u[_+960>>2]=0;v=_;i=(i|0)==0?_:i}}while(0);he=$(s[_+504>>2]);n=$(n+$(he+$(Tr(_,Oe,xe))))}b=b+1|0}while((b|0)!=(Fe|0));L=n>D;me=Q&((A|0)==2&L)?1:A;F=(ke|0)==1;B=F&(p^1);U=(me|0)==1;j=(me|0)==2;W=976+(Oe<<2)|0;z=(ke|2|0)==2;V=F&(Q^1);H=1040+(Le<<2)|0;G=1040+(Oe<<2)|0;Y=976+(Le<<2)|0;q=(ke|0)!=1;L=Q&((A|0)!=0&L);O=e+976|0;F=F^1;n=D;R=0;I=0;he=$(0.0);re=$(0.0);while(1){e:do{if(R>>>0<Fe>>>0){S=u[Ne>>2]|0;b=0;k=$(0.0);C=$(0.0);w=$(0.0);D=$(0.0);_=0;v=0;g=R;while(1){M=u[S+(g<<2)>>2]|0;if((u[M+36>>2]|0)!=1?(u[M+940>>2]=I,(u[M+24>>2]|0)!=1):0){E=$(Tr(M,Oe,xe));X=u[W>>2]|0;t=$(Nr(M+380+(X<<3)|0,ye));T=$(s[M+504>>2]);t=$(OM(t,T));t=$(NM($(Nr(M+364+(X<<3)|0,ye)),t));if(Q&(b|0)!=0&$(E+$(C+t))>n){l=b;E=k;A=g;break e}E=$(E+t);t=$(C+E);E=$(k+E);if(ai(M)|0){w=$(w+$(li(M)));D=$(D-$(T*$(si(M))))}if(v|0)u[v+960>>2]=M;u[M+960>>2]=0;b=b+1|0;v=M;_=(_|0)==0?M:_}else{E=k;t=C}g=g+1|0;if(g>>>0<Fe>>>0){k=E;C=t}else{l=b;A=g;break}}}else{l=0;E=$(0.0);w=$(0.0);D=$(0.0);_=0;A=R}}while(0);X=w>$(0.0)&w<$(1.0);x=X?$(1.0):w;X=D>$(0.0)&D<$(1.0);k=X?$(1.0):D;do{if(!U){if(!(E<ne&((wn(ne)|0)^1))){if(!(E>te&((wn(te)|0)^1))){if(!(r[(u[O>>2]|0)+3>>0]|0)){if(!(x==$(0.0))?!($(li(e))==$(0.0)):0){X=53;break}n=E;X=53}else X=51}else{n=te;X=51}}else{n=ne;X=51}}else X=51}while(0);if((X|0)==51){X=0;if(wn(n)|0)X=53;else{P=$(n-E);N=n}}if((X|0)==53){X=0;if(E<$(0.0)){P=$(-E);N=n}else{P=$(0.0);N=n}}if(!B?(le=(_|0)==0,!le):0){b=u[W>>2]|0;g=P<$(0.0);T=$(P/k);M=P>$(0.0);C=$(P/x);w=$(0.0);E=$(0.0);n=$(0.0);v=_;do{t=$(Nr(v+380+(b<<3)|0,ye));D=$(Nr(v+364+(b<<3)|0,ye));D=$(OM(t,$(NM(D,$(s[v+504>>2])))));if(g){t=$(D*$(si(v)));if(t!=$(-0.0)?(Be=$(D-$(T*t)),se=$(di(v,Oe,Be,N,xe)),Be!=se):0){w=$(w-$(se-D));n=$(n+t)}}else if((M?(fe=$(li(v)),fe!=$(0.0)):0)?(Be=$(D+$(C*fe)),ce=$(di(v,Oe,Be,N,xe)),Be!=ce):0){w=$(w-$(ce-D));E=$(E-fe)}v=u[v+960>>2]|0}while((v|0)!=0);n=$(k+n);D=$(P+w);if(!le){T=$(x+E);g=u[W>>2]|0;M=D<$(0.0);S=n==$(0.0);C=$(D/n);b=D>$(0.0);T=$(D/T);n=$(0.0);do{Be=$(Nr(_+380+(g<<3)|0,ye));w=$(Nr(_+364+(g<<3)|0,ye));w=$(OM(Be,$(NM(w,$(s[_+504>>2])))));if(M){Be=$(w*$(si(_)));D=$(-Be);if(Be!=$(-0.0)){Be=$(C*D);D=$(di(_,Oe,$(w+(S?D:Be)),N,xe))}else D=w}else if(b?(de=$(li(_)),de!=$(0.0)):0)D=$(di(_,Oe,$(w+$(T*de)),N,xe));else D=w;n=$(n-$(D-w));E=$(Tr(_,Oe,xe));t=$(Tr(_,Le,xe));D=$(D+E);s[ue>>2]=D;u[ae>>2]=1;w=$(s[_+396>>2]);e:do{if(wn(w)|0){v=wn(ve)|0;do{if(!v){if(L|(Rr(_,Le,ve)|0|F))break;if((pi(e,_)|0)!=4)break;if((u[(hi(_,Le)|0)+4>>2]|0)==3)break;if((u[(mi(_,Le)|0)+4>>2]|0)==3)break;s[ie>>2]=ve;u[oe>>2]=1;break e}}while(0);if(Rr(_,Le,ve)|0){v=u[_+992+(u[Y>>2]<<2)>>2]|0;Be=$(t+$(Nr(v,ve)));s[ie>>2]=Be;v=q&(u[v+4>>2]|0)==2;u[oe>>2]=((wn(Be)|0|v)^1)&1;break}else{s[ie>>2]=ve;u[oe>>2]=v?0:2;break}}else{Be=$(D-E);x=$(Be/w);Be=$(w*Be);u[oe>>2]=1;s[ie>>2]=$(t+(Pe?x:Be))}}while(0);vi(_,Oe,N,xe,ae,ue);vi(_,Le,ve,xe,oe,ie);do{if(!(Rr(_,Le,ve)|0)?(pi(e,_)|0)==4:0){if((u[(hi(_,Le)|0)+4>>2]|0)==3){v=0;break}v=(u[(mi(_,Le)|0)+4>>2]|0)!=3}else v=0}while(0);Be=$(s[ue>>2]);x=$(s[ie>>2]);Ue=u[ae>>2]|0;je=u[oe>>2]|0;Er(_,Pe?Be:x,Pe?x:Be,Re,Pe?Ue:je,Pe?je:Ue,xe,be,p&(v^1),3488,m)|0;r[K>>0]=r[K>>0]|r[_+508>>0];_=u[_+960>>2]|0}while((_|0)!=0)}else n=$(0.0)}else n=$(0.0);n=$(P+n);je=n<$(0.0)&1;r[K>>0]=je|o[K>>0];if(j&n>$(0.0)){v=u[W>>2]|0;if((u[e+364+(v<<3)+4>>2]|0)!=0?(pe=$(Nr(e+364+(v<<3)|0,ye)),pe>=$(0.0)):0)D=$(NM($(0.0),$(pe-$(N-n))));else D=$(0.0)}else D=n;M=R>>>0<A>>>0;if(M){g=u[Ne>>2]|0;b=R;v=0;do{_=u[g+(b<<2)>>2]|0;if(!(u[_+24>>2]|0)){v=((u[(hi(_,Oe)|0)+4>>2]|0)==3&1)+v|0;v=v+((u[(mi(_,Oe)|0)+4>>2]|0)==3&1)|0}b=b+1|0}while((b|0)!=(A|0));if(v){E=$(0.0);t=$(0.0)}else X=101}else X=101;e:do{if((X|0)==101){X=0;switch(J|0){case 1:{v=0;E=$(D*$(.5));t=$(0.0);break e}case 2:{v=0;E=D;t=$(0.0);break e}case 3:{if(l>>>0<=1){v=0;E=$(0.0);t=$(0.0);break e}t=$((l+-1|0)>>>0);v=0;E=$(0.0);t=$($(NM(D,$(0.0)))/t);break e}case 5:{t=$(D/$((l+1|0)>>>0));v=0;E=t;break e}case 4:{t=$(D/$(l>>>0));v=0;E=$(t*$(.5));break e}default:{v=0;E=$(0.0);t=$(0.0);break e}}}}while(0);n=$(Z+E);if(M){w=$(D/$(v|0));b=u[Ne>>2]|0;_=R;D=$(0.0);do{v=u[b+(_<<2)>>2]|0;e:do{if((u[v+36>>2]|0)!=1){switch(u[v+24>>2]|0){case 1:{if(_i(v,Oe)|0){if(!p)break e;Be=$(bi(v,Oe,N));Be=$(Be+$(Kr(e,Oe)));Be=$(Be+$(Gr(v,Oe,xe)));s[v+400+(u[G>>2]<<2)>>2]=Be;break e}break}case 0:{je=(u[(hi(v,Oe)|0)+4>>2]|0)==3;Be=$(w+n);n=je?Be:n;if(p){je=v+400+(u[G>>2]<<2)|0;s[je>>2]=$(n+$(s[je>>2]))}je=(u[(mi(v,Oe)|0)+4>>2]|0)==3;Be=$(w+n);n=je?Be:n;if(B){Be=$(t+$(Tr(v,Oe,xe)));D=ve;n=$(n+$(Be+$(s[v+504>>2])));break e}else{n=$(n+$(t+$(gi(v,Oe,xe))));D=$(NM(D,$(gi(v,Le,xe))));break e}}default:{}}if(p){Be=$(E+$(Kr(e,Oe)));je=v+400+(u[G>>2]<<2)|0;s[je>>2]=$(Be+$(s[je>>2]))}}}while(0);_=_+1|0}while((_|0)!=(A|0))}else D=$(0.0);t=$(ee+n);if(z)E=$($(di(e,Le,$(Ce+D),Te,f))-Ce);else E=ve;w=$($(di(e,Le,$(Ce+(V?ve:D)),Te,f))-Ce);if(M&p){_=R;do{b=u[(u[Ne>>2]|0)+(_<<2)>>2]|0;do{if((u[b+36>>2]|0)!=1){if((u[b+24>>2]|0)==1){if(_i(b,Le)|0){Be=$(bi(b,Le,ve));Be=$(Be+$(Kr(e,Le)));Be=$(Be+$(Gr(b,Le,xe)));v=u[H>>2]|0;s[b+400+(v<<2)>>2]=Be;if(!(wn(Be)|0))break}else v=u[H>>2]|0;Be=$(Kr(e,Le));s[b+400+(v<<2)>>2]=$(Be+$(Gr(b,Le,xe)));break}v=pi(e,b)|0;do{if((v|0)==4){if((u[(hi(b,Le)|0)+4>>2]|0)==3){X=139;break}if((u[(mi(b,Le)|0)+4>>2]|0)==3){X=139;break}if(Rr(b,Le,ve)|0){n=y;break}Ue=u[b+908+(u[W>>2]<<2)>>2]|0;u[ie>>2]=Ue;n=$(s[b+396>>2]);je=wn(n)|0;D=(u[d>>2]=Ue,$(s[d>>2]));if(je)n=w;else{P=$(Tr(b,Le,xe));Be=$(D/n);n=$(n*D);n=$(P+(Pe?Be:n))}s[ue>>2]=n;s[ie>>2]=$($(Tr(b,Oe,xe))+D);u[oe>>2]=1;u[ae>>2]=1;vi(b,Oe,N,xe,oe,ie);vi(b,Le,ve,xe,ae,ue);n=$(s[ie>>2]);P=$(s[ue>>2]);Be=Pe?n:P;n=Pe?P:n;je=((wn(Be)|0)^1)&1;Er(b,Be,n,Re,je,((wn(n)|0)^1)&1,xe,be,1,3493,m)|0;n=y}else X=139}while(0);e:do{if((X|0)==139){X=0;n=$(E-$(gi(b,Le,xe)));do{if((u[(hi(b,Le)|0)+4>>2]|0)==3){if((u[(mi(b,Le)|0)+4>>2]|0)!=3)break;n=$(y+$(NM($(0.0),$(n*$(.5)))));break e}}while(0);if((u[(mi(b,Le)|0)+4>>2]|0)==3){n=y;break}if((u[(hi(b,Le)|0)+4>>2]|0)==3){n=$(y+$(NM($(0.0),n)));break}switch(v|0){case 1:{n=y;break e}case 2:{n=$(y+$(n*$(.5)));break e}default:{n=$(y+n);break e}}}}while(0);Be=$(he+n);je=b+400+(u[H>>2]<<2)|0;s[je>>2]=$(Be+$(s[je>>2]))}}while(0);_=_+1|0}while((_|0)!=(A|0))}he=$(he+w);re=$(NM(re,t));l=I+1|0;if(A>>>0>=Fe>>>0)break;else{n=N;R=A;I=l}}do{if(p){v=l>>>0>1;if(!v?!(yi(e)|0):0)break;if(!(wn(ve)|0)){n=$(ve-he);e:do{switch(u[e+12>>2]|0){case 3:{y=$(y+n);C=$(0.0);break}case 2:{y=$(y+$(n*$(.5)));C=$(0.0);break}case 4:{if(ve>he)C=$(n/$(l>>>0));else C=$(0.0);break}case 7:if(ve>he){y=$(y+$(n/$(l<<1>>>0)));C=$(n/$(l>>>0));C=v?C:$(0.0);break e}else{y=$(y+$(n*$(.5)));C=$(0.0);break e}case 6:{C=$(n/$(I>>>0));C=ve>he&v?C:$(0.0);break}default:C=$(0.0)}}while(0);if(l|0){M=1040+(Le<<2)|0;S=976+(Le<<2)|0;g=0;_=0;while(1){e:do{if(_>>>0<Fe>>>0){D=$(0.0);w=$(0.0);n=$(0.0);b=_;while(1){v=u[(u[Ne>>2]|0)+(b<<2)>>2]|0;do{if((u[v+36>>2]|0)!=1?(u[v+24>>2]|0)==0:0){if((u[v+940>>2]|0)!=(g|0))break e;if(Di(v,Le)|0){Be=$(s[v+908+(u[S>>2]<<2)>>2]);n=$(NM(n,$(Be+$(Tr(v,Le,xe)))))}if((pi(e,v)|0)!=5)break;pe=$(wi(v));pe=$(pe+$(Gr(v,0,xe)));Be=$(s[v+912>>2]);Be=$($(Be+$(Tr(v,0,xe)))-pe);pe=$(NM(w,pe));Be=$(NM(D,Be));D=Be;w=pe;n=$(NM(n,$(pe+Be)))}}while(0);v=b+1|0;if(v>>>0<Fe>>>0)b=v;else{b=v;break}}}else{w=$(0.0);n=$(0.0);b=_}}while(0);T=$(C+n);t=y;y=$(y+T);if(_>>>0<b>>>0){E=$(t+w);v=_;do{_=u[(u[Ne>>2]|0)+(v<<2)>>2]|0;e:do{if((u[_+36>>2]|0)!=1?(u[_+24>>2]|0)==0:0)switch(pi(e,_)|0){case 1:{Be=$(t+$(Gr(_,Le,xe)));s[_+400+(u[M>>2]<<2)>>2]=Be;break e}case 3:{Be=$($(y-$(Yr(_,Le,xe)))-$(s[_+908+(u[S>>2]<<2)>>2]));s[_+400+(u[M>>2]<<2)>>2]=Be;break e}case 2:{Be=$(t+$($(T-$(s[_+908+(u[S>>2]<<2)>>2]))*$(.5)));s[_+400+(u[M>>2]<<2)>>2]=Be;break e}case 4:{Be=$(t+$(Gr(_,Le,xe)));s[_+400+(u[M>>2]<<2)>>2]=Be;if(Rr(_,Le,ve)|0)break e;if(Pe){D=$(s[_+908>>2]);n=$(D+$(Tr(_,Oe,xe)));w=T}else{w=$(s[_+912>>2]);w=$(w+$(Tr(_,Le,xe)));n=T;D=$(s[_+908>>2])}if(mr(n,D)|0?mr(w,$(s[_+912>>2]))|0:0)break e;Er(_,n,w,Re,1,1,xe,be,1,3501,m)|0;break e}case 5:{s[_+404>>2]=$($(E-$(wi(_)))+$(bi(_,0,ve)));break e}default:break e}}while(0);v=v+1|0}while((v|0)!=(b|0))}g=g+1|0;if((g|0)==(l|0))break;else _=b}}}}}while(0);s[e+908>>2]=$(di(e,2,ge,f,f));s[e+912>>2]=$(di(e,0,_e,c,f));if((me|0)!=0?(we=u[e+32>>2]|0,Ee=(me|0)==2,!(Ee&(we|0)!=2)):0){if(Ee&(we|0)==2){n=$(De+N);n=$(NM($(OM(n,$(Ei(e,Oe,re,ye)))),De));X=198}}else{n=$(di(e,Oe,re,ye,f));X=198}if((X|0)==198)s[e+908+(u[976+(Oe<<2)>>2]<<2)>>2]=n;if((ke|0)!=0?(Se=u[e+32>>2]|0,Ae=(ke|0)==2,!(Ae&(Se|0)!=2)):0){if(Ae&(Se|0)==2){n=$(Ce+ve);n=$(NM($(OM(n,$(Ei(e,Le,$(Ce+he),Te)))),Ce));X=204}}else{n=$(di(e,Le,$(Ce+he),Te,f));X=204}if((X|0)==204)s[e+908+(u[976+(Le<<2)>>2]<<2)>>2]=n;if(p){if((u[Me>>2]|0)==2){_=976+(Le<<2)|0;b=1040+(Le<<2)|0;v=0;do{g=Rn(e,v)|0;if(!(u[g+24>>2]|0)){Ue=u[_>>2]|0;Be=$(s[e+908+(Ue<<2)>>2]);je=g+400+(u[b>>2]<<2)|0;Be=$(Be-$(s[je>>2]));s[je>>2]=$(Be-$(s[g+908+(Ue<<2)>>2]))}v=v+1|0}while((v|0)!=(Fe|0))}if(i|0){v=Pe?me:a;do{Ti(e,i,xe,v,be,Re,m);i=u[i+960>>2]|0}while((i|0)!=0)}v=(Oe|2|0)==3;_=(Le|2|0)==3;if(v|_){i=0;do{b=u[(u[Ne>>2]|0)+(i<<2)>>2]|0;if((u[b+36>>2]|0)!=1){if(v)Ci(e,b,Oe);if(_)Ci(e,b,Le)}i=i+1|0}while((i|0)!=(Fe|0))}}}else ei(e,n,t,a,l,f,c)}while(0);h=Ie;return}function Ar(e,n){e=e|0;n=$(n);var t=0;Cn(e,n>=$(0.0),3147);t=n==$(0.0);s[e+4>>2]=t?$(0.0):n;return}function xr(e,n,t,i){e=e|0;n=$(n);t=$(t);i=i|0;var o=dn,a=dn,l=0,f=0,c=0;u[2278]=(u[2278]|0)+1;Pr(e);if(!(Rr(e,2,n)|0)){o=$(Nr(e+380|0,n));if(!(o>=$(0.0))){c=((wn(n)|0)^1)&1;o=n}else c=2}else{o=$(Nr(u[e+992>>2]|0,n));c=1;o=$(o+$(Tr(e,2,n)))}if(!(Rr(e,0,t)|0)){a=$(Nr(e+388|0,t));if(!(a>=$(0.0))){f=((wn(t)|0)^1)&1;a=t}else f=2}else{a=$(Nr(u[e+996>>2]|0,t));f=1;a=$(a+$(Tr(e,0,n)))}l=e+976|0;if(Er(e,o,a,i,c,f,n,t,1,3189,u[l>>2]|0)|0?(Fr(e,u[e+496>>2]|0,n,t,n),Or(e,$(s[(u[l>>2]|0)+4>>2]),$(0.0),$(0.0)),r[11696]|0):0)vr(e,7);return}function Pr(e){e=e|0;var n=0,t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0;l=h;h=h+32|0;a=l+24|0;o=l+16|0;r=l+8|0;i=l;t=0;do{n=e+380+(t<<3)|0;if(!((u[e+380+(t<<3)+4>>2]|0)!=0?(s=n,f=u[s+4>>2]|0,c=r,u[c>>2]=u[s>>2],u[c+4>>2]=f,c=e+364+(t<<3)|0,f=u[c+4>>2]|0,s=i,u[s>>2]=u[c>>2],u[s+4>>2]=f,u[o>>2]=u[r>>2],u[o+4>>2]=u[r+4>>2],u[a>>2]=u[i>>2],u[a+4>>2]=u[i+4>>2],hr(o,a)|0):0))n=e+348+(t<<3)|0;u[e+992+(t<<2)>>2]=n;t=t+1|0}while((t|0)!=2);h=l;return}function Rr(e,n,t){e=e|0;n=n|0;t=$(t);var r=0;e=u[e+992+(u[976+(n<<2)>>2]<<2)>>2]|0;switch(u[e+4>>2]|0){case 0:case 3:{e=0;break}case 1:{if($(s[e>>2])<$(0.0))e=0;else r=5;break}case 2:{if($(s[e>>2])<$(0.0))e=0;else e=(wn(t)|0)^1;break}default:r=5}if((r|0)==5)e=1;return e|0}function Nr(e,n){e=e|0;n=$(n);switch(u[e+4>>2]|0){case 2:{n=$($($(s[e>>2])*n)/$(100.0));break}case 1:{n=$(s[e>>2]);break}default:n=$(w)}return $(n)}function Fr(e,n,t,r,i){e=e|0;n=n|0;t=$(t);r=$(r);i=$(i);var o=0,a=dn;n=u[e+944>>2]|0?n:1;o=Xr(u[e+4>>2]|0,n)|0;n=ri(o,n)|0;t=$(Pi(e,o,t));r=$(Pi(e,n,r));a=$(t+$(Gr(e,o,i)));s[e+400+(u[1040+(o<<2)>>2]<<2)>>2]=a;t=$(t+$(Yr(e,o,i)));s[e+400+(u[1e3+(o<<2)>>2]<<2)>>2]=t;t=$(r+$(Gr(e,n,i)));s[e+400+(u[1040+(n<<2)>>2]<<2)>>2]=t;i=$(r+$(Yr(e,n,i)));s[e+400+(u[1e3+(n<<2)>>2]<<2)>>2]=i;return}function Or(e,n,t,r){e=e|0;n=$(n);t=$(t);r=$(r);var i=0,o=0,a=dn,l=dn,f=0,c=0,d=dn,p=0,h=dn,m=dn,v=dn,_=dn;if(!(n==$(0.0))){i=e+400|0;_=$(s[i>>2]);o=e+404|0;v=$(s[o>>2]);p=e+416|0;m=$(s[p>>2]);c=e+420|0;a=$(s[c>>2]);h=$(_+t);d=$(v+r);r=$(h+m);l=$(d+a);f=(u[e+988>>2]|0)==1;s[i>>2]=$(br(_,n,0,f));s[o>>2]=$(br(v,n,0,f));t=$(IM($(m*n),$(1.0)));if(mr(t,$(0.0))|0)o=0;else o=(mr(t,$(1.0))|0)^1;t=$(IM($(a*n),$(1.0)));if(mr(t,$(0.0))|0)i=0;else i=(mr(t,$(1.0))|0)^1;_=$(br(r,n,f&o,f&(o^1)));s[p>>2]=$(_-$(br(h,n,0,f)));_=$(br(l,n,f&i,f&(i^1)));s[c>>2]=$(_-$(br(d,n,0,f)));o=(u[e+952>>2]|0)-(u[e+948>>2]|0)>>2;if(o|0){i=0;do{Or(Rn(e,i)|0,n,h,d);i=i+1|0}while((i|0)!=(o|0))}}return}function Lr(e,n,t,r,i){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;switch(t|0){case 5:case 0:{e=uM(u[489]|0,r,i)|0;break}default:e=UM(r,i)|0}return e|0}function Ir(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0;i=h;h=h+16|0;o=i;u[o>>2]=r;Br(e,0,n,t,o);h=i;return}function Br(e,n,t,r,i){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;e=e|0?e:956;SA[u[e+8>>2]&1](e,n,t,r,i)|0;if((t|0)==5)$e();else return}function Ur(e,n,t){e=e|0;n=n|0;t=t|0;r[e+n>>0]=t&1;return}function jr(e,n){e=e|0;n=n|0;var t=0,r=0;u[e>>2]=0;u[e+4>>2]=0;u[e+8>>2]=0;t=n+4|0;r=(u[t>>2]|0)-(u[n>>2]|0)>>2;if(r|0){Wr(e,r);zr(e,u[n>>2]|0,u[t>>2]|0,r)}return}function Wr(e,n){e=e|0;n=n|0;var t=0;if((Hr(e)|0)>>>0<n>>>0)jM(e);if(n>>>0>1073741823)$e();else{t=VM(n<<2)|0;u[e+4>>2]=t;u[e>>2]=t;u[e+8>>2]=t+(n<<2);return}}function zr(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;r=e+4|0;e=t-n|0;if((e|0)>0){iS(u[r>>2]|0,n|0,e|0)|0;u[r>>2]=(u[r>>2]|0)+(e>>>2<<2)}return}function Hr(e){e=e|0;return 1073741823}function Gr(e,n,t){e=e|0;n=n|0;t=$(t);if(qr(n)|0?(u[e+96>>2]|0)!=0:0)e=e+92|0;else e=En(e+60|0,u[1040+(n<<2)>>2]|0,992)|0;return $(Vr(e,t))}function Yr(e,n,t){e=e|0;n=n|0;t=$(t);if(qr(n)|0?(u[e+104>>2]|0)!=0:0)e=e+100|0;else e=En(e+60|0,u[1e3+(n<<2)>>2]|0,992)|0;return $(Vr(e,t))}function qr(e){e=e|0;return(e|1|0)==3|0}function Vr(e,n){e=e|0;n=$(n);if((u[e+4>>2]|0)==3)n=$(0.0);else n=$(Nr(e,n));return $(n)}function $r(e,n){e=e|0;n=n|0;e=u[e>>2]|0;return((e|0)==0?(n|0)>1?n:1:e)|0}function Xr(e,n){e=e|0;n=n|0;var t=0;e:do{if((n|0)==2){switch(e|0){case 2:{e=3;break e}case 3:break;default:{t=4;break e}}e=2}else t=4}while(0);return e|0}function Kr(e,n){e=e|0;n=n|0;var t=dn;if(!((qr(n)|0?(u[e+312>>2]|0)!=0:0)?(t=$(s[e+308>>2]),t>=$(0.0)):0))t=$(NM($(s[(En(e+276|0,u[1040+(n<<2)>>2]|0,992)|0)>>2]),$(0.0)));return $(t)}function Jr(e,n){e=e|0;n=n|0;var t=dn;if(!((qr(n)|0?(u[e+320>>2]|0)!=0:0)?(t=$(s[e+316>>2]),t>=$(0.0)):0))t=$(NM($(s[(En(e+276|0,u[1e3+(n<<2)>>2]|0,992)|0)>>2]),$(0.0)));return $(t)}function Qr(e,n,t){e=e|0;n=n|0;t=$(t);var r=dn;if(!((qr(n)|0?(u[e+240>>2]|0)!=0:0)?(r=$(Nr(e+236|0,t)),r>=$(0.0)):0))r=$(NM($(Nr(En(e+204|0,u[1040+(n<<2)>>2]|0,992)|0,t)),$(0.0)));return $(r)}function Zr(e,n,t){e=e|0;n=n|0;t=$(t);var r=dn;if(!((qr(n)|0?(u[e+248>>2]|0)!=0:0)?(r=$(Nr(e+244|0,t)),r>=$(0.0)):0))r=$(NM($(Nr(En(e+204|0,u[1e3+(n<<2)>>2]|0,992)|0,t)),$(0.0)));return $(r)}function ei(e,n,t,r,i,o,a){e=e|0;n=$(n);t=$(t);r=r|0;i=i|0;o=$(o);a=$(a);var l=dn,f=dn,c=dn,d=dn,p=dn,m=dn,v=0,_=0,b=0;b=h;h=h+16|0;v=b;_=e+964|0;Ln(e,(u[_>>2]|0)!=0,3519);l=$(oi(e,2,n));f=$(oi(e,0,n));c=$(Tr(e,2,n));d=$(Tr(e,0,n));if(wn(n)|0)p=n;else p=$(NM($(0.0),$($(n-c)-l)));if(wn(t)|0)m=t;else m=$(NM($(0.0),$($(t-d)-f)));if((r|0)==1&(i|0)==1){s[e+908>>2]=$(di(e,2,$(n-c),o,o));n=$(di(e,0,$(t-d),a,o))}else{xA[u[_>>2]&1](v,e,p,r,m,i);p=$(l+$(s[v>>2]));m=$(n-c);s[e+908>>2]=$(di(e,2,(r|2|0)==2?p:m,o,o));m=$(f+$(s[v+4>>2]));n=$(t-d);n=$(di(e,0,(i|2|0)==2?m:n,a,o))}s[e+912>>2]=n;h=b;return}function ni(e,n,t,r,i,u,o){e=e|0;n=$(n);t=$(t);r=r|0;i=i|0;u=$(u);o=$(o);var a=dn,l=dn,f=dn,c=dn;f=$(oi(e,2,u));a=$(oi(e,0,u));c=$(Tr(e,2,u));l=$(Tr(e,0,u));n=$(n-c);s[e+908>>2]=$(di(e,2,(r|2|0)==2?f:n,u,u));t=$(t-l);s[e+912>>2]=$(di(e,0,(i|2|0)==2?a:t,o,u));return}function ti(e,n,t,r,i,u,o){e=e|0;n=$(n);t=$(t);r=r|0;i=i|0;u=$(u);o=$(o);var a=0,l=dn,f=dn;a=(r|0)==2;if((!(n<=$(0.0)&a)?!(t<=$(0.0)&(i|0)==2):0)?!((r|0)==1&(i|0)==1):0)e=0;else{l=$(Tr(e,0,u));f=$(Tr(e,2,u));a=n<$(0.0)&a|(wn(n)|0);n=$(n-f);s[e+908>>2]=$(di(e,2,a?$(0.0):n,u,u));n=$(t-l);a=t<$(0.0)&(i|0)==2|(wn(t)|0);s[e+912>>2]=$(di(e,0,a?$(0.0):n,o,u));e=1}return e|0}function ri(e,n){e=e|0;n=n|0;if(ki(e)|0)e=Xr(2,n)|0;else e=0;return e|0}function ii(e,n,t){e=e|0;n=n|0;t=$(t);t=$(Qr(e,n,t));return $(t+$(Kr(e,n)))}function ui(e,n,t){e=e|0;n=n|0;t=$(t);t=$(Zr(e,n,t));return $(t+$(Jr(e,n)))}function oi(e,n,t){e=e|0;n=n|0;t=$(t);var r=dn;r=$(ii(e,n,t));return $(r+$(ui(e,n,t)))}function ai(e){e=e|0;if(!(u[e+24>>2]|0)){if($(li(e))!=$(0.0))e=1;else e=$(si(e))!=$(0.0)}else e=0;return e|0}function li(e){e=e|0;var n=dn;if(u[e+944>>2]|0){n=$(s[e+44>>2]);if(wn(n)|0){n=$(s[e+40>>2]);e=n>$(0.0)&((wn(n)|0)^1);return $(e?n:$(0.0))}}else n=$(0.0);return $(n)}function si(e){e=e|0;var n=dn,t=0,i=dn;do{if(u[e+944>>2]|0){n=$(s[e+48>>2]);if(wn(n)|0){t=r[(u[e+976>>2]|0)+2>>0]|0;if(t<<24>>24==0?(i=$(s[e+40>>2]),i<$(0.0)&((wn(i)|0)^1)):0){n=$(-i);break}n=t<<24>>24?$(1.0):$(0.0)}}else n=$(0.0)}while(0);return $(n)}function fi(e){e=e|0;var n=0,t=0;nS(e+400|0,0,540)|0;r[e+985>>0]=1;Hn(e);t=Pn(e)|0;if(t|0){n=e+948|0;e=0;do{fi(u[(u[n>>2]|0)+(e<<2)>>2]|0);e=e+1|0}while((e|0)!=(t|0))}return}function ci(e,n,t,r,i,o,a,l,f,c){e=e|0;n=n|0;t=$(t);r=r|0;i=$(i);o=$(o);a=$(a);l=l|0;f=f|0;c=c|0;var d=0,p=dn,m=0,v=0,_=dn,b=dn,g=0,y=dn,D=0,E=dn,T=0,C=0,k=0,M=0,S=0,A=0,x=0,P=0,R=0,N=0;R=h;h=h+16|0;k=R+12|0;M=R+8|0;S=R+4|0;A=R;P=Xr(u[e+4>>2]|0,f)|0;T=qr(P)|0;p=$(Nr(Mi(n)|0,T?o:a));C=Rr(n,2,o)|0;x=Rr(n,0,a)|0;do{if(!(wn(p)|0)?!(wn(T?t:i)|0):0){d=n+504|0;if(!(wn($(s[d>>2]))|0)){if(!(Si(u[n+976>>2]|0,0)|0))break;if((u[n+500>>2]|0)==(u[2278]|0))break}s[d>>2]=$(NM(p,$(oi(n,P,o))))}else m=7}while(0);do{if((m|0)==7){D=T^1;if(!(D|C^1)){a=$(Nr(u[n+992>>2]|0,o));s[n+504>>2]=$(NM(a,$(oi(n,2,o))));break}if(!(T|x^1)){a=$(Nr(u[n+996>>2]|0,a));s[n+504>>2]=$(NM(a,$(oi(n,0,o))));break}s[k>>2]=$(w);s[M>>2]=$(w);u[S>>2]=0;u[A>>2]=0;y=$(Tr(n,2,o));E=$(Tr(n,0,o));if(C){_=$(y+$(Nr(u[n+992>>2]|0,o)));s[k>>2]=_;u[S>>2]=1;v=1}else{v=0;_=$(w)}if(x){p=$(E+$(Nr(u[n+996>>2]|0,a)));s[M>>2]=p;u[A>>2]=1;d=1}else{d=0;p=$(w)}m=u[e+32>>2]|0;if(!(T&(m|0)==2)){if(wn(_)|0?!(wn(t)|0):0){s[k>>2]=t;u[S>>2]=2;v=2;_=t}}else m=2;if((!((m|0)==2&D)?wn(p)|0:0)?!(wn(i)|0):0){s[M>>2]=i;u[A>>2]=2;d=2;p=i}b=$(s[n+396>>2]);g=wn(b)|0;do{if(!g){if((v|0)==1&D){s[M>>2]=$($(_-y)/b);u[A>>2]=1;d=1;m=1;break}if(T&(d|0)==1){s[k>>2]=$(b*$(p-E));u[S>>2]=1;d=1;m=1}else m=v}else m=v}while(0);N=wn(t)|0;v=(pi(e,n)|0)!=4;if(!(T|C|((r|0)!=1|N)|(v|(m|0)==1))?(s[k>>2]=t,u[S>>2]=1,!g):0){s[M>>2]=$($(t-y)/b);u[A>>2]=1;d=1}if(!(x|D|((l|0)!=1|(wn(i)|0))|(v|(d|0)==1))?(s[M>>2]=i,u[A>>2]=1,!g):0){s[k>>2]=$(b*$(i-E));u[S>>2]=1}vi(n,2,o,o,S,k);vi(n,0,a,o,A,M);t=$(s[k>>2]);i=$(s[M>>2]);Er(n,t,i,f,u[S>>2]|0,u[A>>2]|0,o,a,0,3565,c)|0;a=$(s[n+908+(u[976+(P<<2)>>2]<<2)>>2]);s[n+504>>2]=$(NM(a,$(oi(n,P,o))))}}while(0);u[n+500>>2]=u[2278];h=R;return}function di(e,n,t,r,i){e=e|0;n=n|0;t=$(t);r=$(r);i=$(i);r=$(Ei(e,n,t,r));return $(NM(r,$(oi(e,n,i))))}function pi(e,n){e=e|0;n=n|0;n=n+20|0;n=u[((u[n>>2]|0)==0?e+16|0:n)>>2]|0;if((n|0)==5?ki(u[e+4>>2]|0)|0:0)n=1;return n|0}function hi(e,n){e=e|0;n=n|0;if(qr(n)|0?(u[e+96>>2]|0)!=0:0)n=4;else n=u[1040+(n<<2)>>2]|0;return e+60+(n<<3)|0}function mi(e,n){e=e|0;n=n|0;if(qr(n)|0?(u[e+104>>2]|0)!=0:0)n=5;else n=u[1e3+(n<<2)>>2]|0;return e+60+(n<<3)|0}function vi(e,n,t,r,i,o){e=e|0;n=n|0;t=$(t);r=$(r);i=i|0;o=o|0;t=$(Nr(e+380+(u[976+(n<<2)>>2]<<3)|0,t));t=$(t+$(Tr(e,n,r)));switch(u[i>>2]|0){case 2:case 1:{i=wn(t)|0;r=$(s[o>>2]);s[o>>2]=i|r<t?r:t;break}case 0:{if(!(wn(t)|0)){u[i>>2]=2;s[o>>2]=t}break}default:{}}return}function _i(e,n){e=e|0;n=n|0;e=e+132|0;if(qr(n)|0?(u[(En(e,4,948)|0)+4>>2]|0)!=0:0)e=1;else e=(u[(En(e,u[1040+(n<<2)>>2]|0,948)|0)+4>>2]|0)!=0;return e|0}function bi(e,n,t){e=e|0;n=n|0;t=$(t);var r=0,i=0;e=e+132|0;if(qr(n)|0?(r=En(e,4,948)|0,(u[r+4>>2]|0)!=0):0)i=4;else{r=En(e,u[1040+(n<<2)>>2]|0,948)|0;if(!(u[r+4>>2]|0))t=$(0.0);else i=4}if((i|0)==4)t=$(Nr(r,t));return $(t)}function gi(e,n,t){e=e|0;n=n|0;t=$(t);var r=dn;r=$(s[e+908+(u[976+(n<<2)>>2]<<2)>>2]);r=$(r+$(Gr(e,n,t)));return $(r+$(Yr(e,n,t)))}function yi(e){e=e|0;var n=0,t=0,r=0;e:do{if(!(ki(u[e+4>>2]|0)|0)){if((u[e+16>>2]|0)!=5){t=Pn(e)|0;if(!t)n=0;else{n=0;while(1){r=Rn(e,n)|0;if((u[r+24>>2]|0)==0?(u[r+20>>2]|0)==5:0){n=1;break e}n=n+1|0;if(n>>>0>=t>>>0){n=0;break}}}}else n=1}else n=0}while(0);return n|0}function Di(e,n){e=e|0;n=n|0;var t=dn;t=$(s[e+908+(u[976+(n<<2)>>2]<<2)>>2]);return t>=$(0.0)&((wn(t)|0)^1)|0}function wi(e){e=e|0;var n=dn,t=0,r=0,i=0,o=0,a=0,l=0,f=dn;t=u[e+968>>2]|0;if(!t){o=Pn(e)|0;do{if(o|0){t=0;i=0;while(1){r=Rn(e,i)|0;if(u[r+940>>2]|0){a=8;break}if((u[r+24>>2]|0)!=1){l=(pi(e,r)|0)==5;if(l){t=r;break}else t=(t|0)==0?r:t}i=i+1|0;if(i>>>0>=o>>>0){a=8;break}}if((a|0)==8)if(!t)break;n=$(wi(t));return $(n+$(s[t+404>>2]))}}while(0);n=$(s[e+912>>2])}else{f=$(s[e+908>>2]);n=$(s[e+912>>2]);n=$(pA[t&0](e,f,n));Ln(e,(wn(n)|0)^1,3573)}return $(n)}function Ei(e,n,t,r){e=e|0;n=n|0;t=$(t);r=$(r);var i=dn,u=0;if(!(ki(n)|0)){if(qr(n)|0){n=0;u=3}else{r=$(w);i=$(w)}}else{n=1;u=3}if((u|0)==3){i=$(Nr(e+364+(n<<3)|0,r));r=$(Nr(e+380+(n<<3)|0,r))}u=r<t&(r>=$(0.0)&((wn(r)|0)^1));t=u?r:t;u=i>=$(0.0)&((wn(i)|0)^1)&t<i;return $(u?i:t)}function Ti(e,n,t,r,i,o,a){e=e|0;n=n|0;t=$(t);r=r|0;i=$(i);o=o|0;a=a|0;var l=dn,f=dn,c=0,d=0,p=dn,h=dn,m=dn,v=0,_=0,b=0,g=0,y=dn,D=0;b=Xr(u[e+4>>2]|0,o)|0;v=ri(b,o)|0;_=qr(b)|0;p=$(Tr(n,2,t));h=$(Tr(n,0,t));if(!(Rr(n,2,t)|0)){if(_i(n,2)|0?Ai(n,2)|0:0){l=$(s[e+908>>2]);f=$(Kr(e,2));f=$(l-$(f+$(Jr(e,2))));l=$(bi(n,2,t));l=$(di(n,2,$(f-$(l+$(xi(n,2,t)))),t,t))}else l=$(w)}else l=$(p+$(Nr(u[n+992>>2]|0,t)));if(!(Rr(n,0,i)|0)){if(_i(n,0)|0?Ai(n,0)|0:0){f=$(s[e+912>>2]);y=$(Kr(e,0));y=$(f-$(y+$(Jr(e,0))));f=$(bi(n,0,i));f=$(di(n,0,$(y-$(f+$(xi(n,0,i)))),i,t))}else f=$(w)}else f=$(h+$(Nr(u[n+996>>2]|0,i)));c=wn(l)|0;d=wn(f)|0;do{if(c^d?(m=$(s[n+396>>2]),!(wn(m)|0)):0)if(c){l=$(p+$($(f-h)*m));break}else{y=$(h+$($(l-p)/m));f=d?y:f;break}}while(0);d=wn(l)|0;c=wn(f)|0;if(d|c){D=(d^1)&1;r=t>$(0.0)&((r|0)!=0&d);l=_?l:r?t:l;Er(n,l,f,o,_?D:r?2:D,d&(c^1)&1,l,f,0,3623,a)|0;l=$(s[n+908>>2]);l=$(l+$(Tr(n,2,t)));f=$(s[n+912>>2]);f=$(f+$(Tr(n,0,t)))}Er(n,l,f,o,1,1,l,f,1,3635,a)|0;if(Ai(n,b)|0?!(_i(n,b)|0):0){D=u[976+(b<<2)>>2]|0;y=$(s[e+908+(D<<2)>>2]);y=$(y-$(s[n+908+(D<<2)>>2]));y=$(y-$(Jr(e,b)));y=$(y-$(Yr(n,b,t)));y=$(y-$(xi(n,b,_?t:i)));s[n+400+(u[1040+(b<<2)>>2]<<2)>>2]=y}else g=21;do{if((g|0)==21){if(!(_i(n,b)|0)?(u[e+8>>2]|0)==1:0){D=u[976+(b<<2)>>2]|0;y=$(s[e+908+(D<<2)>>2]);y=$($(y-$(s[n+908+(D<<2)>>2]))*$(.5));s[n+400+(u[1040+(b<<2)>>2]<<2)>>2]=y;break}if(!(_i(n,b)|0)?(u[e+8>>2]|0)==2:0){D=u[976+(b<<2)>>2]|0;y=$(s[e+908+(D<<2)>>2]);y=$(y-$(s[n+908+(D<<2)>>2]));s[n+400+(u[1040+(b<<2)>>2]<<2)>>2]=y}}}while(0);if(Ai(n,v)|0?!(_i(n,v)|0):0){D=u[976+(v<<2)>>2]|0;y=$(s[e+908+(D<<2)>>2]);y=$(y-$(s[n+908+(D<<2)>>2]));y=$(y-$(Jr(e,v)));y=$(y-$(Yr(n,v,t)));y=$(y-$(xi(n,v,_?i:t)));s[n+400+(u[1040+(v<<2)>>2]<<2)>>2]=y}else g=30;do{if((g|0)==30?!(_i(n,v)|0):0){if((pi(e,n)|0)==2){D=u[976+(v<<2)>>2]|0;y=$(s[e+908+(D<<2)>>2]);y=$($(y-$(s[n+908+(D<<2)>>2]))*$(.5));s[n+400+(u[1040+(v<<2)>>2]<<2)>>2]=y;break}D=(pi(e,n)|0)==3;if(D^(u[e+28>>2]|0)==2){D=u[976+(v<<2)>>2]|0;y=$(s[e+908+(D<<2)>>2]);y=$(y-$(s[n+908+(D<<2)>>2]));s[n+400+(u[1040+(v<<2)>>2]<<2)>>2]=y}}}while(0);return}function Ci(e,n,t){e=e|0;n=n|0;t=t|0;var r=dn,i=0;i=u[976+(t<<2)>>2]|0;r=$(s[n+908+(i<<2)>>2]);r=$($(s[e+908+(i<<2)>>2])-r);r=$(r-$(s[n+400+(u[1040+(t<<2)>>2]<<2)>>2]));s[n+400+(u[1e3+(t<<2)>>2]<<2)>>2]=r;return}function ki(e){e=e|0;return(e|1|0)==1|0}function Mi(e){e=e|0;var n=dn;switch(u[e+56>>2]|0){case 0:case 3:{n=$(s[e+40>>2]);if(n>$(0.0)&((wn(n)|0)^1))e=r[(u[e+976>>2]|0)+2>>0]|0?1056:992;else e=1056;break}default:e=e+52|0}return e|0}function Si(e,n){e=e|0;n=n|0;return(r[e+n>>0]|0)!=0|0}function Ai(e,n){e=e|0;n=n|0;e=e+132|0;if(qr(n)|0?(u[(En(e,5,948)|0)+4>>2]|0)!=0:0)e=1;else e=(u[(En(e,u[1e3+(n<<2)>>2]|0,948)|0)+4>>2]|0)!=0;return e|0}function xi(e,n,t){e=e|0;n=n|0;t=$(t);var r=0,i=0;e=e+132|0;if(qr(n)|0?(r=En(e,5,948)|0,(u[r+4>>2]|0)!=0):0)i=4;else{r=En(e,u[1e3+(n<<2)>>2]|0,948)|0;if(!(u[r+4>>2]|0))t=$(0.0);else i=4}if((i|0)==4)t=$(Nr(r,t));return $(t)}function Pi(e,n,t){e=e|0;n=n|0;t=$(t);if(_i(e,n)|0)t=$(bi(e,n,t));else t=$(-$(xi(e,n,t)));return $(t)}function Ri(e){e=$(e);return(s[d>>2]=e,u[d>>2]|0)|0}function Ni(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>1073741823)$e();else{i=VM(n<<2)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t<<2)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n<<2);return}function Fi(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(0-(i>>2)<<2)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function Oi(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~((r+-4-n|0)>>>2)<<2);e=u[e>>2]|0;if(e|0)XM(e);return}function Li(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0;a=e+4|0;l=u[a>>2]|0;i=l-r|0;o=i>>2;e=n+(o<<2)|0;if(e>>>0<t>>>0){r=l;do{u[r>>2]=u[e>>2];e=e+4|0;r=(u[a>>2]|0)+4|0;u[a>>2]=r}while(e>>>0<t>>>0)}if(o|0)sS(l+(0-o<<2)|0,n|0,i|0)|0;return}function Ii(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0;l=n+4|0;s=u[l>>2]|0;i=u[e>>2]|0;a=t;o=a-i|0;r=s+(0-(o>>2)<<2)|0;u[l>>2]=r;if((o|0)>0)iS(r|0,i|0,o|0)|0;i=e+4|0;o=n+8|0;r=(u[i>>2]|0)-a|0;if((r|0)>0){iS(u[o>>2]|0,t|0,r|0)|0;u[o>>2]=(u[o>>2]|0)+(r>>>2<<2)}a=u[e>>2]|0;u[e>>2]=u[l>>2];u[l>>2]=a;a=u[i>>2]|0;u[i>>2]=u[o>>2];u[o>>2]=a;a=e+8|0;t=n+12|0;e=u[a>>2]|0;u[a>>2]=u[t>>2];u[t>>2]=e;u[n>>2]=u[l>>2];return s|0}function Bi(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;a=u[n>>2]|0;o=u[t>>2]|0;if((a|0)!=(o|0)){i=e+8|0;t=((o+-4-a|0)>>>2)+1|0;e=a;r=u[i>>2]|0;do{u[r>>2]=u[e>>2];r=(u[i>>2]|0)+4|0;u[i>>2]=r;e=e+4|0}while((e|0)!=(o|0));u[n>>2]=a+(t<<2)}return}function Ui(){yn();return}function ji(){var e=0;e=VM(4)|0;Wi(e);return e|0}function Wi(e){e=e|0;u[e>>2]=Bn()|0;return}function zi(e){e=e|0;if(e|0){Hi(e);XM(e)}return}function Hi(e){e=e|0;jn(u[e>>2]|0);return}function Gi(e,n,t){e=e|0;n=n|0;t=t|0;Ur(u[e>>2]|0,n,t);return}function Yi(e,n){e=e|0;n=$(n);Ar(u[e>>2]|0,n);return}function qi(e,n){e=e|0;n=n|0;return Si(u[e>>2]|0,n)|0}function Vi(){var e=0;e=VM(8)|0;$i(e,0);return e|0}function $i(e,n){e=e|0;n=n|0;if(!n)n=kn()|0;else n=Tn(u[n>>2]|0)|0;u[e>>2]=n;u[e+4>>2]=0;Zn(n,e);return}function Xi(e){e=e|0;var n=0;n=VM(8)|0;$i(n,e);return n|0}function Ki(e){e=e|0;if(e|0){Ji(e);XM(e)}return}function Ji(e){e=e|0;var n=0;An(u[e>>2]|0);n=e+4|0;e=u[n>>2]|0;u[n>>2]=0;if(e|0){Qi(e);XM(e)}return}function Qi(e){e=e|0;Zi(e);return}function Zi(e){e=e|0;e=u[e>>2]|0;if(e|0)rn(e|0);return}function eu(e){e=e|0;return et(e)|0}function nu(e){e=e|0;var n=0,t=0;t=e+4|0;n=u[t>>2]|0;u[t>>2]=0;if(n|0){Qi(n);XM(n)}On(u[e>>2]|0);return}function tu(e,n){e=e|0;n=n|0;Kn(u[e>>2]|0,u[n>>2]|0);return}function ru(e,n){e=e|0;n=n|0;ct(u[e>>2]|0,n);return}function iu(e,n,t){e=e|0;n=n|0;t=+t;Ct(u[e>>2]|0,n,$(t));return}function uu(e,n,t){e=e|0;n=n|0;t=+t;kt(u[e>>2]|0,n,$(t));return}function ou(e,n){e=e|0;n=n|0;ut(u[e>>2]|0,n);return}function au(e,n){e=e|0;n=n|0;at(u[e>>2]|0,n);return}function lu(e,n){e=e|0;n=n|0;st(u[e>>2]|0,n);return}function su(e,n){e=e|0;n=n|0;nt(u[e>>2]|0,n);return}function fu(e,n){e=e|0;n=n|0;pt(u[e>>2]|0,n);return}function cu(e,n){e=e|0;n=n|0;rt(u[e>>2]|0,n);return}function du(e,n,t){e=e|0;n=n|0;t=+t;St(u[e>>2]|0,n,$(t));return}function pu(e,n,t){e=e|0;n=n|0;t=+t;At(u[e>>2]|0,n,$(t));return}function hu(e,n){e=e|0;n=n|0;Pt(u[e>>2]|0,n);return}function mu(e,n){e=e|0;n=n|0;mt(u[e>>2]|0,n);return}function vu(e,n){e=e|0;n=n|0;_t(u[e>>2]|0,n);return}function _u(e,n){e=e|0;n=+n;gt(u[e>>2]|0,$(n));return}function bu(e,n){e=e|0;n=+n;wt(u[e>>2]|0,$(n));return}function gu(e,n){e=e|0;n=+n;Et(u[e>>2]|0,$(n));return}function yu(e,n){e=e|0;n=+n;yt(u[e>>2]|0,$(n));return}function Du(e,n){e=e|0;n=+n;Dt(u[e>>2]|0,$(n));return}function wu(e,n){e=e|0;n=+n;It(u[e>>2]|0,$(n));return}function Eu(e,n){e=e|0;n=+n;Bt(u[e>>2]|0,$(n));return}function Tu(e){e=e|0;Ut(u[e>>2]|0);return}function Cu(e,n){e=e|0;n=+n;Wt(u[e>>2]|0,$(n));return}function ku(e,n){e=e|0;n=+n;zt(u[e>>2]|0,$(n));return}function Mu(e){e=e|0;Ht(u[e>>2]|0);return}function Su(e,n){e=e|0;n=+n;Yt(u[e>>2]|0,$(n));return}function Au(e,n){e=e|0;n=+n;qt(u[e>>2]|0,$(n));return}function xu(e,n){e=e|0;n=+n;$t(u[e>>2]|0,$(n));return}function Pu(e,n){e=e|0;n=+n;Xt(u[e>>2]|0,$(n));return}function Ru(e,n){e=e|0;n=+n;Jt(u[e>>2]|0,$(n));return}function Nu(e,n){e=e|0;n=+n;Qt(u[e>>2]|0,$(n));return}function Fu(e,n){e=e|0;n=+n;er(u[e>>2]|0,$(n));return}function Ou(e,n){e=e|0;n=+n;nr(u[e>>2]|0,$(n));return}function Lu(e,n){e=e|0;n=+n;rr(u[e>>2]|0,$(n));return}function Iu(e,n,t){e=e|0;n=n|0;t=+t;Ot(u[e>>2]|0,n,$(t));return}function Bu(e,n,t){e=e|0;n=n|0;t=+t;Rt(u[e>>2]|0,n,$(t));return}function Uu(e,n,t){e=e|0;n=n|0;t=+t;Nt(u[e>>2]|0,n,$(t));return}function ju(e){e=e|0;return dt(u[e>>2]|0)|0}function Wu(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0;r=h;h=h+16|0;i=r;Mt(i,u[n>>2]|0,t);zu(e,i);h=r;return}function zu(e,n){e=e|0;n=n|0;Hu(e,u[n+4>>2]|0,+$(s[n>>2]));return}function Hu(e,n,t){e=e|0;n=n|0;t=+t;u[e>>2]=n;f[e+8>>3]=t;return}function Gu(e){e=e|0;return ot(u[e>>2]|0)|0}function Yu(e){e=e|0;return lt(u[e>>2]|0)|0}function qu(e){e=e|0;return ft(u[e>>2]|0)|0}function Vu(e){e=e|0;return tt(u[e>>2]|0)|0}function $u(e){e=e|0;return ht(u[e>>2]|0)|0}function Xu(e){e=e|0;return it(u[e>>2]|0)|0}function Ku(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0;r=h;h=h+16|0;i=r;xt(i,u[n>>2]|0,t);zu(e,i);h=r;return}function Ju(e){e=e|0;return vt(u[e>>2]|0)|0}function Qu(e){e=e|0;return bt(u[e>>2]|0)|0}function Zu(e,n){e=e|0;n=n|0;var t=0,r=0;t=h;h=h+16|0;r=t;Tt(r,u[n>>2]|0);zu(e,r);h=t;return}function eo(e){e=e|0;return+ +$(Jn(u[e>>2]|0))}function no(e){e=e|0;return+ +$(Qn(u[e>>2]|0))}function to(e,n){e=e|0;n=n|0;var t=0,r=0;t=h;h=h+16|0;r=t;jt(r,u[n>>2]|0);zu(e,r);h=t;return}function ro(e,n){e=e|0;n=n|0;var t=0,r=0;t=h;h=h+16|0;r=t;Gt(r,u[n>>2]|0);zu(e,r);h=t;return}function io(e,n){e=e|0;n=n|0;var t=0,r=0;t=h;h=h+16|0;r=t;Vt(r,u[n>>2]|0);zu(e,r);h=t;return}function uo(e,n){e=e|0;n=n|0;var t=0,r=0;t=h;h=h+16|0;r=t;Kt(r,u[n>>2]|0);zu(e,r);h=t;return}function oo(e,n){e=e|0;n=n|0;var t=0,r=0;t=h;h=h+16|0;r=t;Zt(r,u[n>>2]|0);zu(e,r);h=t;return}function ao(e,n){e=e|0;n=n|0;var t=0,r=0;t=h;h=h+16|0;r=t;tr(r,u[n>>2]|0);zu(e,r);h=t;return}function lo(e){e=e|0;return+ +$(ir(u[e>>2]|0))}function so(e,n){e=e|0;n=n|0;return+ +$(Lt(u[e>>2]|0,n))}function fo(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0;r=h;h=h+16|0;i=r;Ft(i,u[n>>2]|0,t);zu(e,i);h=r;return}function co(e,n,t){e=e|0;n=n|0;t=t|0;zn(u[e>>2]|0,u[n>>2]|0,t);return}function po(e,n){e=e|0;n=n|0;Fn(u[e>>2]|0,u[n>>2]|0);return}function ho(e){e=e|0;return Pn(u[e>>2]|0)|0}function mo(e){e=e|0;e=Vn(u[e>>2]|0)|0;if(!e)e=0;else e=eu(e)|0;return e|0}function vo(e,n){e=e|0;n=n|0;e=Rn(u[e>>2]|0,n)|0;if(!e)e=0;else e=eu(e)|0;return e|0}function _o(e,n){e=e|0;n=n|0;var t=0,r=0;r=VM(4)|0;bo(r,n);t=e+4|0;n=u[t>>2]|0;u[t>>2]=r;if(n|0){Qi(n);XM(n)}Wn(u[e>>2]|0,1);return}function bo(e,n){e=e|0;n=n|0;Bo(e,n);return}function go(e,n,t,r,i,u){e=e|0;n=n|0;t=$(t);r=r|0;i=$(i);u=u|0;var o=0,a=0;o=h;h=h+16|0;a=o;yo(a,et(n)|0,+t,r,+i,u);s[e>>2]=$(+f[a>>3]);s[e+4>>2]=$(+f[a+8>>3]);h=o;return}function yo(e,n,t,r,i,o){e=e|0;n=n|0;t=+t;r=r|0;i=+i;o=o|0;var a=0,l=0,s=0,c=0,d=0;a=h;h=h+32|0;d=a+8|0;c=a+20|0;s=a;l=a+16|0;f[d>>3]=t;u[c>>2]=r;f[s>>3]=i;u[l>>2]=o;Do(e,u[n+4>>2]|0,d,c,s,l);h=a;return}function Do(e,n,t,r,i,o){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;o=o|0;var a=0,l=0;a=h;h=h+16|0;l=a;Ek(l);n=wo(n)|0;Eo(e,n,+f[t>>3],u[r>>2]|0,+f[i>>3],u[o>>2]|0);Ck(l);h=a;return}function wo(e){e=e|0;return u[e>>2]|0}function Eo(e,n,t,r,i,u){e=e|0;n=n|0;t=+t;r=r|0;i=+i;u=u|0;var o=0;o=Co(To()|0)|0;t=+ko(t);r=Mo(r)|0;i=+ko(i);So(e,on(0,o|0,n|0,+t,r|0,+i,Mo(u)|0)|0);return}function To(){var e=0;if(!(r[7608]|0)){Oo(9120);e=7608;u[e>>2]=1;u[e+4>>2]=0}return 9120}function Co(e){e=e|0;return u[e+8>>2]|0}function ko(e){e=+e;return+ +Fo(e)}function Mo(e){e=e|0;return No(e)|0}function So(e,n){e=e|0;n=n|0;var t=0,r=0,i=0;i=h;h=h+32|0;t=i;r=n;if(!(r&1)){u[e>>2]=u[n>>2];u[e+4>>2]=u[n+4>>2];u[e+8>>2]=u[n+8>>2];u[e+12>>2]=u[n+12>>2]}else{Ao(t,0);Be(r|0,t|0)|0;xo(e,t);Po(t)}h=i;return}function Ao(e,n){e=e|0;n=n|0;Ro(e,n);u[e+8>>2]=0;r[e+24>>0]=0;return}function xo(e,n){e=e|0;n=n|0;n=n+8|0;u[e>>2]=u[n>>2];u[e+4>>2]=u[n+4>>2];u[e+8>>2]=u[n+8>>2];u[e+12>>2]=u[n+12>>2];return}function Po(e){e=e|0;r[e+24>>0]=0;return}function Ro(e,n){e=e|0;n=n|0;u[e>>2]=n;return}function No(e){e=e|0;return e|0}function Fo(e){e=+e;return+e}function Oo(e){e=e|0;Io(e,Lo()|0,4);return}function Lo(){return 1064}function Io(e,n,t){e=e|0;n=n|0;t=t|0;u[e>>2]=n;u[e+4>>2]=t;u[e+8>>2]=nn(n|0,t+1|0)|0;return}function Bo(e,n){e=e|0;n=n|0;n=u[n>>2]|0;u[e>>2]=n;Ae(n|0);return}function Uo(e){e=e|0;var n=0,t=0;t=e+4|0;n=u[t>>2]|0;u[t>>2]=0;if(n|0){Qi(n);XM(n)}Wn(u[e>>2]|0,0);return}function jo(e){e=e|0;$n(u[e>>2]|0);return}function Wo(e){e=e|0;return Xn(u[e>>2]|0)|0}function zo(e,n,t,r){e=e|0;n=+n;t=+t;r=r|0;xr(u[e>>2]|0,$(n),$(t),r);return}function Ho(e){e=e|0;return+ +$(ur(u[e>>2]|0))}function Go(e){e=e|0;return+ +$(ar(u[e>>2]|0))}function Yo(e){e=e|0;return+ +$(or(u[e>>2]|0))}function qo(e){e=e|0;return+ +$(lr(u[e>>2]|0))}function Vo(e){e=e|0;return+ +$(sr(u[e>>2]|0))}function $o(e){e=e|0;return+ +$(fr(u[e>>2]|0))}function Xo(e,n){e=e|0;n=n|0;f[e>>3]=+$(ur(u[n>>2]|0));f[e+8>>3]=+$(ar(u[n>>2]|0));f[e+16>>3]=+$(or(u[n>>2]|0));f[e+24>>3]=+$(lr(u[n>>2]|0));f[e+32>>3]=+$(sr(u[n>>2]|0));f[e+40>>3]=+$(fr(u[n>>2]|0));return}function Ko(e,n){e=e|0;n=n|0;return+ +$(cr(u[e>>2]|0,n))}function Jo(e,n){e=e|0;n=n|0;return+ +$(dr(u[e>>2]|0,n))}function Qo(e,n){e=e|0;n=n|0;return+ +$(pr(u[e>>2]|0,n))}function Zo(){return In()|0}function ea(){na();ta();ra();ia();ua();oa();return}function na(){Wy(11713,4938,1);return}function ta(){ny(10448);return}function ra(){Og(10408);return}function ia(){Qb(10324);return}function ua(){Yv(10096);return}function oa(){aa(9132);return}function aa(e){e=e|0;var n=0,t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0,m=0,v=0,_=0,b=0,g=0,y=0,D=0,w=0,E=0,T=0,C=0,k=0,M=0,S=0,A=0,x=0,P=0,R=0,N=0,F=0,O=0,L=0,I=0,B=0,U=0,j=0,W=0,z=0,H=0,G=0,Y=0,q=0,V=0,$=0,X=0,K=0,J=0,Q=0,Z=0,ee=0,ne=0,te=0,re=0,ie=0,ue=0,oe=0,ae=0,le=0,se=0,fe=0,ce=0,de=0,pe=0,he=0,me=0,ve=0,_e=0,be=0,ge=0,ye=0,De=0,we=0,Ee=0,Te=0,Ce=0,ke=0,Me=0,Se=0,Ae=0,xe=0,Pe=0,Re=0;n=h;h=h+672|0;t=n+656|0;Re=n+648|0;Pe=n+640|0;xe=n+632|0;Ae=n+624|0;Se=n+616|0;Me=n+608|0;ke=n+600|0;Ce=n+592|0;Te=n+584|0;Ee=n+576|0;we=n+568|0;De=n+560|0;ye=n+552|0;ge=n+544|0;be=n+536|0;_e=n+528|0;ve=n+520|0;me=n+512|0;he=n+504|0;pe=n+496|0;de=n+488|0;ce=n+480|0;fe=n+472|0;se=n+464|0;le=n+456|0;ae=n+448|0;oe=n+440|0;ue=n+432|0;ie=n+424|0;re=n+416|0;te=n+408|0;ne=n+400|0;ee=n+392|0;Z=n+384|0;Q=n+376|0;J=n+368|0;K=n+360|0;X=n+352|0;$=n+344|0;V=n+336|0;q=n+328|0;Y=n+320|0;G=n+312|0;H=n+304|0;z=n+296|0;W=n+288|0;j=n+280|0;U=n+272|0;B=n+264|0;I=n+256|0;L=n+248|0;O=n+240|0;F=n+232|0;N=n+224|0;R=n+216|0;P=n+208|0;x=n+200|0;A=n+192|0;S=n+184|0;M=n+176|0;k=n+168|0;C=n+160|0;T=n+152|0;E=n+144|0;w=n+136|0;D=n+128|0;y=n+120|0;g=n+112|0;b=n+104|0;_=n+96|0;v=n+88|0;m=n+80|0;p=n+72|0;d=n+64|0;c=n+56|0;f=n+48|0;s=n+40|0;l=n+32|0;a=n+24|0;o=n+16|0;i=n+8|0;r=n;la(e,3646);sa(e,3651,2)|0;fa(e,3665,2)|0;ca(e,3682,18)|0;u[Re>>2]=19;u[Re+4>>2]=0;u[t>>2]=u[Re>>2];u[t+4>>2]=u[Re+4>>2];da(e,3690,t)|0;u[Pe>>2]=1;u[Pe+4>>2]=0;u[t>>2]=u[Pe>>2];u[t+4>>2]=u[Pe+4>>2];pa(e,3696,t)|0;u[xe>>2]=2;u[xe+4>>2]=0;u[t>>2]=u[xe>>2];u[t+4>>2]=u[xe+4>>2];ha(e,3706,t)|0;u[Ae>>2]=1;u[Ae+4>>2]=0;u[t>>2]=u[Ae>>2];u[t+4>>2]=u[Ae+4>>2];ma(e,3722,t)|0;u[Se>>2]=2;u[Se+4>>2]=0;u[t>>2]=u[Se>>2];u[t+4>>2]=u[Se+4>>2];ma(e,3734,t)|0;u[Me>>2]=3;u[Me+4>>2]=0;u[t>>2]=u[Me>>2];u[t+4>>2]=u[Me+4>>2];ha(e,3753,t)|0;u[ke>>2]=4;u[ke+4>>2]=0;u[t>>2]=u[ke>>2];u[t+4>>2]=u[ke+4>>2];ha(e,3769,t)|0;u[Ce>>2]=5;u[Ce+4>>2]=0;u[t>>2]=u[Ce>>2];u[t+4>>2]=u[Ce+4>>2];ha(e,3783,t)|0;u[Te>>2]=6;u[Te+4>>2]=0;u[t>>2]=u[Te>>2];u[t+4>>2]=u[Te+4>>2];ha(e,3796,t)|0;u[Ee>>2]=7;u[Ee+4>>2]=0;u[t>>2]=u[Ee>>2];u[t+4>>2]=u[Ee+4>>2];ha(e,3813,t)|0;u[we>>2]=8;u[we+4>>2]=0;u[t>>2]=u[we>>2];u[t+4>>2]=u[we+4>>2];ha(e,3825,t)|0;u[De>>2]=3;u[De+4>>2]=0;u[t>>2]=u[De>>2];u[t+4>>2]=u[De+4>>2];ma(e,3843,t)|0;u[ye>>2]=4;u[ye+4>>2]=0;u[t>>2]=u[ye>>2];u[t+4>>2]=u[ye+4>>2];ma(e,3853,t)|0;u[ge>>2]=9;u[ge+4>>2]=0;u[t>>2]=u[ge>>2];u[t+4>>2]=u[ge+4>>2];ha(e,3870,t)|0;u[be>>2]=10;u[be+4>>2]=0;u[t>>2]=u[be>>2];u[t+4>>2]=u[be+4>>2];ha(e,3884,t)|0;u[_e>>2]=11;u[_e+4>>2]=0;u[t>>2]=u[_e>>2];u[t+4>>2]=u[_e+4>>2];ha(e,3896,t)|0;u[ve>>2]=1;u[ve+4>>2]=0;u[t>>2]=u[ve>>2];u[t+4>>2]=u[ve+4>>2];va(e,3907,t)|0;u[me>>2]=2;u[me+4>>2]=0;u[t>>2]=u[me>>2];u[t+4>>2]=u[me+4>>2];va(e,3915,t)|0;u[he>>2]=3;u[he+4>>2]=0;u[t>>2]=u[he>>2];u[t+4>>2]=u[he+4>>2];va(e,3928,t)|0;u[pe>>2]=4;u[pe+4>>2]=0;u[t>>2]=u[pe>>2];u[t+4>>2]=u[pe+4>>2];va(e,3948,t)|0;u[de>>2]=5;u[de+4>>2]=0;u[t>>2]=u[de>>2];u[t+4>>2]=u[de+4>>2];va(e,3960,t)|0;u[ce>>2]=6;u[ce+4>>2]=0;u[t>>2]=u[ce>>2];u[t+4>>2]=u[ce+4>>2];va(e,3974,t)|0;u[fe>>2]=7;u[fe+4>>2]=0;u[t>>2]=u[fe>>2];u[t+4>>2]=u[fe+4>>2];va(e,3983,t)|0;u[se>>2]=20;u[se+4>>2]=0;u[t>>2]=u[se>>2];u[t+4>>2]=u[se+4>>2];da(e,3999,t)|0;u[le>>2]=8;u[le+4>>2]=0;u[t>>2]=u[le>>2];u[t+4>>2]=u[le+4>>2];va(e,4012,t)|0;u[ae>>2]=9;u[ae+4>>2]=0;u[t>>2]=u[ae>>2];u[t+4>>2]=u[ae+4>>2];va(e,4022,t)|0;u[oe>>2]=21;u[oe+4>>2]=0;u[t>>2]=u[oe>>2];u[t+4>>2]=u[oe+4>>2];da(e,4039,t)|0;u[ue>>2]=10;u[ue+4>>2]=0;u[t>>2]=u[ue>>2];u[t+4>>2]=u[ue+4>>2];va(e,4053,t)|0;u[ie>>2]=11;u[ie+4>>2]=0;u[t>>2]=u[ie>>2];u[t+4>>2]=u[ie+4>>2];va(e,4065,t)|0;u[re>>2]=12;u[re+4>>2]=0;u[t>>2]=u[re>>2];u[t+4>>2]=u[re+4>>2];va(e,4084,t)|0;u[te>>2]=13;u[te+4>>2]=0;u[t>>2]=u[te>>2];u[t+4>>2]=u[te+4>>2];va(e,4097,t)|0;u[ne>>2]=14;u[ne+4>>2]=0;u[t>>2]=u[ne>>2];u[t+4>>2]=u[ne+4>>2];va(e,4117,t)|0;u[ee>>2]=15;u[ee+4>>2]=0;u[t>>2]=u[ee>>2];u[t+4>>2]=u[ee+4>>2];va(e,4129,t)|0;u[Z>>2]=16;u[Z+4>>2]=0;u[t>>2]=u[Z>>2];u[t+4>>2]=u[Z+4>>2];va(e,4148,t)|0;u[Q>>2]=17;u[Q+4>>2]=0;u[t>>2]=u[Q>>2];u[t+4>>2]=u[Q+4>>2];va(e,4161,t)|0;u[J>>2]=18;u[J+4>>2]=0;u[t>>2]=u[J>>2];u[t+4>>2]=u[J+4>>2];va(e,4181,t)|0;u[K>>2]=5;u[K+4>>2]=0;u[t>>2]=u[K>>2];u[t+4>>2]=u[K+4>>2];ma(e,4196,t)|0;u[X>>2]=6;u[X+4>>2]=0;u[t>>2]=u[X>>2];u[t+4>>2]=u[X+4>>2];ma(e,4206,t)|0;u[$>>2]=7;u[$+4>>2]=0;u[t>>2]=u[$>>2];u[t+4>>2]=u[$+4>>2];ma(e,4217,t)|0;u[V>>2]=3;u[V+4>>2]=0;u[t>>2]=u[V>>2];u[t+4>>2]=u[V+4>>2];_a(e,4235,t)|0;u[q>>2]=1;u[q+4>>2]=0;u[t>>2]=u[q>>2];u[t+4>>2]=u[q+4>>2];ba(e,4251,t)|0;u[Y>>2]=4;u[Y+4>>2]=0;u[t>>2]=u[Y>>2];u[t+4>>2]=u[Y+4>>2];_a(e,4263,t)|0;u[G>>2]=5;u[G+4>>2]=0;u[t>>2]=u[G>>2];u[t+4>>2]=u[G+4>>2];_a(e,4279,t)|0;u[H>>2]=6;u[H+4>>2]=0;u[t>>2]=u[H>>2];u[t+4>>2]=u[H+4>>2];_a(e,4293,t)|0;u[z>>2]=7;u[z+4>>2]=0;u[t>>2]=u[z>>2];u[t+4>>2]=u[z+4>>2];_a(e,4306,t)|0;u[W>>2]=8;u[W+4>>2]=0;u[t>>2]=u[W>>2];u[t+4>>2]=u[W+4>>2];_a(e,4323,t)|0;u[j>>2]=9;u[j+4>>2]=0;u[t>>2]=u[j>>2];u[t+4>>2]=u[j+4>>2];_a(e,4335,t)|0;u[U>>2]=2;u[U+4>>2]=0;u[t>>2]=u[U>>2];u[t+4>>2]=u[U+4>>2];ba(e,4353,t)|0;u[B>>2]=12;u[B+4>>2]=0;u[t>>2]=u[B>>2];u[t+4>>2]=u[B+4>>2];ga(e,4363,t)|0;u[I>>2]=1;u[I+4>>2]=0;u[t>>2]=u[I>>2];u[t+4>>2]=u[I+4>>2];ya(e,4376,t)|0;u[L>>2]=2;u[L+4>>2]=0;u[t>>2]=u[L>>2];u[t+4>>2]=u[L+4>>2];ya(e,4388,t)|0;u[O>>2]=13;u[O+4>>2]=0;u[t>>2]=u[O>>2];u[t+4>>2]=u[O+4>>2];ga(e,4402,t)|0;u[F>>2]=14;u[F+4>>2]=0;u[t>>2]=u[F>>2];u[t+4>>2]=u[F+4>>2];ga(e,4411,t)|0;u[N>>2]=15;u[N+4>>2]=0;u[t>>2]=u[N>>2];u[t+4>>2]=u[N+4>>2];ga(e,4421,t)|0;u[R>>2]=16;u[R+4>>2]=0;u[t>>2]=u[R>>2];u[t+4>>2]=u[R+4>>2];ga(e,4433,t)|0;u[P>>2]=17;u[P+4>>2]=0;u[t>>2]=u[P>>2];u[t+4>>2]=u[P+4>>2];ga(e,4446,t)|0;u[x>>2]=18;u[x+4>>2]=0;u[t>>2]=u[x>>2];u[t+4>>2]=u[x+4>>2];ga(e,4458,t)|0;u[A>>2]=3;u[A+4>>2]=0;u[t>>2]=u[A>>2];u[t+4>>2]=u[A+4>>2];ya(e,4471,t)|0;u[S>>2]=1;u[S+4>>2]=0;u[t>>2]=u[S>>2];u[t+4>>2]=u[S+4>>2];Da(e,4486,t)|0;u[M>>2]=10;u[M+4>>2]=0;u[t>>2]=u[M>>2];u[t+4>>2]=u[M+4>>2];_a(e,4496,t)|0;u[k>>2]=11;u[k+4>>2]=0;u[t>>2]=u[k>>2];u[t+4>>2]=u[k+4>>2];_a(e,4508,t)|0;u[C>>2]=3;u[C+4>>2]=0;u[t>>2]=u[C>>2];u[t+4>>2]=u[C+4>>2];ba(e,4519,t)|0;u[T>>2]=4;u[T+4>>2]=0;u[t>>2]=u[T>>2];u[t+4>>2]=u[T+4>>2];wa(e,4530,t)|0;u[E>>2]=19;u[E+4>>2]=0;u[t>>2]=u[E>>2];u[t+4>>2]=u[E+4>>2];Ea(e,4542,t)|0;u[w>>2]=12;u[w+4>>2]=0;u[t>>2]=u[w>>2];u[t+4>>2]=u[w+4>>2];Ta(e,4554,t)|0;u[D>>2]=13;u[D+4>>2]=0;u[t>>2]=u[D>>2];u[t+4>>2]=u[D+4>>2];Ca(e,4568,t)|0;u[y>>2]=2;u[y+4>>2]=0;u[t>>2]=u[y>>2];u[t+4>>2]=u[y+4>>2];ka(e,4578,t)|0;u[g>>2]=20;u[g+4>>2]=0;u[t>>2]=u[g>>2];u[t+4>>2]=u[g+4>>2];Ma(e,4587,t)|0;u[b>>2]=22;u[b+4>>2]=0;u[t>>2]=u[b>>2];u[t+4>>2]=u[b+4>>2];da(e,4602,t)|0;u[_>>2]=23;u[_+4>>2]=0;u[t>>2]=u[_>>2];u[t+4>>2]=u[_+4>>2];da(e,4619,t)|0;u[v>>2]=14;u[v+4>>2]=0;u[t>>2]=u[v>>2];u[t+4>>2]=u[v+4>>2];Sa(e,4629,t)|0;u[m>>2]=1;u[m+4>>2]=0;u[t>>2]=u[m>>2];u[t+4>>2]=u[m+4>>2];Aa(e,4637,t)|0;u[p>>2]=4;u[p+4>>2]=0;u[t>>2]=u[p>>2];u[t+4>>2]=u[p+4>>2];ya(e,4653,t)|0;u[d>>2]=5;u[d+4>>2]=0;u[t>>2]=u[d>>2];u[t+4>>2]=u[d+4>>2];ya(e,4669,t)|0;u[c>>2]=6;u[c+4>>2]=0;u[t>>2]=u[c>>2];u[t+4>>2]=u[c+4>>2];ya(e,4686,t)|0;u[f>>2]=7;u[f+4>>2]=0;u[t>>2]=u[f>>2];u[t+4>>2]=u[f+4>>2];ya(e,4701,t)|0;u[s>>2]=8;u[s+4>>2]=0;u[t>>2]=u[s>>2];u[t+4>>2]=u[s+4>>2];ya(e,4719,t)|0;u[l>>2]=9;u[l+4>>2]=0;u[t>>2]=u[l>>2];u[t+4>>2]=u[l+4>>2];ya(e,4736,t)|0;u[a>>2]=21;u[a+4>>2]=0;u[t>>2]=u[a>>2];u[t+4>>2]=u[a+4>>2];xa(e,4754,t)|0;u[o>>2]=2;u[o+4>>2]=0;u[t>>2]=u[o>>2];u[t+4>>2]=u[o+4>>2];Da(e,4772,t)|0;u[i>>2]=3;u[i+4>>2]=0;u[t>>2]=u[i>>2];u[t+4>>2]=u[i+4>>2];Da(e,4790,t)|0;u[r>>2]=4;u[r+4>>2]=0;u[t>>2]=u[r>>2];u[t+4>>2]=u[r+4>>2];Da(e,4808,t)|0;h=n;return}function la(e,n){e=e|0;n=n|0;var t=0;t=Fv()|0;u[e>>2]=t;Ov(t,n);fD(u[e>>2]|0);return}function sa(e,n,t){e=e|0;n=n|0;t=t|0;_v(e,Ra(n)|0,t,0);return e|0}function fa(e,n,t){e=e|0;n=n|0;t=t|0;Km(e,Ra(n)|0,t,0);return e|0}function ca(e,n,t){e=e|0;n=n|0;t=t|0;Nm(e,Ra(n)|0,t,0);return e|0}function da(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=u[t+4>>2]|0;u[o>>2]=u[t>>2];u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];hm(e,n,i);h=r;return e|0}function pa(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=u[t+4>>2]|0;u[o>>2]=u[t>>2];u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];qh(e,n,i);h=r;return e|0}function ha(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=u[t+4>>2]|0;u[o>>2]=u[t>>2];u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];Mh(e,n,i);h=r;return e|0}function ma(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=u[t+4>>2]|0;u[o>>2]=u[t>>2];u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];lh(e,n,i);h=r;return e|0}function va(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=u[t+4>>2]|0;u[o>>2]=u[t>>2];u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];Hp(e,n,i);h=r;return e|0}function _a(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=u[t+4>>2]|0;u[o>>2]=u[t>>2];u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];Tp(e,n,i);h=r;return e|0}function ba(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=u[t+4>>2]|0;u[o>>2]=u[t>>2];u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];up(e,n,i);h=r;return e|0}function ga(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=u[t+4>>2]|0;u[o>>2]=u[t>>2];u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];Cd(e,n,i);h=r;return e|0}function ya(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=u[t+4>>2]|0;u[o>>2]=u[t>>2];u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];od(e,n,i);h=r;return e|0}function Da(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=u[t+4>>2]|0;u[o>>2]=u[t>>2];u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];Wc(e,n,i);h=r;return e|0}function wa(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=u[t+4>>2]|0;u[o>>2]=u[t>>2];u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];wc(e,n,i);h=r;return e|0}function Ea(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=u[t+4>>2]|0;u[o>>2]=u[t>>2];u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];ec(e,n,i);h=r;return e|0}function Ta(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=u[t+4>>2]|0;u[o>>2]=u[t>>2];u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];Ff(e,n,i);h=r;return e|0}function Ca(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=u[t+4>>2]|0;u[o>>2]=u[t>>2];u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];mf(e,n,i);h=r;return e|0}function ka(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=u[t+4>>2]|0;u[o>>2]=u[t>>2];u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];Ys(e,n,i);h=r;return e|0}function Ma(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=u[t+4>>2]|0;u[o>>2]=u[t>>2];u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];Ds(e,n,i);h=r;return e|0}function Sa(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=u[t+4>>2]|0;u[o>>2]=u[t>>2];u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];ns(e,n,i);h=r;return e|0}function Aa(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=u[t+4>>2]|0;u[o>>2]=u[t>>2];u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];xl(e,n,i);h=r;return e|0}function xa(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=u[t+4>>2]|0;u[o>>2]=u[t>>2];u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];Pa(e,n,i);h=r;return e|0}function Pa(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+16|0;i=r+8|0;o=r;l=u[t>>2]|0;a=u[t+4>>2]|0;t=Ra(n)|0;u[o>>2]=l;u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];Na(e,t,i,1);h=r;return}function Ra(e){e=e|0;return e|0}function Na(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0;i=h;h=h+32|0;o=i+16|0;c=i+8|0;l=i;f=u[t>>2]|0;s=u[t+4>>2]|0;a=u[e>>2]|0;e=Fa()|0;u[c>>2]=f;u[c+4>>2]=s;u[o>>2]=u[c>>2];u[o+4>>2]=u[c+4>>2];t=Oa(o)|0;u[l>>2]=f;u[l+4>>2]=s;u[o>>2]=u[l>>2];u[o+4>>2]=u[l+4>>2];Ia(a,n,e,t,La(o,r)|0,r);h=i;return}function Fa(){var e=0,n=0;if(!(r[7616]|0)){$a(9136);Le(24,9136,_|0)|0;n=7616;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(9136)|0)){e=9136;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));$a(9136)}return 9136}function Oa(e){e=e|0;return 0}function La(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0;c=h;h=h+32|0;i=c+24|0;a=c+16|0;l=c;s=c+8|0;o=u[e>>2]|0;r=u[e+4>>2]|0;u[l>>2]=o;u[l+4>>2]=r;d=Fa()|0;f=d+24|0;e=Wa(n,4)|0;u[s>>2]=e;n=d+28|0;t=u[n>>2]|0;if(t>>>0<(u[d+32>>2]|0)>>>0){u[a>>2]=o;u[a+4>>2]=r;u[i>>2]=u[a>>2];u[i+4>>2]=u[a+4>>2];za(t,i,e);e=(u[n>>2]|0)+12|0;u[n>>2]=e}else{Ha(f,l,s);e=u[n>>2]|0}h=c;return((e-(u[f>>2]|0)|0)/12|0)+-1|0}function Ia(e,n,t,r,i,o){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;o=o|0;var a=0,l=0,s=0,f=0,c=0,d=0,p=0,m=0;a=h;h=h+32|0;p=a+24|0;d=a+20|0;s=a+16|0;c=a+12|0;f=a+8|0;l=a+4|0;m=a;u[d>>2]=n;u[s>>2]=t;u[c>>2]=r;u[f>>2]=i;u[l>>2]=o;o=e+28|0;u[m>>2]=u[o>>2];u[p>>2]=u[m>>2];Ba(e+24|0,p,d,c,f,s,l)|0;u[o>>2]=u[u[o>>2]>>2];h=a;return}function Ba(e,n,t,r,i,o,a){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;o=o|0;a=a|0;e=Ua(n)|0;n=VM(24)|0;ja(n+4|0,u[t>>2]|0,u[r>>2]|0,u[i>>2]|0,u[o>>2]|0,u[a>>2]|0);u[n>>2]=u[e>>2];u[e>>2]=n;return n|0}function Ua(e){e=e|0;return u[e>>2]|0}function ja(e,n,t,r,i,o){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;o=o|0;u[e>>2]=n;u[e+4>>2]=t;u[e+8>>2]=r;u[e+12>>2]=i;u[e+16>>2]=o;return}function Wa(e,n){e=e|0;n=n|0;return n|e|0}function za(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=u[n+4>>2]|0;u[e>>2]=u[n>>2];u[e+4>>2]=r;u[e+8>>2]=t;return}function Ha(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0;f=h;h=h+48|0;r=f+32|0;a=f+24|0;l=f;s=e+4|0;i=(((u[s>>2]|0)-(u[e>>2]|0)|0)/12|0)+1|0;o=Ga(e)|0;if(o>>>0<i>>>0)jM(e);else{c=u[e>>2]|0;p=((u[e+8>>2]|0)-c|0)/12|0;d=p<<1;Ya(l,p>>>0<o>>>1>>>0?d>>>0<i>>>0?i:d:o,((u[s>>2]|0)-c|0)/12|0,e+8|0);s=l+8|0;o=u[s>>2]|0;i=u[n+4>>2]|0;t=u[t>>2]|0;u[a>>2]=u[n>>2];u[a+4>>2]=i;u[r>>2]=u[a>>2];u[r+4>>2]=u[a+4>>2];za(o,r,t);u[s>>2]=(u[s>>2]|0)+12;qa(e,l);Va(l);h=f;return}}function Ga(e){e=e|0;return 357913941}function Ya(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>357913941)$e();else{i=VM(n*12|0)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t*12|0)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n*12|0);return}function qa(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(((i|0)/-12|0)*12|0)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function Va(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~(((r+-12-n|0)>>>0)/12|0)*12|0);e=u[e>>2]|0;if(e|0)XM(e);return}function $a(e){e=e|0;Qa(e);return}function Xa(e){e=e|0;Ja(e+24|0);return}function Ka(e){e=e|0;return u[e>>2]|0}function Ja(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~(((n+-12-r|0)>>>0)/12|0)*12|0);XM(t)}return}function Qa(e){e=e|0;var n=0;n=Za()|0;tl(e,2,3,n,el()|0,0);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function Za(){return 9228}function el(){return 1140}function nl(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0;t=h;h=h+16|0;r=t+8|0;i=t;o=rl(e)|0;e=u[o+4>>2]|0;u[i>>2]=u[o>>2];u[i+4>>2]=e;u[r>>2]=u[i>>2];u[r+4>>2]=u[i+4>>2];n=il(n,r)|0;h=t;return n|0}function tl(e,n,t,r,i,o){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;o=o|0;u[e>>2]=n;u[e+4>>2]=t;u[e+8>>2]=r;u[e+12>>2]=i;u[e+16>>2]=o;return}function rl(e){e=e|0;return(u[(Fa()|0)+24>>2]|0)+(e*12|0)|0}function il(e,n){e=e|0;n=n|0;var t=0,r=0,i=0;i=h;h=h+48|0;r=i;t=u[n>>2]|0;n=u[n+4>>2]|0;e=e+(n>>1)|0;if(n&1)t=u[(u[e>>2]|0)+t>>2]|0;mA[t&31](r,e);r=ul(r)|0;h=i;return r|0}function ul(e){e=e|0;var n=0,t=0,r=0,i=0;i=h;h=h+32|0;n=i+12|0;t=i;r=al(ol()|0)|0;if(!r)e=dl(e)|0;else{ll(n,r);sl(t,n);fl(e,t);e=cl(n)|0}h=i;return e|0}function ol(){var e=0;if(!(r[7632]|0)){El(9184);Le(25,9184,_|0)|0;e=7632;u[e>>2]=1;u[e+4>>2]=0}return 9184}function al(e){e=e|0;return u[e+36>>2]|0}function ll(e,n){e=e|0;n=n|0;u[e>>2]=n;u[e+4>>2]=e;u[e+8>>2]=0;return}function sl(e,n){e=e|0;n=n|0;u[e>>2]=u[n>>2];u[e+4>>2]=u[n+4>>2];u[e+8>>2]=0;return}function fl(e,n){e=e|0;n=n|0;_l(n,e,e+8|0,e+16|0,e+24|0,e+32|0,e+40|0)|0;return}function cl(e){e=e|0;return u[(u[e+4>>2]|0)+8>>2]|0}function dl(e){e=e|0;var n=0,t=0,r=0,i=0,o=0,a=0,l=0,s=0;s=h;h=h+16|0;t=s+4|0;r=s;i=jE(8)|0;o=i;a=VM(48)|0;l=a;n=l+48|0;do{u[l>>2]=u[e>>2];l=l+4|0;e=e+4|0}while((l|0)<(n|0));n=o+4|0;u[n>>2]=a;l=VM(8)|0;a=u[n>>2]|0;u[r>>2]=0;u[t>>2]=u[r>>2];pl(l,a,t);u[i>>2]=l;h=s;return o|0}function pl(e,n,t){e=e|0;n=n|0;t=t|0;u[e>>2]=n;t=VM(16)|0;u[t+4>>2]=0;u[t+8>>2]=0;u[t>>2]=1092;u[t+12>>2]=n;u[e+4>>2]=t;return}function hl(e){e=e|0;WM(e);XM(e);return}function ml(e){e=e|0;e=u[e+12>>2]|0;if(e|0)XM(e);return}function vl(e){e=e|0;XM(e);return}function _l(e,n,t,r,i,o,a){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;o=o|0;a=a|0;o=bl(u[e>>2]|0,n,t,r,i,o,a)|0;a=e+4|0;u[(u[a>>2]|0)+8>>2]=o;return u[(u[a>>2]|0)+8>>2]|0}function bl(e,n,t,r,i,u,o){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;u=u|0;o=o|0;var a=0,l=0;a=h;h=h+16|0;l=a;Ek(l);e=wo(e)|0;o=gl(e,+f[n>>3],+f[t>>3],+f[r>>3],+f[i>>3],+f[u>>3],+f[o>>3])|0;Ck(l);h=a;return o|0}function gl(e,n,t,r,i,u,o){e=e|0;n=+n;t=+t;r=+r;i=+i;u=+u;o=+o;var a=0;a=Co(yl()|0)|0;n=+ko(n);t=+ko(t);r=+ko(r);i=+ko(i);u=+ko(u);return Me(0,a|0,e|0,+n,+t,+r,+i,+u,+ +ko(o))|0}function yl(){var e=0;if(!(r[7624]|0)){Dl(9172);e=7624;u[e>>2]=1;u[e+4>>2]=0}return 9172}function Dl(e){e=e|0;Io(e,wl()|0,6);return}function wl(){return 1112}function El(e){e=e|0;Al(e);return}function Tl(e){e=e|0;Cl(e+24|0);kl(e+16|0);return}function Cl(e){e=e|0;Sl(e);return}function kl(e){e=e|0;Ml(e);return}function Ml(e){e=e|0;var n=0,t=0;n=u[e>>2]|0;if(n|0)do{t=n;n=u[n>>2]|0;XM(t)}while((n|0)!=0);u[e>>2]=0;return}function Sl(e){e=e|0;var n=0,t=0;n=u[e>>2]|0;if(n|0)do{t=n;n=u[n>>2]|0;XM(t)}while((n|0)!=0);u[e>>2]=0;return}function Al(e){e=e|0;var n=0;u[e+16>>2]=0;u[e+20>>2]=0;n=e+24|0;u[n>>2]=0;u[e+28>>2]=n;u[e+36>>2]=0;r[e+40>>0]=0;r[e+41>>0]=0;return}function xl(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+16|0;i=r+8|0;o=r;l=u[t>>2]|0;a=u[t+4>>2]|0;t=Ra(n)|0;u[o>>2]=l;u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];Pl(e,t,i,0);h=r;return}function Pl(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0;i=h;h=h+32|0;o=i+16|0;c=i+8|0;l=i;f=u[t>>2]|0;s=u[t+4>>2]|0;a=u[e>>2]|0;e=Rl()|0;u[c>>2]=f;u[c+4>>2]=s;u[o>>2]=u[c>>2];u[o+4>>2]=u[c+4>>2];t=Nl(o)|0;u[l>>2]=f;u[l+4>>2]=s;u[o>>2]=u[l>>2];u[o+4>>2]=u[l+4>>2];Ia(a,n,e,t,Fl(o,r)|0,r);h=i;return}function Rl(){var e=0,n=0;if(!(r[7640]|0)){Wl(9232);Le(26,9232,_|0)|0;n=7640;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(9232)|0)){e=9232;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));Wl(9232)}return 9232}function Nl(e){e=e|0;return 0}function Fl(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0;c=h;h=h+32|0;i=c+24|0;a=c+16|0;l=c;s=c+8|0;o=u[e>>2]|0;r=u[e+4>>2]|0;u[l>>2]=o;u[l+4>>2]=r;d=Rl()|0;f=d+24|0;e=Wa(n,4)|0;u[s>>2]=e;n=d+28|0;t=u[n>>2]|0;if(t>>>0<(u[d+32>>2]|0)>>>0){u[a>>2]=o;u[a+4>>2]=r;u[i>>2]=u[a>>2];u[i+4>>2]=u[a+4>>2];Ol(t,i,e);e=(u[n>>2]|0)+12|0;u[n>>2]=e}else{Ll(f,l,s);e=u[n>>2]|0}h=c;return((e-(u[f>>2]|0)|0)/12|0)+-1|0}function Ol(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=u[n+4>>2]|0;u[e>>2]=u[n>>2];u[e+4>>2]=r;u[e+8>>2]=t;return}function Ll(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0;f=h;h=h+48|0;r=f+32|0;a=f+24|0;l=f;s=e+4|0;i=(((u[s>>2]|0)-(u[e>>2]|0)|0)/12|0)+1|0;o=Il(e)|0;if(o>>>0<i>>>0)jM(e);else{c=u[e>>2]|0;p=((u[e+8>>2]|0)-c|0)/12|0;d=p<<1;Bl(l,p>>>0<o>>>1>>>0?d>>>0<i>>>0?i:d:o,((u[s>>2]|0)-c|0)/12|0,e+8|0);s=l+8|0;o=u[s>>2]|0;i=u[n+4>>2]|0;t=u[t>>2]|0;u[a>>2]=u[n>>2];u[a+4>>2]=i;u[r>>2]=u[a>>2];u[r+4>>2]=u[a+4>>2];Ol(o,r,t);u[s>>2]=(u[s>>2]|0)+12;Ul(e,l);jl(l);h=f;return}}function Il(e){e=e|0;return 357913941}function Bl(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>357913941)$e();else{i=VM(n*12|0)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t*12|0)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n*12|0);return}function Ul(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(((i|0)/-12|0)*12|0)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function jl(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~(((r+-12-n|0)>>>0)/12|0)*12|0);e=u[e>>2]|0;if(e|0)XM(e);return}function Wl(e){e=e|0;Gl(e);return}function zl(e){e=e|0;Hl(e+24|0);return}function Hl(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~(((n+-12-r|0)>>>0)/12|0)*12|0);XM(t)}return}function Gl(e){e=e|0;var n=0;n=Za()|0;tl(e,2,1,n,Yl()|0,3);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function Yl(){return 1144}function ql(e,n,t,r,i){e=e|0;n=n|0;t=+t;r=+r;i=i|0;var o=0,a=0,l=0,s=0;o=h;h=h+16|0;a=o+8|0;l=o;s=Vl(e)|0;e=u[s+4>>2]|0;u[l>>2]=u[s>>2];u[l+4>>2]=e;u[a>>2]=u[l>>2];u[a+4>>2]=u[l+4>>2];$l(n,a,t,r,i);h=o;return}function Vl(e){e=e|0;return(u[(Rl()|0)+24>>2]|0)+(e*12|0)|0}function $l(e,n,t,r,i){e=e|0;n=n|0;t=+t;r=+r;i=i|0;var o=0,a=0,l=0,s=0,f=0;f=h;h=h+16|0;a=f+2|0;l=f+1|0;s=f;o=u[n>>2]|0;n=u[n+4>>2]|0;e=e+(n>>1)|0;if(n&1)o=u[(u[e>>2]|0)+o>>2]|0;Xl(a,t);t=+Kl(a,t);Xl(l,r);r=+Kl(l,r);Jl(s,i);s=Ql(s,i)|0;_A[o&1](e,t,r,s);h=f;return}function Xl(e,n){e=e|0;n=+n;return}function Kl(e,n){e=e|0;n=+n;return+ +es(n)}function Jl(e,n){e=e|0;n=n|0;return}function Ql(e,n){e=e|0;n=n|0;return Zl(n)|0}function Zl(e){e=e|0;return e|0}function es(e){e=+e;return+e}function ns(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+16|0;i=r+8|0;o=r;l=u[t>>2]|0;a=u[t+4>>2]|0;t=Ra(n)|0;u[o>>2]=l;u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];ts(e,t,i,1);h=r;return}function ts(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0;i=h;h=h+32|0;o=i+16|0;c=i+8|0;l=i;f=u[t>>2]|0;s=u[t+4>>2]|0;a=u[e>>2]|0;e=rs()|0;u[c>>2]=f;u[c+4>>2]=s;u[o>>2]=u[c>>2];u[o+4>>2]=u[c+4>>2];t=is(o)|0;u[l>>2]=f;u[l+4>>2]=s;u[o>>2]=u[l>>2];u[o+4>>2]=u[l+4>>2];Ia(a,n,e,t,us(o,r)|0,r);h=i;return}function rs(){var e=0,n=0;if(!(r[7648]|0)){ds(9268);Le(27,9268,_|0)|0;n=7648;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(9268)|0)){e=9268;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));ds(9268)}return 9268}function is(e){e=e|0;return 0}function us(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0;c=h;h=h+32|0;i=c+24|0;a=c+16|0;l=c;s=c+8|0;o=u[e>>2]|0;r=u[e+4>>2]|0;u[l>>2]=o;u[l+4>>2]=r;d=rs()|0;f=d+24|0;e=Wa(n,4)|0;u[s>>2]=e;n=d+28|0;t=u[n>>2]|0;if(t>>>0<(u[d+32>>2]|0)>>>0){u[a>>2]=o;u[a+4>>2]=r;u[i>>2]=u[a>>2];u[i+4>>2]=u[a+4>>2];os(t,i,e);e=(u[n>>2]|0)+12|0;u[n>>2]=e}else{as(f,l,s);e=u[n>>2]|0}h=c;return((e-(u[f>>2]|0)|0)/12|0)+-1|0}function os(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=u[n+4>>2]|0;u[e>>2]=u[n>>2];u[e+4>>2]=r;u[e+8>>2]=t;return}function as(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0;f=h;h=h+48|0;r=f+32|0;a=f+24|0;l=f;s=e+4|0;i=(((u[s>>2]|0)-(u[e>>2]|0)|0)/12|0)+1|0;o=ls(e)|0;if(o>>>0<i>>>0)jM(e);else{c=u[e>>2]|0;p=((u[e+8>>2]|0)-c|0)/12|0;d=p<<1;ss(l,p>>>0<o>>>1>>>0?d>>>0<i>>>0?i:d:o,((u[s>>2]|0)-c|0)/12|0,e+8|0);s=l+8|0;o=u[s>>2]|0;i=u[n+4>>2]|0;t=u[t>>2]|0;u[a>>2]=u[n>>2];u[a+4>>2]=i;u[r>>2]=u[a>>2];u[r+4>>2]=u[a+4>>2];os(o,r,t);u[s>>2]=(u[s>>2]|0)+12;fs(e,l);cs(l);h=f;return}}function ls(e){e=e|0;return 357913941}function ss(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>357913941)$e();else{i=VM(n*12|0)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t*12|0)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n*12|0);return}function fs(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(((i|0)/-12|0)*12|0)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function cs(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~(((r+-12-n|0)>>>0)/12|0)*12|0);e=u[e>>2]|0;if(e|0)XM(e);return}function ds(e){e=e|0;ms(e);return}function ps(e){e=e|0;hs(e+24|0);return}function hs(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~(((n+-12-r|0)>>>0)/12|0)*12|0);XM(t)}return}function ms(e){e=e|0;var n=0;n=Za()|0;tl(e,2,4,n,vs()|0,0);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function vs(){return 1160}function _s(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0;t=h;h=h+16|0;r=t+8|0;i=t;o=bs(e)|0;e=u[o+4>>2]|0;u[i>>2]=u[o>>2];u[i+4>>2]=e;u[r>>2]=u[i>>2];u[r+4>>2]=u[i+4>>2];n=gs(n,r)|0;h=t;return n|0}function bs(e){e=e|0;return(u[(rs()|0)+24>>2]|0)+(e*12|0)|0}function gs(e,n){e=e|0;n=n|0;var t=0;t=u[n>>2]|0;n=u[n+4>>2]|0;e=e+(n>>1)|0;if(n&1)t=u[(u[e>>2]|0)+t>>2]|0;return ys(vA[t&31](e)|0)|0}function ys(e){e=e|0;return e&1|0}function Ds(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+16|0;i=r+8|0;o=r;l=u[t>>2]|0;a=u[t+4>>2]|0;t=Ra(n)|0;u[o>>2]=l;u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];ws(e,t,i,0);h=r;return}function ws(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0;i=h;h=h+32|0;o=i+16|0;c=i+8|0;l=i;f=u[t>>2]|0;s=u[t+4>>2]|0;a=u[e>>2]|0;e=Es()|0;u[c>>2]=f;u[c+4>>2]=s;u[o>>2]=u[c>>2];u[o+4>>2]=u[c+4>>2];t=Ts(o)|0;u[l>>2]=f;u[l+4>>2]=s;u[o>>2]=u[l>>2];u[o+4>>2]=u[l+4>>2];Ia(a,n,e,t,Cs(o,r)|0,r);h=i;return}function Es(){var e=0,n=0;if(!(r[7656]|0)){Rs(9304);Le(28,9304,_|0)|0;n=7656;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(9304)|0)){e=9304;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));Rs(9304)}return 9304}function Ts(e){e=e|0;return 0}function Cs(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0;c=h;h=h+32|0;i=c+24|0;a=c+16|0;l=c;s=c+8|0;o=u[e>>2]|0;r=u[e+4>>2]|0;u[l>>2]=o;u[l+4>>2]=r;d=Es()|0;f=d+24|0;e=Wa(n,4)|0;u[s>>2]=e;n=d+28|0;t=u[n>>2]|0;if(t>>>0<(u[d+32>>2]|0)>>>0){u[a>>2]=o;u[a+4>>2]=r;u[i>>2]=u[a>>2];u[i+4>>2]=u[a+4>>2];ks(t,i,e);e=(u[n>>2]|0)+12|0;u[n>>2]=e}else{Ms(f,l,s);e=u[n>>2]|0}h=c;return((e-(u[f>>2]|0)|0)/12|0)+-1|0}function ks(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=u[n+4>>2]|0;u[e>>2]=u[n>>2];u[e+4>>2]=r;u[e+8>>2]=t;return}function Ms(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0;f=h;h=h+48|0;r=f+32|0;a=f+24|0;l=f;s=e+4|0;i=(((u[s>>2]|0)-(u[e>>2]|0)|0)/12|0)+1|0;o=Ss(e)|0;if(o>>>0<i>>>0)jM(e);else{c=u[e>>2]|0;p=((u[e+8>>2]|0)-c|0)/12|0;d=p<<1;As(l,p>>>0<o>>>1>>>0?d>>>0<i>>>0?i:d:o,((u[s>>2]|0)-c|0)/12|0,e+8|0);s=l+8|0;o=u[s>>2]|0;i=u[n+4>>2]|0;t=u[t>>2]|0;u[a>>2]=u[n>>2];u[a+4>>2]=i;u[r>>2]=u[a>>2];u[r+4>>2]=u[a+4>>2];ks(o,r,t);u[s>>2]=(u[s>>2]|0)+12;xs(e,l);Ps(l);h=f;return}}function Ss(e){e=e|0;return 357913941}function As(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>357913941)$e();else{i=VM(n*12|0)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t*12|0)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n*12|0);return}function xs(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(((i|0)/-12|0)*12|0)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function Ps(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~(((r+-12-n|0)>>>0)/12|0)*12|0);e=u[e>>2]|0;if(e|0)XM(e);return}function Rs(e){e=e|0;Os(e);return}function Ns(e){e=e|0;Fs(e+24|0);return}function Fs(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~(((n+-12-r|0)>>>0)/12|0)*12|0);XM(t)}return}function Os(e){e=e|0;var n=0;n=Za()|0;tl(e,2,5,n,Ls()|0,1);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function Ls(){return 1164}function Is(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=Bs(e)|0;e=u[a+4>>2]|0;u[o>>2]=u[a>>2];u[o+4>>2]=e;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];Us(n,i,t);h=r;return}function Bs(e){e=e|0;return(u[(Es()|0)+24>>2]|0)+(e*12|0)|0}function Us(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0;o=h;h=h+16|0;i=o;r=u[n>>2]|0;n=u[n+4>>2]|0;e=e+(n>>1)|0;if(n&1)r=u[(u[e>>2]|0)+r>>2]|0;js(i,t);t=Ws(i,t)|0;mA[r&31](e,t);zs(i);h=o;return}function js(e,n){e=e|0;n=n|0;Hs(e,n);return}function Ws(e,n){e=e|0;n=n|0;return e|0}function zs(e){e=e|0;Qi(e);return}function Hs(e,n){e=e|0;n=n|0;Gs(e,n);return}function Gs(e,n){e=e|0;n=n|0;u[e>>2]=n;return}function Ys(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+16|0;i=r+8|0;o=r;l=u[t>>2]|0;a=u[t+4>>2]|0;t=Ra(n)|0;u[o>>2]=l;u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];qs(e,t,i,0);h=r;return}function qs(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0;i=h;h=h+32|0;o=i+16|0;c=i+8|0;l=i;f=u[t>>2]|0;s=u[t+4>>2]|0;a=u[e>>2]|0;e=Vs()|0;u[c>>2]=f;u[c+4>>2]=s;u[o>>2]=u[c>>2];u[o+4>>2]=u[c+4>>2];t=$s(o)|0;u[l>>2]=f;u[l+4>>2]=s;u[o>>2]=u[l>>2];u[o+4>>2]=u[l+4>>2];Ia(a,n,e,t,Xs(o,r)|0,r);h=i;return}function Vs(){var e=0,n=0;if(!(r[7664]|0)){tf(9340);Le(29,9340,_|0)|0;n=7664;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(9340)|0)){e=9340;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));tf(9340)}return 9340}function $s(e){e=e|0;return 0}function Xs(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0;c=h;h=h+32|0;i=c+24|0;a=c+16|0;l=c;s=c+8|0;o=u[e>>2]|0;r=u[e+4>>2]|0;u[l>>2]=o;u[l+4>>2]=r;d=Vs()|0;f=d+24|0;e=Wa(n,4)|0;u[s>>2]=e;n=d+28|0;t=u[n>>2]|0;if(t>>>0<(u[d+32>>2]|0)>>>0){u[a>>2]=o;u[a+4>>2]=r;u[i>>2]=u[a>>2];u[i+4>>2]=u[a+4>>2];Ks(t,i,e);e=(u[n>>2]|0)+12|0;u[n>>2]=e}else{Js(f,l,s);e=u[n>>2]|0}h=c;return((e-(u[f>>2]|0)|0)/12|0)+-1|0}function Ks(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=u[n+4>>2]|0;u[e>>2]=u[n>>2];u[e+4>>2]=r;u[e+8>>2]=t;return}function Js(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0;f=h;h=h+48|0;r=f+32|0;a=f+24|0;l=f;s=e+4|0;i=(((u[s>>2]|0)-(u[e>>2]|0)|0)/12|0)+1|0;o=Qs(e)|0;if(o>>>0<i>>>0)jM(e);else{c=u[e>>2]|0;p=((u[e+8>>2]|0)-c|0)/12|0;d=p<<1;Zs(l,p>>>0<o>>>1>>>0?d>>>0<i>>>0?i:d:o,((u[s>>2]|0)-c|0)/12|0,e+8|0);s=l+8|0;o=u[s>>2]|0;i=u[n+4>>2]|0;t=u[t>>2]|0;u[a>>2]=u[n>>2];u[a+4>>2]=i;u[r>>2]=u[a>>2];u[r+4>>2]=u[a+4>>2];Ks(o,r,t);u[s>>2]=(u[s>>2]|0)+12;ef(e,l);nf(l);h=f;return}}function Qs(e){e=e|0;return 357913941}function Zs(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>357913941)$e();else{i=VM(n*12|0)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t*12|0)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n*12|0);return}function ef(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(((i|0)/-12|0)*12|0)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function nf(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~(((r+-12-n|0)>>>0)/12|0)*12|0);e=u[e>>2]|0;if(e|0)XM(e);return}function tf(e){e=e|0;of(e);return}function rf(e){e=e|0;uf(e+24|0);return}function uf(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~(((n+-12-r|0)>>>0)/12|0)*12|0);XM(t)}return}function of(e){e=e|0;var n=0;n=Za()|0;tl(e,2,4,n,af()|0,1);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function af(){return 1180}function lf(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=sf(e)|0;e=u[a+4>>2]|0;u[o>>2]=u[a>>2];u[o+4>>2]=e;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];t=ff(n,i,t)|0;h=r;return t|0}function sf(e){e=e|0;return(u[(Vs()|0)+24>>2]|0)+(e*12|0)|0}function ff(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0;o=h;h=h+16|0;i=o;r=u[n>>2]|0;n=u[n+4>>2]|0;e=e+(n>>1)|0;if(n&1)r=u[(u[e>>2]|0)+r>>2]|0;cf(i,t);i=df(i,t)|0;i=pf(EA[r&15](e,i)|0)|0;h=o;return i|0}function cf(e,n){e=e|0;n=n|0;return}function df(e,n){e=e|0;n=n|0;return hf(n)|0}function pf(e){e=e|0;return e|0}function hf(e){e=e|0;return e|0}function mf(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+16|0;i=r+8|0;o=r;l=u[t>>2]|0;a=u[t+4>>2]|0;t=Ra(n)|0;u[o>>2]=l;u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];vf(e,t,i,0);h=r;return}function vf(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0;i=h;h=h+32|0;o=i+16|0;c=i+8|0;l=i;f=u[t>>2]|0;s=u[t+4>>2]|0;a=u[e>>2]|0;e=_f()|0;u[c>>2]=f;u[c+4>>2]=s;u[o>>2]=u[c>>2];u[o+4>>2]=u[c+4>>2];t=bf(o)|0;u[l>>2]=f;u[l+4>>2]=s;u[o>>2]=u[l>>2];u[o+4>>2]=u[l+4>>2];Ia(a,n,e,t,gf(o,r)|0,r);h=i;return}function _f(){var e=0,n=0;if(!(r[7672]|0)){kf(9376);Le(30,9376,_|0)|0;n=7672;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(9376)|0)){e=9376;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));kf(9376)}return 9376}function bf(e){e=e|0;return 0}function gf(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0;c=h;h=h+32|0;i=c+24|0;a=c+16|0;l=c;s=c+8|0;o=u[e>>2]|0;r=u[e+4>>2]|0;u[l>>2]=o;u[l+4>>2]=r;d=_f()|0;f=d+24|0;e=Wa(n,4)|0;u[s>>2]=e;n=d+28|0;t=u[n>>2]|0;if(t>>>0<(u[d+32>>2]|0)>>>0){u[a>>2]=o;u[a+4>>2]=r;u[i>>2]=u[a>>2];u[i+4>>2]=u[a+4>>2];yf(t,i,e);e=(u[n>>2]|0)+12|0;u[n>>2]=e}else{Df(f,l,s);e=u[n>>2]|0}h=c;return((e-(u[f>>2]|0)|0)/12|0)+-1|0}function yf(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=u[n+4>>2]|0;u[e>>2]=u[n>>2];u[e+4>>2]=r;u[e+8>>2]=t;return}function Df(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0;f=h;h=h+48|0;r=f+32|0;a=f+24|0;l=f;s=e+4|0;i=(((u[s>>2]|0)-(u[e>>2]|0)|0)/12|0)+1|0;o=wf(e)|0;if(o>>>0<i>>>0)jM(e);else{c=u[e>>2]|0;p=((u[e+8>>2]|0)-c|0)/12|0;d=p<<1;Ef(l,p>>>0<o>>>1>>>0?d>>>0<i>>>0?i:d:o,((u[s>>2]|0)-c|0)/12|0,e+8|0);s=l+8|0;o=u[s>>2]|0;i=u[n+4>>2]|0;t=u[t>>2]|0;u[a>>2]=u[n>>2];u[a+4>>2]=i;u[r>>2]=u[a>>2];u[r+4>>2]=u[a+4>>2];yf(o,r,t);u[s>>2]=(u[s>>2]|0)+12;Tf(e,l);Cf(l);h=f;return}}function wf(e){e=e|0;return 357913941}function Ef(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>357913941)$e();else{i=VM(n*12|0)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t*12|0)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n*12|0);return}function Tf(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(((i|0)/-12|0)*12|0)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function Cf(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~(((r+-12-n|0)>>>0)/12|0)*12|0);e=u[e>>2]|0;if(e|0)XM(e);return}function kf(e){e=e|0;Af(e);return}function Mf(e){e=e|0;Sf(e+24|0);return}function Sf(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~(((n+-12-r|0)>>>0)/12|0)*12|0);XM(t)}return}function Af(e){e=e|0;var n=0;n=Za()|0;tl(e,2,5,n,xf()|0,0);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function xf(){return 1196}function Pf(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0;t=h;h=h+16|0;r=t+8|0;i=t;o=Rf(e)|0;e=u[o+4>>2]|0;u[i>>2]=u[o>>2];u[i+4>>2]=e;u[r>>2]=u[i>>2];u[r+4>>2]=u[i+4>>2];n=Nf(n,r)|0;h=t;return n|0}function Rf(e){e=e|0;return(u[(_f()|0)+24>>2]|0)+(e*12|0)|0}function Nf(e,n){e=e|0;n=n|0;var t=0;t=u[n>>2]|0;n=u[n+4>>2]|0;e=e+(n>>1)|0;if(n&1)t=u[(u[e>>2]|0)+t>>2]|0;return pf(vA[t&31](e)|0)|0}function Ff(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+16|0;i=r+8|0;o=r;l=u[t>>2]|0;a=u[t+4>>2]|0;t=Ra(n)|0;u[o>>2]=l;u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];Of(e,t,i,1);h=r;return}function Of(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0;i=h;h=h+32|0;o=i+16|0;c=i+8|0;l=i;f=u[t>>2]|0;s=u[t+4>>2]|0;a=u[e>>2]|0;e=Lf()|0;u[c>>2]=f;u[c+4>>2]=s;u[o>>2]=u[c>>2];u[o+4>>2]=u[c+4>>2];t=If(o)|0;u[l>>2]=f;u[l+4>>2]=s;u[o>>2]=u[l>>2];u[o+4>>2]=u[l+4>>2];Ia(a,n,e,t,Bf(o,r)|0,r);h=i;return}function Lf(){var e=0,n=0;if(!(r[7680]|0)){Yf(9412);Le(31,9412,_|0)|0;n=7680;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(9412)|0)){e=9412;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));Yf(9412)}return 9412}function If(e){e=e|0;return 0}function Bf(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0;c=h;h=h+32|0;i=c+24|0;a=c+16|0;l=c;s=c+8|0;o=u[e>>2]|0;r=u[e+4>>2]|0;u[l>>2]=o;u[l+4>>2]=r;d=Lf()|0;f=d+24|0;e=Wa(n,4)|0;u[s>>2]=e;n=d+28|0;t=u[n>>2]|0;if(t>>>0<(u[d+32>>2]|0)>>>0){u[a>>2]=o;u[a+4>>2]=r;u[i>>2]=u[a>>2];u[i+4>>2]=u[a+4>>2];Uf(t,i,e);e=(u[n>>2]|0)+12|0;u[n>>2]=e}else{jf(f,l,s);e=u[n>>2]|0}h=c;return((e-(u[f>>2]|0)|0)/12|0)+-1|0}function Uf(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=u[n+4>>2]|0;u[e>>2]=u[n>>2];u[e+4>>2]=r;u[e+8>>2]=t;return}function jf(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0;f=h;h=h+48|0;r=f+32|0;a=f+24|0;l=f;s=e+4|0;i=(((u[s>>2]|0)-(u[e>>2]|0)|0)/12|0)+1|0;o=Wf(e)|0;if(o>>>0<i>>>0)jM(e);else{c=u[e>>2]|0;p=((u[e+8>>2]|0)-c|0)/12|0;d=p<<1;zf(l,p>>>0<o>>>1>>>0?d>>>0<i>>>0?i:d:o,((u[s>>2]|0)-c|0)/12|0,e+8|0);s=l+8|0;o=u[s>>2]|0;i=u[n+4>>2]|0;t=u[t>>2]|0;u[a>>2]=u[n>>2];u[a+4>>2]=i;u[r>>2]=u[a>>2];u[r+4>>2]=u[a+4>>2];Uf(o,r,t);u[s>>2]=(u[s>>2]|0)+12;Hf(e,l);Gf(l);h=f;return}}function Wf(e){e=e|0;return 357913941}function zf(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>357913941)$e();else{i=VM(n*12|0)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t*12|0)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n*12|0);return}function Hf(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(((i|0)/-12|0)*12|0)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function Gf(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~(((r+-12-n|0)>>>0)/12|0)*12|0);e=u[e>>2]|0;if(e|0)XM(e);return}function Yf(e){e=e|0;$f(e);return}function qf(e){e=e|0;Vf(e+24|0);return}function Vf(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~(((n+-12-r|0)>>>0)/12|0)*12|0);XM(t)}return}function $f(e){e=e|0;var n=0;n=Za()|0;tl(e,2,6,n,Xf()|0,0);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function Xf(){return 1200}function Kf(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0;t=h;h=h+16|0;r=t+8|0;i=t;o=Jf(e)|0;e=u[o+4>>2]|0;u[i>>2]=u[o>>2];u[i+4>>2]=e;u[r>>2]=u[i>>2];u[r+4>>2]=u[i+4>>2];n=Qf(n,r)|0;h=t;return n|0}function Jf(e){e=e|0;return(u[(Lf()|0)+24>>2]|0)+(e*12|0)|0}function Qf(e,n){e=e|0;n=n|0;var t=0;t=u[n>>2]|0;n=u[n+4>>2]|0;e=e+(n>>1)|0;if(n&1)t=u[(u[e>>2]|0)+t>>2]|0;return Zf(vA[t&31](e)|0)|0}function Zf(e){e=e|0;return e|0}function ec(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+16|0;i=r+8|0;o=r;l=u[t>>2]|0;a=u[t+4>>2]|0;t=Ra(n)|0;u[o>>2]=l;u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];nc(e,t,i,0);h=r;return}function nc(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0;i=h;h=h+32|0;o=i+16|0;c=i+8|0;l=i;f=u[t>>2]|0;s=u[t+4>>2]|0;a=u[e>>2]|0;e=tc()|0;u[c>>2]=f;u[c+4>>2]=s;u[o>>2]=u[c>>2];u[o+4>>2]=u[c+4>>2];t=rc(o)|0;u[l>>2]=f;u[l+4>>2]=s;u[o>>2]=u[l>>2];u[o+4>>2]=u[l+4>>2];Ia(a,n,e,t,ic(o,r)|0,r);h=i;return}function tc(){var e=0,n=0;if(!(r[7688]|0)){cc(9448);Le(32,9448,_|0)|0;n=7688;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(9448)|0)){e=9448;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));cc(9448)}return 9448}function rc(e){e=e|0;return 0}function ic(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0;c=h;h=h+32|0;i=c+24|0;a=c+16|0;l=c;s=c+8|0;o=u[e>>2]|0;r=u[e+4>>2]|0;u[l>>2]=o;u[l+4>>2]=r;d=tc()|0;f=d+24|0;e=Wa(n,4)|0;u[s>>2]=e;n=d+28|0;t=u[n>>2]|0;if(t>>>0<(u[d+32>>2]|0)>>>0){u[a>>2]=o;u[a+4>>2]=r;u[i>>2]=u[a>>2];u[i+4>>2]=u[a+4>>2];uc(t,i,e);e=(u[n>>2]|0)+12|0;u[n>>2]=e}else{oc(f,l,s);e=u[n>>2]|0}h=c;return((e-(u[f>>2]|0)|0)/12|0)+-1|0}function uc(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=u[n+4>>2]|0;u[e>>2]=u[n>>2];u[e+4>>2]=r;u[e+8>>2]=t;return}function oc(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0;f=h;h=h+48|0;r=f+32|0;a=f+24|0;l=f;s=e+4|0;i=(((u[s>>2]|0)-(u[e>>2]|0)|0)/12|0)+1|0;o=ac(e)|0;if(o>>>0<i>>>0)jM(e);else{c=u[e>>2]|0;p=((u[e+8>>2]|0)-c|0)/12|0;d=p<<1;lc(l,p>>>0<o>>>1>>>0?d>>>0<i>>>0?i:d:o,((u[s>>2]|0)-c|0)/12|0,e+8|0);s=l+8|0;o=u[s>>2]|0;i=u[n+4>>2]|0;t=u[t>>2]|0;u[a>>2]=u[n>>2];u[a+4>>2]=i;u[r>>2]=u[a>>2];u[r+4>>2]=u[a+4>>2];uc(o,r,t);u[s>>2]=(u[s>>2]|0)+12;sc(e,l);fc(l);h=f;return}}function ac(e){e=e|0;return 357913941}function lc(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>357913941)$e();else{i=VM(n*12|0)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t*12|0)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n*12|0);return}function sc(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(((i|0)/-12|0)*12|0)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function fc(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~(((r+-12-n|0)>>>0)/12|0)*12|0);e=u[e>>2]|0;if(e|0)XM(e);return}function cc(e){e=e|0;hc(e);return}function dc(e){e=e|0;pc(e+24|0);return}function pc(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~(((n+-12-r|0)>>>0)/12|0)*12|0);XM(t)}return}function hc(e){e=e|0;var n=0;n=Za()|0;tl(e,2,6,n,mc()|0,1);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function mc(){return 1204}function vc(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=_c(e)|0;e=u[a+4>>2]|0;u[o>>2]=u[a>>2];u[o+4>>2]=e;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];bc(n,i,t);h=r;return}function _c(e){e=e|0;return(u[(tc()|0)+24>>2]|0)+(e*12|0)|0}function bc(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0;o=h;h=h+16|0;i=o;r=u[n>>2]|0;n=u[n+4>>2]|0;e=e+(n>>1)|0;if(n&1)r=u[(u[e>>2]|0)+r>>2]|0;gc(i,t);i=yc(i,t)|0;mA[r&31](e,i);h=o;return}function gc(e,n){e=e|0;n=n|0;return}function yc(e,n){e=e|0;n=n|0;return Dc(n)|0}function Dc(e){e=e|0;return e|0}function wc(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+16|0;i=r+8|0;o=r;l=u[t>>2]|0;a=u[t+4>>2]|0;t=Ra(n)|0;u[o>>2]=l;u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];Ec(e,t,i,0);h=r;return}function Ec(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0;i=h;h=h+32|0;o=i+16|0;c=i+8|0;l=i;f=u[t>>2]|0;s=u[t+4>>2]|0;a=u[e>>2]|0;e=Tc()|0;u[c>>2]=f;u[c+4>>2]=s;u[o>>2]=u[c>>2];u[o+4>>2]=u[c+4>>2];t=Cc(o)|0;u[l>>2]=f;u[l+4>>2]=s;u[o>>2]=u[l>>2];u[o+4>>2]=u[l+4>>2];Ia(a,n,e,t,kc(o,r)|0,r);h=i;return}function Tc(){var e=0,n=0;if(!(r[7696]|0)){Nc(9484);Le(33,9484,_|0)|0;n=7696;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(9484)|0)){e=9484;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));Nc(9484)}return 9484}function Cc(e){e=e|0;return 0}function kc(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0;c=h;h=h+32|0;i=c+24|0;a=c+16|0;l=c;s=c+8|0;o=u[e>>2]|0;r=u[e+4>>2]|0;u[l>>2]=o;u[l+4>>2]=r;d=Tc()|0;f=d+24|0;e=Wa(n,4)|0;u[s>>2]=e;n=d+28|0;t=u[n>>2]|0;if(t>>>0<(u[d+32>>2]|0)>>>0){u[a>>2]=o;u[a+4>>2]=r;u[i>>2]=u[a>>2];u[i+4>>2]=u[a+4>>2];Mc(t,i,e);e=(u[n>>2]|0)+12|0;u[n>>2]=e}else{Sc(f,l,s);e=u[n>>2]|0}h=c;return((e-(u[f>>2]|0)|0)/12|0)+-1|0}function Mc(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=u[n+4>>2]|0;u[e>>2]=u[n>>2];u[e+4>>2]=r;u[e+8>>2]=t;return}function Sc(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0;f=h;h=h+48|0;r=f+32|0;a=f+24|0;l=f;s=e+4|0;i=(((u[s>>2]|0)-(u[e>>2]|0)|0)/12|0)+1|0;o=Ac(e)|0;if(o>>>0<i>>>0)jM(e);else{c=u[e>>2]|0;p=((u[e+8>>2]|0)-c|0)/12|0;d=p<<1;xc(l,p>>>0<o>>>1>>>0?d>>>0<i>>>0?i:d:o,((u[s>>2]|0)-c|0)/12|0,e+8|0);s=l+8|0;o=u[s>>2]|0;i=u[n+4>>2]|0;t=u[t>>2]|0;u[a>>2]=u[n>>2];u[a+4>>2]=i;u[r>>2]=u[a>>2];u[r+4>>2]=u[a+4>>2];Mc(o,r,t);u[s>>2]=(u[s>>2]|0)+12;Pc(e,l);Rc(l);h=f;return}}function Ac(e){e=e|0;return 357913941}function xc(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>357913941)$e();else{i=VM(n*12|0)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t*12|0)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n*12|0);return}function Pc(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(((i|0)/-12|0)*12|0)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function Rc(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~(((r+-12-n|0)>>>0)/12|0)*12|0);e=u[e>>2]|0;if(e|0)XM(e);return}function Nc(e){e=e|0;Lc(e);return}function Fc(e){e=e|0;Oc(e+24|0);return}function Oc(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~(((n+-12-r|0)>>>0)/12|0)*12|0);XM(t)}return}function Lc(e){e=e|0;var n=0;n=Za()|0;tl(e,2,1,n,Ic()|0,2);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function Ic(){return 1212}function Bc(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0;i=h;h=h+16|0;o=i+8|0;a=i;l=Uc(e)|0;e=u[l+4>>2]|0;u[a>>2]=u[l>>2];u[a+4>>2]=e;u[o>>2]=u[a>>2];u[o+4>>2]=u[a+4>>2];jc(n,o,t,r);h=i;return}function Uc(e){e=e|0;return(u[(Tc()|0)+24>>2]|0)+(e*12|0)|0}function jc(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0;l=h;h=h+16|0;o=l+1|0;a=l;i=u[n>>2]|0;n=u[n+4>>2]|0;e=e+(n>>1)|0;if(n&1)i=u[(u[e>>2]|0)+i>>2]|0;gc(o,t);o=yc(o,t)|0;cf(a,r);a=df(a,r)|0;PA[i&15](e,o,a);h=l;return}function Wc(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+16|0;i=r+8|0;o=r;l=u[t>>2]|0;a=u[t+4>>2]|0;t=Ra(n)|0;u[o>>2]=l;u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];zc(e,t,i,1);h=r;return}function zc(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0;i=h;h=h+32|0;o=i+16|0;c=i+8|0;l=i;f=u[t>>2]|0;s=u[t+4>>2]|0;a=u[e>>2]|0;e=Hc()|0;u[c>>2]=f;u[c+4>>2]=s;u[o>>2]=u[c>>2];u[o+4>>2]=u[c+4>>2];t=Gc(o)|0;u[l>>2]=f;u[l+4>>2]=s;u[o>>2]=u[l>>2];u[o+4>>2]=u[l+4>>2];Ia(a,n,e,t,Yc(o,r)|0,r);h=i;return}function Hc(){var e=0,n=0;if(!(r[7704]|0)){Qc(9520);Le(34,9520,_|0)|0;n=7704;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(9520)|0)){e=9520;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));Qc(9520)}return 9520}function Gc(e){e=e|0;return 0}function Yc(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0;c=h;h=h+32|0;i=c+24|0;a=c+16|0;l=c;s=c+8|0;o=u[e>>2]|0;r=u[e+4>>2]|0;u[l>>2]=o;u[l+4>>2]=r;d=Hc()|0;f=d+24|0;e=Wa(n,4)|0;u[s>>2]=e;n=d+28|0;t=u[n>>2]|0;if(t>>>0<(u[d+32>>2]|0)>>>0){u[a>>2]=o;u[a+4>>2]=r;u[i>>2]=u[a>>2];u[i+4>>2]=u[a+4>>2];qc(t,i,e);e=(u[n>>2]|0)+12|0;u[n>>2]=e}else{Vc(f,l,s);e=u[n>>2]|0}h=c;return((e-(u[f>>2]|0)|0)/12|0)+-1|0}function qc(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=u[n+4>>2]|0;u[e>>2]=u[n>>2];u[e+4>>2]=r;u[e+8>>2]=t;return}function Vc(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0;f=h;h=h+48|0;r=f+32|0;a=f+24|0;l=f;s=e+4|0;i=(((u[s>>2]|0)-(u[e>>2]|0)|0)/12|0)+1|0;o=$c(e)|0;if(o>>>0<i>>>0)jM(e);else{c=u[e>>2]|0;p=((u[e+8>>2]|0)-c|0)/12|0;d=p<<1;Xc(l,p>>>0<o>>>1>>>0?d>>>0<i>>>0?i:d:o,((u[s>>2]|0)-c|0)/12|0,e+8|0);s=l+8|0;o=u[s>>2]|0;i=u[n+4>>2]|0;t=u[t>>2]|0;u[a>>2]=u[n>>2];u[a+4>>2]=i;u[r>>2]=u[a>>2];u[r+4>>2]=u[a+4>>2];qc(o,r,t);u[s>>2]=(u[s>>2]|0)+12;Kc(e,l);Jc(l);h=f;return}}function $c(e){e=e|0;return 357913941}function Xc(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>357913941)$e();else{i=VM(n*12|0)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t*12|0)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n*12|0);return}function Kc(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(((i|0)/-12|0)*12|0)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function Jc(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~(((r+-12-n|0)>>>0)/12|0)*12|0);e=u[e>>2]|0;if(e|0)XM(e);return}function Qc(e){e=e|0;nd(e);return}function Zc(e){e=e|0;ed(e+24|0);return}function ed(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~(((n+-12-r|0)>>>0)/12|0)*12|0);XM(t)}return}function nd(e){e=e|0;var n=0;n=Za()|0;tl(e,2,1,n,td()|0,1);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function td(){return 1224}function rd(e,n,t){e=e|0;n=n|0;t=t|0;var r=0.0,i=0,o=0,a=0,l=0;i=h;h=h+16|0;o=i+8|0;a=i;l=id(e)|0;e=u[l+4>>2]|0;u[a>>2]=u[l>>2];u[a+4>>2]=e;u[o>>2]=u[a>>2];u[o+4>>2]=u[a+4>>2];r=+ud(n,o,t);h=i;return+r}function id(e){e=e|0;return(u[(Hc()|0)+24>>2]|0)+(e*12|0)|0}function ud(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0.0;o=h;h=h+16|0;i=o;r=u[n>>2]|0;n=u[n+4>>2]|0;e=e+(n>>1)|0;if(n&1)r=u[(u[e>>2]|0)+r>>2]|0;Jl(i,t);i=Ql(i,t)|0;a=+Fo(+kA[r&7](e,i));h=o;return+a}function od(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+16|0;i=r+8|0;o=r;l=u[t>>2]|0;a=u[t+4>>2]|0;t=Ra(n)|0;u[o>>2]=l;u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];ad(e,t,i,1);h=r;return}function ad(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0;i=h;h=h+32|0;o=i+16|0;c=i+8|0;l=i;f=u[t>>2]|0;s=u[t+4>>2]|0;a=u[e>>2]|0;e=ld()|0;u[c>>2]=f;u[c+4>>2]=s;u[o>>2]=u[c>>2];u[o+4>>2]=u[c+4>>2];t=sd(o)|0;u[l>>2]=f;u[l+4>>2]=s;u[o>>2]=u[l>>2];u[o+4>>2]=u[l+4>>2];Ia(a,n,e,t,fd(o,r)|0,r);h=i;return}function ld(){var e=0,n=0;if(!(r[7712]|0)){_d(9556);Le(35,9556,_|0)|0;n=7712;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(9556)|0)){e=9556;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));_d(9556)}return 9556}function sd(e){e=e|0;return 0}function fd(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0;c=h;h=h+32|0;i=c+24|0;a=c+16|0;l=c;s=c+8|0;o=u[e>>2]|0;r=u[e+4>>2]|0;u[l>>2]=o;u[l+4>>2]=r;d=ld()|0;f=d+24|0;e=Wa(n,4)|0;u[s>>2]=e;n=d+28|0;t=u[n>>2]|0;if(t>>>0<(u[d+32>>2]|0)>>>0){u[a>>2]=o;u[a+4>>2]=r;u[i>>2]=u[a>>2];u[i+4>>2]=u[a+4>>2];cd(t,i,e);e=(u[n>>2]|0)+12|0;u[n>>2]=e}else{dd(f,l,s);e=u[n>>2]|0}h=c;return((e-(u[f>>2]|0)|0)/12|0)+-1|0}function cd(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=u[n+4>>2]|0;u[e>>2]=u[n>>2];u[e+4>>2]=r;u[e+8>>2]=t;return}function dd(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0;f=h;h=h+48|0;r=f+32|0;a=f+24|0;l=f;s=e+4|0;i=(((u[s>>2]|0)-(u[e>>2]|0)|0)/12|0)+1|0;o=pd(e)|0;if(o>>>0<i>>>0)jM(e);else{c=u[e>>2]|0;p=((u[e+8>>2]|0)-c|0)/12|0;d=p<<1;hd(l,p>>>0<o>>>1>>>0?d>>>0<i>>>0?i:d:o,((u[s>>2]|0)-c|0)/12|0,e+8|0);s=l+8|0;o=u[s>>2]|0;i=u[n+4>>2]|0;t=u[t>>2]|0;u[a>>2]=u[n>>2];u[a+4>>2]=i;u[r>>2]=u[a>>2];u[r+4>>2]=u[a+4>>2];cd(o,r,t);u[s>>2]=(u[s>>2]|0)+12;md(e,l);vd(l);h=f;return}}function pd(e){e=e|0;return 357913941}function hd(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>357913941)$e();else{i=VM(n*12|0)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t*12|0)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n*12|0);return}function md(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(((i|0)/-12|0)*12|0)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function vd(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~(((r+-12-n|0)>>>0)/12|0)*12|0);e=u[e>>2]|0;if(e|0)XM(e);return}function _d(e){e=e|0;yd(e);return}function bd(e){e=e|0;gd(e+24|0);return}function gd(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~(((n+-12-r|0)>>>0)/12|0)*12|0);XM(t)}return}function yd(e){e=e|0;var n=0;n=Za()|0;tl(e,2,5,n,Dd()|0,0);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function Dd(){return 1232}function wd(e,n){e=e|0;n=n|0;var t=0.0,r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=Ed(e)|0;e=u[a+4>>2]|0;u[o>>2]=u[a>>2];u[o+4>>2]=e;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];t=+Td(n,i);h=r;return+t}function Ed(e){e=e|0;return(u[(ld()|0)+24>>2]|0)+(e*12|0)|0}function Td(e,n){e=e|0;n=n|0;var t=0;t=u[n>>2]|0;n=u[n+4>>2]|0;e=e+(n>>1)|0;if(n&1)t=u[(u[e>>2]|0)+t>>2]|0;return+ +Fo(+DA[t&15](e))}function Cd(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+16|0;i=r+8|0;o=r;l=u[t>>2]|0;a=u[t+4>>2]|0;t=Ra(n)|0;u[o>>2]=l;u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];kd(e,t,i,1);h=r;return}function kd(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0;i=h;h=h+32|0;o=i+16|0;c=i+8|0;l=i;f=u[t>>2]|0;s=u[t+4>>2]|0;a=u[e>>2]|0;e=Md()|0;u[c>>2]=f;u[c+4>>2]=s;u[o>>2]=u[c>>2];u[o+4>>2]=u[c+4>>2];t=Sd(o)|0;u[l>>2]=f;u[l+4>>2]=s;u[o>>2]=u[l>>2];u[o+4>>2]=u[l+4>>2];Ia(a,n,e,t,Ad(o,r)|0,r);h=i;return}function Md(){var e=0,n=0;if(!(r[7720]|0)){Ld(9592);Le(36,9592,_|0)|0;n=7720;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(9592)|0)){e=9592;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));Ld(9592)}return 9592}function Sd(e){e=e|0;return 0}function Ad(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0;c=h;h=h+32|0;i=c+24|0;a=c+16|0;l=c;s=c+8|0;o=u[e>>2]|0;r=u[e+4>>2]|0;u[l>>2]=o;u[l+4>>2]=r;d=Md()|0;f=d+24|0;e=Wa(n,4)|0;u[s>>2]=e;n=d+28|0;t=u[n>>2]|0;if(t>>>0<(u[d+32>>2]|0)>>>0){u[a>>2]=o;u[a+4>>2]=r;u[i>>2]=u[a>>2];u[i+4>>2]=u[a+4>>2];xd(t,i,e);e=(u[n>>2]|0)+12|0;u[n>>2]=e}else{Pd(f,l,s);e=u[n>>2]|0}h=c;return((e-(u[f>>2]|0)|0)/12|0)+-1|0}function xd(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=u[n+4>>2]|0;u[e>>2]=u[n>>2];u[e+4>>2]=r;u[e+8>>2]=t;return}function Pd(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0;f=h;h=h+48|0;r=f+32|0;a=f+24|0;l=f;s=e+4|0;i=(((u[s>>2]|0)-(u[e>>2]|0)|0)/12|0)+1|0;o=Rd(e)|0;if(o>>>0<i>>>0)jM(e);else{c=u[e>>2]|0;p=((u[e+8>>2]|0)-c|0)/12|0;d=p<<1;Nd(l,p>>>0<o>>>1>>>0?d>>>0<i>>>0?i:d:o,((u[s>>2]|0)-c|0)/12|0,e+8|0);s=l+8|0;o=u[s>>2]|0;i=u[n+4>>2]|0;t=u[t>>2]|0;u[a>>2]=u[n>>2];u[a+4>>2]=i;u[r>>2]=u[a>>2];u[r+4>>2]=u[a+4>>2];xd(o,r,t);u[s>>2]=(u[s>>2]|0)+12;Fd(e,l);Od(l);h=f;return}}function Rd(e){e=e|0;return 357913941}function Nd(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>357913941)$e();else{i=VM(n*12|0)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t*12|0)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n*12|0);return}function Fd(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(((i|0)/-12|0)*12|0)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function Od(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~(((r+-12-n|0)>>>0)/12|0)*12|0);e=u[e>>2]|0;if(e|0)XM(e);return}function Ld(e){e=e|0;Ud(e);return}function Id(e){e=e|0;Bd(e+24|0);return}function Bd(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~(((n+-12-r|0)>>>0)/12|0)*12|0);XM(t)}return}function Ud(e){e=e|0;var n=0;n=Za()|0;tl(e,2,7,n,jd()|0,0);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function jd(){return 1276}function Wd(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0;t=h;h=h+16|0;r=t+8|0;i=t;o=zd(e)|0;e=u[o+4>>2]|0;u[i>>2]=u[o>>2];u[i+4>>2]=e;u[r>>2]=u[i>>2];u[r+4>>2]=u[i+4>>2];n=Hd(n,r)|0;h=t;return n|0}function zd(e){e=e|0;return(u[(Md()|0)+24>>2]|0)+(e*12|0)|0}function Hd(e,n){e=e|0;n=n|0;var t=0,r=0,i=0;i=h;h=h+16|0;r=i;t=u[n>>2]|0;n=u[n+4>>2]|0;e=e+(n>>1)|0;if(n&1)t=u[(u[e>>2]|0)+t>>2]|0;mA[t&31](r,e);r=Gd(r)|0;h=i;return r|0}function Gd(e){e=e|0;var n=0,t=0,r=0,i=0;i=h;h=h+32|0;n=i+12|0;t=i;r=al(Yd()|0)|0;if(!r)e=Vd(e)|0;else{ll(n,r);sl(t,n);qd(e,t);e=cl(n)|0}h=i;return e|0}function Yd(){var e=0;if(!(r[7736]|0)){ip(9640);Le(25,9640,_|0)|0;e=7736;u[e>>2]=1;u[e+4>>2]=0}return 9640}function qd(e,n){e=e|0;n=n|0;Qd(n,e,e+8|0)|0;return}function Vd(e){e=e|0;var n=0,t=0,r=0,i=0,o=0,a=0,l=0;t=h;h=h+16|0;i=t+4|0;a=t;r=jE(8)|0;n=r;l=VM(16)|0;u[l>>2]=u[e>>2];u[l+4>>2]=u[e+4>>2];u[l+8>>2]=u[e+8>>2];u[l+12>>2]=u[e+12>>2];o=n+4|0;u[o>>2]=l;e=VM(8)|0;o=u[o>>2]|0;u[a>>2]=0;u[i>>2]=u[a>>2];$d(e,o,i);u[r>>2]=e;h=t;return n|0}function $d(e,n,t){e=e|0;n=n|0;t=t|0;u[e>>2]=n;t=VM(16)|0;u[t+4>>2]=0;u[t+8>>2]=0;u[t>>2]=1244;u[t+12>>2]=n;u[e+4>>2]=t;return}function Xd(e){e=e|0;WM(e);XM(e);return}function Kd(e){e=e|0;e=u[e+12>>2]|0;if(e|0)XM(e);return}function Jd(e){e=e|0;XM(e);return}function Qd(e,n,t){e=e|0;n=n|0;t=t|0;n=Zd(u[e>>2]|0,n,t)|0;t=e+4|0;u[(u[t>>2]|0)+8>>2]=n;return u[(u[t>>2]|0)+8>>2]|0}function Zd(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0;r=h;h=h+16|0;i=r;Ek(i);e=wo(e)|0;t=ep(e,u[n>>2]|0,+f[t>>3])|0;Ck(i);h=r;return t|0}function ep(e,n,t){e=e|0;n=n|0;t=+t;var r=0;r=Co(np()|0)|0;n=Mo(n)|0;return Se(0,r|0,e|0,n|0,+ +ko(t))|0}function np(){var e=0;if(!(r[7728]|0)){tp(9628);e=7728;u[e>>2]=1;u[e+4>>2]=0}return 9628}function tp(e){e=e|0;Io(e,rp()|0,2);return}function rp(){return 1264}function ip(e){e=e|0;Al(e);return}function up(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+16|0;i=r+8|0;o=r;l=u[t>>2]|0;a=u[t+4>>2]|0;t=Ra(n)|0;u[o>>2]=l;u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];op(e,t,i,1);h=r;return}function op(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0;i=h;h=h+32|0;o=i+16|0;c=i+8|0;l=i;f=u[t>>2]|0;s=u[t+4>>2]|0;a=u[e>>2]|0;e=ap()|0;u[c>>2]=f;u[c+4>>2]=s;u[o>>2]=u[c>>2];u[o+4>>2]=u[c+4>>2];t=lp(o)|0;u[l>>2]=f;u[l+4>>2]=s;u[o>>2]=u[l>>2];u[o+4>>2]=u[l+4>>2];Ia(a,n,e,t,sp(o,r)|0,r);h=i;return}function ap(){var e=0,n=0;if(!(r[7744]|0)){vp(9684);Le(37,9684,_|0)|0;n=7744;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(9684)|0)){e=9684;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));vp(9684)}return 9684}function lp(e){e=e|0;return 0}function sp(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0;c=h;h=h+32|0;i=c+24|0;a=c+16|0;l=c;s=c+8|0;o=u[e>>2]|0;r=u[e+4>>2]|0;u[l>>2]=o;u[l+4>>2]=r;d=ap()|0;f=d+24|0;e=Wa(n,4)|0;u[s>>2]=e;n=d+28|0;t=u[n>>2]|0;if(t>>>0<(u[d+32>>2]|0)>>>0){u[a>>2]=o;u[a+4>>2]=r;u[i>>2]=u[a>>2];u[i+4>>2]=u[a+4>>2];fp(t,i,e);e=(u[n>>2]|0)+12|0;u[n>>2]=e}else{cp(f,l,s);e=u[n>>2]|0}h=c;return((e-(u[f>>2]|0)|0)/12|0)+-1|0}function fp(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=u[n+4>>2]|0;u[e>>2]=u[n>>2];u[e+4>>2]=r;u[e+8>>2]=t;return}function cp(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0;f=h;h=h+48|0;r=f+32|0;a=f+24|0;l=f;s=e+4|0;i=(((u[s>>2]|0)-(u[e>>2]|0)|0)/12|0)+1|0;o=dp(e)|0;if(o>>>0<i>>>0)jM(e);else{c=u[e>>2]|0;p=((u[e+8>>2]|0)-c|0)/12|0;d=p<<1;pp(l,p>>>0<o>>>1>>>0?d>>>0<i>>>0?i:d:o,((u[s>>2]|0)-c|0)/12|0,e+8|0);s=l+8|0;o=u[s>>2]|0;i=u[n+4>>2]|0;t=u[t>>2]|0;u[a>>2]=u[n>>2];u[a+4>>2]=i;u[r>>2]=u[a>>2];u[r+4>>2]=u[a+4>>2];fp(o,r,t);u[s>>2]=(u[s>>2]|0)+12;hp(e,l);mp(l);h=f;return}}function dp(e){e=e|0;return 357913941}function pp(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>357913941)$e();else{i=VM(n*12|0)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t*12|0)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n*12|0);return}function hp(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(((i|0)/-12|0)*12|0)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function mp(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~(((r+-12-n|0)>>>0)/12|0)*12|0);e=u[e>>2]|0;if(e|0)XM(e);return}function vp(e){e=e|0;gp(e);return}function _p(e){e=e|0;bp(e+24|0);return}function bp(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~(((n+-12-r|0)>>>0)/12|0)*12|0);XM(t)}return}function gp(e){e=e|0;var n=0;n=Za()|0;tl(e,2,5,n,yp()|0,1);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function yp(){return 1280}function Dp(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=wp(e)|0;e=u[a+4>>2]|0;u[o>>2]=u[a>>2];u[o+4>>2]=e;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];t=Ep(n,i,t)|0;h=r;return t|0}function wp(e){e=e|0;return(u[(ap()|0)+24>>2]|0)+(e*12|0)|0}function Ep(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;a=h;h=h+32|0;i=a;o=a+16|0;r=u[n>>2]|0;n=u[n+4>>2]|0;e=e+(n>>1)|0;if(n&1)r=u[(u[e>>2]|0)+r>>2]|0;Jl(o,t);o=Ql(o,t)|0;PA[r&15](i,e,o);o=Gd(i)|0;h=a;return o|0}function Tp(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+16|0;i=r+8|0;o=r;l=u[t>>2]|0;a=u[t+4>>2]|0;t=Ra(n)|0;u[o>>2]=l;u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];Cp(e,t,i,1);h=r;return}function Cp(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0;i=h;h=h+32|0;o=i+16|0;c=i+8|0;l=i;f=u[t>>2]|0;s=u[t+4>>2]|0;a=u[e>>2]|0;e=kp()|0;u[c>>2]=f;u[c+4>>2]=s;u[o>>2]=u[c>>2];u[o+4>>2]=u[c+4>>2];t=Mp(o)|0;u[l>>2]=f;u[l+4>>2]=s;u[o>>2]=u[l>>2];u[o+4>>2]=u[l+4>>2];Ia(a,n,e,t,Sp(o,r)|0,r);h=i;return}function kp(){var e=0,n=0;if(!(r[7752]|0)){Op(9720);Le(38,9720,_|0)|0;n=7752;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(9720)|0)){e=9720;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));Op(9720)}return 9720}function Mp(e){e=e|0;return 0}function Sp(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0;c=h;h=h+32|0;i=c+24|0;a=c+16|0;l=c;s=c+8|0;o=u[e>>2]|0;r=u[e+4>>2]|0;u[l>>2]=o;u[l+4>>2]=r;d=kp()|0;f=d+24|0;e=Wa(n,4)|0;u[s>>2]=e;n=d+28|0;t=u[n>>2]|0;if(t>>>0<(u[d+32>>2]|0)>>>0){u[a>>2]=o;u[a+4>>2]=r;u[i>>2]=u[a>>2];u[i+4>>2]=u[a+4>>2];Ap(t,i,e);e=(u[n>>2]|0)+12|0;u[n>>2]=e}else{xp(f,l,s);e=u[n>>2]|0}h=c;return((e-(u[f>>2]|0)|0)/12|0)+-1|0}function Ap(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=u[n+4>>2]|0;u[e>>2]=u[n>>2];u[e+4>>2]=r;u[e+8>>2]=t;return}function xp(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0;f=h;h=h+48|0;r=f+32|0;a=f+24|0;l=f;s=e+4|0;i=(((u[s>>2]|0)-(u[e>>2]|0)|0)/12|0)+1|0;o=Pp(e)|0;if(o>>>0<i>>>0)jM(e);else{c=u[e>>2]|0;p=((u[e+8>>2]|0)-c|0)/12|0;d=p<<1;Rp(l,p>>>0<o>>>1>>>0?d>>>0<i>>>0?i:d:o,((u[s>>2]|0)-c|0)/12|0,e+8|0);s=l+8|0;o=u[s>>2]|0;i=u[n+4>>2]|0;t=u[t>>2]|0;u[a>>2]=u[n>>2];u[a+4>>2]=i;u[r>>2]=u[a>>2];u[r+4>>2]=u[a+4>>2];Ap(o,r,t);u[s>>2]=(u[s>>2]|0)+12;Np(e,l);Fp(l);h=f;return}}function Pp(e){e=e|0;return 357913941}function Rp(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>357913941)$e();else{i=VM(n*12|0)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t*12|0)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n*12|0);return}function Np(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(((i|0)/-12|0)*12|0)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function Fp(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~(((r+-12-n|0)>>>0)/12|0)*12|0);e=u[e>>2]|0;if(e|0)XM(e);return}function Op(e){e=e|0;Bp(e);return}function Lp(e){e=e|0;Ip(e+24|0);return}function Ip(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~(((n+-12-r|0)>>>0)/12|0)*12|0);XM(t)}return}function Bp(e){e=e|0;var n=0;n=Za()|0;tl(e,2,8,n,Up()|0,0);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function Up(){return 1288}function jp(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0;t=h;h=h+16|0;r=t+8|0;i=t;o=Wp(e)|0;e=u[o+4>>2]|0;u[i>>2]=u[o>>2];u[i+4>>2]=e;u[r>>2]=u[i>>2];u[r+4>>2]=u[i+4>>2];n=zp(n,r)|0;h=t;return n|0}function Wp(e){e=e|0;return(u[(kp()|0)+24>>2]|0)+(e*12|0)|0}function zp(e,n){e=e|0;n=n|0;var t=0;t=u[n>>2]|0;n=u[n+4>>2]|0;e=e+(n>>1)|0;if(n&1)t=u[(u[e>>2]|0)+t>>2]|0;return No(vA[t&31](e)|0)|0}function Hp(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+16|0;i=r+8|0;o=r;l=u[t>>2]|0;a=u[t+4>>2]|0;t=Ra(n)|0;u[o>>2]=l;u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];Gp(e,t,i,0);h=r;return}function Gp(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0;i=h;h=h+32|0;o=i+16|0;c=i+8|0;l=i;f=u[t>>2]|0;s=u[t+4>>2]|0;a=u[e>>2]|0;e=Yp()|0;u[c>>2]=f;u[c+4>>2]=s;u[o>>2]=u[c>>2];u[o+4>>2]=u[c+4>>2];t=qp(o)|0;u[l>>2]=f;u[l+4>>2]=s;u[o>>2]=u[l>>2];u[o+4>>2]=u[l+4>>2];Ia(a,n,e,t,Vp(o,r)|0,r);h=i;return}function Yp(){var e=0,n=0;if(!(r[7760]|0)){eh(9756);Le(39,9756,_|0)|0;n=7760;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(9756)|0)){e=9756;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));eh(9756)}return 9756}function qp(e){e=e|0;return 0}function Vp(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0;c=h;h=h+32|0;i=c+24|0;a=c+16|0;l=c;s=c+8|0;o=u[e>>2]|0;r=u[e+4>>2]|0;u[l>>2]=o;u[l+4>>2]=r;d=Yp()|0;f=d+24|0;e=Wa(n,4)|0;u[s>>2]=e;n=d+28|0;t=u[n>>2]|0;if(t>>>0<(u[d+32>>2]|0)>>>0){u[a>>2]=o;u[a+4>>2]=r;u[i>>2]=u[a>>2];u[i+4>>2]=u[a+4>>2];$p(t,i,e);e=(u[n>>2]|0)+12|0;u[n>>2]=e}else{Xp(f,l,s);e=u[n>>2]|0}h=c;return((e-(u[f>>2]|0)|0)/12|0)+-1|0}function $p(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=u[n+4>>2]|0;u[e>>2]=u[n>>2];u[e+4>>2]=r;u[e+8>>2]=t;return}function Xp(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0;f=h;h=h+48|0;r=f+32|0;a=f+24|0;l=f;s=e+4|0;i=(((u[s>>2]|0)-(u[e>>2]|0)|0)/12|0)+1|0;o=Kp(e)|0;if(o>>>0<i>>>0)jM(e);else{c=u[e>>2]|0;p=((u[e+8>>2]|0)-c|0)/12|0;d=p<<1;Jp(l,p>>>0<o>>>1>>>0?d>>>0<i>>>0?i:d:o,((u[s>>2]|0)-c|0)/12|0,e+8|0);s=l+8|0;o=u[s>>2]|0;i=u[n+4>>2]|0;t=u[t>>2]|0;u[a>>2]=u[n>>2];u[a+4>>2]=i;u[r>>2]=u[a>>2];u[r+4>>2]=u[a+4>>2];$p(o,r,t);u[s>>2]=(u[s>>2]|0)+12;Qp(e,l);Zp(l);h=f;return}}function Kp(e){e=e|0;return 357913941}function Jp(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>357913941)$e();else{i=VM(n*12|0)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t*12|0)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n*12|0);return}function Qp(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(((i|0)/-12|0)*12|0)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function Zp(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~(((r+-12-n|0)>>>0)/12|0)*12|0);e=u[e>>2]|0;if(e|0)XM(e);return}function eh(e){e=e|0;rh(e);return}function nh(e){e=e|0;th(e+24|0);return}function th(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~(((n+-12-r|0)>>>0)/12|0)*12|0);XM(t)}return}function rh(e){e=e|0;var n=0;n=Za()|0;tl(e,2,8,n,ih()|0,1);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function ih(){return 1292}function uh(e,n,t){e=e|0;n=n|0;t=+t;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=oh(e)|0;e=u[a+4>>2]|0;u[o>>2]=u[a>>2];u[o+4>>2]=e;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];ah(n,i,t);h=r;return}function oh(e){e=e|0;return(u[(Yp()|0)+24>>2]|0)+(e*12|0)|0}function ah(e,n,t){e=e|0;n=n|0;t=+t;var r=0,i=0,o=0;o=h;h=h+16|0;i=o;r=u[n>>2]|0;n=u[n+4>>2]|0;e=e+(n>>1)|0;if(n&1)r=u[(u[e>>2]|0)+r>>2]|0;Xl(i,t);t=+Kl(i,t);dA[r&31](e,t);h=o;return}function lh(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+16|0;i=r+8|0;o=r;l=u[t>>2]|0;a=u[t+4>>2]|0;t=Ra(n)|0;u[o>>2]=l;u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];sh(e,t,i,0);h=r;return}function sh(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0;i=h;h=h+32|0;o=i+16|0;c=i+8|0;l=i;f=u[t>>2]|0;s=u[t+4>>2]|0;a=u[e>>2]|0;e=fh()|0;u[c>>2]=f;u[c+4>>2]=s;u[o>>2]=u[c>>2];u[o+4>>2]=u[c+4>>2];t=ch(o)|0;u[l>>2]=f;u[l+4>>2]=s;u[o>>2]=u[l>>2];u[o+4>>2]=u[l+4>>2];Ia(a,n,e,t,dh(o,r)|0,r);h=i;return}function fh(){var e=0,n=0;if(!(r[7768]|0)){gh(9792);Le(40,9792,_|0)|0;n=7768;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(9792)|0)){e=9792;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));gh(9792)}return 9792}function ch(e){e=e|0;return 0}function dh(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0;c=h;h=h+32|0;i=c+24|0;a=c+16|0;l=c;s=c+8|0;o=u[e>>2]|0;r=u[e+4>>2]|0;u[l>>2]=o;u[l+4>>2]=r;d=fh()|0;f=d+24|0;e=Wa(n,4)|0;u[s>>2]=e;n=d+28|0;t=u[n>>2]|0;if(t>>>0<(u[d+32>>2]|0)>>>0){u[a>>2]=o;u[a+4>>2]=r;u[i>>2]=u[a>>2];u[i+4>>2]=u[a+4>>2];ph(t,i,e);e=(u[n>>2]|0)+12|0;u[n>>2]=e}else{hh(f,l,s);e=u[n>>2]|0}h=c;return((e-(u[f>>2]|0)|0)/12|0)+-1|0}function ph(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=u[n+4>>2]|0;u[e>>2]=u[n>>2];u[e+4>>2]=r;u[e+8>>2]=t;return}function hh(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0;f=h;h=h+48|0;r=f+32|0;a=f+24|0;l=f;s=e+4|0;i=(((u[s>>2]|0)-(u[e>>2]|0)|0)/12|0)+1|0;o=mh(e)|0;if(o>>>0<i>>>0)jM(e);else{c=u[e>>2]|0;p=((u[e+8>>2]|0)-c|0)/12|0;d=p<<1;vh(l,p>>>0<o>>>1>>>0?d>>>0<i>>>0?i:d:o,((u[s>>2]|0)-c|0)/12|0,e+8|0);s=l+8|0;o=u[s>>2]|0;i=u[n+4>>2]|0;t=u[t>>2]|0;u[a>>2]=u[n>>2];u[a+4>>2]=i;u[r>>2]=u[a>>2];u[r+4>>2]=u[a+4>>2];ph(o,r,t);u[s>>2]=(u[s>>2]|0)+12;_h(e,l);bh(l);h=f;return}}function mh(e){e=e|0;return 357913941}function vh(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>357913941)$e();else{i=VM(n*12|0)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t*12|0)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n*12|0);return}function _h(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(((i|0)/-12|0)*12|0)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function bh(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~(((r+-12-n|0)>>>0)/12|0)*12|0);e=u[e>>2]|0;if(e|0)XM(e);return}function gh(e){e=e|0;wh(e);return}function yh(e){e=e|0;Dh(e+24|0);return}function Dh(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~(((n+-12-r|0)>>>0)/12|0)*12|0);XM(t)}return}function wh(e){e=e|0;var n=0;n=Za()|0;tl(e,2,1,n,Eh()|0,2);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function Eh(){return 1300}function Th(e,n,t,r){e=e|0;n=n|0;t=t|0;r=+r;var i=0,o=0,a=0,l=0;i=h;h=h+16|0;o=i+8|0;a=i;l=Ch(e)|0;e=u[l+4>>2]|0;u[a>>2]=u[l>>2];u[a+4>>2]=e;u[o>>2]=u[a>>2];u[o+4>>2]=u[a+4>>2];kh(n,o,t,r);h=i;return}function Ch(e){e=e|0;return(u[(fh()|0)+24>>2]|0)+(e*12|0)|0}function kh(e,n,t,r){e=e|0;n=n|0;t=t|0;r=+r;var i=0,o=0,a=0,l=0;l=h;h=h+16|0;o=l+1|0;a=l;i=u[n>>2]|0;n=u[n+4>>2]|0;e=e+(n>>1)|0;if(n&1)i=u[(u[e>>2]|0)+i>>2]|0;Jl(o,t);o=Ql(o,t)|0;Xl(a,r);r=+Kl(a,r);NA[i&15](e,o,r);h=l;return}function Mh(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+16|0;i=r+8|0;o=r;l=u[t>>2]|0;a=u[t+4>>2]|0;t=Ra(n)|0;u[o>>2]=l;u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];Sh(e,t,i,0);h=r;return}function Sh(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0;i=h;h=h+32|0;o=i+16|0;c=i+8|0;l=i;f=u[t>>2]|0;s=u[t+4>>2]|0;a=u[e>>2]|0;e=Ah()|0;u[c>>2]=f;u[c+4>>2]=s;u[o>>2]=u[c>>2];u[o+4>>2]=u[c+4>>2];t=xh(o)|0;u[l>>2]=f;u[l+4>>2]=s;u[o>>2]=u[l>>2];u[o+4>>2]=u[l+4>>2];Ia(a,n,e,t,Ph(o,r)|0,r);h=i;return}function Ah(){var e=0,n=0;if(!(r[7776]|0)){Bh(9828);Le(41,9828,_|0)|0;n=7776;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(9828)|0)){e=9828;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));Bh(9828)}return 9828}function xh(e){e=e|0;return 0}function Ph(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0;c=h;h=h+32|0;i=c+24|0;a=c+16|0;l=c;s=c+8|0;o=u[e>>2]|0;r=u[e+4>>2]|0;u[l>>2]=o;u[l+4>>2]=r;d=Ah()|0;f=d+24|0;e=Wa(n,4)|0;u[s>>2]=e;n=d+28|0;t=u[n>>2]|0;if(t>>>0<(u[d+32>>2]|0)>>>0){u[a>>2]=o;u[a+4>>2]=r;u[i>>2]=u[a>>2];u[i+4>>2]=u[a+4>>2];Rh(t,i,e);e=(u[n>>2]|0)+12|0;u[n>>2]=e}else{Nh(f,l,s);e=u[n>>2]|0}h=c;return((e-(u[f>>2]|0)|0)/12|0)+-1|0}function Rh(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=u[n+4>>2]|0;u[e>>2]=u[n>>2];u[e+4>>2]=r;u[e+8>>2]=t;return}function Nh(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0;f=h;h=h+48|0;r=f+32|0;a=f+24|0;l=f;s=e+4|0;i=(((u[s>>2]|0)-(u[e>>2]|0)|0)/12|0)+1|0;o=Fh(e)|0;if(o>>>0<i>>>0)jM(e);else{c=u[e>>2]|0;p=((u[e+8>>2]|0)-c|0)/12|0;d=p<<1;Oh(l,p>>>0<o>>>1>>>0?d>>>0<i>>>0?i:d:o,((u[s>>2]|0)-c|0)/12|0,e+8|0);s=l+8|0;o=u[s>>2]|0;i=u[n+4>>2]|0;t=u[t>>2]|0;u[a>>2]=u[n>>2];u[a+4>>2]=i;u[r>>2]=u[a>>2];u[r+4>>2]=u[a+4>>2];Rh(o,r,t);u[s>>2]=(u[s>>2]|0)+12;Lh(e,l);Ih(l);h=f;return}}function Fh(e){e=e|0;return 357913941}function Oh(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>357913941)$e();else{i=VM(n*12|0)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t*12|0)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n*12|0);return}function Lh(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(((i|0)/-12|0)*12|0)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function Ih(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~(((r+-12-n|0)>>>0)/12|0)*12|0);e=u[e>>2]|0;if(e|0)XM(e);return}function Bh(e){e=e|0;Wh(e);return}function Uh(e){e=e|0;jh(e+24|0);return}function jh(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~(((n+-12-r|0)>>>0)/12|0)*12|0);XM(t)}return}function Wh(e){e=e|0;var n=0;n=Za()|0;tl(e,2,7,n,zh()|0,1);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function zh(){return 1312}function Hh(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=Gh(e)|0;e=u[a+4>>2]|0;u[o>>2]=u[a>>2];u[o+4>>2]=e;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];Yh(n,i,t);h=r;return}function Gh(e){e=e|0;return(u[(Ah()|0)+24>>2]|0)+(e*12|0)|0}function Yh(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0;o=h;h=h+16|0;i=o;r=u[n>>2]|0;n=u[n+4>>2]|0;e=e+(n>>1)|0;if(n&1)r=u[(u[e>>2]|0)+r>>2]|0;Jl(i,t);i=Ql(i,t)|0;mA[r&31](e,i);h=o;return}function qh(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+16|0;i=r+8|0;o=r;l=u[t>>2]|0;a=u[t+4>>2]|0;t=Ra(n)|0;u[o>>2]=l;u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];Vh(e,t,i,0);h=r;return}function Vh(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0;i=h;h=h+32|0;o=i+16|0;c=i+8|0;l=i;f=u[t>>2]|0;s=u[t+4>>2]|0;a=u[e>>2]|0;e=$h()|0;u[c>>2]=f;u[c+4>>2]=s;u[o>>2]=u[c>>2];u[o+4>>2]=u[c+4>>2];t=Xh(o)|0;u[l>>2]=f;u[l+4>>2]=s;u[o>>2]=u[l>>2];u[o+4>>2]=u[l+4>>2];Ia(a,n,e,t,Kh(o,r)|0,r);h=i;return}function $h(){var e=0,n=0;if(!(r[7784]|0)){rm(9864);Le(42,9864,_|0)|0;n=7784;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(9864)|0)){e=9864;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));rm(9864)}return 9864}function Xh(e){e=e|0;return 0}function Kh(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0;c=h;h=h+32|0;i=c+24|0;a=c+16|0;l=c;s=c+8|0;o=u[e>>2]|0;r=u[e+4>>2]|0;u[l>>2]=o;u[l+4>>2]=r;d=$h()|0;f=d+24|0;e=Wa(n,4)|0;u[s>>2]=e;n=d+28|0;t=u[n>>2]|0;if(t>>>0<(u[d+32>>2]|0)>>>0){u[a>>2]=o;u[a+4>>2]=r;u[i>>2]=u[a>>2];u[i+4>>2]=u[a+4>>2];Jh(t,i,e);e=(u[n>>2]|0)+12|0;u[n>>2]=e}else{Qh(f,l,s);e=u[n>>2]|0}h=c;return((e-(u[f>>2]|0)|0)/12|0)+-1|0}function Jh(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=u[n+4>>2]|0;u[e>>2]=u[n>>2];u[e+4>>2]=r;u[e+8>>2]=t;return}function Qh(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0;f=h;h=h+48|0;r=f+32|0;a=f+24|0;l=f;s=e+4|0;i=(((u[s>>2]|0)-(u[e>>2]|0)|0)/12|0)+1|0;o=Zh(e)|0;if(o>>>0<i>>>0)jM(e);else{c=u[e>>2]|0;p=((u[e+8>>2]|0)-c|0)/12|0;d=p<<1;em(l,p>>>0<o>>>1>>>0?d>>>0<i>>>0?i:d:o,((u[s>>2]|0)-c|0)/12|0,e+8|0);s=l+8|0;o=u[s>>2]|0;i=u[n+4>>2]|0;t=u[t>>2]|0;u[a>>2]=u[n>>2];u[a+4>>2]=i;u[r>>2]=u[a>>2];u[r+4>>2]=u[a+4>>2];Jh(o,r,t);u[s>>2]=(u[s>>2]|0)+12;nm(e,l);tm(l);h=f;return}}function Zh(e){e=e|0;return 357913941}function em(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>357913941)$e();else{i=VM(n*12|0)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t*12|0)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n*12|0);return}function nm(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(((i|0)/-12|0)*12|0)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function tm(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~(((r+-12-n|0)>>>0)/12|0)*12|0);e=u[e>>2]|0;if(e|0)XM(e);return}function rm(e){e=e|0;om(e);return}function im(e){e=e|0;um(e+24|0);return}function um(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~(((n+-12-r|0)>>>0)/12|0)*12|0);XM(t)}return}function om(e){e=e|0;var n=0;n=Za()|0;tl(e,2,8,n,am()|0,1);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function am(){return 1320}function lm(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=sm(e)|0;e=u[a+4>>2]|0;u[o>>2]=u[a>>2];u[o+4>>2]=e;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];fm(n,i,t);h=r;return}function sm(e){e=e|0;return(u[($h()|0)+24>>2]|0)+(e*12|0)|0}function fm(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0;o=h;h=h+16|0;i=o;r=u[n>>2]|0;n=u[n+4>>2]|0;e=e+(n>>1)|0;if(n&1)r=u[(u[e>>2]|0)+r>>2]|0;cm(i,t);i=dm(i,t)|0;mA[r&31](e,i);h=o;return}function cm(e,n){e=e|0;n=n|0;return}function dm(e,n){e=e|0;n=n|0;return pm(n)|0}function pm(e){e=e|0;return e|0}function hm(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+16|0;i=r+8|0;o=r;l=u[t>>2]|0;a=u[t+4>>2]|0;t=Ra(n)|0;u[o>>2]=l;u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];mm(e,t,i,0);h=r;return}function mm(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0;i=h;h=h+32|0;o=i+16|0;c=i+8|0;l=i;f=u[t>>2]|0;s=u[t+4>>2]|0;a=u[e>>2]|0;e=vm()|0;u[c>>2]=f;u[c+4>>2]=s;u[o>>2]=u[c>>2];u[o+4>>2]=u[c+4>>2];t=_m(o)|0;u[l>>2]=f;u[l+4>>2]=s;u[o>>2]=u[l>>2];u[o+4>>2]=u[l+4>>2];Ia(a,n,e,t,bm(o,r)|0,r);h=i;return}function vm(){var e=0,n=0;if(!(r[7792]|0)){Cm(9900);Le(43,9900,_|0)|0;n=7792;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(9900)|0)){e=9900;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));Cm(9900)}return 9900}function _m(e){e=e|0;return 0}function bm(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0;c=h;h=h+32|0;i=c+24|0;a=c+16|0;l=c;s=c+8|0;o=u[e>>2]|0;r=u[e+4>>2]|0;u[l>>2]=o;u[l+4>>2]=r;d=vm()|0;f=d+24|0;e=Wa(n,4)|0;u[s>>2]=e;n=d+28|0;t=u[n>>2]|0;if(t>>>0<(u[d+32>>2]|0)>>>0){u[a>>2]=o;u[a+4>>2]=r;u[i>>2]=u[a>>2];u[i+4>>2]=u[a+4>>2];gm(t,i,e);e=(u[n>>2]|0)+12|0;u[n>>2]=e}else{ym(f,l,s);e=u[n>>2]|0}h=c;return((e-(u[f>>2]|0)|0)/12|0)+-1|0}function gm(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=u[n+4>>2]|0;u[e>>2]=u[n>>2];u[e+4>>2]=r;u[e+8>>2]=t;return}function ym(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0;f=h;h=h+48|0;r=f+32|0;a=f+24|0;l=f;s=e+4|0;i=(((u[s>>2]|0)-(u[e>>2]|0)|0)/12|0)+1|0;o=Dm(e)|0;if(o>>>0<i>>>0)jM(e);else{c=u[e>>2]|0;p=((u[e+8>>2]|0)-c|0)/12|0;d=p<<1;wm(l,p>>>0<o>>>1>>>0?d>>>0<i>>>0?i:d:o,((u[s>>2]|0)-c|0)/12|0,e+8|0);s=l+8|0;o=u[s>>2]|0;i=u[n+4>>2]|0;t=u[t>>2]|0;u[a>>2]=u[n>>2];u[a+4>>2]=i;u[r>>2]=u[a>>2];u[r+4>>2]=u[a+4>>2];gm(o,r,t);u[s>>2]=(u[s>>2]|0)+12;Em(e,l);Tm(l);h=f;return}}function Dm(e){e=e|0;return 357913941}function wm(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>357913941)$e();else{i=VM(n*12|0)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t*12|0)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n*12|0);return}function Em(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(((i|0)/-12|0)*12|0)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function Tm(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~(((r+-12-n|0)>>>0)/12|0)*12|0);e=u[e>>2]|0;if(e|0)XM(e);return}function Cm(e){e=e|0;Sm(e);return}function km(e){e=e|0;Mm(e+24|0);return}function Mm(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~(((n+-12-r|0)>>>0)/12|0)*12|0);XM(t)}return}function Sm(e){e=e|0;var n=0;n=Za()|0;tl(e,2,22,n,Am()|0,0);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function Am(){return 1344}function xm(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0;t=h;h=h+16|0;r=t+8|0;i=t;o=Pm(e)|0;e=u[o+4>>2]|0;u[i>>2]=u[o>>2];u[i+4>>2]=e;u[r>>2]=u[i>>2];u[r+4>>2]=u[i+4>>2];Rm(n,r);h=t;return}function Pm(e){e=e|0;return(u[(vm()|0)+24>>2]|0)+(e*12|0)|0}function Rm(e,n){e=e|0;n=n|0;var t=0;t=u[n>>2]|0;n=u[n+4>>2]|0;e=e+(n>>1)|0;if(n&1)t=u[(u[e>>2]|0)+t>>2]|0;hA[t&127](e);return}function Nm(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0;o=u[e>>2]|0;i=Fm()|0;e=Om(t)|0;Ia(o,n,i,e,Lm(t,r)|0,r);return}function Fm(){var e=0,n=0;if(!(r[7800]|0)){Hm(9936);Le(44,9936,_|0)|0;n=7800;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(9936)|0)){e=9936;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));Hm(9936)}return 9936}function Om(e){e=e|0;return e|0}function Lm(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0;l=h;h=h+16|0;i=l;o=l+4|0;u[i>>2]=e;s=Fm()|0;a=s+24|0;n=Wa(n,4)|0;u[o>>2]=n;t=s+28|0;r=u[t>>2]|0;if(r>>>0<(u[s+32>>2]|0)>>>0){Im(r,e,n);n=(u[t>>2]|0)+8|0;u[t>>2]=n}else{Bm(a,i,o);n=u[t>>2]|0}h=l;return(n-(u[a>>2]|0)>>3)+-1|0}function Im(e,n,t){e=e|0;n=n|0;t=t|0;u[e>>2]=n;u[e+4>>2]=t;return}function Bm(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0;l=h;h=h+32|0;i=l;o=e+4|0;a=((u[o>>2]|0)-(u[e>>2]|0)>>3)+1|0;r=Um(e)|0;if(r>>>0<a>>>0)jM(e);else{s=u[e>>2]|0;c=(u[e+8>>2]|0)-s|0;f=c>>2;jm(i,c>>3>>>0<r>>>1>>>0?f>>>0<a>>>0?a:f:r,(u[o>>2]|0)-s>>3,e+8|0);a=i+8|0;Im(u[a>>2]|0,u[n>>2]|0,u[t>>2]|0);u[a>>2]=(u[a>>2]|0)+8;Wm(e,i);zm(i);h=l;return}}function Um(e){e=e|0;return 536870911}function jm(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>536870911)$e();else{i=VM(n<<3)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t<<3)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n<<3);return}function Wm(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(0-(i>>3)<<3)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function zm(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~((r+-8-n|0)>>>3)<<3);e=u[e>>2]|0;if(e|0)XM(e);return}function Hm(e){e=e|0;qm(e);return}function Gm(e){e=e|0;Ym(e+24|0);return}function Ym(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~((n+-8-r|0)>>>3)<<3);XM(t)}return}function qm(e){e=e|0;var n=0;n=Za()|0;tl(e,1,23,n,mc()|0,1);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function Vm(e,n){e=e|0;n=n|0;Xm(u[($m(e)|0)>>2]|0,n);return}function $m(e){e=e|0;return(u[(Fm()|0)+24>>2]|0)+(e<<3)|0}function Xm(e,n){e=e|0;n=n|0;var t=0,r=0;t=h;h=h+16|0;r=t;gc(r,n);n=yc(r,n)|0;hA[e&127](n);h=t;return}function Km(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0;o=u[e>>2]|0;i=Jm()|0;e=Qm(t)|0;Ia(o,n,i,e,Zm(t,r)|0,r);return}function Jm(){var e=0,n=0;if(!(r[7808]|0)){ov(9972);Le(45,9972,_|0)|0;n=7808;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(9972)|0)){e=9972;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));ov(9972)}return 9972}function Qm(e){e=e|0;return e|0}function Zm(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0;l=h;h=h+16|0;i=l;o=l+4|0;u[i>>2]=e;s=Jm()|0;a=s+24|0;n=Wa(n,4)|0;u[o>>2]=n;t=s+28|0;r=u[t>>2]|0;if(r>>>0<(u[s+32>>2]|0)>>>0){ev(r,e,n);n=(u[t>>2]|0)+8|0;u[t>>2]=n}else{nv(a,i,o);n=u[t>>2]|0}h=l;return(n-(u[a>>2]|0)>>3)+-1|0}function ev(e,n,t){e=e|0;n=n|0;t=t|0;u[e>>2]=n;u[e+4>>2]=t;return}function nv(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0;l=h;h=h+32|0;i=l;o=e+4|0;a=((u[o>>2]|0)-(u[e>>2]|0)>>3)+1|0;r=tv(e)|0;if(r>>>0<a>>>0)jM(e);else{s=u[e>>2]|0;c=(u[e+8>>2]|0)-s|0;f=c>>2;rv(i,c>>3>>>0<r>>>1>>>0?f>>>0<a>>>0?a:f:r,(u[o>>2]|0)-s>>3,e+8|0);a=i+8|0;ev(u[a>>2]|0,u[n>>2]|0,u[t>>2]|0);u[a>>2]=(u[a>>2]|0)+8;iv(e,i);uv(i);h=l;return}}function tv(e){e=e|0;return 536870911}function rv(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>536870911)$e();else{i=VM(n<<3)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t<<3)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n<<3);return}function iv(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(0-(i>>3)<<3)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function uv(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~((r+-8-n|0)>>>3)<<3);e=u[e>>2]|0;if(e|0)XM(e);return}function ov(e){e=e|0;sv(e);return}function av(e){e=e|0;lv(e+24|0);return}function lv(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~((n+-8-r|0)>>>3)<<3);XM(t)}return}function sv(e){e=e|0;var n=0;n=Za()|0;tl(e,1,9,n,fv()|0,1);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function fv(){return 1348}function cv(e,n){e=e|0;n=n|0;return pv(u[(dv(e)|0)>>2]|0,n)|0}function dv(e){e=e|0;return(u[(Jm()|0)+24>>2]|0)+(e<<3)|0}function pv(e,n){e=e|0;n=n|0;var t=0,r=0;t=h;h=h+16|0;r=t;hv(r,n);n=mv(r,n)|0;n=pf(vA[e&31](n)|0)|0;h=t;return n|0}function hv(e,n){e=e|0;n=n|0;return}function mv(e,n){e=e|0;n=n|0;return vv(n)|0}function vv(e){e=e|0;return e|0}function _v(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0;o=u[e>>2]|0;i=bv()|0;e=gv(t)|0;Ia(o,n,i,e,yv(t,r)|0,r);return}function bv(){var e=0,n=0;if(!(r[7816]|0)){Mv(10008);Le(46,10008,_|0)|0;n=7816;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(10008)|0)){e=10008;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));Mv(10008)}return 10008}function gv(e){e=e|0;return e|0}function yv(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0;l=h;h=h+16|0;i=l;o=l+4|0;u[i>>2]=e;s=bv()|0;a=s+24|0;n=Wa(n,4)|0;u[o>>2]=n;t=s+28|0;r=u[t>>2]|0;if(r>>>0<(u[s+32>>2]|0)>>>0){Dv(r,e,n);n=(u[t>>2]|0)+8|0;u[t>>2]=n}else{wv(a,i,o);n=u[t>>2]|0}h=l;return(n-(u[a>>2]|0)>>3)+-1|0}function Dv(e,n,t){e=e|0;n=n|0;t=t|0;u[e>>2]=n;u[e+4>>2]=t;return}function wv(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0;l=h;h=h+32|0;i=l;o=e+4|0;a=((u[o>>2]|0)-(u[e>>2]|0)>>3)+1|0;r=Ev(e)|0;if(r>>>0<a>>>0)jM(e);else{s=u[e>>2]|0;c=(u[e+8>>2]|0)-s|0;f=c>>2;Tv(i,c>>3>>>0<r>>>1>>>0?f>>>0<a>>>0?a:f:r,(u[o>>2]|0)-s>>3,e+8|0);a=i+8|0;Dv(u[a>>2]|0,u[n>>2]|0,u[t>>2]|0);u[a>>2]=(u[a>>2]|0)+8;Cv(e,i);kv(i);h=l;return}}function Ev(e){e=e|0;return 536870911}function Tv(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>536870911)$e();else{i=VM(n<<3)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t<<3)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n<<3);return}function Cv(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(0-(i>>3)<<3)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function kv(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~((r+-8-n|0)>>>3)<<3);e=u[e>>2]|0;if(e|0)XM(e);return}function Mv(e){e=e|0;xv(e);return}function Sv(e){e=e|0;Av(e+24|0);return}function Av(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~((n+-8-r|0)>>>3)<<3);XM(t)}return}function xv(e){e=e|0;var n=0;n=Za()|0;tl(e,1,15,n,xf()|0,0);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function Pv(e){e=e|0;return Nv(u[(Rv(e)|0)>>2]|0)|0}function Rv(e){e=e|0;return(u[(bv()|0)+24>>2]|0)+(e<<3)|0}function Nv(e){e=e|0;return pf(MA[e&7]()|0)|0}function Fv(){var e=0;if(!(r[7832]|0)){Gv(10052);Le(25,10052,_|0)|0;e=7832;u[e>>2]=1;u[e+4>>2]=0}return 10052}function Ov(e,n){e=e|0;n=n|0;u[e>>2]=Lv()|0;u[e+4>>2]=Iv()|0;u[e+12>>2]=n;u[e+8>>2]=Bv()|0;u[e+32>>2]=2;return}function Lv(){return 11709}function Iv(){return 1188}function Bv(){return zv()|0}function Uv(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;if((jv(r,896)|0)==512){if(t|0){Wv(t);XM(t)}}else if(n|0){Ji(n);XM(n)}return}function jv(e,n){e=e|0;n=n|0;return n&e|0}function Wv(e){e=e|0;e=u[e+4>>2]|0;if(e|0)YM(e);return}function zv(){var e=0;if(!(r[7824]|0)){u[2511]=Hv()|0;u[2512]=0;e=7824;u[e>>2]=1;u[e+4>>2]=0}return 10044}function Hv(){return 0}function Gv(e){e=e|0;Al(e);return}function Yv(e){e=e|0;var n=0,t=0,r=0,i=0,o=0;n=h;h=h+32|0;t=n+24|0;o=n+16|0;i=n+8|0;r=n;qv(e,4827);Vv(e,4834,3)|0;$v(e,3682,47)|0;u[o>>2]=9;u[o+4>>2]=0;u[t>>2]=u[o>>2];u[t+4>>2]=u[o+4>>2];Xv(e,4841,t)|0;u[i>>2]=1;u[i+4>>2]=0;u[t>>2]=u[i>>2];u[t+4>>2]=u[i+4>>2];Kv(e,4871,t)|0;u[r>>2]=10;u[r+4>>2]=0;u[t>>2]=u[r>>2];u[t+4>>2]=u[r+4>>2];Jv(e,4891,t)|0;h=n;return}function qv(e,n){e=e|0;n=n|0;var t=0;t=Gb()|0;u[e>>2]=t;Yb(t,n);fD(u[e>>2]|0);return}function Vv(e,n,t){e=e|0;n=n|0;t=t|0;Cb(e,Ra(n)|0,t,0);return e|0}function $v(e,n,t){e=e|0;n=n|0;t=t|0;ab(e,Ra(n)|0,t,0);return e|0}function Xv(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=u[t+4>>2]|0;u[o>>2]=u[t>>2];u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];U_(e,n,i);h=r;return e|0}function Kv(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=u[t+4>>2]|0;u[o>>2]=u[t>>2];u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];__(e,n,i);h=r;return e|0}function Jv(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=u[t+4>>2]|0;u[o>>2]=u[t>>2];u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];Qv(e,n,i);h=r;return e|0}function Qv(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+16|0;i=r+8|0;o=r;l=u[t>>2]|0;a=u[t+4>>2]|0;t=Ra(n)|0;u[o>>2]=l;u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];Zv(e,t,i,1);h=r;return}function Zv(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0;i=h;h=h+32|0;o=i+16|0;c=i+8|0;l=i;f=u[t>>2]|0;s=u[t+4>>2]|0;a=u[e>>2]|0;e=e_()|0;u[c>>2]=f;u[c+4>>2]=s;u[o>>2]=u[c>>2];u[o+4>>2]=u[c+4>>2];t=n_(o)|0;u[l>>2]=f;u[l+4>>2]=s;u[o>>2]=u[l>>2];u[o+4>>2]=u[l+4>>2];Ia(a,n,e,t,t_(o,r)|0,r);h=i;return}function e_(){var e=0,n=0;if(!(r[7840]|0)){s_(10100);Le(48,10100,_|0)|0;n=7840;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(10100)|0)){e=10100;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));s_(10100)}return 10100}function n_(e){e=e|0;return 0}function t_(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0;c=h;h=h+32|0;i=c+24|0;a=c+16|0;l=c;s=c+8|0;o=u[e>>2]|0;r=u[e+4>>2]|0;u[l>>2]=o;u[l+4>>2]=r;d=e_()|0;f=d+24|0;e=Wa(n,4)|0;u[s>>2]=e;n=d+28|0;t=u[n>>2]|0;if(t>>>0<(u[d+32>>2]|0)>>>0){u[a>>2]=o;u[a+4>>2]=r;u[i>>2]=u[a>>2];u[i+4>>2]=u[a+4>>2];r_(t,i,e);e=(u[n>>2]|0)+12|0;u[n>>2]=e}else{i_(f,l,s);e=u[n>>2]|0}h=c;return((e-(u[f>>2]|0)|0)/12|0)+-1|0}function r_(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=u[n+4>>2]|0;u[e>>2]=u[n>>2];u[e+4>>2]=r;u[e+8>>2]=t;return}function i_(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0;f=h;h=h+48|0;r=f+32|0;a=f+24|0;l=f;s=e+4|0;i=(((u[s>>2]|0)-(u[e>>2]|0)|0)/12|0)+1|0;o=u_(e)|0;if(o>>>0<i>>>0)jM(e);else{c=u[e>>2]|0;p=((u[e+8>>2]|0)-c|0)/12|0;d=p<<1;o_(l,p>>>0<o>>>1>>>0?d>>>0<i>>>0?i:d:o,((u[s>>2]|0)-c|0)/12|0,e+8|0);s=l+8|0;o=u[s>>2]|0;i=u[n+4>>2]|0;t=u[t>>2]|0;u[a>>2]=u[n>>2];u[a+4>>2]=i;u[r>>2]=u[a>>2];u[r+4>>2]=u[a+4>>2];r_(o,r,t);u[s>>2]=(u[s>>2]|0)+12;a_(e,l);l_(l);h=f;return}}function u_(e){e=e|0;return 357913941}function o_(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>357913941)$e();else{i=VM(n*12|0)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t*12|0)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n*12|0);return}function a_(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(((i|0)/-12|0)*12|0)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function l_(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~(((r+-12-n|0)>>>0)/12|0)*12|0);e=u[e>>2]|0;if(e|0)XM(e);return}function s_(e){e=e|0;d_(e);return}function f_(e){e=e|0;c_(e+24|0);return}function c_(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~(((n+-12-r|0)>>>0)/12|0)*12|0);XM(t)}return}function d_(e){e=e|0;var n=0;n=Za()|0;tl(e,2,6,n,p_()|0,1);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function p_(){return 1364}function h_(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=m_(e)|0;e=u[a+4>>2]|0;u[o>>2]=u[a>>2];u[o+4>>2]=e;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];t=v_(n,i,t)|0;h=r;return t|0}function m_(e){e=e|0;return(u[(e_()|0)+24>>2]|0)+(e*12|0)|0}function v_(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0;o=h;h=h+16|0;i=o;r=u[n>>2]|0;n=u[n+4>>2]|0;e=e+(n>>1)|0;if(n&1)r=u[(u[e>>2]|0)+r>>2]|0;Jl(i,t);i=Ql(i,t)|0;i=ys(EA[r&15](e,i)|0)|0;h=o;return i|0}function __(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+16|0;i=r+8|0;o=r;l=u[t>>2]|0;a=u[t+4>>2]|0;t=Ra(n)|0;u[o>>2]=l;u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];b_(e,t,i,0);h=r;return}function b_(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0;i=h;h=h+32|0;o=i+16|0;c=i+8|0;l=i;f=u[t>>2]|0;s=u[t+4>>2]|0;a=u[e>>2]|0;e=g_()|0;u[c>>2]=f;u[c+4>>2]=s;u[o>>2]=u[c>>2];u[o+4>>2]=u[c+4>>2];t=y_(o)|0;u[l>>2]=f;u[l+4>>2]=s;u[o>>2]=u[l>>2];u[o+4>>2]=u[l+4>>2];Ia(a,n,e,t,D_(o,r)|0,r);h=i;return}function g_(){var e=0,n=0;if(!(r[7848]|0)){S_(10136);Le(49,10136,_|0)|0;n=7848;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(10136)|0)){e=10136;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));S_(10136)}return 10136}function y_(e){e=e|0;return 0}function D_(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0;c=h;h=h+32|0;i=c+24|0;a=c+16|0;l=c;s=c+8|0;o=u[e>>2]|0;r=u[e+4>>2]|0;u[l>>2]=o;u[l+4>>2]=r;d=g_()|0;f=d+24|0;e=Wa(n,4)|0;u[s>>2]=e;n=d+28|0;t=u[n>>2]|0;if(t>>>0<(u[d+32>>2]|0)>>>0){u[a>>2]=o;u[a+4>>2]=r;u[i>>2]=u[a>>2];u[i+4>>2]=u[a+4>>2];w_(t,i,e);e=(u[n>>2]|0)+12|0;u[n>>2]=e}else{E_(f,l,s);e=u[n>>2]|0}h=c;return((e-(u[f>>2]|0)|0)/12|0)+-1|0}function w_(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=u[n+4>>2]|0;u[e>>2]=u[n>>2];u[e+4>>2]=r;u[e+8>>2]=t;return}function E_(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0;f=h;h=h+48|0;r=f+32|0;a=f+24|0;l=f;s=e+4|0;i=(((u[s>>2]|0)-(u[e>>2]|0)|0)/12|0)+1|0;o=T_(e)|0;if(o>>>0<i>>>0)jM(e);else{c=u[e>>2]|0;p=((u[e+8>>2]|0)-c|0)/12|0;d=p<<1;C_(l,p>>>0<o>>>1>>>0?d>>>0<i>>>0?i:d:o,((u[s>>2]|0)-c|0)/12|0,e+8|0);s=l+8|0;o=u[s>>2]|0;i=u[n+4>>2]|0;t=u[t>>2]|0;u[a>>2]=u[n>>2];u[a+4>>2]=i;u[r>>2]=u[a>>2];u[r+4>>2]=u[a+4>>2];w_(o,r,t);u[s>>2]=(u[s>>2]|0)+12;k_(e,l);M_(l);h=f;return}}function T_(e){e=e|0;return 357913941}function C_(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>357913941)$e();else{i=VM(n*12|0)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t*12|0)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n*12|0);return}function k_(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(((i|0)/-12|0)*12|0)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function M_(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~(((r+-12-n|0)>>>0)/12|0)*12|0);e=u[e>>2]|0;if(e|0)XM(e);return}function S_(e){e=e|0;P_(e);return}function A_(e){e=e|0;x_(e+24|0);return}function x_(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~(((n+-12-r|0)>>>0)/12|0)*12|0);XM(t)}return}function P_(e){e=e|0;var n=0;n=Za()|0;tl(e,2,9,n,R_()|0,1);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function R_(){return 1372}function N_(e,n,t){e=e|0;n=n|0;t=+t;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;i=r+8|0;o=r;a=F_(e)|0;e=u[a+4>>2]|0;u[o>>2]=u[a>>2];u[o+4>>2]=e;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];O_(n,i,t);h=r;return}function F_(e){e=e|0;return(u[(g_()|0)+24>>2]|0)+(e*12|0)|0}function O_(e,n,t){e=e|0;n=n|0;t=+t;var r=0,i=0,o=0,a=dn;o=h;h=h+16|0;i=o;r=u[n>>2]|0;n=u[n+4>>2]|0;e=e+(n>>1)|0;if(n&1)r=u[(u[e>>2]|0)+r>>2]|0;L_(i,t);a=$(I_(i,t));cA[r&1](e,a);h=o;return}function L_(e,n){e=e|0;n=+n;return}function I_(e,n){e=e|0;n=+n;return $(B_(n))}function B_(e){e=+e;return $(e)}function U_(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+16|0;i=r+8|0;o=r;l=u[t>>2]|0;a=u[t+4>>2]|0;t=Ra(n)|0;u[o>>2]=l;u[o+4>>2]=a;u[i>>2]=u[o>>2];u[i+4>>2]=u[o+4>>2];j_(e,t,i,0);h=r;return}function j_(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0;i=h;h=h+32|0;o=i+16|0;c=i+8|0;l=i;f=u[t>>2]|0;s=u[t+4>>2]|0;a=u[e>>2]|0;e=W_()|0;u[c>>2]=f;u[c+4>>2]=s;u[o>>2]=u[c>>2];u[o+4>>2]=u[c+4>>2];t=z_(o)|0;u[l>>2]=f;u[l+4>>2]=s;u[o>>2]=u[l>>2];u[o+4>>2]=u[l+4>>2];Ia(a,n,e,t,H_(o,r)|0,r);h=i;return}function W_(){var e=0,n=0;if(!(r[7856]|0)){K_(10172);Le(50,10172,_|0)|0;n=7856;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(10172)|0)){e=10172;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));K_(10172)}return 10172}function z_(e){e=e|0;return 0}function H_(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0;c=h;h=h+32|0;i=c+24|0;a=c+16|0;l=c;s=c+8|0;o=u[e>>2]|0;r=u[e+4>>2]|0;u[l>>2]=o;u[l+4>>2]=r;d=W_()|0;f=d+24|0;e=Wa(n,4)|0;u[s>>2]=e;n=d+28|0;t=u[n>>2]|0;if(t>>>0<(u[d+32>>2]|0)>>>0){u[a>>2]=o;u[a+4>>2]=r;u[i>>2]=u[a>>2];u[i+4>>2]=u[a+4>>2];G_(t,i,e);e=(u[n>>2]|0)+12|0;u[n>>2]=e}else{Y_(f,l,s);e=u[n>>2]|0}h=c;return((e-(u[f>>2]|0)|0)/12|0)+-1|0}function G_(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=u[n+4>>2]|0;u[e>>2]=u[n>>2];u[e+4>>2]=r;u[e+8>>2]=t;return}function Y_(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0;f=h;h=h+48|0;r=f+32|0;a=f+24|0;l=f;s=e+4|0;i=(((u[s>>2]|0)-(u[e>>2]|0)|0)/12|0)+1|0;o=q_(e)|0;if(o>>>0<i>>>0)jM(e);else{c=u[e>>2]|0;p=((u[e+8>>2]|0)-c|0)/12|0;d=p<<1;V_(l,p>>>0<o>>>1>>>0?d>>>0<i>>>0?i:d:o,((u[s>>2]|0)-c|0)/12|0,e+8|0);s=l+8|0;o=u[s>>2]|0;i=u[n+4>>2]|0;t=u[t>>2]|0;u[a>>2]=u[n>>2];u[a+4>>2]=i;u[r>>2]=u[a>>2];u[r+4>>2]=u[a+4>>2];G_(o,r,t);u[s>>2]=(u[s>>2]|0)+12;$_(e,l);X_(l);h=f;return}}function q_(e){e=e|0;return 357913941}function V_(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>357913941)$e();else{i=VM(n*12|0)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t*12|0)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n*12|0);return}function $_(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(((i|0)/-12|0)*12|0)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function X_(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~(((r+-12-n|0)>>>0)/12|0)*12|0);e=u[e>>2]|0;if(e|0)XM(e);return}function K_(e){e=e|0;Z_(e);return}function J_(e){e=e|0;Q_(e+24|0);return}function Q_(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~(((n+-12-r|0)>>>0)/12|0)*12|0);XM(t)}return}function Z_(e){e=e|0;var n=0;n=Za()|0;tl(e,2,3,n,eb()|0,2);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function eb(){return 1380}function nb(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0;i=h;h=h+16|0;o=i+8|0;a=i;l=tb(e)|0;e=u[l+4>>2]|0;u[a>>2]=u[l>>2];u[a+4>>2]=e;u[o>>2]=u[a>>2];u[o+4>>2]=u[a+4>>2];rb(n,o,t,r);h=i;return}function tb(e){e=e|0;return(u[(W_()|0)+24>>2]|0)+(e*12|0)|0}function rb(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0;l=h;h=h+16|0;o=l+1|0;a=l;i=u[n>>2]|0;n=u[n+4>>2]|0;e=e+(n>>1)|0;if(n&1)i=u[(u[e>>2]|0)+i>>2]|0;Jl(o,t);o=Ql(o,t)|0;ib(a,r);a=ub(a,r)|0;PA[i&15](e,o,a);h=l;return}function ib(e,n){e=e|0;n=n|0;return}function ub(e,n){e=e|0;n=n|0;return ob(n)|0}function ob(e){e=e|0;return(e|0)!=0|0}function ab(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0;o=u[e>>2]|0;i=lb()|0;e=sb(t)|0;Ia(o,n,i,e,fb(t,r)|0,r);return}function lb(){var e=0,n=0;if(!(r[7864]|0)){_b(10208);Le(51,10208,_|0)|0;n=7864;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(10208)|0)){e=10208;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));_b(10208)}return 10208}function sb(e){e=e|0;return e|0}function fb(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0;l=h;h=h+16|0;i=l;o=l+4|0;u[i>>2]=e;s=lb()|0;a=s+24|0;n=Wa(n,4)|0;u[o>>2]=n;t=s+28|0;r=u[t>>2]|0;if(r>>>0<(u[s+32>>2]|0)>>>0){cb(r,e,n);n=(u[t>>2]|0)+8|0;u[t>>2]=n}else{db(a,i,o);n=u[t>>2]|0}h=l;return(n-(u[a>>2]|0)>>3)+-1|0}function cb(e,n,t){e=e|0;n=n|0;t=t|0;u[e>>2]=n;u[e+4>>2]=t;return}function db(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0;l=h;h=h+32|0;i=l;o=e+4|0;a=((u[o>>2]|0)-(u[e>>2]|0)>>3)+1|0;r=pb(e)|0;if(r>>>0<a>>>0)jM(e);else{s=u[e>>2]|0;c=(u[e+8>>2]|0)-s|0;f=c>>2;hb(i,c>>3>>>0<r>>>1>>>0?f>>>0<a>>>0?a:f:r,(u[o>>2]|0)-s>>3,e+8|0);a=i+8|0;cb(u[a>>2]|0,u[n>>2]|0,u[t>>2]|0);u[a>>2]=(u[a>>2]|0)+8;mb(e,i);vb(i);h=l;return}}function pb(e){e=e|0;return 536870911}function hb(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>536870911)$e();else{i=VM(n<<3)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t<<3)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n<<3);return}function mb(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(0-(i>>3)<<3)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function vb(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~((r+-8-n|0)>>>3)<<3);e=u[e>>2]|0;if(e|0)XM(e);return}function _b(e){e=e|0;yb(e);return}function bb(e){e=e|0;gb(e+24|0);return}function gb(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~((n+-8-r|0)>>>3)<<3);XM(t)}return}function yb(e){e=e|0;var n=0;n=Za()|0;tl(e,1,24,n,Db()|0,1);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function Db(){return 1392}function wb(e,n){e=e|0;n=n|0;Tb(u[(Eb(e)|0)>>2]|0,n);return}function Eb(e){e=e|0;return(u[(lb()|0)+24>>2]|0)+(e<<3)|0}function Tb(e,n){e=e|0;n=n|0;var t=0,r=0;t=h;h=h+16|0;r=t;hv(r,n);n=mv(r,n)|0;hA[e&127](n);h=t;return}function Cb(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0;o=u[e>>2]|0;i=kb()|0;e=Mb(t)|0;Ia(o,n,i,e,Sb(t,r)|0,r);return}function kb(){var e=0,n=0;if(!(r[7872]|0)){Ob(10244);Le(52,10244,_|0)|0;n=7872;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(10244)|0)){e=10244;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));Ob(10244)}return 10244}function Mb(e){e=e|0;return e|0}function Sb(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0;l=h;h=h+16|0;i=l;o=l+4|0;u[i>>2]=e;s=kb()|0;a=s+24|0;n=Wa(n,4)|0;u[o>>2]=n;t=s+28|0;r=u[t>>2]|0;if(r>>>0<(u[s+32>>2]|0)>>>0){Ab(r,e,n);n=(u[t>>2]|0)+8|0;u[t>>2]=n}else{xb(a,i,o);n=u[t>>2]|0}h=l;return(n-(u[a>>2]|0)>>3)+-1|0}function Ab(e,n,t){e=e|0;n=n|0;t=t|0;u[e>>2]=n;u[e+4>>2]=t;return}function xb(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0;l=h;h=h+32|0;i=l;o=e+4|0;a=((u[o>>2]|0)-(u[e>>2]|0)>>3)+1|0;r=Pb(e)|0;if(r>>>0<a>>>0)jM(e);else{s=u[e>>2]|0;c=(u[e+8>>2]|0)-s|0;f=c>>2;Rb(i,c>>3>>>0<r>>>1>>>0?f>>>0<a>>>0?a:f:r,(u[o>>2]|0)-s>>3,e+8|0);a=i+8|0;Ab(u[a>>2]|0,u[n>>2]|0,u[t>>2]|0);u[a>>2]=(u[a>>2]|0)+8;Nb(e,i);Fb(i);h=l;return}}function Pb(e){e=e|0;return 536870911}function Rb(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>536870911)$e();else{i=VM(n<<3)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t<<3)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n<<3);return}function Nb(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(0-(i>>3)<<3)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function Fb(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~((r+-8-n|0)>>>3)<<3);e=u[e>>2]|0;if(e|0)XM(e);return}function Ob(e){e=e|0;Bb(e);return}function Lb(e){e=e|0;Ib(e+24|0);return}function Ib(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~((n+-8-r|0)>>>3)<<3);XM(t)}return}function Bb(e){e=e|0;var n=0;n=Za()|0;tl(e,1,16,n,Ub()|0,0);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function Ub(){return 1400}function jb(e){e=e|0;return zb(u[(Wb(e)|0)>>2]|0)|0}function Wb(e){e=e|0;return(u[(kb()|0)+24>>2]|0)+(e<<3)|0}function zb(e){e=e|0;return Hb(MA[e&7]()|0)|0}function Hb(e){e=e|0;return e|0}function Gb(){var e=0;if(!(r[7880]|0)){Jb(10280);Le(25,10280,_|0)|0;e=7880;u[e>>2]=1;u[e+4>>2]=0}return 10280}function Yb(e,n){e=e|0;n=n|0;u[e>>2]=qb()|0;u[e+4>>2]=Vb()|0;u[e+12>>2]=n;u[e+8>>2]=$b()|0;u[e+32>>2]=4;return}function qb(){return 11711}function Vb(){return 1356}function $b(){return zv()|0}function Xb(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;if((jv(r,896)|0)==512){if(t|0){Kb(t);XM(t)}}else if(n|0){Hi(n);XM(n)}return}function Kb(e){e=e|0;e=u[e+4>>2]|0;if(e|0)YM(e);return}function Jb(e){e=e|0;Al(e);return}function Qb(e){e=e|0;Zb(e,4920);eg(e)|0;ng(e)|0;return}function Zb(e,n){e=e|0;n=n|0;var t=0;t=Yd()|0;u[e>>2]=t;Mg(t,n);fD(u[e>>2]|0);return}function eg(e){e=e|0;var n=0;n=u[e>>2]|0;rg(n,mg()|0);return e|0}function ng(e){e=e|0;var n=0;n=u[e>>2]|0;rg(n,tg()|0);return e|0}function tg(){var e=0;if(!(r[7888]|0)){ig(10328);Le(53,10328,_|0)|0;e=7888;u[e>>2]=1;u[e+4>>2]=0}if(!(Ka(10328)|0))ig(10328);return 10328}function rg(e,n){e=e|0;n=n|0;Ia(e,0,n,0,0,0);return}function ig(e){e=e|0;ag(e);sg(e,10);return}function ug(e){e=e|0;og(e+24|0);return}function og(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~((n+-8-r|0)>>>3)<<3);XM(t)}return}function ag(e){e=e|0;var n=0;n=Za()|0;tl(e,5,1,n,dg()|0,2);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function lg(e,n,t){e=e|0;n=n|0;t=+t;fg(e,n,t);return}function sg(e,n){e=e|0;n=n|0;u[e+20>>2]=n;return}function fg(e,n,t){e=e|0;n=n|0;t=+t;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+16|0;o=r+8|0;l=r+13|0;i=r;a=r+12|0;Jl(l,n);u[o>>2]=Ql(l,n)|0;Xl(a,t);f[i>>3]=+Kl(a,t);cg(e,o,i);h=r;return}function cg(e,n,t){e=e|0;n=n|0;t=t|0;Hu(e+8|0,u[n>>2]|0,+f[t>>3]);r[e+24>>0]=1;return}function dg(){return 1404}function pg(e,n){e=e|0;n=+n;return hg(e,n)|0}function hg(e,n){e=e|0;n=+n;var t=0,r=0,i=0,o=0,a=0,l=0,s=0;r=h;h=h+16|0;o=r+4|0;a=r+8|0;l=r;i=jE(8)|0;t=i;s=VM(16)|0;Jl(o,e);e=Ql(o,e)|0;Xl(a,n);Hu(s,e,+Kl(a,n));a=t+4|0;u[a>>2]=s;e=VM(8)|0;a=u[a>>2]|0;u[l>>2]=0;u[o>>2]=u[l>>2];$d(e,a,o);u[i>>2]=e;h=r;return t|0}function mg(){var e=0;if(!(r[7896]|0)){vg(10364);Le(54,10364,_|0)|0;e=7896;u[e>>2]=1;u[e+4>>2]=0}if(!(Ka(10364)|0))vg(10364);return 10364}function vg(e){e=e|0;gg(e);sg(e,55);return}function _g(e){e=e|0;bg(e+24|0);return}function bg(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~((n+-8-r|0)>>>3)<<3);XM(t)}return}function gg(e){e=e|0;var n=0;n=Za()|0;tl(e,5,4,n,Tg()|0,0);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function yg(e){e=e|0;Dg(e);return}function Dg(e){e=e|0;wg(e);return}function wg(e){e=e|0;Eg(e+8|0);r[e+24>>0]=1;return}function Eg(e){e=e|0;u[e>>2]=0;f[e+8>>3]=0.0;return}function Tg(){return 1424}function Cg(){return kg()|0}function kg(){var e=0,n=0,t=0,r=0,i=0,o=0,a=0;n=h;h=h+16|0;i=n+4|0;a=n;t=jE(8)|0;e=t;r=VM(16)|0;Eg(r);o=e+4|0;u[o>>2]=r;r=VM(8)|0;o=u[o>>2]|0;u[a>>2]=0;u[i>>2]=u[a>>2];$d(r,o,i);u[t>>2]=r;h=n;return e|0}function Mg(e,n){e=e|0;n=n|0;u[e>>2]=Sg()|0;u[e+4>>2]=Ag()|0;u[e+12>>2]=n;u[e+8>>2]=xg()|0;u[e+32>>2]=5;return}function Sg(){return 11710}function Ag(){return 1416}function xg(){return Ng()|0}function Pg(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;if((jv(r,896)|0)==512){if(t|0){Rg(t);XM(t)}}else if(n|0)XM(n);return}function Rg(e){e=e|0;e=u[e+4>>2]|0;if(e|0)YM(e);return}function Ng(){var e=0;if(!(r[7904]|0)){u[2600]=Fg()|0;u[2601]=0;e=7904;u[e>>2]=1;u[e+4>>2]=0}return 10400}function Fg(){return u[357]|0}function Og(e){e=e|0;Lg(e,4926);Ig(e)|0;return}function Lg(e,n){e=e|0;n=n|0;var t=0;t=ol()|0;u[e>>2]=t;Xg(t,n);fD(u[e>>2]|0);return}function Ig(e){e=e|0;var n=0;n=u[e>>2]|0;rg(n,Bg()|0);return e|0}function Bg(){var e=0;if(!(r[7912]|0)){Ug(10412);Le(56,10412,_|0)|0;e=7912;u[e>>2]=1;u[e+4>>2]=0}if(!(Ka(10412)|0))Ug(10412);return 10412}function Ug(e){e=e|0;zg(e);sg(e,57);return}function jg(e){e=e|0;Wg(e+24|0);return}function Wg(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~((n+-8-r|0)>>>3)<<3);XM(t)}return}function zg(e){e=e|0;var n=0;n=Za()|0;tl(e,5,5,n,qg()|0,0);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function Hg(e){e=e|0;Gg(e);return}function Gg(e){e=e|0;Yg(e);return}function Yg(e){e=e|0;var n=0,t=0;n=e+8|0;t=n+48|0;do{u[n>>2]=0;n=n+4|0}while((n|0)<(t|0));r[e+56>>0]=1;return}function qg(){return 1432}function Vg(){return $g()|0}function $g(){var e=0,n=0,t=0,r=0,i=0,o=0,a=0,l=0;a=h;h=h+16|0;e=a+4|0;n=a;t=jE(8)|0;r=t;i=VM(48)|0;o=i;l=o+48|0;do{u[o>>2]=0;o=o+4|0}while((o|0)<(l|0));o=r+4|0;u[o>>2]=i;l=VM(8)|0;o=u[o>>2]|0;u[n>>2]=0;u[e>>2]=u[n>>2];pl(l,o,e);u[t>>2]=l;h=a;return r|0}function Xg(e,n){e=e|0;n=n|0;u[e>>2]=Kg()|0;u[e+4>>2]=Jg()|0;u[e+12>>2]=n;u[e+8>>2]=Qg()|0;u[e+32>>2]=6;return}function Kg(){return 11704}function Jg(){return 1436}function Qg(){return Ng()|0}function Zg(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;if((jv(r,896)|0)==512){if(t|0){ey(t);XM(t)}}else if(n|0)XM(n);return}function ey(e){e=e|0;e=u[e+4>>2]|0;if(e|0)YM(e);return}function ny(e){e=e|0;ty(e,4933);ry(e)|0;iy(e)|0;return}function ty(e,n){e=e|0;n=n|0;var t=0;t=Ny()|0;u[e>>2]=t;Fy(t,n);fD(u[e>>2]|0);return}function ry(e){e=e|0;var n=0;n=u[e>>2]|0;rg(n,Dy()|0);return e|0}function iy(e){e=e|0;var n=0;n=u[e>>2]|0;rg(n,uy()|0);return e|0}function uy(){var e=0;if(!(r[7920]|0)){oy(10452);Le(58,10452,_|0)|0;e=7920;u[e>>2]=1;u[e+4>>2]=0}if(!(Ka(10452)|0))oy(10452);return 10452}function oy(e){e=e|0;sy(e);sg(e,1);return}function ay(e){e=e|0;ly(e+24|0);return}function ly(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~((n+-8-r|0)>>>3)<<3);XM(t)}return}function sy(e){e=e|0;var n=0;n=Za()|0;tl(e,5,1,n,hy()|0,2);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function fy(e,n,t){e=e|0;n=+n;t=+t;cy(e,n,t);return}function cy(e,n,t){e=e|0;n=+n;t=+t;var r=0,i=0,u=0,o=0,a=0;r=h;h=h+32|0;u=r+8|0;a=r+17|0;i=r;o=r+16|0;Xl(a,n);f[u>>3]=+Kl(a,n);Xl(o,t);f[i>>3]=+Kl(o,t);dy(e,u,i);h=r;return}function dy(e,n,t){e=e|0;n=n|0;t=t|0;py(e+8|0,+f[n>>3],+f[t>>3]);r[e+24>>0]=1;return}function py(e,n,t){e=e|0;n=+n;t=+t;f[e>>3]=n;f[e+8>>3]=t;return}function hy(){return 1472}function my(e,n){e=+e;n=+n;return vy(e,n)|0}function vy(e,n){e=+e;n=+n;var t=0,r=0,i=0,o=0,a=0,l=0,s=0;r=h;h=h+16|0;a=r+4|0;l=r+8|0;s=r;i=jE(8)|0;t=i;o=VM(16)|0;Xl(a,e);e=+Kl(a,e);Xl(l,n);py(o,e,+Kl(l,n));l=t+4|0;u[l>>2]=o;o=VM(8)|0;l=u[l>>2]|0;u[s>>2]=0;u[a>>2]=u[s>>2];_y(o,l,a);u[i>>2]=o;h=r;return t|0}function _y(e,n,t){e=e|0;n=n|0;t=t|0;u[e>>2]=n;t=VM(16)|0;u[t+4>>2]=0;u[t+8>>2]=0;u[t>>2]=1452;u[t+12>>2]=n;u[e+4>>2]=t;return}function by(e){e=e|0;WM(e);XM(e);return}function gy(e){e=e|0;e=u[e+12>>2]|0;if(e|0)XM(e);return}function yy(e){e=e|0;XM(e);return}function Dy(){var e=0;if(!(r[7928]|0)){wy(10488);Le(59,10488,_|0)|0;e=7928;u[e>>2]=1;u[e+4>>2]=0}if(!(Ka(10488)|0))wy(10488);return 10488}function wy(e){e=e|0;Cy(e);sg(e,60);return}function Ey(e){e=e|0;Ty(e+24|0);return}function Ty(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~((n+-8-r|0)>>>3)<<3);XM(t)}return}function Cy(e){e=e|0;var n=0;n=Za()|0;tl(e,5,6,n,xy()|0,0);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function ky(e){e=e|0;My(e);return}function My(e){e=e|0;Sy(e);return}function Sy(e){e=e|0;Ay(e+8|0);r[e+24>>0]=1;return}function Ay(e){e=e|0;u[e>>2]=0;u[e+4>>2]=0;u[e+8>>2]=0;u[e+12>>2]=0;return}function xy(){return 1492}function Py(){return Ry()|0}function Ry(){var e=0,n=0,t=0,r=0,i=0,o=0,a=0;n=h;h=h+16|0;i=n+4|0;a=n;t=jE(8)|0;e=t;r=VM(16)|0;Ay(r);o=e+4|0;u[o>>2]=r;r=VM(8)|0;o=u[o>>2]|0;u[a>>2]=0;u[i>>2]=u[a>>2];_y(r,o,i);u[t>>2]=r;h=n;return e|0}function Ny(){var e=0;if(!(r[7936]|0)){jy(10524);Le(25,10524,_|0)|0;e=7936;u[e>>2]=1;u[e+4>>2]=0}return 10524}function Fy(e,n){e=e|0;n=n|0;u[e>>2]=Oy()|0;u[e+4>>2]=Ly()|0;u[e+12>>2]=n;u[e+8>>2]=Iy()|0;u[e+32>>2]=7;return}function Oy(){return 11700}function Ly(){return 1484}function Iy(){return Ng()|0}function By(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;if((jv(r,896)|0)==512){if(t|0){Uy(t);XM(t)}}else if(n|0)XM(n);return}function Uy(e){e=e|0;e=u[e+4>>2]|0;if(e|0)YM(e);return}function jy(e){e=e|0;Al(e);return}function Wy(e,n,t){e=e|0;n=n|0;t=t|0;e=Ra(n)|0;n=zy(t)|0;t=Hy(t,0)|0;SD(e,n,t,Gy()|0,0);return}function zy(e){e=e|0;return e|0}function Hy(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0;l=h;h=h+16|0;i=l;o=l+4|0;u[i>>2]=e;s=Gy()|0;a=s+24|0;n=Wa(n,4)|0;u[o>>2]=n;t=s+28|0;r=u[t>>2]|0;if(r>>>0<(u[s+32>>2]|0)>>>0){Qy(r,e,n);n=(u[t>>2]|0)+8|0;u[t>>2]=n}else{Zy(a,i,o);n=u[t>>2]|0}h=l;return(n-(u[a>>2]|0)>>3)+-1|0}function Gy(){var e=0,n=0;if(!(r[7944]|0)){Yy(10568);Le(61,10568,_|0)|0;n=7944;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(10568)|0)){e=10568;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));Yy(10568)}return 10568}function Yy(e){e=e|0;$y(e);return}function qy(e){e=e|0;Vy(e+24|0);return}function Vy(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~((n+-8-r|0)>>>3)<<3);XM(t)}return}function $y(e){e=e|0;var n=0;n=Za()|0;tl(e,1,17,n,Xf()|0,0);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function Xy(e){e=e|0;return Jy(u[(Ky(e)|0)>>2]|0)|0}function Ky(e){e=e|0;return(u[(Gy()|0)+24>>2]|0)+(e<<3)|0}function Jy(e){e=e|0;return Zf(MA[e&7]()|0)|0}function Qy(e,n,t){e=e|0;n=n|0;t=t|0;u[e>>2]=n;u[e+4>>2]=t;return}function Zy(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0;l=h;h=h+32|0;i=l;o=e+4|0;a=((u[o>>2]|0)-(u[e>>2]|0)>>3)+1|0;r=eD(e)|0;if(r>>>0<a>>>0)jM(e);else{s=u[e>>2]|0;c=(u[e+8>>2]|0)-s|0;f=c>>2;nD(i,c>>3>>>0<r>>>1>>>0?f>>>0<a>>>0?a:f:r,(u[o>>2]|0)-s>>3,e+8|0);a=i+8|0;Qy(u[a>>2]|0,u[n>>2]|0,u[t>>2]|0);u[a>>2]=(u[a>>2]|0)+8;tD(e,i);rD(i);h=l;return}}function eD(e){e=e|0;return 536870911}function nD(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>536870911)$e();else{i=VM(n<<3)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t<<3)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n<<3);return}function tD(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(0-(i>>3)<<3)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function rD(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~((r+-8-n|0)>>>3)<<3);e=u[e>>2]|0;if(e|0)XM(e);return}function iD(){uD();return}function uD(){oD(10604);return}function oD(e){e=e|0;aD(e,4955);return}function aD(e,n){e=e|0;n=n|0;var t=0;t=lD()|0;u[e>>2]=t;sD(t,n);fD(u[e>>2]|0);return}function lD(){var e=0;if(!(r[7952]|0)){yD(10612);Le(25,10612,_|0)|0;e=7952;u[e>>2]=1;u[e+4>>2]=0}return 10612}function sD(e,n){e=e|0;n=n|0;u[e>>2]=mD()|0;u[e+4>>2]=vD()|0;u[e+12>>2]=n;u[e+8>>2]=_D()|0;u[e+32>>2]=8;return}function fD(e){e=e|0;var n=0,t=0;n=h;h=h+16|0;t=n;cD()|0;u[t>>2]=e;dD(10608,t);h=n;return}function cD(){if(!(r[11714]|0)){u[2652]=0;Le(62,10608,_|0)|0;r[11714]=1}return 10608}function dD(e,n){e=e|0;n=n|0;var t=0;t=VM(8)|0;u[t+4>>2]=u[n>>2];u[t>>2]=u[e>>2];u[e>>2]=t;return}function pD(e){e=e|0;hD(e);return}function hD(e){e=e|0;var n=0,t=0;n=u[e>>2]|0;if(n|0)do{t=n;n=u[n>>2]|0;XM(t)}while((n|0)!=0);u[e>>2]=0;return}function mD(){return 11715}function vD(){return 1496}function _D(){return zv()|0}function bD(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;if((jv(r,896)|0)==512){if(t|0){gD(t);XM(t)}}else if(n|0)XM(n);return}function gD(e){e=e|0;e=u[e+4>>2]|0;if(e|0)YM(e);return}function yD(e){e=e|0;Al(e);return}function DD(e,n){e=e|0;n=n|0;var t=0,r=0;cD()|0;t=u[2652]|0;e:do{if(t|0){while(1){r=u[t+4>>2]|0;if(r|0?(rM(wD(r)|0,e)|0)==0:0)break;t=u[t>>2]|0;if(!t)break e}ED(r,n)}}while(0);return}function wD(e){e=e|0;return u[e+12>>2]|0}function ED(e,n){e=e|0;n=n|0;var t=0;e=e+36|0;t=u[e>>2]|0;if(t|0){Qi(t);XM(t)}t=VM(4)|0;bo(t,n);u[e>>2]=t;return}function TD(){if(!(r[11716]|0)){u[2664]=0;Le(63,10656,_|0)|0;r[11716]=1}return 10656}function CD(){var e=0;if(!(r[11717]|0)){kD();u[2665]=1504;r[11717]=1;e=1504}else e=u[2665]|0;return e|0}function kD(){if(!(r[11740]|0)){r[11718]=Wa(Wa(8,0)|0,0)|0;r[11719]=Wa(Wa(0,0)|0,0)|0;r[11720]=Wa(Wa(0,16)|0,0)|0;r[11721]=Wa(Wa(8,0)|0,0)|0;r[11722]=Wa(Wa(0,0)|0,0)|0;r[11723]=Wa(Wa(8,0)|0,0)|0;r[11724]=Wa(Wa(0,0)|0,0)|0;r[11725]=Wa(Wa(8,0)|0,0)|0;r[11726]=Wa(Wa(0,0)|0,0)|0;r[11727]=Wa(Wa(8,0)|0,0)|0;r[11728]=Wa(Wa(0,0)|0,0)|0;r[11729]=Wa(Wa(0,0)|0,32)|0;r[11730]=Wa(Wa(0,0)|0,32)|0;r[11740]=1}return}function MD(){return 1572}function SD(e,n,t,r,i){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;var o=0,a=0,l=0,s=0,f=0,c=0;o=h;h=h+32|0;c=o+16|0;f=o+12|0;s=o+8|0;l=o+4|0;a=o;u[c>>2]=e;u[f>>2]=n;u[s>>2]=t;u[l>>2]=r;u[a>>2]=i;TD()|0;AD(10656,c,f,s,l,a);h=o;return}function AD(e,n,t,r,i,o){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;o=o|0;var a=0;a=VM(24)|0;ja(a+4|0,u[n>>2]|0,u[t>>2]|0,u[r>>2]|0,u[i>>2]|0,u[o>>2]|0);u[a>>2]=u[e>>2];u[e>>2]=a;return}function xD(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0,m=0,v=0,_=0,b=0,g=0,y=0;y=h;h=h+32|0;v=y+20|0;_=y+8|0;b=y+4|0;g=y;n=u[n>>2]|0;if(n|0){m=v+4|0;s=v+8|0;f=_+4|0;c=_+8|0;d=_+8|0;p=v+8|0;do{a=n+4|0;l=PD(a)|0;if(l|0){i=RD(l)|0;u[v>>2]=0;u[m>>2]=0;u[s>>2]=0;r=(ND(l)|0)+1|0;FD(v,r);if(r|0)while(1){r=r+-1|0;_k(_,u[i>>2]|0);o=u[m>>2]|0;if(o>>>0<(u[p>>2]|0)>>>0){u[o>>2]=u[_>>2];u[m>>2]=(u[m>>2]|0)+4}else OD(v,_);if(!r)break;else i=i+4|0}r=LD(l)|0;u[_>>2]=0;u[f>>2]=0;u[c>>2]=0;e:do{if(u[r>>2]|0){i=0;o=0;while(1){if((i|0)==(o|0))ID(_,r);else{u[i>>2]=u[r>>2];u[f>>2]=(u[f>>2]|0)+4}r=r+4|0;if(!(u[r>>2]|0))break e;i=u[f>>2]|0;o=u[d>>2]|0}}}while(0);u[b>>2]=BD(a)|0;u[g>>2]=Ka(l)|0;UD(t,e,b,g,v,_);jD(_);WD(v)}n=u[n>>2]|0}while((n|0)!=0)}h=y;return}function PD(e){e=e|0;return u[e+12>>2]|0}function RD(e){e=e|0;return u[e+12>>2]|0}function ND(e){e=e|0;return u[e+16>>2]|0}function FD(e,n){e=e|0;n=n|0;var t=0,r=0,i=0;i=h;h=h+32|0;t=i;r=u[e>>2]|0;if((u[e+8>>2]|0)-r>>2>>>0<n>>>0){yw(t,n,(u[e+4>>2]|0)-r>>2,e+8|0);Dw(e,t);ww(t)}h=i;return}function OD(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0;a=h;h=h+32|0;t=a;r=e+4|0;i=((u[r>>2]|0)-(u[e>>2]|0)>>2)+1|0;o=vw(e)|0;if(o>>>0<i>>>0)jM(e);else{l=u[e>>2]|0;f=(u[e+8>>2]|0)-l|0;s=f>>1;yw(t,f>>2>>>0<o>>>1>>>0?s>>>0<i>>>0?i:s:o,(u[r>>2]|0)-l>>2,e+8|0);o=t+8|0;u[u[o>>2]>>2]=u[n>>2];u[o>>2]=(u[o>>2]|0)+4;Dw(e,t);ww(t);h=a;return}}function LD(e){e=e|0;return u[e+8>>2]|0}function ID(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0;a=h;h=h+32|0;t=a;r=e+4|0;i=((u[r>>2]|0)-(u[e>>2]|0)>>2)+1|0;o=pw(e)|0;if(o>>>0<i>>>0)jM(e);else{l=u[e>>2]|0;f=(u[e+8>>2]|0)-l|0;s=f>>1;_w(t,f>>2>>>0<o>>>1>>>0?s>>>0<i>>>0?i:s:o,(u[r>>2]|0)-l>>2,e+8|0);o=t+8|0;u[u[o>>2]>>2]=u[n>>2];u[o>>2]=(u[o>>2]|0)+4;bw(e,t);gw(t);h=a;return}}function BD(e){e=e|0;return u[e>>2]|0}function UD(e,n,t,r,i,u){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;u=u|0;zD(e,n,t,r,i,u);return}function jD(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~((n+-4-r|0)>>>2)<<2);XM(t)}return}function WD(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~((n+-4-r|0)>>>2)<<2);XM(t)}return}function zD(e,n,t,r,i,o){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;o=o|0;var a=0,l=0,s=0,f=0,c=0,d=0;a=h;h=h+48|0;c=a+40|0;l=a+32|0;d=a+24|0;s=a+12|0;f=a;Ek(l);e=wo(e)|0;u[d>>2]=u[n>>2];t=u[t>>2]|0;r=u[r>>2]|0;HD(s,i);GD(f,o);u[c>>2]=u[d>>2];YD(e,c,t,r,s,f);jD(f);WD(s);Ck(l);h=a;return}function HD(e,n){e=e|0;n=n|0;var t=0,r=0;u[e>>2]=0;u[e+4>>2]=0;u[e+8>>2]=0;t=n+4|0;r=(u[t>>2]|0)-(u[n>>2]|0)>>2;if(r|0){hw(e,r);mw(e,u[n>>2]|0,u[t>>2]|0,r)}return}function GD(e,n){e=e|0;n=n|0;var t=0,r=0;u[e>>2]=0;u[e+4>>2]=0;u[e+8>>2]=0;t=n+4|0;r=(u[t>>2]|0)-(u[n>>2]|0)>>2;if(r|0){cw(e,r);dw(e,u[n>>2]|0,u[t>>2]|0,r)}return}function YD(e,n,t,r,i,o){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;o=o|0;var a=0,l=0,s=0,f=0,c=0,d=0;a=h;h=h+32|0;c=a+28|0;d=a+24|0;l=a+12|0;s=a;f=Co(qD()|0)|0;u[d>>2]=u[n>>2];u[c>>2]=u[d>>2];n=VD(c)|0;t=$D(t)|0;r=XD(r)|0;u[l>>2]=u[i>>2];c=i+4|0;u[l+4>>2]=u[c>>2];d=i+8|0;u[l+8>>2]=u[d>>2];u[d>>2]=0;u[c>>2]=0;u[i>>2]=0;i=KD(l)|0;u[s>>2]=u[o>>2];c=o+4|0;u[s+4>>2]=u[c>>2];d=o+8|0;u[s+8>>2]=u[d>>2];u[d>>2]=0;u[c>>2]=0;u[o>>2]=0;xe(0,f|0,e|0,n|0,t|0,r|0,i|0,JD(s)|0)|0;jD(s);WD(l);h=a;return}function qD(){var e=0;if(!(r[7968]|0)){sw(10708);e=7968;u[e>>2]=1;u[e+4>>2]=0}return 10708}function VD(e){e=e|0;return nw(e)|0}function $D(e){e=e|0;return ZD(e)|0}function XD(e){e=e|0;return Zf(e)|0}function KD(e){e=e|0;return ew(e)|0}function JD(e){e=e|0;return QD(e)|0}function QD(e){e=e|0;var n=0,t=0,r=0;r=(u[e+4>>2]|0)-(u[e>>2]|0)|0;t=r>>2;r=jE(r+4|0)|0;u[r>>2]=t;if(t|0){n=0;do{u[r+4+(n<<2)>>2]=ZD(u[(u[e>>2]|0)+(n<<2)>>2]|0)|0;n=n+1|0}while((n|0)!=(t|0))}return r|0}function ZD(e){e=e|0;return e|0}function ew(e){e=e|0;var n=0,t=0,r=0;r=(u[e+4>>2]|0)-(u[e>>2]|0)|0;t=r>>2;r=jE(r+4|0)|0;u[r>>2]=t;if(t|0){n=0;do{u[r+4+(n<<2)>>2]=nw((u[e>>2]|0)+(n<<2)|0)|0;n=n+1|0}while((n|0)!=(t|0))}return r|0}function nw(e){e=e|0;var n=0,t=0,r=0,i=0;i=h;h=h+32|0;n=i+12|0;t=i;r=al(tw()|0)|0;if(!r)e=rw(e)|0;else{ll(n,r);sl(t,n);yk(e,t);e=cl(n)|0}h=i;return e|0}function tw(){var e=0;if(!(r[7960]|0)){lw(10664);Le(25,10664,_|0)|0;e=7960;u[e>>2]=1;u[e+4>>2]=0}return 10664}function rw(e){e=e|0;var n=0,t=0,r=0,i=0,o=0,a=0,l=0;t=h;h=h+16|0;i=t+4|0;a=t;r=jE(8)|0;n=r;l=VM(4)|0;u[l>>2]=u[e>>2];o=n+4|0;u[o>>2]=l;e=VM(8)|0;o=u[o>>2]|0;u[a>>2]=0;u[i>>2]=u[a>>2];iw(e,o,i);u[r>>2]=e;h=t;return n|0}function iw(e,n,t){e=e|0;n=n|0;t=t|0;u[e>>2]=n;t=VM(16)|0;u[t+4>>2]=0;u[t+8>>2]=0;u[t>>2]=1656;u[t+12>>2]=n;u[e+4>>2]=t;return}function uw(e){e=e|0;WM(e);XM(e);return}function ow(e){e=e|0;e=u[e+12>>2]|0;if(e|0)XM(e);return}function aw(e){e=e|0;XM(e);return}function lw(e){e=e|0;Al(e);return}function sw(e){e=e|0;Io(e,fw()|0,5);return}function fw(){return 1676}function cw(e,n){e=e|0;n=n|0;var t=0;if((pw(e)|0)>>>0<n>>>0)jM(e);if(n>>>0>1073741823)$e();else{t=VM(n<<2)|0;u[e+4>>2]=t;u[e>>2]=t;u[e+8>>2]=t+(n<<2);return}}function dw(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;r=e+4|0;e=t-n|0;if((e|0)>0){iS(u[r>>2]|0,n|0,e|0)|0;u[r>>2]=(u[r>>2]|0)+(e>>>2<<2)}return}function pw(e){e=e|0;return 1073741823}function hw(e,n){e=e|0;n=n|0;var t=0;if((vw(e)|0)>>>0<n>>>0)jM(e);if(n>>>0>1073741823)$e();else{t=VM(n<<2)|0;u[e+4>>2]=t;u[e>>2]=t;u[e+8>>2]=t+(n<<2);return}}function mw(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;r=e+4|0;e=t-n|0;if((e|0)>0){iS(u[r>>2]|0,n|0,e|0)|0;u[r>>2]=(u[r>>2]|0)+(e>>>2<<2)}return}function vw(e){e=e|0;return 1073741823}function _w(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>1073741823)$e();else{i=VM(n<<2)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t<<2)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n<<2);return}function bw(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(0-(i>>2)<<2)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function gw(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~((r+-4-n|0)>>>2)<<2);e=u[e>>2]|0;if(e|0)XM(e);return}function yw(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>1073741823)$e();else{i=VM(n<<2)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t<<2)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n<<2);return}function Dw(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(0-(i>>2)<<2)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function ww(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~((r+-4-n|0)>>>2)<<2);e=u[e>>2]|0;if(e|0)XM(e);return}function Ew(e,n,t,r,i){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;var o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0,m=0,v=0,_=0;_=h;h=h+32|0;c=_+20|0;d=_+12|0;f=_+16|0;p=_+4|0;m=_;v=_+8|0;l=CD()|0;o=u[l>>2]|0;a=u[o>>2]|0;if(a|0){s=u[l+8>>2]|0;l=u[l+4>>2]|0;while(1){_k(c,a);Tw(e,c,l,s);o=o+4|0;a=u[o>>2]|0;if(!a)break;else{s=s+1|0;l=l+1|0}}}o=MD()|0;a=u[o>>2]|0;if(a|0)do{_k(c,a);u[d>>2]=u[o+4>>2];Cw(n,c,d);o=o+8|0;a=u[o>>2]|0}while((a|0)!=0);o=u[(cD()|0)>>2]|0;if(o|0)do{n=u[o+4>>2]|0;_k(c,u[(kw(n)|0)>>2]|0);u[d>>2]=wD(n)|0;Mw(t,c,d);o=u[o>>2]|0}while((o|0)!=0);_k(f,0);o=TD()|0;u[c>>2]=u[f>>2];xD(c,o,i);o=u[(cD()|0)>>2]|0;if(o|0){e=c+4|0;n=c+8|0;t=c+8|0;do{s=u[o+4>>2]|0;_k(d,u[(kw(s)|0)>>2]|0);Aw(p,Sw(s)|0);a=u[p>>2]|0;if(a|0){u[c>>2]=0;u[e>>2]=0;u[n>>2]=0;do{_k(m,u[(kw(u[a+4>>2]|0)|0)>>2]|0);l=u[e>>2]|0;if(l>>>0<(u[t>>2]|0)>>>0){u[l>>2]=u[m>>2];u[e>>2]=(u[e>>2]|0)+4}else OD(c,m);a=u[a>>2]|0}while((a|0)!=0);xw(r,d,c);WD(c)}u[v>>2]=u[d>>2];f=Pw(s)|0;u[c>>2]=u[v>>2];xD(c,f,i);kl(p);o=u[o>>2]|0}while((o|0)!=0)}h=_;return}function Tw(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;Yw(e,n,t,r);return}function Cw(e,n,t){e=e|0;n=n|0;t=t|0;Gw(e,n,t);return}function kw(e){e=e|0;return e|0}function Mw(e,n,t){e=e|0;n=n|0;t=t|0;Uw(e,n,t);return}function Sw(e){e=e|0;return e+16|0}function Aw(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0;o=h;h=h+16|0;i=o+8|0;t=o;u[e>>2]=0;r=u[n>>2]|0;u[i>>2]=r;u[t>>2]=e;t=Iw(t)|0;if(r|0){r=VM(12)|0;a=(Bw(i)|0)+4|0;e=u[a+4>>2]|0;n=r+4|0;u[n>>2]=u[a>>2];u[n+4>>2]=e;n=u[u[i>>2]>>2]|0;u[i>>2]=n;if(!n)e=r;else{n=r;while(1){e=VM(12)|0;s=(Bw(i)|0)+4|0;l=u[s+4>>2]|0;a=e+4|0;u[a>>2]=u[s>>2];u[a+4>>2]=l;u[n>>2]=e;a=u[u[i>>2]>>2]|0;u[i>>2]=a;if(!a)break;else n=e}}u[e>>2]=u[t>>2];u[t>>2]=r}h=o;return}function xw(e,n,t){e=e|0;n=n|0;t=t|0;Rw(e,n,t);return}function Pw(e){e=e|0;return e+24|0}function Rw(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+32|0;a=r+24|0;i=r+16|0;l=r+12|0;o=r;Ek(i);e=wo(e)|0;u[l>>2]=u[n>>2];HD(o,t);u[a>>2]=u[l>>2];Nw(e,a,o);WD(o);Ck(i);h=r;return}function Nw(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0;r=h;h=h+32|0;a=r+16|0;l=r+12|0;i=r;o=Co(Fw()|0)|0;u[l>>2]=u[n>>2];u[a>>2]=u[l>>2];n=VD(a)|0;u[i>>2]=u[t>>2];a=t+4|0;u[i+4>>2]=u[a>>2];l=t+8|0;u[i+8>>2]=u[l>>2];u[l>>2]=0;u[a>>2]=0;u[t>>2]=0;ke(0,o|0,e|0,n|0,KD(i)|0)|0;WD(i);h=r;return}function Fw(){var e=0;if(!(r[7976]|0)){Ow(10720);e=7976;u[e>>2]=1;u[e+4>>2]=0}return 10720}function Ow(e){e=e|0;Io(e,Lw()|0,2);return}function Lw(){return 1732}function Iw(e){e=e|0;return u[e>>2]|0}function Bw(e){e=e|0;return u[e>>2]|0}function Uw(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+32|0;o=r+16|0;i=r+8|0;a=r;Ek(i);e=wo(e)|0;u[a>>2]=u[n>>2];t=u[t>>2]|0;u[o>>2]=u[a>>2];jw(e,o,t);Ck(i);h=r;return}function jw(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+16|0;o=r+4|0;a=r;i=Co(Ww()|0)|0;u[a>>2]=u[n>>2];u[o>>2]=u[a>>2];n=VD(o)|0;ke(0,i|0,e|0,n|0,$D(t)|0)|0;h=r;return}function Ww(){var e=0;if(!(r[7984]|0)){zw(10732);e=7984;u[e>>2]=1;u[e+4>>2]=0}return 10732}function zw(e){e=e|0;Io(e,Hw()|0,2);return}function Hw(){return 1744}function Gw(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0;r=h;h=h+32|0;o=r+16|0;i=r+8|0;a=r;Ek(i);e=wo(e)|0;u[a>>2]=u[n>>2];t=u[t>>2]|0;u[o>>2]=u[a>>2];jw(e,o,t);Ck(i);h=r;return}function Yw(e,n,t,i){e=e|0;n=n|0;t=t|0;i=i|0;var o=0,a=0,l=0,s=0;o=h;h=h+32|0;l=o+16|0;a=o+8|0;s=o;Ek(a);e=wo(e)|0;u[s>>2]=u[n>>2];t=r[t>>0]|0;i=r[i>>0]|0;u[l>>2]=u[s>>2];qw(e,l,t,i);Ck(a);h=o;return}function qw(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0;i=h;h=h+16|0;a=i+4|0;l=i;o=Co(Vw()|0)|0;u[l>>2]=u[n>>2];u[a>>2]=u[l>>2];n=VD(a)|0;t=$w(t)|0;tn(0,o|0,e|0,n|0,t|0,$w(r)|0)|0;h=i;return}function Vw(){var e=0;if(!(r[7992]|0)){Kw(10744);e=7992;u[e>>2]=1;u[e+4>>2]=0}return 10744}function $w(e){e=e|0;return Xw(e)|0}function Xw(e){e=e|0;return e&255|0}function Kw(e){e=e|0;Io(e,Jw()|0,3);return}function Jw(){return 1756}function Qw(e,n,t){e=e|0;n=n|0;t=t|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0,m=0;m=h;h=h+32|0;s=m+8|0;f=m+4|0;c=m+20|0;d=m;Gs(e,0);i=gk(n)|0;u[s>>2]=0;p=s+4|0;u[p>>2]=0;u[s+8>>2]=0;switch(i<<24>>24){case 0:{r[c>>0]=0;Zw(f,t,c);eE(e,f)|0;Zi(f);break}case 8:{p=bk(n)|0;r[c>>0]=8;_k(d,u[p+4>>2]|0);nE(f,t,c,d,p+8|0);eE(e,f)|0;Zi(f);break}case 9:{a=bk(n)|0;n=u[a+4>>2]|0;if(n|0){l=s+8|0;o=a+12|0;while(1){n=n+-1|0;_k(f,u[o>>2]|0);i=u[p>>2]|0;if(i>>>0<(u[l>>2]|0)>>>0){u[i>>2]=u[f>>2];u[p>>2]=(u[p>>2]|0)+4}else OD(s,f);if(!n)break;else o=o+4|0}}r[c>>0]=9;_k(d,u[a+8>>2]|0);tE(f,t,c,d,s);eE(e,f)|0;Zi(f);break}default:{p=bk(n)|0;r[c>>0]=i;_k(d,u[p+4>>2]|0);rE(f,t,c,d);eE(e,f)|0;Zi(f)}}WD(s);h=m;return}function Zw(e,n,t){e=e|0;n=n|0;t=t|0;var i=0,u=0;i=h;h=h+16|0;u=i;Ek(u);n=wo(n)|0;_E(e,n,r[t>>0]|0);Ck(u);h=i;return}function eE(e,n){e=e|0;n=n|0;var t=0;t=u[e>>2]|0;if(t|0)rn(t|0);u[e>>2]=u[n>>2];u[n>>2]=0;return e|0}function nE(e,n,t,i,o){e=e|0;n=n|0;t=t|0;i=i|0;o=o|0;var a=0,l=0,s=0,f=0;a=h;h=h+32|0;s=a+16|0;l=a+8|0;f=a;Ek(l);n=wo(n)|0;t=r[t>>0]|0;u[f>>2]=u[i>>2];o=u[o>>2]|0;u[s>>2]=u[f>>2];pE(e,n,t,s,o);Ck(l);h=a;return}function tE(e,n,t,i,o){e=e|0;n=n|0;t=t|0;i=i|0;o=o|0;var a=0,l=0,s=0,f=0,c=0;a=h;h=h+32|0;f=a+24|0;l=a+16|0;c=a+12|0;s=a;Ek(l);n=wo(n)|0;t=r[t>>0]|0;u[c>>2]=u[i>>2];HD(s,o);u[f>>2]=u[c>>2];sE(e,n,t,f,s);WD(s);Ck(l);h=a;return}function rE(e,n,t,i){e=e|0;n=n|0;t=t|0;i=i|0;var o=0,a=0,l=0,s=0;o=h;h=h+32|0;l=o+16|0;a=o+8|0;s=o;Ek(a);n=wo(n)|0;t=r[t>>0]|0;u[s>>2]=u[i>>2];u[l>>2]=u[s>>2];iE(e,n,t,l);Ck(a);h=o;return}function iE(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0,a=0,l=0;i=h;h=h+16|0;o=i+4|0;l=i;a=Co(uE()|0)|0;t=$w(t)|0;u[l>>2]=u[r>>2];u[o>>2]=u[l>>2];oE(e,ke(0,a|0,n|0,t|0,VD(o)|0)|0);h=i;return}function uE(){var e=0;if(!(r[8e3]|0)){aE(10756);e=8e3;u[e>>2]=1;u[e+4>>2]=0}return 10756}function oE(e,n){e=e|0;n=n|0;Gs(e,n);return}function aE(e){e=e|0;Io(e,lE()|0,2);return}function lE(){return 1772}function sE(e,n,t,r,i){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;var o=0,a=0,l=0,s=0,f=0;o=h;h=h+32|0;s=o+16|0;f=o+12|0;a=o;l=Co(fE()|0)|0;t=$w(t)|0;u[f>>2]=u[r>>2];u[s>>2]=u[f>>2];r=VD(s)|0;u[a>>2]=u[i>>2];s=i+4|0;u[a+4>>2]=u[s>>2];f=i+8|0;u[a+8>>2]=u[f>>2];u[f>>2]=0;u[s>>2]=0;u[i>>2]=0;oE(e,tn(0,l|0,n|0,t|0,r|0,KD(a)|0)|0);WD(a);h=o;return}function fE(){var e=0;if(!(r[8008]|0)){cE(10768);e=8008;u[e>>2]=1;u[e+4>>2]=0}return 10768}function cE(e){e=e|0;Io(e,dE()|0,3);return}function dE(){return 1784}function pE(e,n,t,r,i){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;var o=0,a=0,l=0,s=0;o=h;h=h+16|0;l=o+4|0;s=o;a=Co(hE()|0)|0;t=$w(t)|0;u[s>>2]=u[r>>2];u[l>>2]=u[s>>2];r=VD(l)|0;oE(e,tn(0,a|0,n|0,t|0,r|0,XD(i)|0)|0);h=o;return}function hE(){var e=0;if(!(r[8016]|0)){mE(10780);e=8016;u[e>>2]=1;u[e+4>>2]=0}return 10780}function mE(e){e=e|0;Io(e,vE()|0,3);return}function vE(){return 1800}function _E(e,n,t){e=e|0;n=n|0;t=t|0;var r=0;r=Co(bE()|0)|0;oE(e,un(0,r|0,n|0,$w(t)|0)|0);return}function bE(){var e=0;if(!(r[8024]|0)){gE(10792);e=8024;u[e>>2]=1;u[e+4>>2]=0}return 10792}function gE(e){e=e|0;Io(e,yE()|0,1);return}function yE(){return 1816}function DE(){wE();EE();TE();return}function wE(){u[2702]=$M(65536)|0;return}function EE(){VE(10856);return}function TE(){CE(10816);return}function CE(e){e=e|0;kE(e,5044);ME(e)|0;return}function kE(e,n){e=e|0;n=n|0;var t=0;t=tw()|0;u[e>>2]=t;WE(t,n);fD(u[e>>2]|0);return}function ME(e){e=e|0;var n=0;n=u[e>>2]|0;rg(n,SE()|0);return e|0}function SE(){var e=0;if(!(r[8032]|0)){AE(10820);Le(64,10820,_|0)|0;e=8032;u[e>>2]=1;u[e+4>>2]=0}if(!(Ka(10820)|0))AE(10820);return 10820}function AE(e){e=e|0;RE(e);sg(e,25);return}function xE(e){e=e|0;PE(e+24|0);return}function PE(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~((n+-8-r|0)>>>3)<<3);XM(t)}return}function RE(e){e=e|0;var n=0;n=Za()|0;tl(e,5,18,n,IE()|0,1);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function NE(e,n){e=e|0;n=n|0;FE(e,n);return}function FE(e,n){e=e|0;n=n|0;var t=0,r=0,i=0;t=h;h=h+16|0;r=t;i=t+4|0;cf(i,n);u[r>>2]=df(i,n)|0;OE(e,r);h=t;return}function OE(e,n){e=e|0;n=n|0;LE(e+4|0,u[n>>2]|0);r[e+8>>0]=1;return}function LE(e,n){e=e|0;n=n|0;u[e>>2]=n;return}function IE(){return 1824}function BE(e){e=e|0;return UE(e)|0}function UE(e){e=e|0;var n=0,t=0,r=0,i=0,o=0,a=0,l=0;t=h;h=h+16|0;i=t+4|0;a=t;r=jE(8)|0;n=r;l=VM(4)|0;cf(i,e);LE(l,df(i,e)|0);o=n+4|0;u[o>>2]=l;e=VM(8)|0;o=u[o>>2]|0;u[a>>2]=0;u[i>>2]=u[a>>2];iw(e,o,i);u[r>>2]=e;h=t;return n|0}function jE(e){e=e|0;var n=0,t=0;e=e+7&-8;if(e>>>0<=32768?(n=u[2701]|0,e>>>0<=(65536-n|0)>>>0):0){t=(u[2702]|0)+n|0;u[2701]=n+e;e=t}else{e=$M(e+8|0)|0;u[e>>2]=u[2703];u[2703]=e;e=e+8|0}return e|0}function WE(e,n){e=e|0;n=n|0;u[e>>2]=zE()|0;u[e+4>>2]=HE()|0;u[e+12>>2]=n;u[e+8>>2]=GE()|0;u[e+32>>2]=9;return}function zE(){return 11744}function HE(){return 1832}function GE(){return Ng()|0}function YE(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;if((jv(r,896)|0)==512){if(t|0){qE(t);XM(t)}}else if(n|0)XM(n);return}function qE(e){e=e|0;e=u[e+4>>2]|0;if(e|0)YM(e);return}function VE(e){e=e|0;$E(e,5052);XE(e)|0;KE(e,5058,26)|0;JE(e,5069,1)|0;QE(e,5077,10)|0;ZE(e,5087,19)|0;nT(e,5094,27)|0;return}function $E(e,n){e=e|0;n=n|0;var t=0;t=sk()|0;u[e>>2]=t;fk(t,n);fD(u[e>>2]|0);return}function XE(e){e=e|0;var n=0;n=u[e>>2]|0;rg(n,$C()|0);return e|0}function KE(e,n,t){e=e|0;n=n|0;t=t|0;MC(e,Ra(n)|0,t,0);return e|0}function JE(e,n,t){e=e|0;n=n|0;t=t|0;sC(e,Ra(n)|0,t,0);return e|0}function QE(e,n,t){e=e|0;n=n|0;t=t|0;BT(e,Ra(n)|0,t,0);return e|0}function ZE(e,n,t){e=e|0;n=n|0;t=t|0;yT(e,Ra(n)|0,t,0);return e|0}function eT(e,n){e=e|0;n=n|0;var t=0,r=0;e:while(1){t=u[2703]|0;while(1){if((t|0)==(n|0))break e;r=u[t>>2]|0;u[2703]=r;if(!t)t=r;else break}XM(t)}u[2701]=e;return}function nT(e,n,t){e=e|0;n=n|0;t=t|0;tT(e,Ra(n)|0,t,0);return e|0}function tT(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0;o=u[e>>2]|0;i=rT()|0;e=iT(t)|0;Ia(o,n,i,e,uT(t,r)|0,r);return}function rT(){var e=0,n=0;if(!(r[8040]|0)){dT(10860);Le(65,10860,_|0)|0;n=8040;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(10860)|0)){e=10860;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));dT(10860)}return 10860}function iT(e){e=e|0;return e|0}function uT(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0;l=h;h=h+16|0;i=l;o=l+4|0;u[i>>2]=e;s=rT()|0;a=s+24|0;n=Wa(n,4)|0;u[o>>2]=n;t=s+28|0;r=u[t>>2]|0;if(r>>>0<(u[s+32>>2]|0)>>>0){oT(r,e,n);n=(u[t>>2]|0)+8|0;u[t>>2]=n}else{aT(a,i,o);n=u[t>>2]|0}h=l;return(n-(u[a>>2]|0)>>3)+-1|0}function oT(e,n,t){e=e|0;n=n|0;t=t|0;u[e>>2]=n;u[e+4>>2]=t;return}function aT(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0;l=h;h=h+32|0;i=l;o=e+4|0;a=((u[o>>2]|0)-(u[e>>2]|0)>>3)+1|0;r=lT(e)|0;if(r>>>0<a>>>0)jM(e);else{s=u[e>>2]|0;c=(u[e+8>>2]|0)-s|0;f=c>>2;sT(i,c>>3>>>0<r>>>1>>>0?f>>>0<a>>>0?a:f:r,(u[o>>2]|0)-s>>3,e+8|0);a=i+8|0;oT(u[a>>2]|0,u[n>>2]|0,u[t>>2]|0);u[a>>2]=(u[a>>2]|0)+8;fT(e,i);cT(i);h=l;return}}function lT(e){e=e|0;return 536870911}function sT(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>536870911)$e();else{i=VM(n<<3)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t<<3)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n<<3);return}function fT(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(0-(i>>3)<<3)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function cT(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~((r+-8-n|0)>>>3)<<3);e=u[e>>2]|0;if(e|0)XM(e);return}function dT(e){e=e|0;mT(e);return}function pT(e){e=e|0;hT(e+24|0);return}function hT(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~((n+-8-r|0)>>>3)<<3);XM(t)}return}function mT(e){e=e|0;var n=0;n=Za()|0;tl(e,1,11,n,vT()|0,2);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function vT(){return 1840}function _T(e,n,t){e=e|0;n=n|0;t=t|0;gT(u[(bT(e)|0)>>2]|0,n,t);return}function bT(e){e=e|0;return(u[(rT()|0)+24>>2]|0)+(e<<3)|0}function gT(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,u=0;r=h;h=h+16|0;u=r+1|0;i=r;cf(u,n);n=df(u,n)|0;cf(i,t);t=df(i,t)|0;mA[e&31](n,t);h=r;return}function yT(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0;o=u[e>>2]|0;i=DT()|0;e=wT(t)|0;Ia(o,n,i,e,ET(t,r)|0,r);return}function DT(){var e=0,n=0;if(!(r[8048]|0)){xT(10896);Le(66,10896,_|0)|0;n=8048;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(10896)|0)){e=10896;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));xT(10896)}return 10896}function wT(e){e=e|0;return e|0}function ET(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0;l=h;h=h+16|0;i=l;o=l+4|0;u[i>>2]=e;s=DT()|0;a=s+24|0;n=Wa(n,4)|0;u[o>>2]=n;t=s+28|0;r=u[t>>2]|0;if(r>>>0<(u[s+32>>2]|0)>>>0){TT(r,e,n);n=(u[t>>2]|0)+8|0;u[t>>2]=n}else{CT(a,i,o);n=u[t>>2]|0}h=l;return(n-(u[a>>2]|0)>>3)+-1|0}function TT(e,n,t){e=e|0;n=n|0;t=t|0;u[e>>2]=n;u[e+4>>2]=t;return}function CT(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0;l=h;h=h+32|0;i=l;o=e+4|0;a=((u[o>>2]|0)-(u[e>>2]|0)>>3)+1|0;r=kT(e)|0;if(r>>>0<a>>>0)jM(e);else{s=u[e>>2]|0;c=(u[e+8>>2]|0)-s|0;f=c>>2;MT(i,c>>3>>>0<r>>>1>>>0?f>>>0<a>>>0?a:f:r,(u[o>>2]|0)-s>>3,e+8|0);a=i+8|0;TT(u[a>>2]|0,u[n>>2]|0,u[t>>2]|0);u[a>>2]=(u[a>>2]|0)+8;ST(e,i);AT(i);h=l;return}}function kT(e){e=e|0;return 536870911}function MT(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>536870911)$e();else{i=VM(n<<3)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t<<3)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n<<3);return}function ST(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(0-(i>>3)<<3)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function AT(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~((r+-8-n|0)>>>3)<<3);e=u[e>>2]|0;if(e|0)XM(e);return}function xT(e){e=e|0;NT(e);return}function PT(e){e=e|0;RT(e+24|0);return}function RT(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~((n+-8-r|0)>>>3)<<3);XM(t)}return}function NT(e){e=e|0;var n=0;n=Za()|0;tl(e,1,11,n,FT()|0,1);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function FT(){return 1852}function OT(e,n){e=e|0;n=n|0;return IT(u[(LT(e)|0)>>2]|0,n)|0}function LT(e){e=e|0;return(u[(DT()|0)+24>>2]|0)+(e<<3)|0}function IT(e,n){e=e|0;n=n|0;var t=0,r=0;t=h;h=h+16|0;r=t;cf(r,n);n=df(r,n)|0;n=Zf(vA[e&31](n)|0)|0;h=t;return n|0}function BT(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0;o=u[e>>2]|0;i=UT()|0;e=jT(t)|0;Ia(o,n,i,e,WT(t,r)|0,r);return}function UT(){var e=0,n=0;if(!(r[8056]|0)){$T(10932);Le(67,10932,_|0)|0;n=8056;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(10932)|0)){e=10932;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));$T(10932)}return 10932}function jT(e){e=e|0;return e|0}function WT(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0;l=h;h=h+16|0;i=l;o=l+4|0;u[i>>2]=e;s=UT()|0;a=s+24|0;n=Wa(n,4)|0;u[o>>2]=n;t=s+28|0;r=u[t>>2]|0;if(r>>>0<(u[s+32>>2]|0)>>>0){zT(r,e,n);n=(u[t>>2]|0)+8|0;u[t>>2]=n}else{HT(a,i,o);n=u[t>>2]|0}h=l;return(n-(u[a>>2]|0)>>3)+-1|0}function zT(e,n,t){e=e|0;n=n|0;t=t|0;u[e>>2]=n;u[e+4>>2]=t;return}function HT(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0;l=h;h=h+32|0;i=l;o=e+4|0;a=((u[o>>2]|0)-(u[e>>2]|0)>>3)+1|0;r=GT(e)|0;if(r>>>0<a>>>0)jM(e);else{s=u[e>>2]|0;c=(u[e+8>>2]|0)-s|0;f=c>>2;YT(i,c>>3>>>0<r>>>1>>>0?f>>>0<a>>>0?a:f:r,(u[o>>2]|0)-s>>3,e+8|0);a=i+8|0;zT(u[a>>2]|0,u[n>>2]|0,u[t>>2]|0);u[a>>2]=(u[a>>2]|0)+8;qT(e,i);VT(i);h=l;return}}function GT(e){e=e|0;return 536870911}function YT(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>536870911)$e();else{i=VM(n<<3)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t<<3)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n<<3);return}function qT(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(0-(i>>3)<<3)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function VT(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~((r+-8-n|0)>>>3)<<3);e=u[e>>2]|0;if(e|0)XM(e);return}function $T(e){e=e|0;JT(e);return}function XT(e){e=e|0;KT(e+24|0);return}function KT(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~((n+-8-r|0)>>>3)<<3);XM(t)}return}function JT(e){e=e|0;var n=0;n=Za()|0;tl(e,1,7,n,QT()|0,2);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function QT(){return 1860}function ZT(e,n,t){e=e|0;n=n|0;t=t|0;return nC(u[(eC(e)|0)>>2]|0,n,t)|0}function eC(e){e=e|0;return(u[(UT()|0)+24>>2]|0)+(e<<3)|0}function nC(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0;r=h;h=h+32|0;a=r+12|0;o=r+8|0;l=r;s=r+16|0;i=r+4|0;tC(s,n);rC(l,s,n);js(i,t);t=Ws(i,t)|0;u[a>>2]=u[l>>2];PA[e&15](o,a,t);t=iC(o)|0;Zi(o);zs(i);h=r;return t|0}function tC(e,n){e=e|0;n=n|0;return}function rC(e,n,t){e=e|0;n=n|0;t=t|0;uC(e,t);return}function iC(e){e=e|0;return wo(e)|0}function uC(e,n){e=e|0;n=n|0;var t=0,r=0,i=0;i=h;h=h+16|0;t=i;r=n;if(!(r&1))u[e>>2]=u[n>>2];else{oC(t,0);Be(r|0,t|0)|0;aC(e,t);lC(t)}h=i;return}function oC(e,n){e=e|0;n=n|0;Ro(e,n);u[e+4>>2]=0;r[e+8>>0]=0;return}function aC(e,n){e=e|0;n=n|0;u[e>>2]=u[n+4>>2];return}function lC(e){e=e|0;r[e+8>>0]=0;return}function sC(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0;o=u[e>>2]|0;i=fC()|0;e=cC(t)|0;Ia(o,n,i,e,dC(t,r)|0,r);return}function fC(){var e=0,n=0;if(!(r[8064]|0)){gC(10968);Le(68,10968,_|0)|0;n=8064;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(10968)|0)){e=10968;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));gC(10968)}return 10968}function cC(e){e=e|0;return e|0}function dC(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0;l=h;h=h+16|0;i=l;o=l+4|0;u[i>>2]=e;s=fC()|0;a=s+24|0;n=Wa(n,4)|0;u[o>>2]=n;t=s+28|0;r=u[t>>2]|0;if(r>>>0<(u[s+32>>2]|0)>>>0){pC(r,e,n);n=(u[t>>2]|0)+8|0;u[t>>2]=n}else{hC(a,i,o);n=u[t>>2]|0}h=l;return(n-(u[a>>2]|0)>>3)+-1|0}function pC(e,n,t){e=e|0;n=n|0;t=t|0;u[e>>2]=n;u[e+4>>2]=t;return}function hC(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0;l=h;h=h+32|0;i=l;o=e+4|0;a=((u[o>>2]|0)-(u[e>>2]|0)>>3)+1|0;r=mC(e)|0;if(r>>>0<a>>>0)jM(e);else{s=u[e>>2]|0;c=(u[e+8>>2]|0)-s|0;f=c>>2;vC(i,c>>3>>>0<r>>>1>>>0?f>>>0<a>>>0?a:f:r,(u[o>>2]|0)-s>>3,e+8|0);a=i+8|0;pC(u[a>>2]|0,u[n>>2]|0,u[t>>2]|0);u[a>>2]=(u[a>>2]|0)+8;_C(e,i);bC(i);h=l;return}}function mC(e){e=e|0;return 536870911}function vC(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>536870911)$e();else{i=VM(n<<3)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t<<3)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n<<3);return}function _C(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(0-(i>>3)<<3)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function bC(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~((r+-8-n|0)>>>3)<<3);e=u[e>>2]|0;if(e|0)XM(e);return}function gC(e){e=e|0;wC(e);return}function yC(e){e=e|0;DC(e+24|0);return}function DC(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~((n+-8-r|0)>>>3)<<3);XM(t)}return}function wC(e){e=e|0;var n=0;n=Za()|0;tl(e,1,1,n,EC()|0,5);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function EC(){return 1872}function TC(e,n,t,r,i,o){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;o=o|0;kC(u[(CC(e)|0)>>2]|0,n,t,r,i,o);return}function CC(e){e=e|0;return(u[(fC()|0)+24>>2]|0)+(e<<3)|0}function kC(e,n,t,r,i,u){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;u=u|0;var o=0,a=0,l=0,s=0,f=0,c=0;o=h;h=h+32|0;a=o+16|0;l=o+12|0;s=o+8|0;f=o+4|0;c=o;js(a,n);n=Ws(a,n)|0;js(l,t);t=Ws(l,t)|0;js(s,r);r=Ws(s,r)|0;js(f,i);i=Ws(f,i)|0;js(c,u);u=Ws(c,u)|0;fA[e&1](n,t,r,i,u);zs(c);zs(f);zs(s);zs(l);zs(a);h=o;return}function MC(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0;o=u[e>>2]|0;i=SC()|0;e=AC(t)|0;Ia(o,n,i,e,xC(t,r)|0,r);return}function SC(){var e=0,n=0;if(!(r[8072]|0)){IC(11004);Le(69,11004,_|0)|0;n=8072;u[n>>2]=1;u[n+4>>2]=0}if(!(Ka(11004)|0)){e=11004;n=e+36|0;do{u[e>>2]=0;e=e+4|0}while((e|0)<(n|0));IC(11004)}return 11004}function AC(e){e=e|0;return e|0}function xC(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0,l=0,s=0;l=h;h=h+16|0;i=l;o=l+4|0;u[i>>2]=e;s=SC()|0;a=s+24|0;n=Wa(n,4)|0;u[o>>2]=n;t=s+28|0;r=u[t>>2]|0;if(r>>>0<(u[s+32>>2]|0)>>>0){PC(r,e,n);n=(u[t>>2]|0)+8|0;u[t>>2]=n}else{RC(a,i,o);n=u[t>>2]|0}h=l;return(n-(u[a>>2]|0)>>3)+-1|0}function PC(e,n,t){e=e|0;n=n|0;t=t|0;u[e>>2]=n;u[e+4>>2]=t;return}function RC(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0;l=h;h=h+32|0;i=l;o=e+4|0;a=((u[o>>2]|0)-(u[e>>2]|0)>>3)+1|0;r=NC(e)|0;if(r>>>0<a>>>0)jM(e);else{s=u[e>>2]|0;c=(u[e+8>>2]|0)-s|0;f=c>>2;FC(i,c>>3>>>0<r>>>1>>>0?f>>>0<a>>>0?a:f:r,(u[o>>2]|0)-s>>3,e+8|0);a=i+8|0;PC(u[a>>2]|0,u[n>>2]|0,u[t>>2]|0);u[a>>2]=(u[a>>2]|0)+8;OC(e,i);LC(i);h=l;return}}function NC(e){e=e|0;return 536870911}function FC(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0;u[e+12>>2]=0;u[e+16>>2]=r;do{if(n){if(n>>>0>536870911)$e();else{i=VM(n<<3)|0;break}}else i=0}while(0);u[e>>2]=i;r=i+(t<<3)|0;u[e+8>>2]=r;u[e+4>>2]=r;u[e+12>>2]=i+(n<<3);return}function OC(e,n){e=e|0;n=n|0;var t=0,r=0,i=0,o=0,a=0;r=u[e>>2]|0;a=e+4|0;o=n+4|0;i=(u[a>>2]|0)-r|0;t=(u[o>>2]|0)+(0-(i>>3)<<3)|0;u[o>>2]=t;if((i|0)>0){iS(t|0,r|0,i|0)|0;r=o;t=u[o>>2]|0}else r=o;o=u[e>>2]|0;u[e>>2]=t;u[r>>2]=o;o=n+8|0;i=u[a>>2]|0;u[a>>2]=u[o>>2];u[o>>2]=i;o=e+8|0;a=n+12|0;e=u[o>>2]|0;u[o>>2]=u[a>>2];u[a>>2]=e;u[n>>2]=u[r>>2];return}function LC(e){e=e|0;var n=0,t=0,r=0;n=u[e+4>>2]|0;t=e+8|0;r=u[t>>2]|0;if((r|0)!=(n|0))u[t>>2]=r+(~((r+-8-n|0)>>>3)<<3);e=u[e>>2]|0;if(e|0)XM(e);return}function IC(e){e=e|0;jC(e);return}function BC(e){e=e|0;UC(e+24|0);return}function UC(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~((n+-8-r|0)>>>3)<<3);XM(t)}return}function jC(e){e=e|0;var n=0;n=Za()|0;tl(e,1,12,n,WC()|0,2);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function WC(){return 1896}function zC(e,n,t){e=e|0;n=n|0;t=t|0;GC(u[(HC(e)|0)>>2]|0,n,t);return}function HC(e){e=e|0;return(u[(SC()|0)+24>>2]|0)+(e<<3)|0}function GC(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,u=0;r=h;h=h+16|0;u=r+4|0;i=r;YC(u,n);n=qC(u,n)|0;js(i,t);t=Ws(i,t)|0;mA[e&31](n,t);zs(i);h=r;return}function YC(e,n){e=e|0;n=n|0;return}function qC(e,n){e=e|0;n=n|0;return VC(n)|0}function VC(e){e=e|0;return e|0}function $C(){var e=0;if(!(r[8080]|0)){XC(11040);Le(70,11040,_|0)|0;e=8080;u[e>>2]=1;u[e+4>>2]=0}if(!(Ka(11040)|0))XC(11040);return 11040}function XC(e){e=e|0;QC(e);sg(e,71);return}function KC(e){e=e|0;JC(e+24|0);return}function JC(e){e=e|0;var n=0,t=0,r=0;t=u[e>>2]|0;r=t;if(t|0){e=e+4|0;n=u[e>>2]|0;if((n|0)!=(t|0))u[e>>2]=n+(~((n+-8-r|0)>>>3)<<3);XM(t)}return}function QC(e){e=e|0;var n=0;n=Za()|0;tl(e,5,7,n,tk()|0,0);u[e+24>>2]=0;u[e+28>>2]=0;u[e+32>>2]=0;return}function ZC(e){e=e|0;ek(e);return}function ek(e){e=e|0;nk(e);return}function nk(e){e=e|0;r[e+8>>0]=1;return}function tk(){return 1936}function rk(){return ik()|0}function ik(){var e=0,n=0,t=0,r=0,i=0,o=0,a=0;n=h;h=h+16|0;i=n+4|0;a=n;t=jE(8)|0;e=t;o=e+4|0;u[o>>2]=VM(1)|0;r=VM(8)|0;o=u[o>>2]|0;u[a>>2]=0;u[i>>2]=u[a>>2];uk(r,o,i);u[t>>2]=r;h=n;return e|0}function uk(e,n,t){e=e|0;n=n|0;t=t|0;u[e>>2]=n;t=VM(16)|0;u[t+4>>2]=0;u[t+8>>2]=0;u[t>>2]=1916;u[t+12>>2]=n;u[e+4>>2]=t;return}function ok(e){e=e|0;WM(e);XM(e);return}function ak(e){e=e|0;e=u[e+12>>2]|0;if(e|0)XM(e);return}function lk(e){e=e|0;XM(e);return}function sk(){var e=0;if(!(r[8088]|0)){vk(11076);Le(25,11076,_|0)|0;e=8088;u[e>>2]=1;u[e+4>>2]=0}return 11076}function fk(e,n){e=e|0;n=n|0;u[e>>2]=ck()|0;u[e+4>>2]=dk()|0;u[e+12>>2]=n;u[e+8>>2]=pk()|0;u[e+32>>2]=10;return}function ck(){return 11745}function dk(){return 1940}function pk(){return zv()|0}function hk(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;if((jv(r,896)|0)==512){if(t|0){mk(t);XM(t)}}else if(n|0)XM(n);return}function mk(e){e=e|0;e=u[e+4>>2]|0;if(e|0)YM(e);return}function vk(e){e=e|0;Al(e);return}function _k(e,n){e=e|0;n=n|0;u[e>>2]=n;return}function bk(e){e=e|0;return u[e>>2]|0}function gk(e){e=e|0;return r[u[e>>2]>>0]|0}function yk(e,n){e=e|0;n=n|0;var t=0,r=0;t=h;h=h+16|0;r=t;u[r>>2]=u[e>>2];Dk(n,r)|0;h=t;return}function Dk(e,n){e=e|0;n=n|0;var t=0;t=wk(u[e>>2]|0,n)|0;n=e+4|0;u[(u[n>>2]|0)+8>>2]=t;return u[(u[n>>2]|0)+8>>2]|0}function wk(e,n){e=e|0;n=n|0;var t=0,r=0;t=h;h=h+16|0;r=t;Ek(r);e=wo(e)|0;n=Tk(e,u[n>>2]|0)|0;Ck(r);h=t;return n|0}function Ek(e){e=e|0;u[e>>2]=u[2701];u[e+4>>2]=u[2703];return}function Tk(e,n){e=e|0;n=n|0;var t=0;t=Co(kk()|0)|0;return un(0,t|0,e|0,XD(n)|0)|0}function Ck(e){e=e|0;eT(u[e>>2]|0,u[e+4>>2]|0);return}function kk(){var e=0;if(!(r[8096]|0)){Mk(11120);e=8096;u[e>>2]=1;u[e+4>>2]=0}return 11120}function Mk(e){e=e|0;Io(e,Sk()|0,1);return}function Sk(){return 1948}function Ak(){xk();return}function xk(){var e=0,n=0,t=0,i=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0,m=0,v=0,_=0,b=0,g=0;b=h;h=h+16|0;p=b+4|0;m=b;Ne(65536,10804,u[2702]|0,10812);t=CD()|0;n=u[t>>2]|0;e=u[n>>2]|0;if(e|0){i=u[t+8>>2]|0;t=u[t+4>>2]|0;while(1){We(e|0,o[t>>0]|0|0,r[i>>0]|0);n=n+4|0;e=u[n>>2]|0;if(!e)break;else{i=i+1|0;t=t+1|0}}}e=MD()|0;n=u[e>>2]|0;if(n|0)do{ze(n|0,u[e+4>>2]|0);e=e+8|0;n=u[e>>2]|0}while((n|0)!=0);ze(Pk()|0,5167);d=cD()|0;e=u[d>>2]|0;e:do{if(e|0){do{Rk(u[e+4>>2]|0);e=u[e>>2]|0}while((e|0)!=0);e=u[d>>2]|0;if(e|0){c=d;do{while(1){a=e;e=u[e>>2]|0;a=u[a+4>>2]|0;if(!(Nk(a)|0))break;u[m>>2]=c;u[p>>2]=u[m>>2];Fk(d,p)|0;if(!e)break e}Ok(a);c=u[c>>2]|0;n=Lk(a)|0;l=Ke()|0;s=h;h=h+((1*(n<<2)|0)+15&-16)|0;f=h;h=h+((1*(n<<2)|0)+15&-16)|0;n=u[(Sw(a)|0)>>2]|0;if(n|0){t=s;i=f;while(1){u[t>>2]=u[(kw(u[n+4>>2]|0)|0)>>2];u[i>>2]=u[n+8>>2];n=u[n>>2]|0;if(!n)break;else{t=t+4|0;i=i+4|0}}}g=kw(a)|0;n=Ik(a)|0;t=Lk(a)|0;i=Bk(a)|0;qe(g|0,n|0,s|0,f|0,t|0,i|0,wD(a)|0);Oe(l|0)}while((e|0)!=0)}}}while(0);e=u[(TD()|0)>>2]|0;if(e|0)do{g=e+4|0;d=PD(g)|0;a=LD(d)|0;l=RD(d)|0;s=(ND(d)|0)+1|0;f=Uk(d)|0;c=jk(g)|0;d=Ka(d)|0;p=BD(g)|0;m=Wk(g)|0;Ge(0,a|0,l|0,s|0,f|0,c|0,d|0,p|0,m|0,zk(g)|0);e=u[e>>2]|0}while((e|0)!=0);e=u[(cD()|0)>>2]|0;e:do{if(e|0){n:while(1){n=u[e+4>>2]|0;if(n|0?(v=u[(kw(n)|0)>>2]|0,_=u[(Pw(n)|0)>>2]|0,_|0):0){t=_;do{n=t+4|0;i=PD(n)|0;t:do{if(i|0)switch(Ka(i)|0){case 0:break n;case 4:case 3:case 2:{f=LD(i)|0;c=RD(i)|0;d=(ND(i)|0)+1|0;p=Uk(i)|0;m=Ka(i)|0;g=BD(n)|0;Ge(v|0,f|0,c|0,d|0,p|0,0,m|0,g|0,Wk(n)|0,zk(n)|0);break t}case 1:{s=LD(i)|0;f=RD(i)|0;c=(ND(i)|0)+1|0;d=Uk(i)|0;p=jk(n)|0;m=Ka(i)|0;g=BD(n)|0;Ge(v|0,s|0,f|0,c|0,d|0,p|0,m|0,g|0,Wk(n)|0,zk(n)|0);break t}case 5:{d=LD(i)|0;p=RD(i)|0;m=(ND(i)|0)+1|0;g=Uk(i)|0;Ge(v|0,d|0,p|0,m|0,g|0,Hk(i)|0,Ka(i)|0,0,0,0);break t}default:break t}}while(0);t=u[t>>2]|0}while((t|0)!=0)}e=u[e>>2]|0;if(!e)break e}$e()}}while(0);Ve();h=b;return}function Pk(){return 11703}function Rk(e){e=e|0;r[e+40>>0]=0;return}function Nk(e){e=e|0;return(r[e+40>>0]|0)!=0|0}function Fk(e,n){e=e|0;n=n|0;n=Gk(n)|0;e=u[n>>2]|0;u[n>>2]=u[e>>2];XM(e);return u[n>>2]|0}function Ok(e){e=e|0;r[e+40>>0]=1;return}function Lk(e){e=e|0;return u[e+20>>2]|0}function Ik(e){e=e|0;return u[e+8>>2]|0}function Bk(e){e=e|0;return u[e+32>>2]|0}function Uk(e){e=e|0;return u[e+4>>2]|0}function jk(e){e=e|0;return u[e+4>>2]|0}function Wk(e){e=e|0;return u[e+8>>2]|0}function zk(e){e=e|0;return u[e+16>>2]|0}function Hk(e){e=e|0;return u[e+20>>2]|0}function Gk(e){e=e|0;return u[e>>2]|0}function Yk(e){e=e|0;var n=0,t=0,r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0,m=0,v=0,_=0,b=0,g=0,y=0,D=0,w=0,E=0;E=h;h=h+16|0;p=E;do{if(e>>>0<245){f=e>>>0<11?16:e+11&-8;e=f>>>3;d=u[2783]|0;t=d>>>e;if(t&3|0){n=(t&1^1)+e|0;e=11172+(n<<1<<2)|0;t=e+8|0;r=u[t>>2]|0;i=r+8|0;o=u[i>>2]|0;if((e|0)==(o|0))u[2783]=d&~(1<<n);else{u[o+12>>2]=e;u[t>>2]=o}w=n<<3;u[r+4>>2]=w|3;w=r+w+4|0;u[w>>2]=u[w>>2]|1;w=i;h=E;return w|0}c=u[2785]|0;if(f>>>0>c>>>0){if(t|0){n=2<<e;n=t<<e&(n|0-n);n=(n&0-n)+-1|0;a=n>>>12&16;n=n>>>a;t=n>>>5&8;n=n>>>t;i=n>>>2&4;n=n>>>i;e=n>>>1&2;n=n>>>e;r=n>>>1&1;r=(t|a|i|e|r)+(n>>>r)|0;n=11172+(r<<1<<2)|0;e=n+8|0;i=u[e>>2]|0;a=i+8|0;t=u[a>>2]|0;if((n|0)==(t|0)){e=d&~(1<<r);u[2783]=e}else{u[t+12>>2]=n;u[e>>2]=t;e=d}o=(r<<3)-f|0;u[i+4>>2]=f|3;r=i+f|0;u[r+4>>2]=o|1;u[r+o>>2]=o;if(c|0){i=u[2788]|0;n=c>>>3;t=11172+(n<<1<<2)|0;n=1<<n;if(!(e&n)){u[2783]=e|n;n=t;e=t+8|0}else{e=t+8|0;n=u[e>>2]|0}u[e>>2]=i;u[n+12>>2]=i;u[i+8>>2]=n;u[i+12>>2]=t}u[2785]=o;u[2788]=r;w=a;h=E;return w|0}l=u[2784]|0;if(l){t=(l&0-l)+-1|0;a=t>>>12&16;t=t>>>a;o=t>>>5&8;t=t>>>o;s=t>>>2&4;t=t>>>s;r=t>>>1&2;t=t>>>r;e=t>>>1&1;e=u[11436+((o|a|s|r|e)+(t>>>e)<<2)>>2]|0;t=(u[e+4>>2]&-8)-f|0;r=u[e+16+(((u[e+16>>2]|0)==0&1)<<2)>>2]|0;if(!r){s=e;o=t}else{do{a=(u[r+4>>2]&-8)-f|0;s=a>>>0<t>>>0;t=s?a:t;e=s?r:e;r=u[r+16+(((u[r+16>>2]|0)==0&1)<<2)>>2]|0}while((r|0)!=0);s=e;o=t}a=s+f|0;if(s>>>0<a>>>0){i=u[s+24>>2]|0;n=u[s+12>>2]|0;do{if((n|0)==(s|0)){e=s+20|0;n=u[e>>2]|0;if(!n){e=s+16|0;n=u[e>>2]|0;if(!n){t=0;break}}while(1){t=n+20|0;r=u[t>>2]|0;if(r|0){n=r;e=t;continue}t=n+16|0;r=u[t>>2]|0;if(!r)break;else{n=r;e=t}}u[e>>2]=0;t=n}else{t=u[s+8>>2]|0;u[t+12>>2]=n;u[n+8>>2]=t;t=n}}while(0);do{if(i|0){n=u[s+28>>2]|0;e=11436+(n<<2)|0;if((s|0)==(u[e>>2]|0)){u[e>>2]=t;if(!t){u[2784]=l&~(1<<n);break}}else{u[i+16+(((u[i+16>>2]|0)!=(s|0)&1)<<2)>>2]=t;if(!t)break}u[t+24>>2]=i;n=u[s+16>>2]|0;if(n|0){u[t+16>>2]=n;u[n+24>>2]=t}n=u[s+20>>2]|0;if(n|0){u[t+20>>2]=n;u[n+24>>2]=t}}}while(0);if(o>>>0<16){w=o+f|0;u[s+4>>2]=w|3;w=s+w+4|0;u[w>>2]=u[w>>2]|1}else{u[s+4>>2]=f|3;u[a+4>>2]=o|1;u[a+o>>2]=o;if(c|0){r=u[2788]|0;n=c>>>3;t=11172+(n<<1<<2)|0;n=1<<n;if(!(d&n)){u[2783]=d|n;n=t;e=t+8|0}else{e=t+8|0;n=u[e>>2]|0}u[e>>2]=r;u[n+12>>2]=r;u[r+8>>2]=n;u[r+12>>2]=t}u[2785]=o;u[2788]=a}w=s+8|0;h=E;return w|0}else d=f}else d=f}else d=f}else if(e>>>0<=4294967231){e=e+11|0;f=e&-8;s=u[2784]|0;if(s){r=0-f|0;e=e>>>8;if(e){if(f>>>0>16777215)l=31;else{d=(e+1048320|0)>>>16&8;D=e<<d;c=(D+520192|0)>>>16&4;D=D<<c;l=(D+245760|0)>>>16&2;l=14-(c|d|l)+(D<<l>>>15)|0;l=f>>>(l+7|0)&1|l<<1}}else l=0;t=u[11436+(l<<2)>>2]|0;e:do{if(!t){t=0;e=0;D=57}else{e=0;a=f<<((l|0)==31?0:25-(l>>>1)|0);o=0;while(1){i=(u[t+4>>2]&-8)-f|0;if(i>>>0<r>>>0)if(!i){e=t;r=0;i=t;D=61;break e}else{e=t;r=i}i=u[t+20>>2]|0;t=u[t+16+(a>>>31<<2)>>2]|0;o=(i|0)==0|(i|0)==(t|0)?o:i;i=(t|0)==0;if(i){t=o;D=57;break}else a=a<<((i^1)&1)}}}while(0);if((D|0)==57){if((t|0)==0&(e|0)==0){e=2<<l;e=s&(e|0-e);if(!e){d=f;break}d=(e&0-e)+-1|0;a=d>>>12&16;d=d>>>a;o=d>>>5&8;d=d>>>o;l=d>>>2&4;d=d>>>l;c=d>>>1&2;d=d>>>c;t=d>>>1&1;e=0;t=u[11436+((o|a|l|c|t)+(d>>>t)<<2)>>2]|0}if(!t){l=e;a=r}else{i=t;D=61}}if((D|0)==61)while(1){D=0;t=(u[i+4>>2]&-8)-f|0;d=t>>>0<r>>>0;t=d?t:r;e=d?i:e;i=u[i+16+(((u[i+16>>2]|0)==0&1)<<2)>>2]|0;if(!i){l=e;a=t;break}else{r=t;D=61}}if((l|0)!=0?a>>>0<((u[2785]|0)-f|0)>>>0:0){o=l+f|0;if(l>>>0>=o>>>0){w=0;h=E;return w|0}i=u[l+24>>2]|0;n=u[l+12>>2]|0;do{if((n|0)==(l|0)){e=l+20|0;n=u[e>>2]|0;if(!n){e=l+16|0;n=u[e>>2]|0;if(!n){n=0;break}}while(1){t=n+20|0;r=u[t>>2]|0;if(r|0){n=r;e=t;continue}t=n+16|0;r=u[t>>2]|0;if(!r)break;else{n=r;e=t}}u[e>>2]=0}else{w=u[l+8>>2]|0;u[w+12>>2]=n;u[n+8>>2]=w}}while(0);do{if(i){e=u[l+28>>2]|0;t=11436+(e<<2)|0;if((l|0)==(u[t>>2]|0)){u[t>>2]=n;if(!n){r=s&~(1<<e);u[2784]=r;break}}else{u[i+16+(((u[i+16>>2]|0)!=(l|0)&1)<<2)>>2]=n;if(!n){r=s;break}}u[n+24>>2]=i;e=u[l+16>>2]|0;if(e|0){u[n+16>>2]=e;u[e+24>>2]=n}e=u[l+20>>2]|0;if(e){u[n+20>>2]=e;u[e+24>>2]=n;r=s}else r=s}else r=s}while(0);do{if(a>>>0>=16){u[l+4>>2]=f|3;u[o+4>>2]=a|1;u[o+a>>2]=a;n=a>>>3;if(a>>>0<256){t=11172+(n<<1<<2)|0;e=u[2783]|0;n=1<<n;if(!(e&n)){u[2783]=e|n;n=t;e=t+8|0}else{e=t+8|0;n=u[e>>2]|0}u[e>>2]=o;u[n+12>>2]=o;u[o+8>>2]=n;u[o+12>>2]=t;break}n=a>>>8;if(n){if(a>>>0>16777215)n=31;else{D=(n+1048320|0)>>>16&8;w=n<<D;y=(w+520192|0)>>>16&4;w=w<<y;n=(w+245760|0)>>>16&2;n=14-(y|D|n)+(w<<n>>>15)|0;n=a>>>(n+7|0)&1|n<<1}}else n=0;t=11436+(n<<2)|0;u[o+28>>2]=n;e=o+16|0;u[e+4>>2]=0;u[e>>2]=0;e=1<<n;if(!(r&e)){u[2784]=r|e;u[t>>2]=o;u[o+24>>2]=t;u[o+12>>2]=o;u[o+8>>2]=o;break}e=a<<((n|0)==31?0:25-(n>>>1)|0);t=u[t>>2]|0;while(1){if((u[t+4>>2]&-8|0)==(a|0)){D=97;break}r=t+16+(e>>>31<<2)|0;n=u[r>>2]|0;if(!n){D=96;break}else{e=e<<1;t=n}}if((D|0)==96){u[r>>2]=o;u[o+24>>2]=t;u[o+12>>2]=o;u[o+8>>2]=o;break}else if((D|0)==97){D=t+8|0;w=u[D>>2]|0;u[w+12>>2]=o;u[D>>2]=o;u[o+8>>2]=w;u[o+12>>2]=t;u[o+24>>2]=0;break}}else{w=a+f|0;u[l+4>>2]=w|3;w=l+w+4|0;u[w>>2]=u[w>>2]|1}}while(0);w=l+8|0;h=E;return w|0}else d=f}else d=f}else d=-1}while(0);t=u[2785]|0;if(t>>>0>=d>>>0){n=t-d|0;e=u[2788]|0;if(n>>>0>15){w=e+d|0;u[2788]=w;u[2785]=n;u[w+4>>2]=n|1;u[w+n>>2]=n;u[e+4>>2]=d|3}else{u[2785]=0;u[2788]=0;u[e+4>>2]=t|3;w=e+t+4|0;u[w>>2]=u[w>>2]|1}w=e+8|0;h=E;return w|0}a=u[2786]|0;if(a>>>0>d>>>0){y=a-d|0;u[2786]=y;w=u[2789]|0;D=w+d|0;u[2789]=D;u[D+4>>2]=y|1;u[w+4>>2]=d|3;w=w+8|0;h=E;return w|0}if(!(u[2901]|0)){u[2903]=4096;u[2902]=4096;u[2904]=-1;u[2905]=-1;u[2906]=0;u[2894]=0;e=p&-16^1431655768;u[p>>2]=e;u[2901]=e;e=4096}else e=u[2903]|0;l=d+48|0;s=d+47|0;o=e+s|0;i=0-e|0;f=o&i;if(f>>>0<=d>>>0){w=0;h=E;return w|0}e=u[2893]|0;if(e|0?(c=u[2891]|0,p=c+f|0,p>>>0<=c>>>0|p>>>0>e>>>0):0){w=0;h=E;return w|0}e:do{if(!(u[2894]&4)){t=u[2789]|0;n:do{if(t){r=11580;while(1){e=u[r>>2]|0;if(e>>>0<=t>>>0?(_=r+4|0,(e+(u[_>>2]|0)|0)>>>0>t>>>0):0)break;e=u[r+8>>2]|0;if(!e){D=118;break n}else r=e}n=o-a&i;if(n>>>0<2147483647){e=lS(n|0)|0;if((e|0)==((u[r>>2]|0)+(u[_>>2]|0)|0)){if((e|0)!=(-1|0)){a=n;o=e;D=135;break e}}else{r=e;D=126}}else n=0}else D=118}while(0);do{if((D|0)==118){t=lS(0)|0;if((t|0)!=(-1|0)?(n=t,m=u[2902]|0,v=m+-1|0,n=((v&n|0)==0?0:(v+n&0-m)-n|0)+f|0,m=u[2891]|0,v=n+m|0,n>>>0>d>>>0&n>>>0<2147483647):0){_=u[2893]|0;if(_|0?v>>>0<=m>>>0|v>>>0>_>>>0:0){n=0;break}e=lS(n|0)|0;if((e|0)==(t|0)){a=n;o=t;D=135;break e}else{r=e;D=126}}else n=0}}while(0);do{if((D|0)==126){t=0-n|0;if(!(l>>>0>n>>>0&(n>>>0<2147483647&(r|0)!=(-1|0))))if((r|0)==(-1|0)){n=0;break}else{a=n;o=r;D=135;break e}e=u[2903]|0;e=s-n+e&0-e;if(e>>>0>=2147483647){a=n;o=r;D=135;break e}if((lS(e|0)|0)==(-1|0)){lS(t|0)|0;n=0;break}else{a=e+n|0;o=r;D=135;break e}}}while(0);u[2894]=u[2894]|4;D=133}else{n=0;D=133}}while(0);if(((D|0)==133?f>>>0<2147483647:0)?(y=lS(f|0)|0,_=lS(0)|0,b=_-y|0,g=b>>>0>(d+40|0)>>>0,!((y|0)==(-1|0)|g^1|y>>>0<_>>>0&((y|0)!=(-1|0)&(_|0)!=(-1|0))^1)):0){a=g?b:n;o=y;D=135}if((D|0)==135){n=(u[2891]|0)+a|0;u[2891]=n;if(n>>>0>(u[2892]|0)>>>0)u[2892]=n;s=u[2789]|0;do{if(s){n=11580;while(1){e=u[n>>2]|0;t=n+4|0;r=u[t>>2]|0;if((o|0)==(e+r|0)){D=145;break}i=u[n+8>>2]|0;if(!i)break;else n=i}if(((D|0)==145?(u[n+12>>2]&8|0)==0:0)?s>>>0<o>>>0&s>>>0>=e>>>0:0){u[t>>2]=r+a;w=s+8|0;w=(w&7|0)==0?0:0-w&7;D=s+w|0;w=(u[2786]|0)+(a-w)|0;u[2789]=D;u[2786]=w;u[D+4>>2]=w|1;u[D+w+4>>2]=40;u[2790]=u[2905];break}if(o>>>0<(u[2787]|0)>>>0)u[2787]=o;t=o+a|0;n=11580;while(1){if((u[n>>2]|0)==(t|0)){D=153;break}e=u[n+8>>2]|0;if(!e)break;else n=e}if((D|0)==153?(u[n+12>>2]&8|0)==0:0){u[n>>2]=o;c=n+4|0;u[c>>2]=(u[c>>2]|0)+a;c=o+8|0;c=o+((c&7|0)==0?0:0-c&7)|0;n=t+8|0;n=t+((n&7|0)==0?0:0-n&7)|0;f=c+d|0;l=n-c-d|0;u[c+4>>2]=d|3;do{if((n|0)!=(s|0)){if((n|0)==(u[2788]|0)){w=(u[2785]|0)+l|0;u[2785]=w;u[2788]=f;u[f+4>>2]=w|1;u[f+w>>2]=w;break}e=u[n+4>>2]|0;if((e&3|0)==1){a=e&-8;r=e>>>3;e:do{if(e>>>0<256){e=u[n+8>>2]|0;t=u[n+12>>2]|0;if((t|0)==(e|0)){u[2783]=u[2783]&~(1<<r);break}else{u[e+12>>2]=t;u[t+8>>2]=e;break}}else{o=u[n+24>>2]|0;e=u[n+12>>2]|0;do{if((e|0)==(n|0)){r=n+16|0;t=r+4|0;e=u[t>>2]|0;if(!e){e=u[r>>2]|0;if(!e){e=0;break}else t=r}while(1){r=e+20|0;i=u[r>>2]|0;if(i|0){e=i;t=r;continue}r=e+16|0;i=u[r>>2]|0;if(!i)break;else{e=i;t=r}}u[t>>2]=0}else{w=u[n+8>>2]|0;u[w+12>>2]=e;u[e+8>>2]=w}}while(0);if(!o)break;t=u[n+28>>2]|0;r=11436+(t<<2)|0;do{if((n|0)!=(u[r>>2]|0)){u[o+16+(((u[o+16>>2]|0)!=(n|0)&1)<<2)>>2]=e;if(!e)break e}else{u[r>>2]=e;if(e|0)break;u[2784]=u[2784]&~(1<<t);break e}}while(0);u[e+24>>2]=o;t=n+16|0;r=u[t>>2]|0;if(r|0){u[e+16>>2]=r;u[r+24>>2]=e}t=u[t+4>>2]|0;if(!t)break;u[e+20>>2]=t;u[t+24>>2]=e}}while(0);n=n+a|0;i=a+l|0}else i=l;n=n+4|0;u[n>>2]=u[n>>2]&-2;u[f+4>>2]=i|1;u[f+i>>2]=i;n=i>>>3;if(i>>>0<256){t=11172+(n<<1<<2)|0;e=u[2783]|0;n=1<<n;if(!(e&n)){u[2783]=e|n;n=t;e=t+8|0}else{e=t+8|0;n=u[e>>2]|0}u[e>>2]=f;u[n+12>>2]=f;u[f+8>>2]=n;u[f+12>>2]=t;break}n=i>>>8;do{if(!n)n=0;else{if(i>>>0>16777215){n=31;break}D=(n+1048320|0)>>>16&8;w=n<<D;y=(w+520192|0)>>>16&4;w=w<<y;n=(w+245760|0)>>>16&2;n=14-(y|D|n)+(w<<n>>>15)|0;n=i>>>(n+7|0)&1|n<<1}}while(0);r=11436+(n<<2)|0;u[f+28>>2]=n;e=f+16|0;u[e+4>>2]=0;u[e>>2]=0;e=u[2784]|0;t=1<<n;if(!(e&t)){u[2784]=e|t;u[r>>2]=f;u[f+24>>2]=r;u[f+12>>2]=f;u[f+8>>2]=f;break}e=i<<((n|0)==31?0:25-(n>>>1)|0);t=u[r>>2]|0;while(1){if((u[t+4>>2]&-8|0)==(i|0)){D=194;break}r=t+16+(e>>>31<<2)|0;n=u[r>>2]|0;if(!n){D=193;break}else{e=e<<1;t=n}}if((D|0)==193){u[r>>2]=f;u[f+24>>2]=t;u[f+12>>2]=f;u[f+8>>2]=f;break}else if((D|0)==194){D=t+8|0;w=u[D>>2]|0;u[w+12>>2]=f;u[D>>2]=f;u[f+8>>2]=w;u[f+12>>2]=t;u[f+24>>2]=0;break}}else{w=(u[2786]|0)+l|0;u[2786]=w;u[2789]=f;u[f+4>>2]=w|1}}while(0);w=c+8|0;h=E;return w|0}n=11580;while(1){e=u[n>>2]|0;if(e>>>0<=s>>>0?(w=e+(u[n+4>>2]|0)|0,w>>>0>s>>>0):0)break;n=u[n+8>>2]|0}i=w+-47|0;e=i+8|0;e=i+((e&7|0)==0?0:0-e&7)|0;i=s+16|0;e=e>>>0<i>>>0?s:e;n=e+8|0;t=o+8|0;t=(t&7|0)==0?0:0-t&7;D=o+t|0;t=a+-40-t|0;u[2789]=D;u[2786]=t;u[D+4>>2]=t|1;u[D+t+4>>2]=40;u[2790]=u[2905];t=e+4|0;u[t>>2]=27;u[n>>2]=u[2895];u[n+4>>2]=u[2896];u[n+8>>2]=u[2897];u[n+12>>2]=u[2898];u[2895]=o;u[2896]=a;u[2898]=0;u[2897]=n;n=e+24|0;do{D=n;n=n+4|0;u[n>>2]=7}while((D+8|0)>>>0<w>>>0);if((e|0)!=(s|0)){o=e-s|0;u[t>>2]=u[t>>2]&-2;u[s+4>>2]=o|1;u[e>>2]=o;n=o>>>3;if(o>>>0<256){t=11172+(n<<1<<2)|0;e=u[2783]|0;n=1<<n;if(!(e&n)){u[2783]=e|n;n=t;e=t+8|0}else{e=t+8|0;n=u[e>>2]|0}u[e>>2]=s;u[n+12>>2]=s;u[s+8>>2]=n;u[s+12>>2]=t;break}n=o>>>8;if(n){if(o>>>0>16777215)t=31;else{D=(n+1048320|0)>>>16&8;w=n<<D;y=(w+520192|0)>>>16&4;w=w<<y;t=(w+245760|0)>>>16&2;t=14-(y|D|t)+(w<<t>>>15)|0;t=o>>>(t+7|0)&1|t<<1}}else t=0;r=11436+(t<<2)|0;u[s+28>>2]=t;u[s+20>>2]=0;u[i>>2]=0;n=u[2784]|0;e=1<<t;if(!(n&e)){u[2784]=n|e;u[r>>2]=s;u[s+24>>2]=r;u[s+12>>2]=s;u[s+8>>2]=s;break}e=o<<((t|0)==31?0:25-(t>>>1)|0);t=u[r>>2]|0;while(1){if((u[t+4>>2]&-8|0)==(o|0)){D=216;break}r=t+16+(e>>>31<<2)|0;n=u[r>>2]|0;if(!n){D=215;break}else{e=e<<1;t=n}}if((D|0)==215){u[r>>2]=s;u[s+24>>2]=t;u[s+12>>2]=s;u[s+8>>2]=s;break}else if((D|0)==216){D=t+8|0;w=u[D>>2]|0;u[w+12>>2]=s;u[D>>2]=s;u[s+8>>2]=w;u[s+12>>2]=t;u[s+24>>2]=0;break}}}else{w=u[2787]|0;if((w|0)==0|o>>>0<w>>>0)u[2787]=o;u[2895]=o;u[2896]=a;u[2898]=0;u[2792]=u[2901];u[2791]=-1;n=0;do{w=11172+(n<<1<<2)|0;u[w+12>>2]=w;u[w+8>>2]=w;n=n+1|0}while((n|0)!=32);w=o+8|0;w=(w&7|0)==0?0:0-w&7;D=o+w|0;w=a+-40-w|0;u[2789]=D;u[2786]=w;u[D+4>>2]=w|1;u[D+w+4>>2]=40;u[2790]=u[2905]}}while(0);n=u[2786]|0;if(n>>>0>d>>>0){y=n-d|0;u[2786]=y;w=u[2789]|0;D=w+d|0;u[2789]=D;u[D+4>>2]=y|1;u[w+4>>2]=d|3;w=w+8|0;h=E;return w|0}}u[(Qk()|0)>>2]=12;w=0;h=E;return w|0}function qk(e){e=e|0;var n=0,t=0,r=0,i=0,o=0,a=0,l=0,s=0;if(!e)return;t=e+-8|0;i=u[2787]|0;e=u[e+-4>>2]|0;n=e&-8;s=t+n|0;do{if(!(e&1)){r=u[t>>2]|0;if(!(e&3))return;a=t+(0-r)|0;o=r+n|0;if(a>>>0<i>>>0)return;if((a|0)==(u[2788]|0)){e=s+4|0;n=u[e>>2]|0;if((n&3|0)!=3){l=a;n=o;break}u[2785]=o;u[e>>2]=n&-2;u[a+4>>2]=o|1;u[a+o>>2]=o;return}t=r>>>3;if(r>>>0<256){e=u[a+8>>2]|0;n=u[a+12>>2]|0;if((n|0)==(e|0)){u[2783]=u[2783]&~(1<<t);l=a;n=o;break}else{u[e+12>>2]=n;u[n+8>>2]=e;l=a;n=o;break}}i=u[a+24>>2]|0;e=u[a+12>>2]|0;do{if((e|0)==(a|0)){t=a+16|0;n=t+4|0;e=u[n>>2]|0;if(!e){e=u[t>>2]|0;if(!e){e=0;break}else n=t}while(1){t=e+20|0;r=u[t>>2]|0;if(r|0){e=r;n=t;continue}t=e+16|0;r=u[t>>2]|0;if(!r)break;else{e=r;n=t}}u[n>>2]=0}else{l=u[a+8>>2]|0;u[l+12>>2]=e;u[e+8>>2]=l}}while(0);if(i){n=u[a+28>>2]|0;t=11436+(n<<2)|0;if((a|0)==(u[t>>2]|0)){u[t>>2]=e;if(!e){u[2784]=u[2784]&~(1<<n);l=a;n=o;break}}else{u[i+16+(((u[i+16>>2]|0)!=(a|0)&1)<<2)>>2]=e;if(!e){l=a;n=o;break}}u[e+24>>2]=i;n=a+16|0;t=u[n>>2]|0;if(t|0){u[e+16>>2]=t;u[t+24>>2]=e}n=u[n+4>>2]|0;if(n){u[e+20>>2]=n;u[n+24>>2]=e;l=a;n=o}else{l=a;n=o}}else{l=a;n=o}}else{l=t;a=t}}while(0);if(a>>>0>=s>>>0)return;e=s+4|0;r=u[e>>2]|0;if(!(r&1))return;if(!(r&2)){e=u[2788]|0;if((s|0)==(u[2789]|0)){s=(u[2786]|0)+n|0;u[2786]=s;u[2789]=l;u[l+4>>2]=s|1;if((l|0)!=(e|0))return;u[2788]=0;u[2785]=0;return}if((s|0)==(e|0)){s=(u[2785]|0)+n|0;u[2785]=s;u[2788]=a;u[l+4>>2]=s|1;u[a+s>>2]=s;return}i=(r&-8)+n|0;t=r>>>3;do{if(r>>>0<256){n=u[s+8>>2]|0;e=u[s+12>>2]|0;if((e|0)==(n|0)){u[2783]=u[2783]&~(1<<t);break}else{u[n+12>>2]=e;u[e+8>>2]=n;break}}else{o=u[s+24>>2]|0;e=u[s+12>>2]|0;do{if((e|0)==(s|0)){t=s+16|0;n=t+4|0;e=u[n>>2]|0;if(!e){e=u[t>>2]|0;if(!e){t=0;break}else n=t}while(1){t=e+20|0;r=u[t>>2]|0;if(r|0){e=r;n=t;continue}t=e+16|0;r=u[t>>2]|0;if(!r)break;else{e=r;n=t}}u[n>>2]=0;t=e}else{t=u[s+8>>2]|0;u[t+12>>2]=e;u[e+8>>2]=t;t=e}}while(0);if(o|0){e=u[s+28>>2]|0;n=11436+(e<<2)|0;if((s|0)==(u[n>>2]|0)){u[n>>2]=t;if(!t){u[2784]=u[2784]&~(1<<e);break}}else{u[o+16+(((u[o+16>>2]|0)!=(s|0)&1)<<2)>>2]=t;if(!t)break}u[t+24>>2]=o;e=s+16|0;n=u[e>>2]|0;if(n|0){u[t+16>>2]=n;u[n+24>>2]=t}e=u[e+4>>2]|0;if(e|0){u[t+20>>2]=e;u[e+24>>2]=t}}}}while(0);u[l+4>>2]=i|1;u[a+i>>2]=i;if((l|0)==(u[2788]|0)){u[2785]=i;return}}else{u[e>>2]=r&-2;u[l+4>>2]=n|1;u[a+n>>2]=n;i=n}e=i>>>3;if(i>>>0<256){t=11172+(e<<1<<2)|0;n=u[2783]|0;e=1<<e;if(!(n&e)){u[2783]=n|e;e=t;n=t+8|0}else{n=t+8|0;e=u[n>>2]|0}u[n>>2]=l;u[e+12>>2]=l;u[l+8>>2]=e;u[l+12>>2]=t;return}e=i>>>8;if(e){if(i>>>0>16777215)e=31;else{a=(e+1048320|0)>>>16&8;s=e<<a;o=(s+520192|0)>>>16&4;s=s<<o;e=(s+245760|0)>>>16&2;e=14-(o|a|e)+(s<<e>>>15)|0;e=i>>>(e+7|0)&1|e<<1}}else e=0;r=11436+(e<<2)|0;u[l+28>>2]=e;u[l+20>>2]=0;u[l+16>>2]=0;n=u[2784]|0;t=1<<e;do{if(n&t){n=i<<((e|0)==31?0:25-(e>>>1)|0);t=u[r>>2]|0;while(1){if((u[t+4>>2]&-8|0)==(i|0)){e=73;break}r=t+16+(n>>>31<<2)|0;e=u[r>>2]|0;if(!e){e=72;break}else{n=n<<1;t=e}}if((e|0)==72){u[r>>2]=l;u[l+24>>2]=t;u[l+12>>2]=l;u[l+8>>2]=l;break}else if((e|0)==73){a=t+8|0;s=u[a>>2]|0;u[s+12>>2]=l;u[a>>2]=l;u[l+8>>2]=s;u[l+12>>2]=t;u[l+24>>2]=0;break}}else{u[2784]=n|t;u[r>>2]=l;u[l+24>>2]=r;u[l+12>>2]=l;u[l+8>>2]=l}}while(0);s=(u[2791]|0)+-1|0;u[2791]=s;if(!s)e=11588;else return;while(1){e=u[e>>2]|0;if(!e)break;else e=e+8|0}u[2791]=-1;return}function Vk(){return 11628}function $k(e){e=e|0;var n=0,t=0;n=h;h=h+16|0;t=n;u[t>>2]=nM(u[e+60>>2]|0)|0;e=Jk(an(6,t|0)|0)|0;h=n;return e|0}function Xk(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0,m=0;d=h;h=h+48|0;f=d+16|0;o=d;i=d+32|0;l=e+28|0;r=u[l>>2]|0;u[i>>2]=r;s=e+20|0;r=(u[s>>2]|0)-r|0;u[i+4>>2]=r;u[i+8>>2]=n;u[i+12>>2]=t;r=r+t|0;a=e+60|0;u[o>>2]=u[a>>2];u[o+4>>2]=i;u[o+8>>2]=2;o=Jk(fn(146,o|0)|0)|0;e:do{if((r|0)!=(o|0)){n=2;while(1){if((o|0)<0)break;r=r-o|0;m=u[i+4>>2]|0;p=o>>>0>m>>>0;i=p?i+8|0:i;n=(p<<31>>31)+n|0;m=o-(p?m:0)|0;u[i>>2]=(u[i>>2]|0)+m;p=i+4|0;u[p>>2]=(u[p>>2]|0)-m;u[f>>2]=u[a>>2];u[f+4>>2]=i;u[f+8>>2]=n;o=Jk(fn(146,f|0)|0)|0;if((r|0)==(o|0)){c=3;break e}}u[e+16>>2]=0;u[l>>2]=0;u[s>>2]=0;u[e>>2]=u[e>>2]|32;if((n|0)==2)t=0;else t=t-(u[i+4>>2]|0)|0}else c=3}while(0);if((c|0)==3){m=u[e+44>>2]|0;u[e+16>>2]=m+(u[e+48>>2]|0);u[l>>2]=m;u[s>>2]=m}h=d;return t|0}function Kk(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0;i=h;h=h+32|0;o=i;r=i+20|0;u[o>>2]=u[e+60>>2];u[o+4>>2]=0;u[o+8>>2]=n;u[o+12>>2]=r;u[o+16>>2]=t;if((Jk(sn(140,o|0)|0)|0)<0){u[r>>2]=-1;e=-1}else e=u[r>>2]|0;h=i;return e|0}function Jk(e){e=e|0;if(e>>>0>4294963200){u[(Qk()|0)>>2]=0-e;e=-1}return e|0}function Qk(){return(Zk()|0)+64|0}function Zk(){return eM()|0}function eM(){return 2084}function nM(e){e=e|0;return e|0}function tM(e,n,t){e=e|0;n=n|0;t=t|0;var i=0,o=0;o=h;h=h+32|0;i=o;u[e+36>>2]=1;if((u[e>>2]&64|0)==0?(u[i>>2]=u[e+60>>2],u[i+4>>2]=21523,u[i+8>>2]=o+16,Je(54,i|0)|0):0)r[e+75>>0]=-1;i=Xk(e,n,t)|0;h=o;return i|0}function rM(e,n){e=e|0;n=n|0;var t=0,i=0;t=r[e>>0]|0;i=r[n>>0]|0;if(t<<24>>24==0?1:t<<24>>24!=i<<24>>24)e=i;else{do{e=e+1|0;n=n+1|0;t=r[e>>0]|0;i=r[n>>0]|0}while(!(t<<24>>24==0?1:t<<24>>24!=i<<24>>24));e=i}return(t&255)-(e&255)|0}function iM(e,n,t){e=e|0;n=n|0;t=t|0;var i=0,u=0;e:do{if(!t)e=0;else{while(1){i=r[e>>0]|0;u=r[n>>0]|0;if(i<<24>>24!=u<<24>>24)break;t=t+-1|0;if(!t){e=0;break e}else{e=e+1|0;n=n+1|0}}e=(i&255)-(u&255)|0}}while(0);return e|0}function uM(e,n,t){e=e|0;n=n|0;t=t|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0,m=0,v=0,_=0,b=0;b=h;h=h+224|0;d=b+120|0;p=b+80|0;v=b;_=b+136|0;i=p;o=i+40|0;do{u[i>>2]=0;i=i+4|0}while((i|0)<(o|0));u[d>>2]=u[t>>2];if((oM(0,n,d,v,p)|0)<0)t=-1;else{if((u[e+76>>2]|0)>-1)m=aM(e)|0;else m=0;t=u[e>>2]|0;c=t&32;if((r[e+74>>0]|0)<1)u[e>>2]=t&-33;i=e+48|0;if(!(u[i>>2]|0)){o=e+44|0;a=u[o>>2]|0;u[o>>2]=_;l=e+28|0;u[l>>2]=_;s=e+20|0;u[s>>2]=_;u[i>>2]=80;f=e+16|0;u[f>>2]=_+80;t=oM(e,n,d,v,p)|0;if(a){gA[u[e+36>>2]&7](e,0,0)|0;t=(u[s>>2]|0)==0?-1:t;u[o>>2]=a;u[i>>2]=0;u[f>>2]=0;u[l>>2]=0;u[s>>2]=0}}else t=oM(e,n,d,v,p)|0;i=u[e>>2]|0;u[e>>2]=i|c;if(m|0)lM(e);t=(i&32|0)==0?t:-1}h=b;return t|0}function oM(e,n,t,o,a){e=e|0;n=n|0;t=t|0;o=o|0;a=a|0;var l=0,s=0,c=0,d=0,p=0,m=0,v=0,_=0,b=0,g=0,y=0,D=0,w=0,E=0,T=0,C=0,k=0,M=0,S=0,x=0,P=0,R=0,N=0;N=h;h=h+64|0;S=N+16|0;x=N;k=N+24|0;P=N+8|0;R=N+20|0;u[S>>2]=n;E=(e|0)!=0;T=k+40|0;C=T;k=k+39|0;M=P+4|0;s=0;l=0;m=0;e:while(1){do{if((l|0)>-1)if((s|0)>(2147483647-l|0)){u[(Qk()|0)>>2]=75;l=-1;break}else{l=s+l|0;break}}while(0);s=r[n>>0]|0;if(!(s<<24>>24)){w=87;break}else c=n;n:while(1){switch(s<<24>>24){case 37:{s=c;w=9;break n}case 0:{s=c;break n}default:{}}D=c+1|0;u[S>>2]=D;s=r[D>>0]|0;c=D}n:do{if((w|0)==9)while(1){w=0;if((r[c+1>>0]|0)!=37)break n;s=s+1|0;c=c+2|0;u[S>>2]=c;if((r[c>>0]|0)==37)w=9;else break}}while(0);s=s-n|0;if(E)sM(e,n,s);if(s|0){n=c;continue}d=c+1|0;s=(r[d>>0]|0)+-48|0;if(s>>>0<10){D=(r[c+2>>0]|0)==36;y=D?s:-1;m=D?1:m;d=D?c+3|0:d}else y=-1;u[S>>2]=d;s=r[d>>0]|0;c=(s<<24>>24)+-32|0;n:do{if(c>>>0<32){p=0;v=s;while(1){s=1<<c;if(!(s&75913)){s=v;break n}p=s|p;d=d+1|0;u[S>>2]=d;s=r[d>>0]|0;c=(s<<24>>24)+-32|0;if(c>>>0>=32)break;else v=s}}else p=0}while(0);if(s<<24>>24==42){c=d+1|0;s=(r[c>>0]|0)+-48|0;if(s>>>0<10?(r[d+2>>0]|0)==36:0){u[a+(s<<2)>>2]=10;s=u[o+((r[c>>0]|0)+-48<<3)>>2]|0;m=1;d=d+3|0}else{if(m|0){l=-1;break}if(E){m=(u[t>>2]|0)+(4-1)&~(4-1);s=u[m>>2]|0;u[t>>2]=m+4;m=0;d=c}else{s=0;m=0;d=c}}u[S>>2]=d;D=(s|0)<0;s=D?0-s|0:s;p=D?p|8192:p}else{s=fM(S)|0;if((s|0)<0){l=-1;break}d=u[S>>2]|0}do{if((r[d>>0]|0)==46){if((r[d+1>>0]|0)!=42){u[S>>2]=d+1;c=fM(S)|0;d=u[S>>2]|0;break}v=d+2|0;c=(r[v>>0]|0)+-48|0;if(c>>>0<10?(r[d+3>>0]|0)==36:0){u[a+(c<<2)>>2]=10;c=u[o+((r[v>>0]|0)+-48<<3)>>2]|0;d=d+4|0;u[S>>2]=d;break}if(m|0){l=-1;break e}if(E){D=(u[t>>2]|0)+(4-1)&~(4-1);c=u[D>>2]|0;u[t>>2]=D+4}else c=0;u[S>>2]=v;d=v}else c=-1}while(0);g=0;while(1){if(((r[d>>0]|0)+-65|0)>>>0>57){l=-1;break e}D=d+1|0;u[S>>2]=D;v=r[(r[d>>0]|0)+-65+(5178+(g*58|0))>>0]|0;_=v&255;if((_+-1|0)>>>0<8){g=_;d=D}else break}if(!(v<<24>>24)){l=-1;break}b=(y|0)>-1;do{if(v<<24>>24==19){if(b){l=-1;break e}else w=49}else{if(b){u[a+(y<<2)>>2]=_;b=o+(y<<3)|0;y=u[b+4>>2]|0;w=x;u[w>>2]=u[b>>2];u[w+4>>2]=y;w=49;break}if(!E){l=0;break e}cM(x,_,t)}}while(0);if((w|0)==49?(w=0,!E):0){s=0;n=D;continue}d=r[d>>0]|0;d=(g|0)!=0&(d&15|0)==3?d&-33:d;b=p&-65537;y=(p&8192|0)==0?p:b;n:do{switch(d|0){case 110:switch((g&255)<<24>>24){case 0:{u[u[x>>2]>>2]=l;s=0;n=D;continue e}case 1:{u[u[x>>2]>>2]=l;s=0;n=D;continue e}case 2:{s=u[x>>2]|0;u[s>>2]=l;u[s+4>>2]=((l|0)<0)<<31>>31;s=0;n=D;continue e}case 3:{i[u[x>>2]>>1]=l;s=0;n=D;continue e}case 4:{r[u[x>>2]>>0]=l;s=0;n=D;continue e}case 6:{u[u[x>>2]>>2]=l;s=0;n=D;continue e}case 7:{s=u[x>>2]|0;u[s>>2]=l;u[s+4>>2]=((l|0)<0)<<31>>31;s=0;n=D;continue e}default:{s=0;n=D;continue e}}case 112:{d=120;c=c>>>0>8?c:8;n=y|8;w=61;break}case 88:case 120:{n=y;w=61;break}case 111:{d=x;n=u[d>>2]|0;d=u[d+4>>2]|0;_=pM(n,d,T)|0;b=C-_|0;p=0;v=5642;c=(y&8|0)==0|(c|0)>(b|0)?c:b+1|0;b=y;w=67;break}case 105:case 100:{d=x;n=u[d>>2]|0;d=u[d+4>>2]|0;if((d|0)<0){n=ZM(0,0,n|0,d|0)|0;d=A;p=x;u[p>>2]=n;u[p+4>>2]=d;p=1;v=5642;w=66;break n}else{p=(y&2049|0)!=0&1;v=(y&2048|0)==0?(y&1|0)==0?5642:5644:5643;w=66;break n}}case 117:{d=x;p=0;v=5642;n=u[d>>2]|0;d=u[d+4>>2]|0;w=66;break}case 99:{r[k>>0]=u[x>>2];n=k;p=0;v=5642;_=T;d=1;c=b;break}case 109:{d=mM(u[(Qk()|0)>>2]|0)|0;w=71;break}case 115:{d=u[x>>2]|0;d=d|0?d:5652;w=71;break}case 67:{u[P>>2]=u[x>>2];u[M>>2]=0;u[x>>2]=P;_=-1;d=P;w=75;break}case 83:{n=u[x>>2]|0;if(!c){_M(e,32,s,0,y);n=0;w=84}else{_=c;d=n;w=75}break}case 65:case 71:case 70:case 69:case 97:case 103:case 102:case 101:{s=gM(e,+f[x>>3],s,c,y,d)|0;n=D;continue e}default:{p=0;v=5642;_=T;d=c;c=y}}}while(0);n:do{if((w|0)==61){y=x;g=u[y>>2]|0;y=u[y+4>>2]|0;_=dM(g,y,T,d&32)|0;v=(n&8|0)==0|(g|0)==0&(y|0)==0;p=v?0:2;v=v?5642:5642+(d>>4)|0;b=n;n=g;d=y;w=67}else if((w|0)==66){_=hM(n,d,T)|0;b=y;w=67}else if((w|0)==71){w=0;y=vM(d,0,c)|0;g=(y|0)==0;n=d;p=0;v=5642;_=g?d+c|0:y;d=g?c:y-d|0;c=b}else if((w|0)==75){w=0;v=d;n=0;c=0;while(1){p=u[v>>2]|0;if(!p)break;c=bM(R,p)|0;if((c|0)<0|c>>>0>(_-n|0)>>>0)break;n=c+n|0;if(_>>>0>n>>>0)v=v+4|0;else break}if((c|0)<0){l=-1;break e}_M(e,32,s,n,y);if(!n){n=0;w=84}else{p=0;while(1){c=u[d>>2]|0;if(!c){w=84;break n}c=bM(R,c)|0;p=c+p|0;if((p|0)>(n|0)){w=84;break n}sM(e,R,c);if(p>>>0>=n>>>0){w=84;break}else d=d+4|0}}}}while(0);if((w|0)==67){w=0;d=(n|0)!=0|(d|0)!=0;y=(c|0)!=0|d;d=((d^1)&1)+(C-_)|0;n=y?_:T;_=T;d=y?(c|0)>(d|0)?c:d:c;c=(c|0)>-1?b&-65537:b}else if((w|0)==84){w=0;_M(e,32,s,n,y^8192);s=(s|0)>(n|0)?s:n;n=D;continue}g=_-n|0;b=(d|0)<(g|0)?g:d;y=b+p|0;s=(s|0)<(y|0)?y:s;_M(e,32,s,y,c);sM(e,v,p);_M(e,48,s,y,c^65536);_M(e,48,b,g,0);sM(e,n,g);_M(e,32,s,y,c^8192);n=D}e:do{if((w|0)==87)if(!e)if(!m)l=0;else{l=1;while(1){n=u[a+(l<<2)>>2]|0;if(!n)break;cM(o+(l<<3)|0,n,t);l=l+1|0;if((l|0)>=10){l=1;break e}}while(1){if(u[a+(l<<2)>>2]|0){l=-1;break e}l=l+1|0;if((l|0)>=10){l=1;break}}}}while(0);h=N;return l|0}function aM(e){e=e|0;return 0}function lM(e){e=e|0;return}function sM(e,n,t){e=e|0;n=n|0;t=t|0;if(!(u[e>>2]&32))PM(n,t,e)|0;return}function fM(e){e=e|0;var n=0,t=0,i=0;t=u[e>>2]|0;i=(r[t>>0]|0)+-48|0;if(i>>>0<10){n=0;do{n=i+(n*10|0)|0;t=t+1|0;u[e>>2]=t;i=(r[t>>0]|0)+-48|0}while(i>>>0<10)}else n=0;return n|0}function cM(e,n,t){e=e|0;n=n|0;t=t|0;var r=0,i=0,o=0.0;e:do{if(n>>>0<=20)do{switch(n|0){case 9:{r=(u[t>>2]|0)+(4-1)&~(4-1);n=u[r>>2]|0;u[t>>2]=r+4;u[e>>2]=n;break e}case 10:{r=(u[t>>2]|0)+(4-1)&~(4-1);n=u[r>>2]|0;u[t>>2]=r+4;r=e;u[r>>2]=n;u[r+4>>2]=((n|0)<0)<<31>>31;break e}case 11:{r=(u[t>>2]|0)+(4-1)&~(4-1);n=u[r>>2]|0;u[t>>2]=r+4;r=e;u[r>>2]=n;u[r+4>>2]=0;break e}case 12:{r=(u[t>>2]|0)+(8-1)&~(8-1);n=r;i=u[n>>2]|0;n=u[n+4>>2]|0;u[t>>2]=r+8;r=e;u[r>>2]=i;u[r+4>>2]=n;break e}case 13:{i=(u[t>>2]|0)+(4-1)&~(4-1);r=u[i>>2]|0;u[t>>2]=i+4;r=(r&65535)<<16>>16;i=e;u[i>>2]=r;u[i+4>>2]=((r|0)<0)<<31>>31;break e}case 14:{i=(u[t>>2]|0)+(4-1)&~(4-1);r=u[i>>2]|0;u[t>>2]=i+4;i=e;u[i>>2]=r&65535;u[i+4>>2]=0;break e}case 15:{i=(u[t>>2]|0)+(4-1)&~(4-1);r=u[i>>2]|0;u[t>>2]=i+4;r=(r&255)<<24>>24;i=e;u[i>>2]=r;u[i+4>>2]=((r|0)<0)<<31>>31;break e}case 16:{i=(u[t>>2]|0)+(4-1)&~(4-1);r=u[i>>2]|0;u[t>>2]=i+4;i=e;u[i>>2]=r&255;u[i+4>>2]=0;break e}case 17:{i=(u[t>>2]|0)+(8-1)&~(8-1);o=+f[i>>3];u[t>>2]=i+8;f[e>>3]=o;break e}case 18:{i=(u[t>>2]|0)+(8-1)&~(8-1);o=+f[i>>3];u[t>>2]=i+8;f[e>>3]=o;break e}default:break e}}while(0)}while(0);return}function dM(e,n,t,i){e=e|0;n=n|0;t=t|0;i=i|0;if(!((e|0)==0&(n|0)==0))do{t=t+-1|0;r[t>>0]=o[5694+(e&15)>>0]|0|i;e=rS(e|0,n|0,4)|0;n=A}while(!((e|0)==0&(n|0)==0));return t|0}function pM(e,n,t){e=e|0;n=n|0;t=t|0;if(!((e|0)==0&(n|0)==0))do{t=t+-1|0;r[t>>0]=e&7|48;e=rS(e|0,n|0,3)|0;n=A}while(!((e|0)==0&(n|0)==0));return t|0}function hM(e,n,t){e=e|0;n=n|0;t=t|0;var i=0;if(n>>>0>0|(n|0)==0&e>>>0>4294967295){while(1){i=fS(e|0,n|0,10,0)|0;t=t+-1|0;r[t>>0]=i&255|48;i=e;e=aS(e|0,n|0,10,0)|0;if(!(n>>>0>9|(n|0)==9&i>>>0>4294967295))break;else n=A}n=e}else n=e;if(n)while(1){t=t+-1|0;r[t>>0]=(n>>>0)%10|0|48;if(n>>>0<10)break;else n=(n>>>0)/10|0}return t|0}function mM(e){e=e|0;return kM(e,u[(CM()|0)+188>>2]|0)|0}function vM(e,n,t){e=e|0;n=n|0;t=t|0;var i=0,o=0,a=0,l=0;a=n&255;i=(t|0)!=0;e:do{if(i&(e&3|0)!=0){o=n&255;while(1){if((r[e>>0]|0)==o<<24>>24){l=6;break e}e=e+1|0;t=t+-1|0;i=(t|0)!=0;if(!(i&(e&3|0)!=0)){l=5;break}}}else l=5}while(0);if((l|0)==5)if(i)l=6;else t=0;e:do{if((l|0)==6){o=n&255;if((r[e>>0]|0)!=o<<24>>24){i=G(a,16843009)|0;n:do{if(t>>>0>3)while(1){a=u[e>>2]^i;if((a&-2139062144^-2139062144)&a+-16843009|0)break;e=e+4|0;t=t+-4|0;if(t>>>0<=3){l=11;break n}}else l=11}while(0);if((l|0)==11)if(!t){t=0;break}while(1){if((r[e>>0]|0)==o<<24>>24)break e;e=e+1|0;t=t+-1|0;if(!t){t=0;break}}}}}while(0);return(t|0?e:0)|0}function _M(e,n,t,r,i){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;var u=0,o=0;o=h;h=h+256|0;u=o;if((t|0)>(r|0)&(i&73728|0)==0){i=t-r|0;nS(u|0,n|0,(i>>>0<256?i:256)|0)|0;if(i>>>0>255){n=t-r|0;do{sM(e,u,256);i=i+-256|0}while(i>>>0>255);i=n&255}sM(e,u,i)}h=o;return}function bM(e,n){e=e|0;n=n|0;if(!e)e=0;else e=EM(e,n,0)|0;return e|0}function gM(e,n,t,i,a,l){e=e|0;n=+n;t=t|0;i=i|0;a=a|0;l=l|0;var s=0,f=0,c=0,d=0,p=0,m=0,v=0,_=0.0,b=0,g=0,y=0,D=0,w=0,E=0,T=0,C=0,k=0,M=0,S=0,x=0,P=0,R=0,N=0;N=h;h=h+560|0;c=N+8|0;y=N;R=N+524|0;P=R;d=N+512|0;u[y>>2]=0;x=d+12|0;yM(n)|0;if((A|0)<0){n=-n;M=1;k=5659}else{M=(a&2049|0)!=0&1;k=(a&2048|0)==0?(a&1|0)==0?5660:5665:5662}yM(n)|0;S=A&2146435072;do{if(S>>>0<2146435072|(S|0)==2146435072&0<0){_=+DM(n,y)*2.0;s=_!=0.0;if(s)u[y>>2]=(u[y>>2]|0)+-1;w=l|32;if((w|0)==97){b=l&32;v=(b|0)==0?k:k+9|0;m=M|2;s=12-i|0;do{if(!(i>>>0>11|(s|0)==0)){n=8.0;do{s=s+-1|0;n=n*16.0}while((s|0)!=0);if((r[v>>0]|0)==45){n=-(n+(-_-n));break}else{n=_+n-n;break}}else n=_}while(0);f=u[y>>2]|0;s=(f|0)<0?0-f|0:f;s=hM(s,((s|0)<0)<<31>>31,x)|0;if((s|0)==(x|0)){s=d+11|0;r[s>>0]=48}r[s+-1>>0]=(f>>31&2)+43;p=s+-2|0;r[p>>0]=l+15;d=(i|0)<1;c=(a&8|0)==0;s=R;do{S=~~n;f=s+1|0;r[s>>0]=o[5694+S>>0]|b;n=(n-+(S|0))*16.0;if((f-P|0)==1?!(c&(d&n==0.0)):0){r[f>>0]=46;s=s+2|0}else s=f}while(n!=0.0);S=s-P|0;P=x-p|0;x=(i|0)!=0&(S+-2|0)<(i|0)?i+2|0:S;s=P+m+x|0;_M(e,32,t,s,a);sM(e,v,m);_M(e,48,t,s,a^65536);sM(e,R,S);_M(e,48,x-S|0,0,0);sM(e,p,P);_M(e,32,t,s,a^8192);break}f=(i|0)<0?6:i;if(s){s=(u[y>>2]|0)+-28|0;u[y>>2]=s;n=_*268435456.0}else{n=_;s=u[y>>2]|0}S=(s|0)<0?c:c+288|0;c=S;do{T=~~n>>>0;u[c>>2]=T;c=c+4|0;n=(n-+(T>>>0))*1.0e9}while(n!=0.0);if((s|0)>0){d=S;m=c;while(1){p=(s|0)<29?s:29;s=m+-4|0;if(s>>>0>=d>>>0){c=0;do{E=tS(u[s>>2]|0,0,p|0)|0;E=eS(E|0,A|0,c|0,0)|0;T=A;D=fS(E|0,T|0,1e9,0)|0;u[s>>2]=D;c=aS(E|0,T|0,1e9,0)|0;s=s+-4|0}while(s>>>0>=d>>>0);if(c){d=d+-4|0;u[d>>2]=c}}c=m;while(1){if(c>>>0<=d>>>0)break;s=c+-4|0;if(!(u[s>>2]|0))c=s;else break}s=(u[y>>2]|0)-p|0;u[y>>2]=s;if((s|0)>0)m=c;else break}}else d=S;if((s|0)<0){i=((f+25|0)/9|0)+1|0;g=(w|0)==102;do{b=0-s|0;b=(b|0)<9?b:9;if(d>>>0<c>>>0){p=(1<<b)+-1|0;m=1e9>>>b;v=0;s=d;do{T=u[s>>2]|0;u[s>>2]=(T>>>b)+v;v=G(T&p,m)|0;s=s+4|0}while(s>>>0<c>>>0);s=(u[d>>2]|0)==0?d+4|0:d;if(!v){d=s;s=c}else{u[c>>2]=v;d=s;s=c+4|0}}else{d=(u[d>>2]|0)==0?d+4|0:d;s=c}c=g?S:d;c=(s-c>>2|0)>(i|0)?c+(i<<2)|0:s;s=(u[y>>2]|0)+b|0;u[y>>2]=s}while((s|0)<0);s=d;i=c}else{s=d;i=c}T=S;if(s>>>0<i>>>0){c=(T-s>>2)*9|0;p=u[s>>2]|0;if(p>>>0>=10){d=10;do{d=d*10|0;c=c+1|0}while(p>>>0>=d>>>0)}}else c=0;g=(w|0)==103;D=(f|0)!=0;d=f-((w|0)!=102?c:0)+((D&g)<<31>>31)|0;if((d|0)<(((i-T>>2)*9|0)+-9|0)){d=d+9216|0;b=S+4+(((d|0)/9|0)+-1024<<2)|0;d=((d|0)%9|0)+1|0;if((d|0)<9){p=10;do{p=p*10|0;d=d+1|0}while((d|0)!=9)}else p=10;m=u[b>>2]|0;v=(m>>>0)%(p>>>0)|0;d=(b+4|0)==(i|0);if(!(d&(v|0)==0)){_=(((m>>>0)/(p>>>0)|0)&1|0)==0?9007199254740992.0:9007199254740994.0;E=(p|0)/2|0;n=v>>>0<E>>>0?.5:d&(v|0)==(E|0)?1.0:1.5;if(M){E=(r[k>>0]|0)==45;n=E?-n:n;_=E?-_:_}d=m-v|0;u[b>>2]=d;if(_+n!=_){E=d+p|0;u[b>>2]=E;if(E>>>0>999999999){c=b;while(1){d=c+-4|0;u[c>>2]=0;if(d>>>0<s>>>0){s=s+-4|0;u[s>>2]=0}E=(u[d>>2]|0)+1|0;u[d>>2]=E;if(E>>>0>999999999)c=d;else break}}else d=b;c=(T-s>>2)*9|0;m=u[s>>2]|0;if(m>>>0>=10){p=10;do{p=p*10|0;c=c+1|0}while(m>>>0>=p>>>0)}}else d=b}else d=b;d=d+4|0;d=i>>>0>d>>>0?d:i;E=s}else{d=i;E=s}w=d;while(1){if(w>>>0<=E>>>0){y=0;break}s=w+-4|0;if(!(u[s>>2]|0))w=s;else{y=1;break}}i=0-c|0;do{if(g){s=((D^1)&1)+f|0;if((s|0)>(c|0)&(c|0)>-5){p=l+-1|0;f=s+-1-c|0}else{p=l+-2|0;f=s+-1|0}s=a&8;if(!s){if(y?(C=u[w+-4>>2]|0,(C|0)!=0):0){if(!((C>>>0)%10|0)){d=0;s=10;do{s=s*10|0;d=d+1|0}while(!((C>>>0)%(s>>>0)|0|0))}else d=0}else d=9;s=((w-T>>2)*9|0)+-9|0;if((p|32|0)==102){b=s-d|0;b=(b|0)>0?b:0;f=(f|0)<(b|0)?f:b;b=0;break}else{b=s+c-d|0;b=(b|0)>0?b:0;f=(f|0)<(b|0)?f:b;b=0;break}}else b=s}else{p=l;b=a&8}}while(0);g=f|b;m=(g|0)!=0&1;v=(p|32|0)==102;if(v){D=0;s=(c|0)>0?c:0}else{s=(c|0)<0?i:c;s=hM(s,((s|0)<0)<<31>>31,x)|0;d=x;if((d-s|0)<2)do{s=s+-1|0;r[s>>0]=48}while((d-s|0)<2);r[s+-1>>0]=(c>>31&2)+43;s=s+-2|0;r[s>>0]=p;D=s;s=d-s|0}s=M+1+f+m+s|0;_M(e,32,t,s,a);sM(e,k,M);_M(e,48,t,s,a^65536);if(v){p=E>>>0>S>>>0?S:E;b=R+9|0;m=b;v=R+8|0;d=p;do{c=hM(u[d>>2]|0,0,b)|0;if((d|0)==(p|0)){if((c|0)==(b|0)){r[v>>0]=48;c=v}}else if(c>>>0>R>>>0){nS(R|0,48,c-P|0)|0;do{c=c+-1|0}while(c>>>0>R>>>0)}sM(e,c,m-c|0);d=d+4|0}while(d>>>0<=S>>>0);if(g|0)sM(e,5710,1);if(d>>>0<w>>>0&(f|0)>0)while(1){c=hM(u[d>>2]|0,0,b)|0;if(c>>>0>R>>>0){nS(R|0,48,c-P|0)|0;do{c=c+-1|0}while(c>>>0>R>>>0)}sM(e,c,(f|0)<9?f:9);d=d+4|0;c=f+-9|0;if(!(d>>>0<w>>>0&(f|0)>9)){f=c;break}else f=c}_M(e,48,f+9|0,9,0)}else{g=y?w:E+4|0;if((f|0)>-1){y=R+9|0;b=(b|0)==0;i=y;m=0-P|0;v=R+8|0;p=E;do{c=hM(u[p>>2]|0,0,y)|0;if((c|0)==(y|0)){r[v>>0]=48;c=v}do{if((p|0)==(E|0)){d=c+1|0;sM(e,c,1);if(b&(f|0)<1){c=d;break}sM(e,5710,1);c=d}else{if(c>>>0<=R>>>0)break;nS(R|0,48,c+m|0)|0;do{c=c+-1|0}while(c>>>0>R>>>0)}}while(0);P=i-c|0;sM(e,c,(f|0)>(P|0)?P:f);f=f-P|0;p=p+4|0}while(p>>>0<g>>>0&(f|0)>-1)}_M(e,48,f+18|0,18,0);sM(e,D,x-D|0)}_M(e,32,t,s,a^8192)}else{R=(l&32|0)!=0;s=M+3|0;_M(e,32,t,s,a&-65537);sM(e,k,M);sM(e,n!=n|0.0!=0.0?R?5686:5690:R?5678:5682,3);_M(e,32,t,s,a^8192)}}while(0);h=N;return((s|0)<(t|0)?t:s)|0}function yM(e){e=+e;var n=0;f[d>>3]=e;n=u[d>>2]|0;A=u[d+4>>2]|0;return n|0}function DM(e,n){e=+e;n=n|0;return+ +wM(e,n)}function wM(e,n){e=+e;n=n|0;var t=0,r=0,i=0;f[d>>3]=e;t=u[d>>2]|0;r=u[d+4>>2]|0;i=rS(t|0,r|0,52)|0;switch(i&2047){case 0:{if(e!=0.0){e=+wM(e*18446744073709551616.0,n);t=(u[n>>2]|0)+-64|0}else t=0;u[n>>2]=t;break}case 2047:break;default:{u[n>>2]=(i&2047)+-1022;u[d>>2]=t;u[d+4>>2]=r&-2146435073|1071644672;e=+f[d>>3]}}return+e}function EM(e,n,t){e=e|0;n=n|0;t=t|0;do{if(e){if(n>>>0<128){r[e>>0]=n;e=1;break}if(!(u[u[(TM()|0)+188>>2]>>2]|0))if((n&-128|0)==57216){r[e>>0]=n;e=1;break}else{u[(Qk()|0)>>2]=84;e=-1;break}if(n>>>0<2048){r[e>>0]=n>>>6|192;r[e+1>>0]=n&63|128;e=2;break}if(n>>>0<55296|(n&-8192|0)==57344){r[e>>0]=n>>>12|224;r[e+1>>0]=n>>>6&63|128;r[e+2>>0]=n&63|128;e=3;break}if((n+-65536|0)>>>0<1048576){r[e>>0]=n>>>18|240;r[e+1>>0]=n>>>12&63|128;r[e+2>>0]=n>>>6&63|128;r[e+3>>0]=n&63|128;e=4;break}else{u[(Qk()|0)>>2]=84;e=-1;break}}else e=1}while(0);return e|0}function TM(){return eM()|0}function CM(){return eM()|0}function kM(e,n){e=e|0;n=n|0;var t=0,i=0;i=0;while(1){if((o[5712+i>>0]|0)==(e|0)){e=2;break}t=i+1|0;if((t|0)==87){t=5800;i=87;e=5;break}else i=t}if((e|0)==2)if(!i)t=5800;else{t=5800;e=5}if((e|0)==5)while(1){do{e=t;t=t+1|0}while((r[e>>0]|0)!=0);i=i+-1|0;if(!i)break;else e=5}return MM(t,u[n+20>>2]|0)|0}function MM(e,n){e=e|0;n=n|0;return SM(e,n)|0}function SM(e,n){e=e|0;n=n|0;if(!n)n=0;else n=AM(u[n>>2]|0,u[n+4>>2]|0,e)|0;return(n|0?n:e)|0}function AM(e,n,t){e=e|0;n=n|0;t=t|0;var i=0,o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0,h=0;h=(u[e>>2]|0)+1794895138|0;a=xM(u[e+8>>2]|0,h)|0;i=xM(u[e+12>>2]|0,h)|0;o=xM(u[e+16>>2]|0,h)|0;e:do{if((a>>>0<n>>>2>>>0?(p=n-(a<<2)|0,i>>>0<p>>>0&o>>>0<p>>>0):0)?((o|i)&3|0)==0:0){p=i>>>2;d=o>>>2;c=0;while(1){s=a>>>1;f=c+s|0;l=f<<1;o=l+p|0;i=xM(u[e+(o<<2)>>2]|0,h)|0;o=xM(u[e+(o+1<<2)>>2]|0,h)|0;if(!(o>>>0<n>>>0&i>>>0<(n-o|0)>>>0)){i=0;break e}if(r[e+(o+i)>>0]|0){i=0;break e}i=rM(t,e+o|0)|0;if(!i)break;i=(i|0)<0;if((a|0)==1){i=0;break e}else{c=i?c:f;a=i?s:a-s|0}}i=l+d|0;o=xM(u[e+(i<<2)>>2]|0,h)|0;i=xM(u[e+(i+1<<2)>>2]|0,h)|0;if(i>>>0<n>>>0&o>>>0<(n-i|0)>>>0)i=(r[e+(i+o)>>0]|0)==0?e+i|0:0;else i=0}else i=0}while(0);return i|0}function xM(e,n){e=e|0;n=n|0;var t=0;t=cS(e|0)|0;return((n|0)==0?e:t)|0}function PM(e,n,t){e=e|0;n=n|0;t=t|0;var i=0,o=0,a=0,l=0,s=0;i=t+16|0;o=u[i>>2]|0;if(!o){if(!(RM(t)|0)){o=u[i>>2]|0;a=5}else i=0}else a=5;e:do{if((a|0)==5){s=t+20|0;l=u[s>>2]|0;i=l;if((o-l|0)>>>0<n>>>0){i=gA[u[t+36>>2]&7](t,e,n)|0;break}n:do{if((r[t+75>>0]|0)>-1){l=n;while(1){if(!l){a=0;o=e;break n}o=l+-1|0;if((r[e+o>>0]|0)==10)break;else l=o}i=gA[u[t+36>>2]&7](t,e,l)|0;if(i>>>0<l>>>0)break e;a=l;o=e+l|0;n=n-l|0;i=u[s>>2]|0}else{a=0;o=e}}while(0);iS(i|0,o|0,n|0)|0;u[s>>2]=(u[s>>2]|0)+n;i=a+n|0}}while(0);return i|0}function RM(e){e=e|0;var n=0,t=0;n=e+74|0;t=r[n>>0]|0;r[n>>0]=t+255|t;n=u[e>>2]|0;if(!(n&8)){u[e+8>>2]=0;u[e+4>>2]=0;t=u[e+44>>2]|0;u[e+28>>2]=t;u[e+20>>2]=t;u[e+16>>2]=t+(u[e+48>>2]|0);e=0}else{u[e>>2]=n|32;e=-1}return e|0}function NM(e,n){e=$(e);n=$(n);var t=0,r=0;t=FM(e)|0;do{if((t&2147483647)>>>0<=2139095040){r=FM(n)|0;if((r&2147483647)>>>0<=2139095040)if((r^t|0)<0){e=(t|0)<0?n:e;break}else{e=e<n?n:e;break}}else e=n}while(0);return $(e)}function FM(e){e=$(e);return(s[d>>2]=e,u[d>>2]|0)|0}function OM(e,n){e=$(e);n=$(n);var t=0,r=0;t=LM(e)|0;do{if((t&2147483647)>>>0<=2139095040){r=LM(n)|0;if((r&2147483647)>>>0<=2139095040)if((r^t|0)<0){e=(t|0)<0?e:n;break}else{e=e<n?e:n;break}}else e=n}while(0);return $(e)}function LM(e){e=$(e);return(s[d>>2]=e,u[d>>2]|0)|0}function IM(e,n){e=$(e);n=$(n);var t=0,r=0,i=0,o=0,a=0,l=0,f=0,c=0;o=(s[d>>2]=e,u[d>>2]|0);l=(s[d>>2]=n,u[d>>2]|0);t=o>>>23&255;a=l>>>23&255;f=o&-2147483648;i=l<<1;e:do{if((i|0)!=0?!((t|0)==255|((BM(n)|0)&2147483647)>>>0>2139095040):0){r=o<<1;if(r>>>0<=i>>>0){n=$(e*$(0.0));return $((r|0)==(i|0)?n:e)}if(!t){t=o<<9;if((t|0)>-1){r=t;t=0;do{t=t+-1|0;r=r<<1}while((r|0)>-1)}else t=0;r=o<<1-t}else r=o&8388607|8388608;if(!a){o=l<<9;if((o|0)>-1){i=0;do{i=i+-1|0;o=o<<1}while((o|0)>-1)}else i=0;a=i;l=l<<1-i}else l=l&8388607|8388608;i=r-l|0;o=(i|0)>-1;n:do{if((t|0)>(a|0)){while(1){if(o)if(!i)break;else r=i;r=r<<1;t=t+-1|0;i=r-l|0;o=(i|0)>-1;if((t|0)<=(a|0))break n}n=$(e*$(0.0));break e}}while(0);if(o)if(!i){n=$(e*$(0.0));break}else r=i;if(r>>>0<8388608)do{r=r<<1;t=t+-1|0}while(r>>>0<8388608);if((t|0)>0)t=r+-8388608|t<<23;else t=r>>>(1-t|0);n=(u[d>>2]=t|f,$(s[d>>2]))}else c=3}while(0);if((c|0)==3){n=$(e*n);n=$(n/n)}return $(n)}function BM(e){e=$(e);return(s[d>>2]=e,u[d>>2]|0)|0}function UM(e,n){e=e|0;n=n|0;return uM(u[582]|0,e,n)|0}function jM(e){e=e|0;$e()}function WM(e){e=e|0;return}function zM(e,n){e=e|0;n=n|0;return 0}function HM(e){e=e|0;if((GM(e+4|0)|0)==-1){hA[u[(u[e>>2]|0)+8>>2]&127](e);e=1}else e=0;return e|0}function GM(e){e=e|0;var n=0;n=u[e>>2]|0;u[e>>2]=n+-1;return n+-1|0}function YM(e){e=e|0;if(HM(e)|0)qM(e);return}function qM(e){e=e|0;var n=0;n=e+8|0;if(!((u[n>>2]|0)!=0?(GM(n)|0)!=-1:0))hA[u[(u[e>>2]|0)+16>>2]&127](e);return}function VM(e){e=e|0;var n=0;n=(e|0)==0?1:e;while(1){e=Yk(n)|0;if(e|0)break;e=JM()|0;if(!e){e=0;break}RA[e&0]()}return e|0}function $M(e){e=e|0;return VM(e)|0}function XM(e){e=e|0;qk(e);return}function KM(e){e=e|0;if((r[e+11>>0]|0)<0)XM(u[e>>2]|0);return}function JM(){var e=0;e=u[2923]|0;u[2923]=e+0;return e|0}function QM(){}function ZM(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;r=n-r-(t>>>0>e>>>0|0)>>>0;return(A=r,e-t>>>0|0)|0}function eS(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;t=e+t>>>0;return(A=n+r+(t>>>0<e>>>0|0)>>>0,t|0)|0}function nS(e,n,t){e=e|0;n=n|0;t=t|0;var i=0,o=0,a=0,l=0;a=e+t|0;n=n&255;if((t|0)>=67){while(e&3){r[e>>0]=n;e=e+1|0}i=a&-4|0;o=i-64|0;l=n|n<<8|n<<16|n<<24;while((e|0)<=(o|0)){u[e>>2]=l;u[e+4>>2]=l;u[e+8>>2]=l;u[e+12>>2]=l;u[e+16>>2]=l;u[e+20>>2]=l;u[e+24>>2]=l;u[e+28>>2]=l;u[e+32>>2]=l;u[e+36>>2]=l;u[e+40>>2]=l;u[e+44>>2]=l;u[e+48>>2]=l;u[e+52>>2]=l;u[e+56>>2]=l;u[e+60>>2]=l;e=e+64|0}while((e|0)<(i|0)){u[e>>2]=l;e=e+4|0}}while((e|0)<(a|0)){r[e>>0]=n;e=e+1|0}return a-t|0}function tS(e,n,t){e=e|0;n=n|0;t=t|0;if((t|0)<32){A=n<<t|(e&(1<<t)-1<<32-t)>>>32-t;return e<<t}A=e<<t-32;return 0}function rS(e,n,t){e=e|0;n=n|0;t=t|0;if((t|0)<32){A=n>>>t;return e>>>t|(n&(1<<t)-1)<<32-t}A=0;return n>>>t-32|0}function iS(e,n,t){e=e|0;n=n|0;t=t|0;var i=0,o=0,a=0;if((t|0)>=8192)return He(e|0,n|0,t|0)|0;a=e|0;o=e+t|0;if((e&3)==(n&3)){while(e&3){if(!t)return a|0;r[e>>0]=r[n>>0]|0;e=e+1|0;n=n+1|0;t=t-1|0}t=o&-4|0;i=t-64|0;while((e|0)<=(i|0)){u[e>>2]=u[n>>2];u[e+4>>2]=u[n+4>>2];u[e+8>>2]=u[n+8>>2];u[e+12>>2]=u[n+12>>2];u[e+16>>2]=u[n+16>>2];u[e+20>>2]=u[n+20>>2];u[e+24>>2]=u[n+24>>2];u[e+28>>2]=u[n+28>>2];u[e+32>>2]=u[n+32>>2];u[e+36>>2]=u[n+36>>2];u[e+40>>2]=u[n+40>>2];u[e+44>>2]=u[n+44>>2];u[e+48>>2]=u[n+48>>2];u[e+52>>2]=u[n+52>>2];u[e+56>>2]=u[n+56>>2];u[e+60>>2]=u[n+60>>2];e=e+64|0;n=n+64|0}while((e|0)<(t|0)){u[e>>2]=u[n>>2];e=e+4|0;n=n+4|0}}else{t=o-4|0;while((e|0)<(t|0)){r[e>>0]=r[n>>0]|0;r[e+1>>0]=r[n+1>>0]|0;r[e+2>>0]=r[n+2>>0]|0;r[e+3>>0]=r[n+3>>0]|0;e=e+4|0;n=n+4|0}}while((e|0)<(o|0)){r[e>>0]=r[n>>0]|0;e=e+1|0;n=n+1|0}return a|0}function uS(e){e=e|0;var n=0;n=r[v+(e&255)>>0]|0;if((n|0)<8)return n|0;n=r[v+(e>>8&255)>>0]|0;if((n|0)<8)return n+8|0;n=r[v+(e>>16&255)>>0]|0;if((n|0)<8)return n+16|0;return(r[v+(e>>>24)>>0]|0)+24|0}function oS(e,n,t,r,i){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;var o=0,a=0,l=0,s=0,f=0,c=0,d=0,p=0,h=0,m=0;c=e;s=n;f=s;a=t;p=r;l=p;if(!f){o=(i|0)!=0;if(!l){if(o){u[i>>2]=(c>>>0)%(a>>>0);u[i+4>>2]=0}p=0;i=(c>>>0)/(a>>>0)>>>0;return(A=p,i)|0}else{if(!o){p=0;i=0;return(A=p,i)|0}u[i>>2]=e|0;u[i+4>>2]=n&0;p=0;i=0;return(A=p,i)|0}}o=(l|0)==0;do{if(a){if(!o){o=(V(l|0)|0)-(V(f|0)|0)|0;if(o>>>0<=31){d=o+1|0;l=31-o|0;n=o-31>>31;a=d;e=c>>>(d>>>0)&n|f<<l;n=f>>>(d>>>0)&n;o=0;l=c<<l;break}if(!i){p=0;i=0;return(A=p,i)|0}u[i>>2]=e|0;u[i+4>>2]=s|n&0;p=0;i=0;return(A=p,i)|0}o=a-1|0;if(o&a|0){l=(V(a|0)|0)+33-(V(f|0)|0)|0;m=64-l|0;d=32-l|0;s=d>>31;h=l-32|0;n=h>>31;a=l;e=d-1>>31&f>>>(h>>>0)|(f<<d|c>>>(l>>>0))&n;n=n&f>>>(l>>>0);o=c<<m&s;l=(f<<m|c>>>(h>>>0))&s|c<<d&l-33>>31;break}if(i|0){u[i>>2]=o&c;u[i+4>>2]=0}if((a|0)==1){h=s|n&0;m=e|0|0;return(A=h,m)|0}else{m=uS(a|0)|0;h=f>>>(m>>>0)|0;m=f<<32-m|c>>>(m>>>0)|0;return(A=h,m)|0}}else{if(o){if(i|0){u[i>>2]=(f>>>0)%(a>>>0);u[i+4>>2]=0}h=0;m=(f>>>0)/(a>>>0)>>>0;return(A=h,m)|0}if(!c){if(i|0){u[i>>2]=0;u[i+4>>2]=(f>>>0)%(l>>>0)}h=0;m=(f>>>0)/(l>>>0)>>>0;return(A=h,m)|0}o=l-1|0;if(!(o&l)){if(i|0){u[i>>2]=e|0;u[i+4>>2]=o&f|n&0}h=0;m=f>>>((uS(l|0)|0)>>>0);return(A=h,m)|0}o=(V(l|0)|0)-(V(f|0)|0)|0;if(o>>>0<=30){n=o+1|0;l=31-o|0;a=n;e=f<<l|c>>>(n>>>0);n=f>>>(n>>>0);o=0;l=c<<l;break}if(!i){h=0;m=0;return(A=h,m)|0}u[i>>2]=e|0;u[i+4>>2]=s|n&0;h=0;m=0;return(A=h,m)|0}}while(0);if(!a){f=l;s=0;l=0}else{d=t|0|0;c=p|r&0;f=eS(d|0,c|0,-1,-1)|0;t=A;s=l;l=0;do{r=s;s=o>>>31|s<<1;o=l|o<<1;r=e<<1|r>>>31|0;p=e>>>31|n<<1|0;ZM(f|0,t|0,r|0,p|0)|0;m=A;h=m>>31|((m|0)<0?-1:0)<<1;l=h&1;e=ZM(r|0,p|0,h&d|0,(((m|0)<0?-1:0)>>31|((m|0)<0?-1:0)<<1)&c|0)|0;n=A;a=a-1|0}while((a|0)!=0);f=s;s=0}a=0;if(i|0){u[i>>2]=e;u[i+4>>2]=n}h=(o|0)>>>31|(f|a)<<1|(a<<1|o>>>31)&0|s;m=(o<<1|0>>>31)&-2|l;return(A=h,m)|0}function aS(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;return oS(e,n,t,r,0)|0}function lS(e){e=e|0;var n=0,t=0;t=e+15&-16|0;n=u[c>>2]|0;e=n+t|0;if((t|0)>0&(e|0)<(n|0)|(e|0)<0){Z()|0;Ye(12);return-1}u[c>>2]=e;if((e|0)>(Q()|0)?(J()|0)==0:0){u[c>>2]=n;Ye(12);return-1}return n|0}function sS(e,n,t){e=e|0;n=n|0;t=t|0;var i=0;if((n|0)<(e|0)&(e|0)<(n+t|0)){i=e;n=n+t|0;e=e+t|0;while((t|0)>0){e=e-1|0;n=n-1|0;t=t-1|0;r[e>>0]=r[n>>0]|0}e=i}else iS(e,n,t)|0;return e|0}function fS(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;var i=0,o=0;o=h;h=h+16|0;i=o|0;oS(e,n,t,r,i)|0;h=o;return(A=u[i+4>>2]|0,u[i>>2]|0)|0}function cS(e){e=e|0;return(e&255)<<24|(e>>8&255)<<16|(e>>16&255)<<8|e>>>24|0}function dS(e,n,t,r,i,u){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;u=u|0;fA[e&1](n|0,t|0,r|0,i|0,u|0)}function pS(e,n,t){e=e|0;n=n|0;t=$(t);cA[e&1](n|0,$(t))}function hS(e,n,t){e=e|0;n=n|0;t=+t;dA[e&31](n|0,+t)}function mS(e,n,t,r){e=e|0;n=n|0;t=$(t);r=$(r);return $(pA[e&0](n|0,$(t),$(r)))}function vS(e,n){e=e|0;n=n|0;hA[e&127](n|0)}function _S(e,n,t){e=e|0;n=n|0;t=t|0;mA[e&31](n|0,t|0)}function bS(e,n){e=e|0;n=n|0;return vA[e&31](n|0)|0}function gS(e,n,t,r,i){e=e|0;n=n|0;t=+t;r=+r;i=i|0;_A[e&1](n|0,+t,+r,i|0)}function yS(e,n,t,r){e=e|0;n=n|0;t=+t;r=+r;bA[e&1](n|0,+t,+r)}function DS(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;return gA[e&7](n|0,t|0,r|0)|0}function wS(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;return+yA[e&1](n|0,t|0,r|0)}function ES(e,n){e=e|0;n=n|0;return+DA[e&15](n|0)}function TS(e,n,t){e=e|0;n=n|0;t=+t;return wA[e&1](n|0,+t)|0}function CS(e,n,t){e=e|0;n=n|0;t=t|0;return EA[e&15](n|0,t|0)|0}function kS(e,n,t,r,i,u){e=e|0;n=n|0;t=t|0;r=+r;i=+i;u=u|0;TA[e&1](n|0,t|0,+r,+i,u|0)}function MS(e,n,t,r,i,u,o){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;u=u|0;o=o|0;CA[e&1](n|0,t|0,r|0,i|0,u|0,o|0)}function SS(e,n,t){e=e|0;n=n|0;t=t|0;return+kA[e&7](n|0,t|0)}function AS(e){e=e|0;return MA[e&7]()|0}function xS(e,n,t,r,i,u){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;u=u|0;return SA[e&1](n|0,t|0,r|0,i|0,u|0)|0}function PS(e,n,t,r,i){e=e|0;n=n|0;t=t|0;r=r|0;i=+i;AA[e&1](n|0,t|0,r|0,+i)}function RS(e,n,t,r,i,u,o){e=e|0;n=n|0;t=t|0;r=$(r);i=i|0;u=$(u);o=o|0;xA[e&1](n|0,t|0,$(r),i|0,$(u),o|0)}function NS(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;PA[e&15](n|0,t|0,r|0)}function FS(e){e=e|0;RA[e&0]()}function OS(e,n,t,r){e=e|0;n=n|0;t=t|0;r=+r;NA[e&15](n|0,t|0,+r)}function LS(e,n,t){e=e|0;n=+n;t=+t;return FA[e&1](+n,+t)|0}function IS(e,n,t,r,i){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;OA[e&15](n|0,t|0,r|0,i|0)}function BS(e,n,t,r,i){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;X(0)}function US(e,n){e=e|0;n=$(n);X(1)}function jS(e,n){e=e|0;n=+n;X(2)}function WS(e,n,t){e=e|0;n=$(n);t=$(t);X(3);return dn}function zS(e){e=e|0;X(4)}function HS(e,n){e=e|0;n=n|0;X(5)}function GS(e){e=e|0;X(6);return 0}function YS(e,n,t,r){e=e|0;n=+n;t=+t;r=r|0;X(7)}function qS(e,n,t){e=e|0;n=+n;t=+t;X(8)}function VS(e,n,t){e=e|0;n=n|0;t=t|0;X(9);return 0}function $S(e,n,t){e=e|0;n=n|0;t=t|0;X(10);return 0.0}function XS(e){e=e|0;X(11);return 0.0}function KS(e,n){e=e|0;n=+n;X(12);return 0}function JS(e,n){e=e|0;n=n|0;X(13);return 0}function QS(e,n,t,r,i){e=e|0;n=n|0;t=+t;r=+r;i=i|0;X(14)}function ZS(e,n,t,r,i,u){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;u=u|0;X(15)}function eA(e,n){e=e|0;n=n|0;X(16);return 0.0}function nA(){X(17);return 0}function tA(e,n,t,r,i){e=e|0;n=n|0;t=t|0;r=r|0;i=i|0;X(18);return 0}function rA(e,n,t,r){e=e|0;n=n|0;t=t|0;r=+r;X(19)}function iA(e,n,t,r,i,u){e=e|0;n=n|0;t=$(t);r=r|0;i=$(i);u=u|0;X(20)}function uA(e,n,t){e=e|0;n=n|0;t=t|0;X(21)}function oA(){X(22)}function aA(e,n,t){e=e|0;n=n|0;t=+t;X(23)}function lA(e,n){e=+e;n=+n;X(24);return 0}function sA(e,n,t,r){e=e|0;n=n|0;t=t|0;r=r|0;X(25)}var fA=[BS,Ew];var cA=[US,Yi];var dA=[jS,_u,bu,gu,yu,Du,wu,Eu,Cu,ku,Su,Au,xu,Pu,Ru,Nu,Fu,Ou,Lu,jS,jS,jS,jS,jS,jS,jS,jS,jS,jS,jS,jS,jS];var pA=[WS];var hA=[zS,WM,hl,ml,vl,Xd,Kd,Jd,by,gy,yy,uw,ow,aw,ok,ak,lk,Dn,Ki,nu,Tu,Mu,Uo,jo,Xa,Tl,zl,ps,Ns,rf,Mf,qf,dc,Fc,Zc,bd,Id,_p,Lp,nh,yh,Uh,im,km,Gm,av,Sv,zi,f_,A_,J_,bb,Lb,ug,_g,yg,jg,Hg,ay,Ey,ky,qy,pD,Cl,xE,pT,PT,XT,yC,BC,KC,ZC,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS,zS];var mA=[HS,tu,ru,ou,au,lu,su,fu,cu,hu,mu,vu,Zu,to,ro,io,uo,oo,ao,po,_o,Xo,xm,Vm,wb,NE,DD,eT,HS,HS,HS,HS];var vA=[GS,$k,Xi,ju,Gu,Yu,qu,Vu,$u,Xu,Ju,Qu,ho,mo,Wo,Pv,jb,Xy,BE,jE,GS,GS,GS,GS,GS,GS,GS,GS,GS,GS,GS,GS];var _A=[YS,zo];var bA=[qS,fy];var gA=[VS,Xk,Kk,tM,lf,Dp,h_,ZT];var yA=[$S,rd];var DA=[XS,eo,no,lo,Ho,Go,Yo,qo,Vo,$o,XS,XS,XS,XS,XS,XS];var wA=[KS,pg];var EA=[JS,zM,vo,nl,_s,Pf,Kf,Wd,jp,cv,qi,OT,JS,JS,JS,JS];var TA=[QS,ql];var CA=[ZS,TC];var kA=[eA,so,Ko,Jo,Qo,wd,eA,eA];var MA=[nA,Zo,Vi,ji,Cg,Vg,Py,rk];var SA=[tA,Lr];var AA=[rA,Th];var xA=[iA,go];var PA=[uA,Wu,Ku,fo,co,Is,vc,Hh,lm,Gi,Qw,_T,zC,uA,uA,uA];var RA=[oA];var NA=[aA,iu,uu,du,pu,Iu,Bu,Uu,uh,N_,lg,aA,aA,aA,aA,aA];var FA=[lA,my];var OA=[sA,Bc,Uv,nb,Xb,Pg,Zg,By,bD,YE,hk,sA,sA,sA,sA,sA];return{_llvm_bswap_i32:cS,dynCall_idd:LS,dynCall_i:AS,_i64Subtract:ZM,___udivdi3:aS,dynCall_vif:pS,setThrew:_n,dynCall_viii:NS,_bitshift64Lshr:rS,_bitshift64Shl:tS,dynCall_vi:vS,dynCall_viiddi:kS,dynCall_diii:wS,dynCall_iii:CS,_memset:nS,_sbrk:lS,_memcpy:iS,__GLOBAL__sub_I_Yoga_cpp:Ui,dynCall_vii:_S,___uremdi3:fS,dynCall_vid:hS,stackAlloc:pn,_nbind_init:Ak,getTempRet0:gn,dynCall_di:ES,dynCall_iid:TS,setTempRet0:bn,_i64Add:eS,dynCall_fiff:mS,dynCall_iiii:DS,_emscripten_get_global_libc:Vk,dynCall_viid:OS,dynCall_viiid:PS,dynCall_viififi:RS,dynCall_ii:bS,__GLOBAL__sub_I_Binding_cc:DE,dynCall_viiii:IS,dynCall_iiiiii:xS,stackSave:hn,dynCall_viiiii:dS,__GLOBAL__sub_I_nbind_cc:ea,dynCall_vidd:yS,_free:qk,runPostSets:QM,dynCall_viiiiii:MS,establishStackSpace:vn,_memmove:sS,stackRestore:mn,_malloc:Yk,__GLOBAL__sub_I_common_cc:iD,dynCall_viddi:gS,dynCall_dii:SS,dynCall_v:FS}}(Module.asmGlobalArg,Module.asmLibraryArg,buffer),_llvm_bswap_i32=Module._llvm_bswap_i32=asm._llvm_bswap_i32,getTempRet0=Module.getTempRet0=asm.getTempRet0,___udivdi3=Module.___udivdi3=asm.___udivdi3,setThrew=Module.setThrew=asm.setThrew,_bitshift64Lshr=Module._bitshift64Lshr=asm._bitshift64Lshr,_bitshift64Shl=Module._bitshift64Shl=asm._bitshift64Shl,_memset=Module._memset=asm._memset,_sbrk=Module._sbrk=asm._sbrk,_memcpy=Module._memcpy=asm._memcpy,stackAlloc=Module.stackAlloc=asm.stackAlloc,___uremdi3=Module.___uremdi3=asm.___uremdi3,_nbind_init=Module._nbind_init=asm._nbind_init,_i64Subtract=Module._i64Subtract=asm._i64Subtract,setTempRet0=Module.setTempRet0=asm.setTempRet0,_i64Add=Module._i64Add=asm._i64Add,_emscripten_get_global_libc=Module._emscripten_get_global_libc=asm._emscripten_get_global_libc,__GLOBAL__sub_I_Yoga_cpp=Module.__GLOBAL__sub_I_Yoga_cpp=asm.__GLOBAL__sub_I_Yoga_cpp,__GLOBAL__sub_I_Binding_cc=Module.__GLOBAL__sub_I_Binding_cc=asm.__GLOBAL__sub_I_Binding_cc,stackSave=Module.stackSave=asm.stackSave,__GLOBAL__sub_I_nbind_cc=Module.__GLOBAL__sub_I_nbind_cc=asm.__GLOBAL__sub_I_nbind_cc,_free=Module._free=asm._free,runPostSets=Module.runPostSets=asm.runPostSets,establishStackSpace=Module.establishStackSpace=asm.establishStackSpace,_memmove=Module._memmove=asm._memmove,stackRestore=Module.stackRestore=asm.stackRestore,_malloc=Module._malloc=asm._malloc,__GLOBAL__sub_I_common_cc=Module.__GLOBAL__sub_I_common_cc=asm.__GLOBAL__sub_I_common_cc,dynCall_viiiii=Module.dynCall_viiiii=asm.dynCall_viiiii,dynCall_vif=Module.dynCall_vif=asm.dynCall_vif,dynCall_vid=Module.dynCall_vid=asm.dynCall_vid,dynCall_fiff=Module.dynCall_fiff=asm.dynCall_fiff,dynCall_vi=Module.dynCall_vi=asm.dynCall_vi,dynCall_vii=Module.dynCall_vii=asm.dynCall_vii,dynCall_ii=Module.dynCall_ii=asm.dynCall_ii,dynCall_viddi=Module.dynCall_viddi=asm.dynCall_viddi,dynCall_vidd=Module.dynCall_vidd=asm.dynCall_vidd,dynCall_iiii=Module.dynCall_iiii=asm.dynCall_iiii,dynCall_diii=Module.dynCall_diii=asm.dynCall_diii,dynCall_di=Module.dynCall_di=asm.dynCall_di,dynCall_iid=Module.dynCall_iid=asm.dynCall_iid,dynCall_iii=Module.dynCall_iii=asm.dynCall_iii,dynCall_viiddi=Module.dynCall_viiddi=asm.dynCall_viiddi,dynCall_viiiiii=Module.dynCall_viiiiii=asm.dynCall_viiiiii,dynCall_dii=Module.dynCall_dii=asm.dynCall_dii,dynCall_i=Module.dynCall_i=asm.dynCall_i,dynCall_iiiiii=Module.dynCall_iiiiii=asm.dynCall_iiiiii,dynCall_viiid=Module.dynCall_viiid=asm.dynCall_viiid,dynCall_viififi=Module.dynCall_viififi=asm.dynCall_viififi,dynCall_viii=Module.dynCall_viii=asm.dynCall_viii,dynCall_v=Module.dynCall_v=asm.dynCall_v,dynCall_viid=Module.dynCall_viid=asm.dynCall_viid,dynCall_idd=Module.dynCall_idd=asm.dynCall_idd,dynCall_viiii=Module.dynCall_viiii=asm.dynCall_viiii,initialStackTop;function ExitStatus(e){this.name="ExitStatus",this.message="Program terminated with exit("+e+")",this.status=e}Runtime.stackAlloc=Module.stackAlloc,Runtime.stackSave=Module.stackSave,Runtime.stackRestore=Module.stackRestore,Runtime.establishStackSpace=Module.establishStackSpace,Runtime.setTempRet0=Module.setTempRet0,Runtime.getTempRet0=Module.getTempRet0,Module.asm=asm,ExitStatus.prototype=new Error,ExitStatus.prototype.constructor=ExitStatus;var preloadStartTime=null,calledMain=!1;function run(e){function n(){Module.calledRun||(Module.calledRun=!0,ABORT||(ensureInitRuntime(),preMain(),Module.onRuntimeInitialized&&Module.onRuntimeInitialized(),Module._main&&shouldRunNow&&Module.callMain(e),postRun()))}e=e||Module.arguments,null===preloadStartTime&&(preloadStartTime=Date.now()),runDependencies>0||(preRun(),runDependencies>0||Module.calledRun||(Module.setStatus?(Module.setStatus("Running..."),setTimeout((function(){setTimeout((function(){Module.setStatus("")}),1),n()}),1)):n()))}function exit(e,n){n&&Module.noExitRuntime||(Module.noExitRuntime||(ABORT=!0,EXITSTATUS=e,STACKTOP=initialStackTop,exitRuntime(),Module.onExit&&Module.onExit(e)),ENVIRONMENT_IS_NODE&&process.exit(e),Module.quit(e,new ExitStatus(e)))}dependenciesFulfilled=function e(){Module.calledRun||run(),Module.calledRun||(dependenciesFulfilled=e)},Module.callMain=Module.callMain=function(e){e=e||[],ensureInitRuntime();var n=e.length+1;function t(){for(var e=0;e<3;e++)r.push(0)}var r=[allocate(intArrayFromString(Module.thisProgram),"i8",ALLOC_NORMAL)];t();for(var i=0;i<n-1;i+=1)r.push(allocate(intArrayFromString(e[i]),"i8",ALLOC_NORMAL)),t();r.push(0),r=allocate(r,"i32",ALLOC_NORMAL);try{exit(Module._main(n,r,0),!0)}catch(e){if(e instanceof ExitStatus)return;if("SimulateInfiniteLoop"==e)return void(Module.noExitRuntime=!0);var u=e;e&&"object"==typeof e&&e.stack&&(u=[e,e.stack]),Module.printErr("exception thrown: "+u),Module.quit(1,e)}finally{calledMain=!0}},Module.run=Module.run=run,Module.exit=Module.exit=exit;var abortDecorators=[];function abort(e){Module.onAbort&&Module.onAbort(e),void 0!==e?(Module.print(e),Module.printErr(e),e=JSON.stringify(e)):e="",ABORT=!0,EXITSTATUS=1;var n="abort("+e+") at "+stackTrace()+"\nIf this abort() is unexpected, build with -s ASSERTIONS=1 which can give more information.";throw abortDecorators&&abortDecorators.forEach((function(t){n=t(n,e)})),n}if(Module.abort=Module.abort=abort,Module.preInit)for("function"==typeof Module.preInit&&(Module.preInit=[Module.preInit]);Module.preInit.length>0;)Module.preInit.pop()();var shouldRunNow=!0;Module.noInitialRun&&(shouldRunNow=!1),run()},void 0===(__WEBPACK_AMD_DEFINE_RESULT__=function(){return wrapper}.apply(exports,__WEBPACK_AMD_DEFINE_ARRAY__=[]))||(module.exports=__WEBPACK_AMD_DEFINE_RESULT__)},9532:e=>{"use strict";e.exports={ALIGN_COUNT:8,ALIGN_AUTO:0,ALIGN_FLEX_START:1,ALIGN_CENTER:2,ALIGN_FLEX_END:3,ALIGN_STRETCH:4,ALIGN_BASELINE:5,ALIGN_SPACE_BETWEEN:6,ALIGN_SPACE_AROUND:7,DIMENSION_COUNT:2,DIMENSION_WIDTH:0,DIMENSION_HEIGHT:1,DIRECTION_COUNT:3,DIRECTION_INHERIT:0,DIRECTION_LTR:1,DIRECTION_RTL:2,DISPLAY_COUNT:2,DISPLAY_FLEX:0,DISPLAY_NONE:1,EDGE_COUNT:9,EDGE_LEFT:0,EDGE_TOP:1,EDGE_RIGHT:2,EDGE_BOTTOM:3,EDGE_START:4,EDGE_END:5,EDGE_HORIZONTAL:6,EDGE_VERTICAL:7,EDGE_ALL:8,EXPERIMENTAL_FEATURE_COUNT:1,EXPERIMENTAL_FEATURE_WEB_FLEX_BASIS:0,FLEX_DIRECTION_COUNT:4,FLEX_DIRECTION_COLUMN:0,FLEX_DIRECTION_COLUMN_REVERSE:1,FLEX_DIRECTION_ROW:2,FLEX_DIRECTION_ROW_REVERSE:3,JUSTIFY_COUNT:6,JUSTIFY_FLEX_START:0,JUSTIFY_CENTER:1,JUSTIFY_FLEX_END:2,JUSTIFY_SPACE_BETWEEN:3,JUSTIFY_SPACE_AROUND:4,JUSTIFY_SPACE_EVENLY:5,LOG_LEVEL_COUNT:6,LOG_LEVEL_ERROR:0,LOG_LEVEL_WARN:1,LOG_LEVEL_INFO:2,LOG_LEVEL_DEBUG:3,LOG_LEVEL_VERBOSE:4,LOG_LEVEL_FATAL:5,MEASURE_MODE_COUNT:3,MEASURE_MODE_UNDEFINED:0,MEASURE_MODE_EXACTLY:1,MEASURE_MODE_AT_MOST:2,NODE_TYPE_COUNT:2,NODE_TYPE_DEFAULT:0,NODE_TYPE_TEXT:1,OVERFLOW_COUNT:3,OVERFLOW_VISIBLE:0,OVERFLOW_HIDDEN:1,OVERFLOW_SCROLL:2,POSITION_TYPE_COUNT:2,POSITION_TYPE_RELATIVE:0,POSITION_TYPE_ABSOLUTE:1,PRINT_OPTIONS_COUNT:3,PRINT_OPTIONS_LAYOUT:1,PRINT_OPTIONS_STYLE:2,PRINT_OPTIONS_CHILDREN:4,UNIT_COUNT:4,UNIT_UNDEFINED:0,UNIT_POINT:1,UNIT_PERCENT:2,UNIT_AUTO:3,WRAP_COUNT:3,WRAP_NO_WRAP:0,WRAP_WRAP:1,WRAP_WRAP_REVERSE:2}},2821:(e,n,t)=>{"use strict";var r=t(6863),i=t(7356),u=!1,o=null;if(i({},(function(e,n){if(!u){if(u=!0,e)throw e;o=n}})),!u)throw new Error("Failed to load the yoga module - it needed to be loaded synchronously, but didn't");e.exports=r(o.bind,o.lib)},6863:(e,n,t)=>{"use strict";var r=Object.assign||function(e){for(var n=1;n<arguments.length;n++){var t=arguments[n];for(var r in t)Object.prototype.hasOwnProperty.call(t,r)&&(e[r]=t[r])}return e},i=function(){function e(e,n){for(var t=0;t<n.length;t++){var r=n[t];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(n,t,r){return t&&e(n.prototype,t),r&&e(n,r),n}}();function u(e,n,t){return n in e?Object.defineProperty(e,n,{value:t,enumerable:!0,configurable:!0,writable:!0}):e[n]=t,e}function o(e,n){if(!(e instanceof n))throw new TypeError("Cannot call a class as a function")}var a=t(9532),l=function(){function e(n,t,r,i,u,a){o(this,e),this.left=n,this.right=t,this.top=r,this.bottom=i,this.width=u,this.height=a}return i(e,[{key:"fromJS",value:function(e){e(this.left,this.right,this.top,this.bottom,this.width,this.height)}},{key:"toString",value:function(){return"<Layout#"+this.left+":"+this.right+";"+this.top+":"+this.bottom+";"+this.width+":"+this.height+">"}}]),e}(),s=function(){function e(n,t){o(this,e),this.width=n,this.height=t}return i(e,null,[{key:"fromJS",value:function(n){return new e(n.width,n.height)}}]),i(e,[{key:"fromJS",value:function(e){e(this.width,this.height)}},{key:"toString",value:function(){return"<Size#"+this.width+"x"+this.height+">"}}]),e}(),f=function(){function e(n,t){o(this,e),this.unit=n,this.value=t}return i(e,[{key:"fromJS",value:function(e){e(this.unit,this.value)}},{key:"toString",value:function(){switch(this.unit){case a.UNIT_POINT:return String(this.value);case a.UNIT_PERCENT:return this.value+"%";case a.UNIT_AUTO:return"auto";default:return this.value+"?"}}},{key:"valueOf",value:function(){return this.value}}]),e}();e.exports=function(e,n){function t(e,n,t){var r=e[n];e[n]=function(){for(var e=arguments.length,n=Array(e),i=0;i<e;i++)n[i]=arguments[i];return t.call.apply(t,[this,r].concat(n))}}for(var i=["setPosition","setMargin","setFlexBasis","setWidth","setHeight","setMinWidth","setMinHeight","setMaxWidth","setMaxHeight","setPadding"],o=function(){var e,r=i[c],o=(u(e={},a.UNIT_POINT,n.Node.prototype[r]),u(e,a.UNIT_PERCENT,n.Node.prototype[r+"Percent"]),u(e,a.UNIT_AUTO,n.Node.prototype[r+"Auto"]),e);t(n.Node.prototype,r,(function(e){for(var n=arguments.length,t=Array(n>1?n-1:0),i=1;i<n;i++)t[i-1]=arguments[i];var u,l,s=t.pop(),c=void 0,d=void 0;if("auto"===s)c=a.UNIT_AUTO,d=void 0;else if(s instanceof f)c=s.unit,d=s.valueOf();else if(c="string"==typeof s&&s.endsWith("%")?a.UNIT_PERCENT:a.UNIT_POINT,d=parseFloat(s),!Number.isNaN(s)&&Number.isNaN(d))throw new Error("Invalid value "+s+" for "+r);if(!o[c])throw new Error('Failed to execute "'+r+"\": Unsupported unit '"+s+"'");return void 0!==d?(u=o[c]).call.apply(u,[this].concat(t,[d])):(l=o[c]).call.apply(l,[this].concat(t))}))},c=0;c<i.length;c++)o();return t(n.Config.prototype,"free",(function(){n.Config.destroy(this)})),t(n.Node,"create",(function(e,t){return t?n.Node.createWithConfig(t):n.Node.createDefault()})),t(n.Node.prototype,"free",(function(){n.Node.destroy(this)})),t(n.Node.prototype,"freeRecursive",(function(){for(var e=0,n=this.getChildCount();e<n;++e)this.getChild(0).freeRecursive();this.free()})),t(n.Node.prototype,"setMeasureFunc",(function(e,n){return n?e.call(this,(function(){return s.fromJS(n.apply(void 0,arguments))})):this.unsetMeasureFunc()})),t(n.Node.prototype,"calculateLayout",(function(e){var n=arguments.length>1&&void 0!==arguments[1]?arguments[1]:NaN,t=arguments.length>2&&void 0!==arguments[2]?arguments[2]:NaN,r=arguments.length>3&&void 0!==arguments[3]?arguments[3]:a.DIRECTION_LTR;return e.call(this,n,t,r)})),r({Config:n.Config,Node:n.Node,Layout:e("Layout",l),Size:e("Size",s),Value:e("Value",f),getInstanceCount:function(){return n.getInstanceCount.apply(n,arguments)}},a)}},2594:e=>{"use strict";e.exports=require("@yarnpkg/cli")},966:e=>{"use strict";e.exports=require("@yarnpkg/core")},4688:e=>{"use strict";e.exports=require("@yarnpkg/fslib")},9145:e=>{"use strict";e.exports=require("@yarnpkg/parsers")},2357:e=>{"use strict";e.exports=require("assert")},8042:e=>{"use strict";e.exports=require("clipanion")},8614:e=>{"use strict";e.exports=require("events")},2087:e=>{"use strict";e.exports=require("os")},1058:e=>{"use strict";e.exports=require("readline")},9513:e=>{"use strict";e.exports=require("semver")},9440:e=>{"use strict";e.exports=require("yup")}},__webpack_module_cache__={};function __webpack_require__(e){if(__webpack_module_cache__[e])return __webpack_module_cache__[e].exports;var n=__webpack_module_cache__[e]={id:e,loaded:!1,exports:{}};return __webpack_modules__[e].call(n.exports,n,n.exports,__webpack_require__),n.loaded=!0,n.exports}return __webpack_require__.n=e=>{var n=e&&e.__esModule?()=>e.default:()=>e;return __webpack_require__.d(n,{a:n}),n},__webpack_require__.d=(e,n)=>{for(var t in n)__webpack_require__.o(n,t)&&!__webpack_require__.o(e,t)&&Object.defineProperty(e,t,{enumerable:!0,get:n[t]})},__webpack_require__.o=(e,n)=>Object.prototype.hasOwnProperty.call(e,n),__webpack_require__.r=e=>{"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},__webpack_require__.nmd=e=>(e.paths=[],e.children||(e.children=[]),e),__webpack_require__(3354)})();
return plugin;
}
};